@@ -22,7 +22,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "macros.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "display/sp-canvas.h"
 #include "inkscape.h"
 #include "sp-ellipse.h"
@@ -164,15 +164,10 @@ static void shape_event_attr_changed(SPRepr * repr, const gchar * name, const gc
 }
 
 static SPReprEventVector shape_repr_events = {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     shape_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
@@ -305,7 +300,7 @@ static gint sp_arc_context_root_handler(SPEventContext *event_context, GdkEvent
                 /* Snap center to nearest magnetic point */
                 namedview_free_snap(event_context->desktop->namedview, Snapper::SNAP_POINT, ac->center);
                 sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
-                                    GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
+                                    GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
                                     NULL, event->button.time);
                 ret = TRUE;
             }
@@ -435,7 +430,7 @@ static void sp_arc_drag(SPArcContext *ac, NR::Point pt, guint state)
         }
 
         /* Create object */
-        SPRepr *repr = sp_repr_new("path");
+        SPRepr *repr = sp_repr_new("svg:path");
         sp_repr_set_attr(repr, "sodipodi:type", "arc");
 
         /* Set style */
@@ -507,8 +502,8 @@ static void sp_arc_drag(SPArcContext *ac, NR::Point pt, guint state)
 
     sp_arc_position_set(SP_ARC(ac->item), (x0 + x1) / 2, (y0 + y1) / 2, (x1 - x0) / 2, (y1 - y0) / 2);
 
-    GString *xs = SP_PT_TO_METRIC_STRING(fabs(x1-x0), SP_DEFAULT_METRIC);
-    GString *ys = SP_PT_TO_METRIC_STRING(fabs(y1-y0), SP_DEFAULT_METRIC);
+    GString *xs = SP_PX_TO_METRIC_STRING(fabs(x1-x0), sp_desktop_get_default_metric(desktop));
+    GString *ys = SP_PX_TO_METRIC_STRING(fabs(y1-y0), sp_desktop_get_default_metric(desktop));
     ac->_message_context->setF(Inkscape::NORMAL_MESSAGE, _("<b>Ellipse</b>: %s x %s; with <b>Ctrl</b> to make circle or integer-ratio ellipse; with <b>Shift</b> to draw around the starting point"), xs->str, ys->str);
     g_string_free(xs, FALSE);
     g_string_free(ys, FALSE);
