@@ -86,6 +86,7 @@ enum {
 	SP_ATTR_INKSCAPE_GRID_POINTS,
 	SP_ATTR_INKSCAPE_GUIDE_POINTS,
 	SP_ATTR_INKSCAPE_CURRENT_LAYER,
+	SP_ATTR_INKSCAPE_DOCUMENT_UNITS,
 	/* SPGuide */
 	SP_ATTR_ORIENTATION,
 	SP_ATTR_POSITION,
@@ -220,6 +221,7 @@ enum {
 	SP_PROP_TEXT_DECORATION,
 	SP_PROP_UNICODE_BIDI,
 	SP_PROP_WORD_SPACING,
+	SP_PROP_LINE_HEIGHT,
 	/* Misc */
 	SP_PROP_CLIP,
 	SP_PROP_COLOR,
