@@ -23,6 +23,7 @@
 #include "helper/helper-forward.h"
 #include "xml/xml-forward.h"
 #include "forward.h"
+#include "sp-metric.h"
 #include "view.h"
 
 namespace Inkscape { class ObjectHierarchy; }
@@ -91,8 +92,9 @@ struct SPDesktop : public SPView {
 	SPCanvasGroup *sketch;
 	SPCanvasGroup *controls;
 
-	SPCanvasItem *page; // background
-	SPCanvasItem *page_border; // border
+	SPCanvasItem *table; // outside-of-page background
+	SPCanvasItem *page; // page background
+	SPCanvasItem *page_border; // page border
 
 	NR::Matrix d2w, w2d, doc2dt;
 
@@ -219,6 +221,7 @@ void sp_desktop_prev_zoom (SPDesktop *dt);
 void sp_desktop_next_zoom (SPDesktop *dt);
 
 const SPUnit *sp_desktop_get_default_unit (SPDesktop *dt);
+SPMetric sp_desktop_get_default_metric(SPDesktop *dt);
 
 
 #ifdef HAVE_GTK_WINDOW_FULLSCREEN
