@@ -15,7 +15,7 @@
 
 
 #include <config.h>
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 
 #include "dialogs/align.h"
 #include "dialogs/docker.h"
@@ -72,7 +72,7 @@ public :
         _id(id),         
         _parent(parent)
     {
-        Gtk::Image*  pImage = Gtk::manage( new Gtk::Image(PixBufFactory::get().getFromSVG(_id)));
+        Gtk::Image*  pImage = Gtk::manage( new Gtk::Image(PixBufFactory::get().getIcon(_id)));
 	Gtk::Button * pButton = Gtk::manage(new Gtk::Button());
         pButton->set_relief(Gtk::RELIEF_NONE);
 	pImage->show();
@@ -679,7 +679,7 @@ void sp_quick_align_dialog (void)
 #include <gtk/gtkmenuitem.h>
 #include <gtk/gtklabel.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/window.h"
 #include "widgets/button.h"
 #include "widgets/sp-widget.h"
@@ -1391,16 +1391,16 @@ static void sp_align_distribute_v_clicked(GtkWidget *w, gchar const *layout)
 {
     sp_align_distribute_h_or_v_clicked(w, layout, NR::Y);
 }
+#endif
 
 
 /*
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
-#endif
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
