@@ -11,33 +11,19 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <locale>
-#include <sstream>
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
+#include <locale>
+#include <sstream>
+#include <utility>  // pair
+#include <algorithm>  // swap
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-/*
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhseparator.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkoptionmenu.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkframe.h>
-*/
 
 #include "macros.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/unit-menu.h"
 #include "helper/units.h"
 #include "helper/window.h"
@@ -66,6 +52,8 @@
 
 #include "rdf.h"
 
+using std::pair;
+
 static void sp_dtw_activate_desktop(Inkscape::Application *inkscape,
                                     SPDesktop *desktop, GtkWidget *dialog);
 
@@ -95,47 +83,122 @@ static win_data wd;
 static gint x = -1000, y = -1000, w = 0, h = 0;
 static gchar *prefs_path = "dialogs.documentoptions";
 
-struct inkscape_papers_t {
-    gchar const * const name;
-    gdouble const height;
-    gdouble const width;
+struct PaperSize {
+    char const * const name;
+    double const smaller;
+    double const larger;
+    SPUnitId const unit;
 };
 
-static inkscape_papers_t const inkscape_papers[] = {
-    { "A4", 842, 595 },
-    { "US Letter", 792, 612 },
-    { "US Legal", 1008, 612 },
-    { "US Executive", 720, 542 },
-    { "A0", 3368, 2380 },
-    { "A1", 2380, 1684 },
-    { "A2", 1684, 1190 },
-    { "A3", 1190, 842 },
-    { "A5", 595, 421 },
-    { "A6", 421, 297 },
-    { "A7", 297, 210 },
-    { "A8", 210, 148 },
-    { "A9", 148, 105 },
-    { "B0", 4008, 2836 },
-    { "B1", 2836, 2004 },
-    { "B2", 2004, 1418 },
-    { "B3", 1418, 1002 },
-    { "B4", 1002, 709 },
-    { "B5", 709, 501 },
-    { "B6", 501, 355 },
-    { "B7", 355, 250 },
-    { "B8", 250, 178 },
-    { "B9", 178, 125 },
-    { "B10", 125, 89 },
-    { "CSE", 649, 462 },
-    { "Comm10E", 683, 298 },
-    { "DLE", 624, 312 },
-    { "Folio", 935, 595 },
-    { "Ledger", 792, 1224 },
-    { "Tabloid", 1225, 792 },
-    { "Banner 468x60", 60, 468 },
-    { "Icon 16x16", 16, 16 },
-    { "Icon 32x32", 32, 32 },
-    { NULL, 0, 0 },
+static PaperSize const inkscape_papers[] = {
+    /*
+     * N.B. the ISO page sizes in the table below differ from ghostscript's idea of page sizes (by
+     * less than 1pt).  Being off by <1pt should be OK for most purposes, but may cause fuzziness
+     * (antialiasing) problems when printing to 72dpi or 144dpi printers or bitmap files due to
+     * postscript's different coordinate system (y=0 meaning bottom of page in postscript and top
+     * of page in SVG).  I haven't looked into whether this does in fact cause fuzziness, I merely
+     * note the possibility.  Rounding done by extension/internal/ps.cpp (e.g. floor/ceil calls)
+     * will also affect whether fuzziness occurs.
+     *
+     * The remainder of this comment discusses the origin of the numbers used for ISO page sizes in
+     * this table and in ghostscript.
+     *
+     * The versions here, in mm, are the official sizes according to
+     * http://en.wikipedia.org/wiki/Paper_sizes at 2005-01-25.  (The ISO entries in the below table
+     * were produced mechanically from the table on that page.)
+     *
+     * (The rule seems to be that A0, B0, ..., D0. sizes are rounded to the nearest number of mm
+     * from the "theoretical size" (i.e. 1000 * sqrt(2) or pow(2.0, .25) or the like), whereas
+     * going from e.g. A0 to A1 always take the floor of halving -- which by chance coincides
+     * exactly with flooring the "theoretical size" for n != 0 instead of the rounding to nearest
+     * done for n==0.)
+     *
+     * Ghostscript paper sizes are given in gs_statd.ps according to gs(1).  gs_statd.ps always
+     * uses an integer number of pt: sometimes gs_statd.ps rounds to nearest (e.g. a1), sometimes
+     * floors (e.g. a10), sometimes ceils (e.g. a8).
+     *
+     * I'm not sure how ghostscript's gs_statd.ps was calculated: it isn't just rounding the
+     * "theoretical size" of each page to pt (see a0), nor is it rounding the a0 size times an
+     * appropriate power of two (see a1).  Possibly it was prepared manually, with a human applying
+     * inconsistent rounding rules when converting from mm to pt.
+     */
+
+    { "A4", 210, 297, SP_UNIT_MM },
+    { "US Letter", 8.5, 11, SP_UNIT_IN },
+    { "US Legal", 8.5, 14, SP_UNIT_IN },
+    { "US Executive", 7.25, 10.5, SP_UNIT_IN },
+    { "A0", 841, 1189, SP_UNIT_MM },
+    { "A1", 594, 841, SP_UNIT_MM },
+    { "A2", 420, 594, SP_UNIT_MM },
+    { "A3", 297, 420, SP_UNIT_MM },
+    { "A5", 148, 210, SP_UNIT_MM },
+    { "A6", 105, 148, SP_UNIT_MM },
+    { "A7", 74, 105, SP_UNIT_MM },
+    { "A8", 52, 74, SP_UNIT_MM },
+    { "A9", 37, 52, SP_UNIT_MM },
+    { "A10", 26, 37, SP_UNIT_MM },
+    { "B0", 1000, 1414, SP_UNIT_MM },
+    { "B1", 707, 1000, SP_UNIT_MM },
+    { "B2", 500, 707, SP_UNIT_MM },
+    { "B3", 353, 500, SP_UNIT_MM },
+    { "B4", 250, 353, SP_UNIT_MM },
+    { "B5", 176, 250, SP_UNIT_MM },
+    { "B6", 125, 176, SP_UNIT_MM },
+    { "B7", 88, 125, SP_UNIT_MM },
+    { "B8", 62, 88, SP_UNIT_MM },
+    { "B9", 44, 62, SP_UNIT_MM },
+    { "B10", 31, 44, SP_UNIT_MM },
+
+    /* Should we include the JIS B series (used in Japan) ?  (JIS B0 is sometimes called JB0, and
+     * similarly for JB1 etc.)
+     *
+     * Should we exclude B7..B10 and A7..10 to make the list smaller ?
+     *
+     * Should we include any of the ISO C, D and E series (see below) ?
+     */
+
+#if 0 /* Whether to include or exclude these depends on how big we mind our page size menu
+         becoming.  C series is used for envelopes; don't know what D and E series are used for. */
+    { "C0", 917, 1297, SP_UNIT_MM },
+    { "C1", 648, 917, SP_UNIT_MM },
+    { "C2", 458, 648, SP_UNIT_MM },
+    { "C3", 324, 458, SP_UNIT_MM },
+    { "C4", 229, 324, SP_UNIT_MM },
+    { "C5", 162, 229, SP_UNIT_MM },
+    { "C6", 114, 162, SP_UNIT_MM },
+    { "C7", 81, 114, SP_UNIT_MM },
+    { "C8", 57, 81, SP_UNIT_MM },
+    { "C9", 40, 57, SP_UNIT_MM },
+    { "C10", 28, 40, SP_UNIT_MM },
+    { "D1", 545, 771, SP_UNIT_MM },
+    { "D2", 385, 545, SP_UNIT_MM },
+    { "D3", 272, 385, SP_UNIT_MM },
+    { "D4", 192, 272, SP_UNIT_MM },
+    { "D5", 136, 192, SP_UNIT_MM },
+    { "D6", 96, 136, SP_UNIT_MM },
+    { "D7", 68, 96, SP_UNIT_MM },
+    { "E3", 400, 560, SP_UNIT_MM },
+    { "E4", 280, 400, SP_UNIT_MM },
+    { "E5", 200, 280, SP_UNIT_MM },
+    { "E6", 140, 200, SP_UNIT_MM },
+#endif
+
+    { "CSE", 462, 649, SP_UNIT_PT },
+    { "US #10 Envelope", 4.125, 9.5, SP_UNIT_IN }, // TODO: Select landscape by default.
+    /* See http://www.hbp.com/content/PCR_envelopes.cfm for a much larger list of US envelope
+       sizes. */
+    { "DL Envelope", 110, 220, SP_UNIT_MM }, // TODO: Select landscape by default.
+    { "Ledger/Tabloid", 11, 17, SP_UNIT_IN },
+    /* Note that `Folio' (used in QPrinter/KPrinter) is deliberately absent from this list, as it
+       means different sizes to different people: different people may expect the width to be
+       either 8, 8.25 or 8.5 inches, and the height to be either 13 or 13.5 inches, even
+       restricting our interpretation to foolscap folio.  If you wish to introduce a folio-like
+       page size to the list, then please consider using a name more specific than just `Folio' or
+       `Foolscap Folio'. */
+    { "Banner 468x60", 60, 468, SP_UNIT_PX },  // TODO: Select landscape by default.
+    { "Icon 16x16", 16, 16, SP_UNIT_PX },
+    { "Icon 32x32", 32, 32, SP_UNIT_PX },
+    { NULL, 0, 0, SP_UNIT_PX },
 };
 
 static void
@@ -147,15 +210,10 @@ docoptions_event_attr_changed(SPRepr *, gchar const *, gchar const *, gchar cons
 }
 
 static SPReprEventVector docoptions_repr_events = {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     docoptions_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
@@ -187,7 +245,7 @@ sp_dtw_dialog_delete(GtkObject *object, GdkEvent *event, gpointer data)
 static void
 sp_dtw_whatever_toggled(GtkToggleButton *tb, GtkWidget *dialog)
 {
-    if (gtk_object_get_data(GTK_OBJECT(dialog), "update")) {
+    if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
@@ -202,19 +260,23 @@ sp_dtw_whatever_toggled(GtkToggleButton *tb, GtkWidget *dialog)
     SPRepr *repr = SP_OBJECT_REPR(dt->namedview);
     gchar const *key = (gchar const *)gtk_object_get_data(GTK_OBJECT(tb), "key");
 
+    gtk_object_set_data(GTK_OBJECT(dlg), "update", GINT_TO_POINTER(TRUE));
+
     gboolean saved = sp_document_get_undo_sensitive(doc);
     sp_document_set_undo_sensitive(doc, FALSE);
     sp_repr_set_boolean(repr, key, gtk_toggle_button_get_active(tb));
     sp_repr_set_attr (doc->rroot, "sodipodi:modified", "true");
     sp_document_set_undo_sensitive(doc, saved);
     sp_document_done(doc);
+
+    gtk_object_set_data(GTK_OBJECT(dlg), "update", GINT_TO_POINTER(FALSE));
 }
 
 
 static void
 sp_dtw_border_layer_toggled(GtkToggleButton *tb, GtkWidget *dialog)
 {
-    if (gtk_object_get_data(GTK_OBJECT(dialog), "update")) {
+    if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
@@ -245,7 +307,7 @@ sp_dtw_border_layer_toggled(GtkToggleButton *tb, GtkWidget *dialog)
 static void
 sp_dtw_whatever_changed(GtkAdjustment *adjustment, GtkWidget *dialog)
 {
-    if (gtk_object_get_data(GTK_OBJECT(dialog), "update")) {
+    if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
@@ -265,12 +327,16 @@ sp_dtw_whatever_changed(GtkAdjustment *adjustment, GtkWidget *dialog)
     if (us != NULL)
         os << sp_unit_selector_get_unit(us)->abbr;
 
+    gtk_object_set_data(GTK_OBJECT(dlg), "update", GINT_TO_POINTER(TRUE));
+
     gboolean saved = sp_document_get_undo_sensitive(doc);
     sp_document_set_undo_sensitive(doc, FALSE);
     sp_repr_set_attr(repr, key, os.str().c_str());
     sp_repr_set_attr (doc->rroot, "sodipodi:modified", "true");
     sp_document_set_undo_sensitive(doc, saved);
     sp_document_done(doc);
+
+    gtk_object_set_data(GTK_OBJECT(dlg), "update", GINT_TO_POINTER(FALSE));
 }
 
 
@@ -342,7 +408,7 @@ sp_doc_dialog_work_entity_changed ( GtkWidget *widget, gpointer data )
 static void
 sp_doc_dialog_whatever_changed(GtkAdjustment *adjustment, GtkWidget *dialog)
 {
-    if (gtk_object_get_data(GTK_OBJECT(dialog), "update")) {
+    if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
@@ -405,7 +471,7 @@ static void
 sp_dtw_grid_snap_distance_changed(GtkAdjustment *adjustment,
                                   GtkWidget *dialog)
 {
-    if (gtk_object_get_data(GTK_OBJECT(dialog), "update")) {
+    if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
@@ -430,7 +496,7 @@ static void
 sp_dtw_grid_emp_spacing_changed (GtkAdjustment *adjustment,
                                  GtkWidget *dialog)
 {
-    if (gtk_object_get_data(GTK_OBJECT(dialog), "update")) {
+    if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
@@ -454,7 +520,7 @@ static void
 sp_dtw_guides_snap_distance_changed(GtkAdjustment *adjustment,
                                     GtkWidget *dialog)
 {
-    if (gtk_object_get_data(GTK_OBJECT(dialog), "update")) {
+    if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
@@ -475,48 +541,51 @@ sp_dtw_guides_snap_distance_changed(GtkAdjustment *adjustment,
 }
 
 
+static pair<double, double>
+get_paper_size(PaperSize const &paper, bool const landscape, SPUnit const *const dest_unit)
+{
+    double h, w;
+    if (landscape) {
+        w = paper.larger;
+        h = paper.smaller;
+    } else {
+        w = paper.smaller;
+        h = paper.larger;
+    }
+    SPUnit const &src_unit = sp_unit_get_by_id(paper.unit);
+    sp_convert_distance(&w, &src_unit, dest_unit);
+    sp_convert_distance(&h, &src_unit, dest_unit);
+    return pair<double, double>(w, h);
+}
 
 static void
 sp_doc_dialog_paper_selected(GtkWidget *widget, gpointer data)
 {
-    GtkWidget *ww, *hw, *om;
-    gint landscape;
-    double h, w;
-    GtkAdjustment *aw, *ah;
-    SPUnitSelector *us;
-
     if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
-    struct inkscape_papers_t const *paper = (struct inkscape_papers_t const *) data;
+    PaperSize const *const paper = (PaperSize const *) data;
 
-    ww = (GtkWidget *)gtk_object_get_data(GTK_OBJECT(dlg), "widthsb");
-    gtk_widget_set_sensitive(ww, FALSE);
-    hw = (GtkWidget *)gtk_object_get_data(GTK_OBJECT(dlg), "heightsb");
-    gtk_widget_set_sensitive(hw, FALSE);
-
-    om = (GtkWidget *)gtk_object_get_data(GTK_OBJECT(dlg), "orientation");
-    landscape = gtk_option_menu_get_history(GTK_OPTION_MENU(om));
-
-    us = (SPUnitSelector *)gtk_object_get_data(GTK_OBJECT(dlg), "units");
-    SPUnit const *unit = sp_unit_selector_get_unit(us);
-    aw = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dlg), "width");
-    ah = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dlg), "height");
+    GtkWidget *const ww = (GtkWidget *)gtk_object_get_data(GTK_OBJECT(dlg), "widthsb");
+    GtkWidget *const hw = (GtkWidget *)gtk_object_get_data(GTK_OBJECT(dlg), "heightsb");
 
     if (paper) {
-        if (!landscape) {
-            w = paper->width;
-            h = paper->height;
-        } else {
-            w = paper->height;
-            h = paper->width;
-        }
-        SPUnit const * const pt = &sp_unit_get_by_id(SP_UNIT_PT);
-        sp_convert_distance(&w, pt, unit);
-        gtk_adjustment_set_value(aw, w);
-        sp_convert_distance(&h, pt, unit);
-        gtk_adjustment_set_value(ah, h);
+        gtk_widget_set_sensitive(ww, FALSE);
+        gtk_widget_set_sensitive(hw, FALSE);
+
+        GtkWidget *const om = (GtkWidget *)gtk_object_get_data(GTK_OBJECT(dlg), "orientation");
+        bool const landscape = gtk_option_menu_get_history(GTK_OPTION_MENU(om));
+
+        SPUnitSelector *const us = (SPUnitSelector *)gtk_object_get_data(GTK_OBJECT(dlg), "units");
+        SPUnit const *const unit = sp_unit_selector_get_unit(us);
+
+        pair<double, double> const w_h(get_paper_size(*paper, landscape, unit));
+
+        GtkAdjustment *const aw = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dlg), "width");
+        GtkAdjustment *const ah = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dlg), "height");
+        gtk_adjustment_set_value(aw, w_h.first);
+        gtk_adjustment_set_value(ah, w_h.second);
     } else {
         gtk_widget_set_sensitive(ww, TRUE);
         gtk_widget_set_sensitive(hw, TRUE);
@@ -532,33 +601,29 @@ sp_doc_dialog_paper_selected(GtkWidget *widget, gpointer data)
 static void
 sp_doc_dialog_paper_orientation_selected(GtkWidget *widget, gpointer data)
 {
-    gdouble w, h, t;
-    GtkAdjustment *aw, *ah;
-
     if (gtk_object_get_data(GTK_OBJECT(dlg), "update")) {
         return;
     }
 
-    aw = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dlg), "width");
-    ah = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dlg), "height");
+    GtkAdjustment *aw = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dlg), "width");
+    GtkAdjustment *ah = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dlg), "height");
 
-    w = gtk_adjustment_get_value(aw);
-    h = gtk_adjustment_get_value(ah);
+    gdouble w = gtk_adjustment_get_value(aw);
+    gdouble h = gtk_adjustment_get_value(ah);
 
     /* only toggle when we actually swap */
     GtkWidget *om = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(dlg), "orientation");
-    gint landscape = gtk_option_menu_get_history(GTK_OPTION_MENU(om));
+    gint const landscape = gtk_option_menu_get_history(GTK_OPTION_MENU(om));
 
-    if ((w > h && !landscape) ||
-        (w < h &&  landscape)   )
+    if ( landscape
+         ? (w < h)
+         : (w > h) )
     {
-        t = w; w = h; h = t;
+        std::swap(w, h);
     }
 
     gtk_adjustment_set_value(aw, w);
     gtk_adjustment_set_value(ah, h);
-
-    gtk_object_set_data(GTK_OBJECT(dlg), "update", GINT_TO_POINTER(FALSE));
 }
 
 /**
@@ -751,6 +816,32 @@ sp_doc_dialog_license_selected ( GtkWidget *widget, gpointer data )
     sp_document_done ( SP_ACTIVE_DOCUMENT );
 }
 
+static gboolean set_doc_units (SPUnitSelector *,
+                             SPUnit const *old,
+                             SPUnit const *new_units,
+                             GObject *dlg)
+{
+    SPDesktop *dt = SP_ACTIVE_DESKTOP;
+
+    if (!dt) {
+        return FALSE;
+    }
+
+    SPDocument *doc = SP_DT_DOCUMENT(dt);
+
+    SPRepr *repr = SP_OBJECT_REPR(dt->namedview);
+
+    gboolean saved = sp_document_get_undo_sensitive(doc);
+    sp_document_set_undo_sensitive(doc, FALSE);
+    sp_repr_set_attr (repr, "inkscape:document-units", sp_unit_get_abbreviation (new_units));
+    sp_repr_set_attr (doc->rroot, "sodipodi:modified", "true");
+    sp_document_set_undo_sensitive(doc, saved);
+    sp_document_done(doc);
+
+    return TRUE;
+}
+
+
 /*
  * \brief   Creates the desktop properties dialog
  *
@@ -818,6 +909,7 @@ sp_desktop_dialog(void)
 
 
         /* Checkbuttons */
+        // FIXME: gray out snapping when grid is off
         spw_vbox_checkbutton(dlg, v, _("Show grid"), "showgrid", cb);
         spw_vbox_checkbutton(dlg, v, _("Snap bounding boxes to grid"), "inkscape:grid-bbox", cb);
         spw_vbox_checkbutton(dlg, v, _("Snap points to grid"), "inkscape:grid-points", cb);
@@ -836,15 +928,15 @@ sp_desktop_dialog(void)
 
         cb = G_CALLBACK(sp_dtw_whatever_changed);
 
-        GtkWidget *us = sp_unit_selector_new(SP_UNIT_ABSOLUTE);
+        GtkWidget *us = sp_unit_selector_new(SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE);
         int row = 0;
         spw_dropdown(dlg, t, _("Grid units:"), "grid_units", row++, us);
 
         spw_unit_selector(dlg, t, _("Origin X:"), "gridoriginx",
-                          row++, us, cb);
+                          row++, us, cb, true);
 
         spw_unit_selector(dlg, t, _("Origin Y:"), "gridoriginy",
-                          row++, us, cb);
+                          row++, us, cb, true);
 
         spw_unit_selector(dlg, t, _("Spacing X:"), "gridspacingx",
                           row++, us, cb);
@@ -899,6 +991,7 @@ sp_desktop_dialog(void)
         gtk_notebook_append_page(GTK_NOTEBOOK(nb), v, l);
 
         /* Checkbuttons */
+        // FIXME: gray out snapping when guides are off
         cb = G_CALLBACK(sp_dtw_whatever_toggled);
         spw_vbox_checkbutton(dlg, v, _("Show guides"), "showguides", cb);
         spw_vbox_checkbutton(dlg, v, _("Snap bounding boxes to guides"), "inkscape:guide-bbox", cb);
@@ -939,7 +1032,7 @@ sp_desktop_dialog(void)
         gtk_notebook_prepend_page(GTK_NOTEBOOK(nb), t, l);
         gtk_notebook_set_current_page(GTK_NOTEBOOK(nb), 0);
 
-        sp_color_picker_button(dlg, t, _("Background (also for export)"),
+        sp_color_picker_button(dlg, t, _("Background (also for export):"),
                                "pagecolor", _("Background color"),
                                "inkscape:pageopacity", 0);
 
@@ -951,16 +1044,28 @@ sp_desktop_dialog(void)
         spw_checkbutton(dlg, t, _("Border on top of drawing"),
                         "borderlayer", 0, 2, 0, cb);
 
-        sp_color_picker_button(dlg, t, _("Border color"),
+        sp_color_picker_button(dlg, t, _("Border color:"),
                                "bordercolor", _("Canvas border color"),
                                "borderopacity", 4);
 
+        l = gtk_label_new(_("Default units:"));
+        gtk_misc_set_alignment (GTK_MISC (l), 1.0, 0.5);
+        gtk_widget_show(l);
+        gtk_table_attach (GTK_TABLE (t), l, 0, 1, 5, 6,
+                    (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), (GtkAttachOptions)0, 0, 0);
+        GtkWidget *doc_units = sp_unit_selector_new(SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE);
+        gtk_tooltips_set_tip(tooltips, doc_units, _("Units for the tool controls, ruler, and the statusbar"), NULL);
+        g_signal_connect(G_OBJECT(doc_units), "set_unit", G_CALLBACK(set_doc_units), NULL);
+        gtk_object_set_data (GTK_OBJECT (dlg), "doc_units", doc_units);
+        gtk_widget_show(doc_units);
+        gtk_table_attach (GTK_TABLE (t), doc_units, 1, 2, 5, 6,
+                    (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), (GtkAttachOptions)0, 0, 0);
 
         // The following comes from the former "document settings" dialog
 
         GtkWidget *vb = gtk_vbox_new(FALSE, 4);
         gtk_widget_show(vb);
-        gtk_table_attach(GTK_TABLE(t), vb, 0, 2, 5, 6,
+        gtk_table_attach(GTK_TABLE(t), vb, 0, 2, 6, 7,
                          (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ),
                          (GtkAttachOptions)0, 0, 0);
 
@@ -981,8 +1086,8 @@ sp_desktop_dialog(void)
         gtk_widget_show(m);
 
         GtkWidget *i;
-        for (struct inkscape_papers_t const *paper = inkscape_papers;
-             paper && paper->name;
+        for (PaperSize const *paper = inkscape_papers;
+             paper->name;
              paper++) {
             i = gtk_menu_item_new_with_label(paper->name);
             gtk_widget_show(i);
@@ -1041,7 +1146,7 @@ sp_desktop_dialog(void)
         gtk_table_set_col_spacings(GTK_TABLE(tt), 4);
         gtk_container_add(GTK_CONTAINER(f), tt);
 
-        us = sp_unit_selector_new(SP_UNIT_ABSOLUTE);
+        us = sp_unit_selector_new(SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE);
         spw_dropdown(dlg, tt, _("Units:"), "units", 0, us);
 
         l = gtk_label_new(_("Width:"));
@@ -1212,6 +1317,33 @@ sp_dtw_deactivate_desktop(Inkscape::Application *inkscape,
     sp_dtw_update(dialog, NULL);
 }
 
+/** Returns an index into inkscape_papers of a paper of the specified size (specified in px),
+    or -1 if there's no such paper.
+**/
+static int
+find_paper_size(double const w_px, double const h_px)
+{
+    double given[2];
+    if ( w_px < h_px ) {
+        given[0] = w_px; given[1] = h_px;
+    } else {
+        given[0] = h_px; given[1] = w_px;
+    }
+    g_return_val_if_fail(given[0] <= given[1], -1);
+    for (unsigned i = 0; i < G_N_ELEMENTS(inkscape_papers) - 1; ++i) {
+        SPUnit const &i_unit = sp_unit_get_by_id(inkscape_papers[i].unit);
+        double const i_sizes[2] = { sp_units_get_pixels(inkscape_papers[i].smaller, i_unit),
+                                    sp_units_get_pixels(inkscape_papers[i].larger, i_unit) };
+        g_return_val_if_fail(i_sizes[0] <= i_sizes[1], -1);
+        if ((fabs(given[0] - i_sizes[0]) <= .1) &&
+            (fabs(given[1] - i_sizes[1]) <= .1)   )
+        {
+            return (int) i;
+        }
+    }
+    return -1;
+}
+
 static void
 sp_dtw_update(GtkWidget *dialog, SPDesktop *desktop)
 {
@@ -1240,7 +1372,7 @@ sp_dtw_update(GtkWidget *dialog, SPDesktop *desktop)
     } else {
         SPNamedView *nv = desktop->namedview;
 
-        gtk_object_set_data(GTK_OBJECT(dialog), "update", GINT_TO_POINTER(TRUE));
+        gtk_object_set_data(GTK_OBJECT(dlg), "update", GINT_TO_POINTER(TRUE));
         gtk_widget_set_sensitive(dialog, TRUE);
 
         GtkObject *o = (GtkObject *)gtk_object_get_data(GTK_OBJECT(dialog), "showgrid");
@@ -1254,21 +1386,20 @@ sp_dtw_update(GtkWidget *dialog, SPDesktop *desktop)
         o = (GtkObject *)gtk_object_get_data(GTK_OBJECT(dialog), "grid_units");
         sp_unit_selector_set_unit(SP_UNIT_SELECTOR(o), nv->gridunit);
 
-        SPUnit const * const pt = &sp_unit_get_by_id(SP_UNIT_PT);
         gdouble val = nv->gridorigin[NR::X];
-        sp_convert_distance(&val, pt, nv->gridunit);
+        val = sp_pixels_get_units (val, *(nv->gridunit));
         o = (GtkObject *)gtk_object_get_data(GTK_OBJECT(dialog), "gridoriginx");
         gtk_adjustment_set_value(GTK_ADJUSTMENT(o), val);
         val = nv->gridorigin[NR::Y];
-        sp_convert_distance(&val, pt, nv->gridunit);
+        val = sp_pixels_get_units (val, *(nv->gridunit));
         o = (GtkObject *)gtk_object_get_data(GTK_OBJECT(dialog), "gridoriginy");
         gtk_adjustment_set_value(GTK_ADJUSTMENT(o), val);
         val = nv->gridspacing[NR::X];
-        sp_convert_distance(&val, pt, nv->gridunit);
+        val = sp_pixels_get_units (val, *(nv->gridunit));
         o = (GtkObject *)gtk_object_get_data(GTK_OBJECT(dialog), "gridspacingx");
         gtk_adjustment_set_value(GTK_ADJUSTMENT(o), val);
         val = nv->gridspacing[NR::Y];
-        sp_convert_distance(&val, pt, nv->gridunit);
+        val = sp_pixels_get_units (val, *(nv->gridunit));
         o = (GtkObject *)gtk_object_get_data(GTK_OBJECT(dialog), "gridspacingy");
         gtk_adjustment_set_value(GTK_ADJUSTMENT(o), val);
 
@@ -1343,14 +1474,14 @@ sp_dtw_update(GtkWidget *dialog, SPDesktop *desktop)
             gtk_widget_set_sensitive(GTK_WIDGET(w), TRUE);
         }
 
+        o = (GtkObject *)gtk_object_get_data(GTK_OBJECT(dialog), "doc_units");
+        if (nv->doc_units) 
+            sp_unit_selector_set_unit (SP_UNIT_SELECTOR(o), nv->doc_units);
+
         // Start of former "document settings" stuff
 
-        gtk_object_set_data(GTK_OBJECT(dialog), "update", GINT_TO_POINTER(TRUE));
-        gtk_widget_set_sensitive(dialog, TRUE);
-
-        gdouble docw = sp_document_width(SP_DT_DOCUMENT(desktop));
-        gdouble doch = sp_document_height(SP_DT_DOCUMENT(desktop));
-
+        gdouble const doc_w_px = sp_document_width(SP_DT_DOCUMENT(desktop));
+        gdouble const doc_h_px = sp_document_height(SP_DT_DOCUMENT(desktop));
 
         GtkWidget *ww = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(dialog), "widthsb");
         GtkWidget *hw = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(dialog), "heightsb");
@@ -1358,55 +1489,26 @@ sp_dtw_update(GtkWidget *dialog, SPDesktop *desktop)
         GtkWidget *om = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(dialog), "orientation");
 
         /* select paper orientation */
-        gdouble ph, pw;
-        if (docw > doch) {
-            /* wider than tall: landscape */
-            gtk_option_menu_set_history(GTK_OPTION_MENU(om), 1);
-            ph = docw;
-            pw = doch;
-        }
-        else {
-            /* taller than wide: portrait */
-            gtk_option_menu_set_history(GTK_OPTION_MENU(om), 0);
-            ph = doch;
-            pw = docw;
-        }
-        //printf("have ph: %f pw: %f\n",ph,pw);
+        gint const landscape = ( doc_w_px > doc_h_px );
+        gtk_option_menu_set_history(GTK_OPTION_MENU(om), landscape);
 
         /* find matching paper size */
-        gint pos;
-        struct inkscape_papers_t const *paper;
-        for (paper = inkscape_papers, pos=1;
-             paper && paper->name;
-             paper++, pos++) {
-            //printf("checking %s (%fx%f)\n",paper->name,paper->height,paper->width);
-            if (paper->width == pw
-                && paper->height == ph)
-            {
-                //printf("matched\n");
-                break;
-            }
-        }
-        if (paper && paper->name) {
-            //printf("using pos %d (%s)\n",pos,paper->name);
-            gtk_option_menu_set_history(GTK_OPTION_MENU(pm), pos);
-            gtk_widget_set_sensitive(ww, FALSE);
-            gtk_widget_set_sensitive(hw, FALSE);
-        } else {
-            //printf("using custom\n");
-            gtk_option_menu_set_history(GTK_OPTION_MENU(pm), 0);
-            gtk_widget_set_sensitive(ww, TRUE);
-            gtk_widget_set_sensitive(hw, TRUE);
-        }
+        gint const pos = 1 + find_paper_size(doc_w_px, doc_h_px);
+        gtk_option_menu_set_history(GTK_OPTION_MENU(pm), pos);
+        gtk_widget_set_sensitive(ww, !pos);
+        gtk_widget_set_sensitive(hw, !pos);
 
-        SPUnitSelector *us = (SPUnitSelector *)gtk_object_get_data(GTK_OBJECT(dialog), "units");
-        SPUnit const *unit = sp_unit_selector_get_unit(us);
-        GtkAdjustment *a = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dialog), "width");
-        sp_convert_distance(&docw, pt, unit);
-        gtk_adjustment_set_value(a, docw);
-        a = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dialog), "height");
-        sp_convert_distance(&doch, pt, unit);
-        gtk_adjustment_set_value(a, doch);
+        /* Show document width/height in the requested units. */
+        {
+            SPUnitSelector const *us = (SPUnitSelector *)gtk_object_get_data(GTK_OBJECT(dialog), "units");
+            SPUnit const *unit = sp_unit_selector_get_unit(us);
+            gdouble const doc_w_u = sp_pixels_get_units(doc_w_px, *unit);
+            gdouble const doc_h_u = sp_pixels_get_units(doc_h_px, *unit);
+            GtkAdjustment *w_adj = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dialog), "width");
+            GtkAdjustment *h_adj = (GtkAdjustment *)gtk_object_get_data(GTK_OBJECT(dialog), "height");
+            gtk_adjustment_set_value(w_adj, doc_w_u);
+            gtk_adjustment_set_value(h_adj, doc_h_u);
+        }
 
         // end of "document settings" stuff
 
@@ -1440,7 +1542,7 @@ sp_dtw_update(GtkWidget *dialog, SPDesktop *desktop)
                                        license ? FALSE : TRUE ); 
         sp_doc_dialog_update_work_entity( entity );
 
-        gtk_object_set_data(GTK_OBJECT(dialog), "update", GINT_TO_POINTER(FALSE));
+        gtk_object_set_data(GTK_OBJECT(dlg), "update", GINT_TO_POINTER(FALSE));
     }
 }
 
@@ -1562,7 +1664,7 @@ sp_color_picker_window_destroy(GtkObject *object, GObject *cp)
 static void
 sp_color_picker_color_mod(SPColorSelector *csel, GObject *cp)
 {
-    if (g_object_get_data(G_OBJECT(cp), "update")) {
+    if (g_object_get_data(G_OBJECT(dlg), "update")) {
         return;
     }
 
@@ -1679,4 +1781,4 @@ sp_color_picker_clicked(GObject *cp, void *data)
   fill-column:99
   End:
 */
-// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
