@@ -16,7 +16,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/window.h"
 #include "../inkscape.h"
 #include "../prefs-utils.h"
@@ -33,7 +33,8 @@
 #include "../selection-chemistry.h"
 #include "../style.h"
 #include "../desktop.h"
-#include "xml/repr-private.h"
+#include "../unit-constants.h"
+#include "xml/repr.h"
 
 #include "display-settings.h"
 
@@ -1009,8 +1010,8 @@ sp_display_dialog (void)
 
         options_sb (
             _("Arrow keys move by:"), 
-            _("Pressing an arrow key moves selected object(s) or node(s) by this distance (in points)"), tt,
-            _("pt"),
+            _("Pressing an arrow key moves selected object(s) or node(s) by this distance (in SVG pixels)"), tt,
+            _("px"),
             vb,
             0.0, 3000.0, 0.01, 1.0, 1.0,
             "options.nudgedistance", "value", 2.0,
@@ -1020,8 +1021,8 @@ sp_display_dialog (void)
 
         options_sb (
             _("> and < scale by:"), 
-            _("Pressing > or < scales selection up or down by this increment (in points)"), tt,
-            _("pt"),
+            _("Pressing > or < scales selection up or down by this increment (in SVG pixels)"), tt,
+            _("px"),
             vb,
             0.0, 3000.0, 0.01, 1.0, 1.0,
             "options.defaultscale", "value", 2.0,
@@ -1031,8 +1032,8 @@ sp_display_dialog (void)
 
         options_sb (
             _("Inset/Outset by:"), 
-            _("Inset and Outset commands displace the path by this distance (in points)"), tt,
-            _("pt"),
+            _("Inset and Outset commands displace the path by this distance (in SVG pixels)"), tt,
+            _("px"),
             vb,
             0.0, 3000.0, 0.01, 1.0, 1.0,
             "options.defaultoffsetwidth", "value", 2.0,
@@ -1396,12 +1397,12 @@ options_checkbox (
             _("dpi"),
             vb,
             0.0, 6000.0, 1.0, 1.0, 1.0,
-            "dialogs.export.defaultxdpi", "value", 72.0,
+            "dialogs.export.defaultxdpi", "value", PX_PER_IN,
             true, false,
             options_changed_int
             );
 
-options_checkbox (
+        options_checkbox (
     /* TRANSLATORS: When on, an imported bitmap creates an <image> element; otherwise it is a
      * rectangle with bitmap fill. */
     _("Import bitmap as <image>"), 
@@ -1409,6 +1410,17 @@ options_checkbox (
     vb,
     "options.importbitmapsasimages", "value", 1,
     options_changed_boolean
+    );
+
+        options_checkbox (
+    /* TRANSLATORS: When on, the print out (currently Postscript) will have
+     * a comment with the each object's label visible, marking the section
+     * of the printing commands that represent the given object. */
+    _("Add label comments to printing output"), 
+    _("When on, a comment will be added to the raw print output, marking the rendered output for an object with its label"), tt,
+    vb,
+    "printing.debug", "show-label-comments", 0,
+    options_changed_boolean
     );
 
         options_sb (
