@@ -23,9 +23,10 @@
 #include <gtk/gtk.h>
 
 #include "xml/repr.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/unit-menu.h"
 #include "helper/units.h"
+#include "unit-constants.h"
 #include "helper/window.h"
 #include "widgets/spw-utilities.h"
 #include "inkscape.h"
@@ -49,11 +50,13 @@
 #include "extension/output.h"
 #include "extension/db.h"
 
+#include "io/sys.h"
+
 #include "export.h"
 
 #define SP_EXPORT_MIN_SIZE 1.0
 
-
+#define DPI_BASE PX_PER_IN
 
 static void sp_export_area_toggled   ( GtkToggleButton *tb, GtkObject *base );
 static void sp_export_export_clicked ( GtkButton *button, GtkObject *base );
@@ -91,10 +94,10 @@ static void sp_export_set_area      ( GtkObject *base, float x0, float y0,
                                       float x1, float y1 );
 static void sp_export_value_set     ( GtkObject *base, const gchar *key, 
                                       float val );
-static void sp_export_value_set_pt  ( GtkObject *base, const gchar *key, 
+static void sp_export_value_set_px  ( GtkObject *base, const gchar *key, 
                                       float val );
 static float sp_export_value_get    ( GtkObject *base, const gchar *key );
-static float sp_export_value_get_pt ( GtkObject *base, const gchar *key );
+static float sp_export_value_get_px ( GtkObject *base, const gchar *key );
 
 static void sp_export_filename_modified (GtkObject * object, gpointer data);
 static inline void sp_export_find_default_selection(GtkWidget * dlg);
@@ -256,7 +259,10 @@ sp_export_dialog_area_frame (GtkWidget * dlg)
     /* gets added to the vbox later, but the unit selector is needed
        earlier than that */
 
-    us = sp_unit_selector_new (SP_UNIT_ABSOLUTE);
+    us = sp_unit_selector_new (SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE);
+    SPDesktop *desktop = SP_ACTIVE_DESKTOP;
+    if (desktop)
+        sp_unit_selector_set_unit (SP_UNIT_SELECTOR(us), sp_desktop_get_default_unit (desktop));
     gtk_box_pack_end (GTK_BOX (unitbox), us, FALSE, FALSE, 0);
     l = gtk_label_new (_("Units:"));
     gtk_box_pack_end (GTK_BOX (unitbox), l, FALSE, FALSE, 3);
@@ -413,7 +419,7 @@ sp_export_dialog (void)
         sp_export_spinbutton_new ( "xdpi", 
                                    prefs_get_double_attribute 
                                        ( "dialogs.export.defaultxdpi", 
-                                         "value", 72.0), 
+                                         "value", DPI_BASE), 
                                    1.0, 9600.0, 0.1, 1.0, NULL, t, 3, 0,
                                    NULL, _("dpi"), 2, 1,
                                    G_CALLBACK (sp_export_xdpi_value_changed), 
@@ -429,7 +435,7 @@ sp_export_dialog (void)
          */
         sp_export_spinbutton_new ( "ydpi", prefs_get_double_attribute 
                                                ( "dialogs.export.defaultxdpi", 
-                                                 "value", 72.0), 
+                                                 "value", DPI_BASE), 
                                    1.0, 9600.0, 0.1, 1.0, NULL, t, 3, 1,
                                    NULL, _("dpi"), 2, 0, NULL, dlg );
 
@@ -654,6 +660,9 @@ sp_export_selection_modified ( Inkscape::Application *inkscape,
 static void
 sp_export_area_toggled (GtkToggleButton *tb, GtkObject *base)
 {
+    if (gtk_object_get_data (base, "update"))
+        return;
+
     selection_type key, old_key;
     key = (selection_type)((int)gtk_object_get_data (GTK_OBJECT (tb), "key"));
     old_key = (selection_type)((int)gtk_object_get_data(GTK_OBJECT(base), "selection-type"));
@@ -679,6 +688,64 @@ sp_export_area_toggled (GtkToggleButton *tb, GtkObject *base)
               FALSE );
     }
 
+    if ( SP_ACTIVE_DESKTOP )
+    {
+        SPDocument *doc;
+        NRRect bbox;
+        doc = SP_DT_DOCUMENT (SP_ACTIVE_DESKTOP);
+        
+        /* Notice how the switch is used to 'fall through' here to get
+           various backups.  If you modify this without noticing you'll
+           probabaly screw something up. */
+        switch (key) {
+            case SELECTION_SELECTION:
+                if ((SP_DT_SELECTION(SP_ACTIVE_DESKTOP))->isEmpty() == false)
+                {
+                    (SP_DT_SELECTION (SP_ACTIVE_DESKTOP))->bounds(&bbox);
+                    /* Only if there is a selection that we can set
+                       do we break, otherwise we fall through to the
+                       drawing */
+                    // std::cout << "Using selection: SELECTION" << std::endl;
+                    key = SELECTION_SELECTION;
+                    break;
+                }
+            case SELECTION_DRAWING:
+                /* 
+                 * TODO: this returns wrong values if the document has a 
+                 * viewBox
+                 */
+                sp_item_bbox_desktop (SP_ITEM (SP_DOCUMENT_ROOT (doc)), &bbox);
+                
+                /* If the drawing is valid, then we'll use it and break
+                   otherwise we drop through to the page settings */
+                if (!(bbox.x0 > bbox.x1 && bbox.y0 > bbox.y1)) { 
+                    // std::cout << "Using selection: DRAWING" << std::endl;
+                    key = SELECTION_DRAWING;
+                    break;
+                }
+            case SELECTION_PAGE:
+                bbox.x0 = 0.0;
+                bbox.y0 = 0.0;
+                bbox.x1 = sp_document_width (doc);
+                bbox.y1 = sp_document_height (doc);
+                // std::cout << "Using selection: PAGE" << std::endl;
+                key = SELECTION_PAGE;
+                break;
+            case SELECTION_CUSTOM:
+            default:
+                break;
+        } // switch
+        
+        // remember area setting
+        prefs_set_string_attribute ( "dialogs.export.exportarea", 
+                                     "value", selection_names[key]);
+
+        if (key != SELECTION_CUSTOM)
+            sp_export_set_area (base, bbox.x0, bbox.y0, bbox.x1, bbox.y1);
+    
+    } // end of if ( SP_ACTIVE_DESKTOP )
+
+
     if (SP_ACTIVE_DESKTOP && !gtk_object_get_data(GTK_OBJECT(base), "filename-modified")) {
         GtkWidget * file_entry;
         const gchar * filename = NULL;
@@ -824,67 +891,7 @@ sp_export_area_toggled (GtkToggleButton *tb, GtkObject *base)
             sp_export_value_set(base, "ydpi", ydpi);
         }
     }
-
-    if (gtk_object_get_data (base, "update"))
-        return;
-
-    if ( SP_ACTIVE_DESKTOP )
-    {
-        SPDocument *doc;
-        NRRect bbox;
-        doc = SP_DT_DOCUMENT (SP_ACTIVE_DESKTOP);
-        
-        /* Notice how the switch is used to 'fall through' here to get
-           various backups.  If you modify this without noticing you'll
-           probabaly screw something up. */
-        switch (key) {
-            case SELECTION_SELECTION:
-                if ((SP_DT_SELECTION(SP_ACTIVE_DESKTOP))->isEmpty() == false)
-                {
-                    (SP_DT_SELECTION (SP_ACTIVE_DESKTOP))->bounds(&bbox);
-                    /* Only if there is a selection that we can set
-                       do we break, otherwise we fall through to the
-                       drawing */
-                    // std::cout << "Using selection: SELECTION" << std::endl;
-                    key = SELECTION_SELECTION;
-                    break;
-                }
-            case SELECTION_DRAWING:
-                /* 
-                 * TODO: this returns wrong values if the document has a 
-                 * viewBox
-                 */
-                sp_item_bbox_desktop (SP_ITEM (SP_DOCUMENT_ROOT (doc)), &bbox);
-                
-                /* If the drawing is valid, then we'll use it and break
-                   otherwise we drop through to the page settings */
-                if (!(bbox.x0 > bbox.x1 && bbox.y0 > bbox.y1)) { 
-                    // std::cout << "Using selection: DRAWING" << std::endl;
-                    key = SELECTION_DRAWING;
-                    break;
-                }
-            case SELECTION_PAGE:
-                bbox.x0 = 0.0;
-                bbox.y0 = 0.0;
-                bbox.x1 = sp_document_width (doc);
-                bbox.y1 = sp_document_height (doc);
-                // std::cout << "Using selection: PAGE" << std::endl;
-                key = SELECTION_PAGE;
-                break;
-            case SELECTION_CUSTOM:
-            default:
-                break;
-        } // switch
-        
-        // remember area setting
-        prefs_set_string_attribute ( "dialogs.export.exportarea", 
-                                     "value", selection_names[key]);
-
-        if (key != SELECTION_CUSTOM)
-            sp_export_set_area (base, bbox.x0, bbox.y0, bbox.x1, bbox.y1);
-    
-    } // end of if ( SP_ACTIVE_DESKTOP )
-    
+   
     return;
 } // end of sp_export_area_toggled()
 
@@ -942,10 +949,10 @@ sp_export_export_clicked (GtkButton *button, GtkObject *base)
     fe = (GtkWidget *)gtk_object_get_data (base, "filename");
     filename = gtk_entry_get_text (GTK_ENTRY (fe));
 
-    x0 = sp_export_value_get_pt (base, "x0");
-    y0 = sp_export_value_get_pt (base, "y0");
-    x1 = sp_export_value_get_pt (base, "x1");
-    y1 = sp_export_value_get_pt (base, "y1");
+    x0 = sp_export_value_get_px (base, "x0");
+    y0 = sp_export_value_get_px (base, "y0");
+    x1 = sp_export_value_get_px (base, "x1");
+    y1 = sp_export_value_get_px (base, "y1");
     xdpi = sp_export_value_get (base, "xdpi");
     ydpi = sp_export_value_get (base, "ydpi");
     width = (int) (sp_export_value_get (base, "bmwidth") + 0.5);
@@ -962,10 +969,12 @@ sp_export_export_clicked (GtkButton *button, GtkObject *base)
     }
 
     gchar * dirname = g_dirname(filename);
-    if (dirname == NULL || !g_file_test(dirname, (GFileTest)(G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))) {
+    if (dirname == NULL || !Inkscape::IO::file_test(dirname, (GFileTest)(G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))) {
         gchar * error;
-        error = g_strdup_printf(_("Directory %s does not exist or is not a directory.\n"), dirname);
+        gchar * safeDir = Inkscape::IO::sanitizeString(dirname);
+        error = g_strdup_printf(_("Directory %s does not exist or is not a directory.\n"), safeDir);
         sp_ui_error_dialog(error);
+        g_free(safeDir);
         g_free(error);
         g_free(dirname);
         return;
@@ -1010,8 +1019,10 @@ sp_export_export_clicked (GtkButton *button, GtkObject *base)
                              nv->pagecolor, 
                              sp_export_progress_callback, base)) {
         gchar * error;
-        error = g_strdup_printf(_("Could not export to filename %s.\n"), filename);
+        gchar * safeFile = Inkscape::IO::sanitizeString(filename);
+        error = g_strdup_printf(_("Could not export to filename %s.\n"), safeFile);
         sp_ui_error_dialog(error);
+        g_free(safeFile);
         g_free(error);
     }
             
@@ -1210,10 +1221,10 @@ sp_export_detect_size(GtkObject * base) {
     selection_type this_test[SELECTION_NUMBER_OF + 1];
     selection_type key = SELECTION_NUMBER_OF;
 
-    NR::Point x(sp_export_value_get_pt (base, "x0"),
-                sp_export_value_get_pt (base, "y0"));
-    NR::Point y(sp_export_value_get_pt (base, "x1"),
-                sp_export_value_get_pt (base, "y1"));
+    NR::Point x(sp_export_value_get_px (base, "x0"),
+                sp_export_value_get_px (base, "y0"));
+    NR::Point y(sp_export_value_get_px (base, "x1"),
+                sp_export_value_get_px (base, "y1"));
     NR::Rect current_bbox(x, y);
     current_bbox.round(2);
     // std::cout << "Current " << current_bbox;
@@ -1287,7 +1298,10 @@ sp_export_detect_size(GtkObject * base) {
 
     /* We're now using a custom size, not a fixed one */
     /* printf("Detecting state: %s\n", selection_names[key]); */
+    selection_type old = (selection_type)((int)gtk_object_get_data(GTK_OBJECT(base), "selection-type"));
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gtk_object_get_data(base, selection_names[old])), FALSE);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gtk_object_get_data(base, selection_names[key])), TRUE);
+    gtk_object_set_data(GTK_OBJECT(base), "selection-type", (gpointer)key);
 
     return;
 } /* sp_export_detect_size */
@@ -1308,11 +1322,11 @@ sp_export_area_x_value_changed (GtkAdjustment *adj, GtkObject *base)
     
     gtk_object_set_data ( base, "update", GUINT_TO_POINTER (TRUE) );
 
-    x0 = sp_export_value_get_pt (base, "x0");
-    x1 = sp_export_value_get_pt (base, "x1");
+    x0 = sp_export_value_get_px (base, "x0");
+    x1 = sp_export_value_get_px (base, "x1");
     xdpi = sp_export_value_get (base, "xdpi");
 
-    width = floor ((x1 - x0) * xdpi / 72.0 + 0.5);
+    width = floor ((x1 - x0) * xdpi / DPI_BASE + 0.5);
 
     if (width < SP_EXPORT_MIN_SIZE) {
         const gchar *key;
@@ -1320,15 +1334,15 @@ sp_export_area_x_value_changed (GtkAdjustment *adj, GtkObject *base)
         key = (const gchar *)gtk_object_get_data (GTK_OBJECT (adj), "key");
         
         if (!strcmp (key, "x0")) {
-            x1 = x0 + width * 72.0 / xdpi;
-            sp_export_value_set_pt (base, "x1", x1);
+            x1 = x0 + width * DPI_BASE / xdpi;
+            sp_export_value_set_px (base, "x1", x1);
         } else {
-            x0 = x1 - width * 72.0 / xdpi;
-            sp_export_value_set_pt (base, "x0", x0);
+            x0 = x1 - width * DPI_BASE / xdpi;
+            sp_export_value_set_px (base, "x0", x0);
         }
     }
 
-    sp_export_value_set_pt (base, "width", x1 - x0);
+    sp_export_value_set_px (base, "width", x1 - x0);
     sp_export_value_set (base, "bmwidth", width);
 
     sp_export_detect_size(base);
@@ -1355,26 +1369,26 @@ sp_export_area_y_value_changed (GtkAdjustment *adj, GtkObject *base)
        
     gtk_object_set_data (base, "update", GUINT_TO_POINTER (TRUE));
 
-    y0 = sp_export_value_get_pt (base, "y0");
-    y1 = sp_export_value_get_pt (base, "y1");
+    y0 = sp_export_value_get_px (base, "y0");
+    y1 = sp_export_value_get_px (base, "y1");
     ydpi = sp_export_value_get (base, "ydpi");
 
-    height = floor ((y1 - y0) * ydpi / 72.0 + 0.5);
+    height = floor ((y1 - y0) * ydpi / DPI_BASE + 0.5);
 
     if (height < SP_EXPORT_MIN_SIZE) {
         const gchar *key;
         height = SP_EXPORT_MIN_SIZE;
         key = (const gchar *)gtk_object_get_data (GTK_OBJECT (adj), "key");
         if (!strcmp (key, "y0")) {
-            y1 = y0 + height * 72.0 / ydpi;
-            sp_export_value_set_pt (base, "y1", y1);
+            y1 = y0 + height * DPI_BASE / ydpi;
+            sp_export_value_set_px (base, "y1", y1);
         } else {
-            y0 = y1 - height * 72.0 / ydpi;
-            sp_export_value_set_pt (base, "y0", y0);
+            y0 = y1 - height * DPI_BASE / ydpi;
+            sp_export_value_set_px (base, "y0", y0);
         }
     }
 
-    sp_export_value_set_pt (base, "height", y1 - y0);
+    sp_export_value_set_px (base, "height", y1 - y0);
     sp_export_value_set (base, "bmheight", height);
 
     sp_export_detect_size(base);
@@ -1400,20 +1414,20 @@ sp_export_area_width_value_changed (GtkAdjustment *adj, GtkObject *base)
     
     gtk_object_set_data (base, "update", GUINT_TO_POINTER (TRUE));
 
-    x0 = sp_export_value_get_pt (base, "x0");
-    x1 = sp_export_value_get_pt (base, "x1");
+    x0 = sp_export_value_get_px (base, "x0");
+    x1 = sp_export_value_get_px (base, "x1");
     xdpi = sp_export_value_get (base, "xdpi");
-    width = sp_export_value_get_pt (base, "width");
-    bmwidth = floor (width * xdpi / 72.0 + 0.5);
+    width = sp_export_value_get_px (base, "width");
+    bmwidth = floor (width * xdpi / DPI_BASE + 0.5);
 
     if (bmwidth < SP_EXPORT_MIN_SIZE) {
     
         bmwidth = SP_EXPORT_MIN_SIZE;
-        width = bmwidth * 72.0 / xdpi;
-        sp_export_value_set_pt (base, "width", width);
+        width = bmwidth * DPI_BASE / xdpi;
+        sp_export_value_set_px (base, "width", width);
     }
 
-    sp_export_value_set_pt (base, "x1", x0 + width);
+    sp_export_value_set_px (base, "x1", x0 + width);
     sp_export_value_set (base, "bmwidth", bmwidth);
 
     gtk_object_set_data (base, "update", GUINT_TO_POINTER (FALSE));
@@ -1438,19 +1452,19 @@ sp_export_area_height_value_changed (GtkAdjustment *adj, GtkObject *base)
     
     gtk_object_set_data (base, "update", GUINT_TO_POINTER (TRUE));
 
-    y0 = sp_export_value_get_pt (base, "y0");
-    y1 = sp_export_value_get_pt (base, "y1");
+    y0 = sp_export_value_get_px (base, "y0");
+    y1 = sp_export_value_get_px (base, "y1");
     ydpi = sp_export_value_get (base, "ydpi");
-    height = sp_export_value_get_pt (base, "height");
-    bmheight = floor (height * ydpi / 72.0 + 0.5);
+    height = sp_export_value_get_px (base, "height");
+    bmheight = floor (height * ydpi / DPI_BASE + 0.5);
 
     if (bmheight < SP_EXPORT_MIN_SIZE) {
         bmheight = SP_EXPORT_MIN_SIZE;
-        height = bmheight * 72.0 / ydpi;
-        sp_export_value_set_pt (base, "height", height);
+        height = bmheight * DPI_BASE / ydpi;
+        sp_export_value_set_px (base, "height", height);
     }
 
-    sp_export_value_set_pt (base, "y1", y0 + height);
+    sp_export_value_set_px (base, "y1", y0 + height);
     sp_export_value_set (base, "bmheight", bmheight);
 
     gtk_object_set_data (base, "update", GUINT_TO_POINTER (FALSE));
@@ -1471,12 +1485,12 @@ sp_export_set_image_y (GtkObject *base)
 {
     float y0, y1, xdpi;
 
-    y0 = sp_export_value_get_pt (base, "y0");
-    y1 = sp_export_value_get_pt (base, "y1");
+    y0 = sp_export_value_get_px (base, "y0");
+    y1 = sp_export_value_get_px (base, "y1");
     xdpi = sp_export_value_get (base, "xdpi");
 
     sp_export_value_set (base, "ydpi", xdpi);
-    sp_export_value_set (base, "bmheight", (y1 - y0) * xdpi / 72.0);
+    sp_export_value_set (base, "bmheight", (y1 - y0) * xdpi / DPI_BASE);
 
     return;
 } // end of sp_export_set_image_y()
@@ -1497,8 +1511,8 @@ sp_export_bitmap_width_value_changed (GtkAdjustment *adj, GtkObject *base)
     
     gtk_object_set_data (base, "update", GUINT_TO_POINTER (TRUE));
 
-    x0 = sp_export_value_get_pt (base, "x0");
-    x1 = sp_export_value_get_pt (base, "x1");
+    x0 = sp_export_value_get_px (base, "x0");
+    x1 = sp_export_value_get_px (base, "x1");
     bmwidth = sp_export_value_get (base, "bmwidth");
 
     if (bmwidth < SP_EXPORT_MIN_SIZE) {
@@ -1506,7 +1520,7 @@ sp_export_bitmap_width_value_changed (GtkAdjustment *adj, GtkObject *base)
         sp_export_value_set (base, "bmwidth", bmwidth);
     }
 
-    xdpi = bmwidth * 72.0 / (x1 - x0);
+    xdpi = bmwidth * DPI_BASE / (x1 - x0);
     sp_export_value_set (base, "xdpi", xdpi);
 
     sp_export_set_image_y (base);
@@ -1559,21 +1573,21 @@ sp_export_xdpi_value_changed (GtkAdjustment *adj, GtkObject *base)
     
     gtk_object_set_data (base, "update", GUINT_TO_POINTER (TRUE));
 
-    x0 = sp_export_value_get_pt (base, "x0");
-    x1 = sp_export_value_get_pt (base, "x1");
+    x0 = sp_export_value_get_px (base, "x0");
+    x1 = sp_export_value_get_px (base, "x1");
     xdpi = sp_export_value_get (base, "xdpi");
 
     // remember xdpi setting
     prefs_set_double_attribute ("dialogs.export.defaultxdpi", "value", xdpi);
 
-    bmwidth = (x1 - x0) * xdpi / 72.0;
+    bmwidth = (x1 - x0) * xdpi / DPI_BASE;
 
     if (bmwidth < SP_EXPORT_MIN_SIZE) {
         bmwidth = SP_EXPORT_MIN_SIZE;
         if (x1 != x0) 
-            xdpi = bmwidth * 72.0 / (x1 - x0);
+            xdpi = bmwidth * DPI_BASE / (x1 - x0);
         else 
-            xdpi = 72.0;
+            xdpi = DPI_BASE;
         sp_export_value_set (base, "xdpi", xdpi);
     }
 
@@ -1596,7 +1610,7 @@ sp_export_xdpi_value_changed (GtkAdjustment *adj, GtkObject *base)
     \param  x1    Horizontal lower right hand corner of the picture in points
     \param  y1    Vertical lower right hand corner of the picture in points
 
-    This function just calls \c sp_export_value_set_pt for each of the
+    This function just calls \c sp_export_value_set_px for each of the
     parameters that is passed in.  This allows for setting them all in
     one convient area.
 
@@ -1610,10 +1624,10 @@ static void
 sp_export_set_area ( GtkObject *base, float x0, float y0, float x1, float y1 )
 {
     gtk_object_set_data ( base, "update", GUINT_TO_POINTER (TRUE) );
-    sp_export_value_set_pt (base, "x1", x1);
-    sp_export_value_set_pt (base, "y1", y1);
-    sp_export_value_set_pt (base, "x0", x0);
-    sp_export_value_set_pt (base, "y0", y0);
+    sp_export_value_set_px (base, "x1", x1);
+    sp_export_value_set_px (base, "y1", y1);
+    sp_export_value_set_px (base, "x0", x0);
+    sp_export_value_set_px (base, "y0", y0);
     gtk_object_set_data ( base, "update", GUINT_TO_POINTER (FALSE) );
 
     sp_export_area_x_value_changed ((GtkAdjustment *)gtk_object_get_data (base, "x1"), base);
@@ -1640,9 +1654,7 @@ sp_export_value_set ( GtkObject *base, const gchar *key, float val )
     adj = (GtkAdjustment *)gtk_object_get_data (base, key);
 
     gtk_adjustment_set_value (adj, val);
-
-    return;
-} // end of sp_export_value_set()
+}
 
 /**
     \brief  A function to set a value using the units points
@@ -1656,18 +1668,14 @@ sp_export_value_set ( GtkObject *base, const gchar *key, float val )
     value and sets the adjustment.
 */
 static void
-sp_export_value_set_pt (GtkObject *base, const gchar *key, float val)
+sp_export_value_set_px (GtkObject *base, const gchar *key, float val)
 {
-    const SPUnit *unit;
+    const SPUnit *unit = sp_unit_selector_get_unit ((SPUnitSelector *)gtk_object_get_data (base, "units") );
 
-    unit = 
-        sp_unit_selector_get_unit ((SPUnitSelector *)gtk_object_get_data 
-            (base, "units") );
-
-    sp_export_value_set (base, key, sp_points_get_units (val, unit));
+    sp_export_value_set (base, key, sp_pixels_get_units (val, *unit));
 
     return;
-} // end of sp_export_value_set_pt()
+} // end of sp_export_value_set_px()
 
 /**
     \brief  Get the value of an adjustment in the export dialog
@@ -1701,17 +1709,13 @@ sp_export_value_get ( GtkObject *base, const gchar *key )
     dialog.  Using that it converts the returned value into points.
 */
 static float
-sp_export_value_get_pt ( GtkObject *base, const gchar *key )
+sp_export_value_get_px ( GtkObject *base, const gchar *key )
 {
-    float value;
-    const SPUnit *unit;
+    float value = sp_export_value_get(base, key);
+    const SPUnit *unit = sp_unit_selector_get_unit ((SPUnitSelector *)gtk_object_get_data (base, "units"));
 
-    value = sp_export_value_get(base, key);
-
-    unit = sp_unit_selector_get_unit ((SPUnitSelector *)gtk_object_get_data (base, "units"));
-
-    return sp_units_get_points (value, unit);
-} // end of sp_export_value_get_pt()
+    return sp_units_get_pixels (value, *unit);
+} // end of sp_export_value_get_px()
 
 /**
     \brief  This function is called when the filename is changed by
