@@ -43,11 +43,13 @@
 
 #include "interface.h"
 #include "filedialog.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "prefs-utils.h"
 
 #include <dialogs/dialog-events.h>
 #include <extension/extension.h>
+#include <extension/input.h>
+#include <extension/output.h>
 #include <extension/db.h>
 
 //for the preview widget
@@ -67,6 +69,7 @@ namespace Inkscape {
 namespace UI {
 namespace Dialogs {
 
+void FileDialogExtensionToPattern (Glib::ustring &pattern, gchar * in_file_extension);
 
 /*#########################################################################
 ### SVG Preview Widget
@@ -239,7 +242,7 @@ void SVGPreview::showImage(Glib::ustring &theFileName)
           "xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n"
           "width=\"%d\" height=\"%d\">\n"
           "<rect\n"
-          "  style=\"fill:#eeeeee;stroke:none;\"\n"
+          "  style=\"fill:#eeeeee;stroke:none\"\n"
           "  x=\"-100\" y=\"-100\" width=\"4000\" height=\"4000\"/>\n"
           "<image x=\"%d\" y=\"%d\" width=\"%d\" height=\"%d\"\n"
           "xlink:href=\"%s\"/>\n"
@@ -247,12 +250,12 @@ void SVGPreview::showImage(Glib::ustring &theFileName)
           "  style=\"fill:none;"
           "    stroke:#000000;stroke-width:1.0;"
           "    stroke-linejoin:miter;stroke-opacity:1.0000000;"
-          "    stroke-miterlimit:4.0000000;stroke-dasharray:none;\"\n"
+          "    stroke-miterlimit:4.0000000;stroke-dasharray:none\"\n"
           "  x=\"%d\" y=\"%d\" width=\"%d\" height=\"%d\"/>\n"
           "<text\n"
           "  style=\"font-size:24.000000;font-style:normal;font-weight:normal;"
           "    fill:#000000;fill-opacity:1.0000000;stroke:none;"
-          "    font-family:Bitstream Vera Sans;\"\n"
+          "    font-family:Bitstream Vera Sans\"\n"
           "  x=\"10\" y=\"26\">%d x %d</text>\n"
           "</svg>\n\n";
 
@@ -294,33 +297,33 @@ void SVGPreview::showNoPreview()
           "xmlns=\"http://www.w3.org/2000/svg\"\n"
           "xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n"
           "width=\"%d\" height=\"%d\">\n"
-          "<g transform=\"translate(-170,24.27184)\" style=\"opacity:0.12;\">\n"
+          "<g transform=\"translate(-190,24.27184)\" style=\"opacity:0.12\">\n"
           "<path\n"
-          "style=\"font-size:12;fill:#ffffff;fill-rule:evenodd;stroke:#000000;stroke-width:0.936193pt;\"\n"
+          "style=\"font-size:12;fill:#ffffff;fill-rule:evenodd;stroke:#000000;stroke-width:0.936193pt\"\n"
           "d=\"M 397.64309 320.25301 L 280.39197 282.517 L 250.74227 124.83447 L 345.08225 "
           "29.146783 L 393.59996 46.667064 L 483.89679 135.61619 L 397.64309 320.25301 z \"\n"
           "id=\"whiteSpace\" />\n"
           "<path\n"
-          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1;\"\n"
+          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1\"\n"
           "d=\"M 476.95792 339.17168 C 495.78197 342.93607 499.54842 356.11361 495.78197 359.87802 "
           "C 492.01856 363.6434 482.6065 367.40781 475.07663 361.76014 C 467.54478 "
           "356.11361 467.54478 342.93607 476.95792 339.17168 z \"\n"
           "id=\"droplet01\" />\n"
           "<path\n"
-          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1;\"\n"
+          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1\"\n"
           "d=\"M 286.46194 340.42914 C 284.6277 340.91835 269.30405 327.71337 257.16909 333.8338 "
           "C 245.03722 339.95336 236.89276 353.65666 248.22676 359.27982 C 259.56184 364.90298 "
           "267.66433 358.41867 277.60113 351.44119 C 287.53903 344.46477 "
           "287.18046 343.1206 286.46194 340.42914 z \"\n"
           "id=\"droplet02\" />\n"
           "<path\n"
-          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1;\"\n"
+          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1\"\n"
           "d=\"M 510.35756 306.92856 C 520.59494 304.36879 544.24333 306.92856 540.47688 321.98634 "
           "C 536.71354 337.04806 504.71297 331.39827 484.00371 323.87156 C 482.12141 "
           "308.81083 505.53237 308.13423 510.35756 306.92856 z \"\n"
           "id=\"droplet03\" />\n"
           "<path\n"
-          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1;\"\n"
+          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1\"\n"
           "d=\"M 359.2403 21.362537 C 347.92693 21.362537 336.6347 25.683095 327.96556 34.35223 "
           "L 173.87387 188.41466 C 165.37697 196.9114 161.1116 207.95813 160.94269 219.04577 "
           "L 160.88418 219.04577 C 160.88418 219.08524 160.94076 219.12322 160.94269 219.16279 "
@@ -350,13 +353,13 @@ void SVGPreview::showNoPreview()
           "275.37038 359.88393 275.50997 L 360.76161 284.72563 C 343.2235 282.91785 306.11346 "
           "274.45012 297.36372 269.98057 L 290.92738 261.61333 z \"\n"
           "id=\"mountainDroplet\" />\n"
-          "</g>\n"
+          "</g> <g transform=\"translate(-20,0)\">\n"
           "<text xml:space=\"preserve\"\n"
           "style=\"font-size:32.000000;font-style:normal;font-variant:normal;font-weight:bold;"
           "font-stretch:normal;fill:#000000;fill-opacity:1.0000000;stroke:none;stroke-width:1.0000000pt;"
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"
-          "font-family:Bitstream Vera Sans;text-anchor:middle;writing-mode:lr;\"\n"
-          "x=\"190\" y=\"240\">%s</text>\n"
+          "font-family:Bitstream Vera Sans;text-anchor:middle;writing-mode:lr\"\n"
+          "x=\"190\" y=\"240\">%s</text></g>\n"
           "</svg>\n\n";
 
     //Fill in the template
@@ -386,33 +389,33 @@ void SVGPreview::showTooLarge(long fileLength)
           "xmlns=\"http://www.w3.org/2000/svg\"\n"
           "xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n"
           "width=\"%d\" height=\"%d\">\n"
-          "<g transform=\"translate(-170,24.27184)\" style=\"opacity:0.12;\">\n"
+          "<g transform=\"translate(-170,24.27184)\" style=\"opacity:0.12\">\n"
           "<path\n"
-          "style=\"font-size:12;fill:#ffffff;fill-rule:evenodd;stroke:#000000;stroke-width:0.936193pt;\"\n"
+          "style=\"font-size:12;fill:#ffffff;fill-rule:evenodd;stroke:#000000;stroke-width:0.936193pt\"\n"
           "d=\"M 397.64309 320.25301 L 280.39197 282.517 L 250.74227 124.83447 L 345.08225 "
           "29.146783 L 393.59996 46.667064 L 483.89679 135.61619 L 397.64309 320.25301 z \"\n"
           "id=\"whiteSpace\" />\n"
           "<path\n"
-          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1;\"\n"
+          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1\"\n"
           "d=\"M 476.95792 339.17168 C 495.78197 342.93607 499.54842 356.11361 495.78197 359.87802 "
           "C 492.01856 363.6434 482.6065 367.40781 475.07663 361.76014 C 467.54478 "
           "356.11361 467.54478 342.93607 476.95792 339.17168 z \"\n"
           "id=\"droplet01\" />\n"
           "<path\n"
-          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1;\"\n"
+          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1\"\n"
           "d=\"M 286.46194 340.42914 C 284.6277 340.91835 269.30405 327.71337 257.16909 333.8338 "
           "C 245.03722 339.95336 236.89276 353.65666 248.22676 359.27982 C 259.56184 364.90298 "
           "267.66433 358.41867 277.60113 351.44119 C 287.53903 344.46477 "
           "287.18046 343.1206 286.46194 340.42914 z \"\n"
           "id=\"droplet02\" />\n"
           "<path\n"
-          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1;\"\n"
+          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1\"\n"
           "d=\"M 510.35756 306.92856 C 520.59494 304.36879 544.24333 306.92856 540.47688 321.98634 "
           "C 536.71354 337.04806 504.71297 331.39827 484.00371 323.87156 C 482.12141 "
           "308.81083 505.53237 308.13423 510.35756 306.92856 z \"\n"
           "id=\"droplet03\" />\n"
           "<path\n"
-          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1;\"\n"
+          "style=\"font-size:12;fill-rule:evenodd;stroke-width:1pt;fill:#000000;fill-opacity:1\"\n"
           "d=\"M 359.2403 21.362537 C 347.92693 21.362537 336.6347 25.683095 327.96556 34.35223 "
           "L 173.87387 188.41466 C 165.37697 196.9114 161.1116 207.95813 160.94269 219.04577 "
           "L 160.88418 219.04577 C 160.88418 219.08524 160.94076 219.12322 160.94269 219.16279 "
@@ -447,13 +450,13 @@ void SVGPreview::showTooLarge(long fileLength)
           "style=\"font-size:32.000000;font-style:normal;font-variant:normal;font-weight:bold;"
           "font-stretch:normal;fill:#000000;fill-opacity:1.0000000;stroke:none;stroke-width:1.0000000pt;"
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"
-          "font-family:Bitstream Vera Sans;text-anchor:middle;writing-mode:lr;\"\n"
+          "font-family:Bitstream Vera Sans;text-anchor:middle;writing-mode:lr\"\n"
           "x=\"170\" y=\"215\">%5.1f MB</text>\n"
           "<text xml:space=\"preserve\"\n"
           "style=\"font-size:24.000000;font-style:normal;font-variant:normal;font-weight:bold;"
           "font-stretch:normal;fill:#000000;fill-opacity:1.0000000;stroke:none;stroke-width:1.0000000pt;"
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"
-          "font-family:Bitstream Vera Sans;text-anchor:middle;writing-mode:lr;\"\n"
+          "font-family:Bitstream Vera Sans;text-anchor:middle;writing-mode:lr\"\n"
           "x=\"180\" y=\"245\">%s</text>\n"
           "</svg>\n\n";
 
@@ -772,56 +775,34 @@ void FileOpenDialogImpl::createFilterMenu()
     extensionMap[Glib::ustring(_("All Inkscape Files"))]=NULL;
     add_filter(allInkscapeFilter);
 
-    Gtk::FileFilter svgFilter;
-    svgFilter.set_name(_("SVG Files"));
-    extensionMap[Glib::ustring(_("SVG Files"))]=NULL;
-    svgFilter.add_pattern("*.[Ss][Vv][Gg]");
-    add_filter(svgFilter);
+    Inkscape::Extension::DB::InputList extension_list;
+    Inkscape::Extension::db.get_input_list(extension_list);
 
-    Gtk::FileFilter svgzFilter;
-    svgzFilter.set_name(_("Compressed SVG Files"));
-    extensionMap[Glib::ustring(_("Compressed SVG Files"))]=NULL;
-    svgzFilter.add_pattern("*.[Ss][Vv][Gg][Zz]");
-    add_filter(svgzFilter);
+    for (Inkscape::Extension::DB::InputList::iterator current_item = extension_list.begin();
+         current_item != extension_list.end(); current_item++)
+    {
+        Inkscape::Extension::Input * imod = *current_item;
 
-    /*We need to find out how to do a menu separator
-    Gtk::FileFilter spacer;
-    svgzFilter.set_name("-");
-    add_filter(spacer);
-    */
-
-    GSList *extension_list = Inkscape::Extension::db.get_input_list();
-    if (extension_list == NULL) {
-        // Another exception
-        g_warning("Internal error.  We need extensions.\n");
-        return;
-    }
-
-    for (GSList *current_item = g_slist_next(extension_list);
-         current_item; current_item = g_slist_next(current_item))
-        {
-        Inkscape::Extension::DB::IOExtensionDescription * ioext =
-              reinterpret_cast<Inkscape::Extension::DB::IOExtensionDescription *>(current_item->data);
+        // FIXME: would be nice to grey them out instead of not listing them
+        if (imod->deactivated()) continue;
 
         Glib::ustring upattern("*");
-        upattern += ioext->pattern;
-        if (!( strcmp(".svg",  ioext->file_extension)==0 ||
-               strcmp(".svgz", ioext->file_extension)==0   ))
-            {
-            Gtk::FileFilter filter;
-            Glib::ustring uname(_(ioext->name));
-            filter.set_name(uname);
-            filter.add_pattern(upattern);
-            add_filter(filter);
-            extensionMap[uname]=ioext->extension;
-            }
+        FileDialogExtensionToPattern (upattern, imod->get_extension());
+
+        Gtk::FileFilter filter;
+        Glib::ustring uname(_(imod->get_filetypename()));
+        filter.set_name(uname);
+        filter.add_pattern(upattern);
+        add_filter(filter);
+        extensionMap[uname] = imod;
+
         //g_message("ext %s:%s '%s'\n", ioext->name, ioext->mimetype, upattern.c_str());
         allInkscapeFilter.add_pattern(upattern);
-        if ( strncmp("image", ioext->mimetype, 5)==0 )
+        if ( strncmp("image", imod->get_mimetype(), 5)==0 )
             allImageFilter.add_pattern(upattern);
-        }
+    }
 
-    Inkscape::Extension::db.free_list(extension_list);
+    return;
 }
 
 
@@ -858,6 +839,7 @@ FileOpenDialogImpl::FileOpenDialogImpl(char const *dir,
     //###### Add a preview widget
     set_preview_widget(svgPreview);
     set_preview_widget_active(true);
+    set_use_preview_label (false);
 
     //Catch selection-changed events, so we can adjust the text widget
     signal_update_preview().connect(
@@ -1155,51 +1137,26 @@ void FileSaveDialogImpl::fileTypeChangedCallback()
 
 void FileSaveDialogImpl::createFileTypeMenu()
 {
-    FileType inkscapeType;
-    inkscapeType.name = _("Inkscape SVG");
-    inkscapeType.pattern = "*.svg";
-    inkscapeType.extension = Inkscape::Extension::db.get(SP_MODULE_KEY_OUTPUT_SVG_INKSCAPE);
-    fileTypeComboBox.append_text(inkscapeType.name);
-    fileTypes.push_back(inkscapeType);
+    Inkscape::Extension::DB::OutputList extension_list;
+    Inkscape::Extension::db.get_output_list(extension_list);
 
-    FileType plainType;
-    plainType.name = _("Plain SVG");
-    plainType.pattern = "*.svg";
-    plainType.extension = Inkscape::Extension::db.get(SP_MODULE_KEY_OUTPUT_SVG);
-    fileTypeComboBox.append_text(plainType.name);
-    fileTypes.push_back(plainType);
+    for (Inkscape::Extension::DB::OutputList::iterator current_item = extension_list.begin();
+         current_item != extension_list.end(); current_item++)
+    {
+        Inkscape::Extension::Output * omod = *current_item;
 
-    GSList *extension_list = Inkscape::Extension::db.get_output_list();
-    if (extension_list == NULL) {
-        // Another exception
-        g_warning("Internal error.  We need extensions.\n");
-        return;
+        // FIXME: would be nice to grey them out instead of not listing them
+        if (omod->deactivated()) continue;
+
+        FileType type;
+        type.name     = (_(omod->get_filetypename()));
+        type.pattern  = "*";
+        FileDialogExtensionToPattern (type.pattern, omod->get_extension());
+        type.extension= omod;
+        fileTypeComboBox.append_text(type.name);
+        fileTypes.push_back(type);
     }
 
-    for (GSList *current_item = g_slist_next(extension_list);
-         current_item; current_item = g_slist_next(current_item))
-        {
-        Inkscape::Extension::DB::IOExtensionDescription * ioext =
-              reinterpret_cast<Inkscape::Extension::DB::IOExtensionDescription *>(current_item->data);
-
-        if ( ( strcmp(".svg",  ioext->file_extension)==0 ))
-            {
-            //Skip these. we already did them
-            }
-        else
-            {
-            FileType type;
-            type.name     = (_(ioext->name));
-            type.pattern  = "*";
-            type.pattern += ioext->file_extension;
-            type.extension=ioext->extension;
-            fileTypeComboBox.append_text(type.name);
-            fileTypes.push_back(type);
-            }
-        }
-
-    Inkscape::Extension::db.free_list(extension_list);
-
     //#Let user choose
     FileType guessType;
     guessType.name = _("Guess from extension");
@@ -1298,6 +1255,7 @@ FileSaveDialogImpl::FileSaveDialogImpl(char const *dir,
     //###### Add a preview widget
     set_preview_widget(svgPreview);
     set_preview_widget_active(true);
+    set_use_preview_label (false);
 
     //Catch selection-changed events, so we can adjust the text widget
     signal_update_preview().connect(
@@ -1426,12 +1384,38 @@ FileSaveDialogImpl::getFilename()
     return g_strdup(myFilename.c_str());
 }
 
+/**
+    \brief  A quick function to turn a standard extension into a searchable
+            pattern for the file dialogs
+    \param  pattern  The patter that the extension should be written to
+    \param  in_file_extension  The C string that represents the extension
 
+    This function just goes through the string, and takes all characters
+    and puts a [<upper><lower>] so that both are searched and shown in
+    the file dialog.  This function edits the pattern string to make
+    this happen.
+*/
+void
+FileDialogExtensionToPattern (Glib::ustring &pattern, gchar * in_file_extension)
+{
+    Glib::ustring tmp(in_file_extension);
 
+    for ( guint i = 0; i < tmp.length(); i++ ) {
+        Glib::ustring::value_type ch = tmp.at(i);
+        if ( Glib::Unicode::isalpha(ch) ) {
+            pattern += '[';
+            pattern += Glib::Unicode::toupper(ch);
+            pattern += Glib::Unicode::tolower(ch);
+            pattern += ']';
+        } else {
+            pattern += ch;
+        }
+    }
+}
 
-}; //namespace Dialogs
-}; //namespace UI
-}; //namespace Inkscape
+} //namespace Dialogs
+} //namespace UI
+} //namespace Inkscape
 
 
 /*
