@@ -76,7 +76,7 @@ DialogFind::DialogFind():
     Gtk::Image*  pImage = 
         Gtk::manage( new Gtk::Image(
                          PixBufFactory::get().
-                         getFromSVG(id)));
+                         getIcon(id)));
     _widget.pack_start(*pImage);
     _widget.pack_start(_fieldsTable);
     addSearchField("_Text", _("Find objects by their text content (exact or partial match)"), 0);
@@ -100,7 +100,7 @@ DialogFind & DialogFind::get()
 #include <gtk/gtk.h>
 
 #include "../inkscape-stock.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/window.h"
 #include "helper/unit-menu.h"
 #include "libnr/nr-scale.h"
@@ -358,7 +358,7 @@ all_items (SPObject *r, GSList *l, bool hidden, bool locked)
     if (SP_IS_DEFS(r))
         return l; // we're not interested in items in defs 
 
-    if (!strcmp (sp_repr_name (SP_OBJECT_REPR (r)), "metadata"))
+    if (!strcmp (sp_repr_name (SP_OBJECT_REPR (r)), "svg:metadata"))
         return l; // we're not interested in metadata
 
     for (SPObject *child = sp_object_first_child(r); child; child = SP_OBJECT_NEXT (child)) {
@@ -425,10 +425,13 @@ void sp_find_dialog_find(GObject *, GObject *dlg)
     }
 
     if (n != NULL) {
+        int count = g_slist_length (n);
         desktop->messageStack()->flashF(Inkscape::NORMAL_MESSAGE,
                                         // TRANSLATORS: "%s" is replaced with "exact" or "partial" when this string is displayed
-                                        _("<b>%d</b> object(s) found (out of <b>%d</b>), %s match."),
-                                        g_slist_length (n), all, exact? _("exact") : _("partial"));
+                                        ngettext("<b>%d</b> object found (out of <b>%d</b>), %s match.",
+                                                 "<b>%d</b> objects found (out of <b>%d</b>), %s match.",
+                                                 count),
+                                        count, all, exact? _("exact") : _("partial"));
 
         SPSelection *selection = SP_DT_SELECTION (desktop);
         selection->clear();
@@ -813,15 +816,13 @@ sp_find_dialog_old (void)
 }
 
 
-
 /*
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
-
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
