@@ -30,7 +30,7 @@
 #include <gtk/gtktextbuffer.h>
 #include <gtk/gtktooltips.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/window.h"
 #include "../svg/svg.h"
 #include "../svg/stringstream.h"
