@@ -24,6 +24,7 @@
 #include "inkscape.h"
 #include "xml/repr.h"
 #include "rdf.h"
+#include "sp-item-group.h"
 
 /*
 
@@ -214,7 +215,8 @@ struct rdf_license_t rdf_licenses [] = {
     { NULL, NULL, rdf_license_empty, }
 };
 
-#define XML_TAG_NAME_METADATA "metadata"
+#define XML_TAG_NAME_SVG      "svg:svg"
+#define XML_TAG_NAME_METADATA "svg:metadata"
 #define XML_TAG_NAME_RDF      "rdf:RDF"
 #define XML_TAG_NAME_WORK     "cc:Work"
 #define XML_TAG_NAME_LICENSE  "cc:License"
@@ -442,8 +444,6 @@ rdf_get_repr_text ( SPRepr * repr, struct rdf_work_entity_t * entity )
     static gchar * bag = NULL;
     gchar * holder = NULL;
 
-    //printf("Getting '%s' contents from '%s'\n",entity->tag,SP_REPR_NAME(repr));
-
     SPRepr * temp=NULL;
     switch (entity->datatype) {
         case RDF_CONTENT:
@@ -487,8 +487,9 @@ rdf_get_repr_text ( SPRepr * repr, struct rdf_work_entity_t * entity )
             for ( temp = sp_repr_children(temp) ;
                   temp ;
                   temp = sp_repr_next(temp) ) {
-                if (!strcmp(sp_repr_name(temp),"rdf:li")) {
-                    gchar * str = (gchar *)sp_repr_content(temp);
+                if (!strcmp(sp_repr_name(temp),"rdf:li") &&
+                    temp->firstChild()) {
+                    const gchar * str = temp->firstChild()->content();
                     if (bag) {
                         holder = bag;
                         bag = g_strconcat(holder, ", ", str, NULL);
@@ -639,7 +640,7 @@ rdf_get_rdf_root_repr ( SPDocument * doc, bool build )
         //printf("missing XML '%s'\n",XML_TAG_NAME_RDF);
         if (!build) return NULL;
 
-        SPRepr * svg = sp_repr_lookup_name ( doc->rroot, "svg" );
+        SPRepr * svg = sp_repr_lookup_name ( doc->rroot, XML_TAG_NAME_SVG );
         g_return_val_if_fail ( svg != NULL, NULL );
 
         SPRepr * parent = sp_repr_lookup_name ( svg, XML_TAG_NAME_METADATA );
@@ -950,6 +951,17 @@ rdf_set_defaults ( SPDocument * document )
 {
     g_assert ( document != NULL );
 
+    // Create metadata node if it doesn't already exist
+    if (!sp_item_group_get_child_by_name ((SPGroup *) document->root, NULL,
+                                          XML_TAG_NAME_METADATA)) {
+        // create repr
+        SPRepr * rnew = sp_repr_new (XML_TAG_NAME_METADATA);
+        // insert into the document
+        sp_repr_add_child (document->rroot, rnew, NULL);
+        // clean up
+        sp_repr_unref (rnew);
+    }
+
     /* install defaults */
     for ( struct rdf_entity_default_t * rdf_default = rdf_defaults;
           rdf_default->name;
