@@ -29,7 +29,7 @@
 
 #include <gtk/gtk.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/unit-menu.h"
 #include "helper/units.h"
 #include "svg/svg.h"
@@ -51,6 +51,7 @@
 #include "document.h"
 #include "desktop-handles.h"
 #include "desktop-style.h"
+#include "desktop.h"
 #include "marker-status.h"
 #include "selection.h"
 #include "sp-item.h"
@@ -63,12 +64,12 @@
 #include "sp-shape.h"
 #include "sp-rect.h"
 #include "document-private.h"
-#include "xml/repr-private.h"
 #include "display/nr-arena.h"
 #include "display/nr-arena-item.h"
 #include "path-prefix.h"
 #include "widgets/icon.h"
 #include "helper/stock-items.h"
+#include "io/sys.h"
 #include <file.h>
 
 #include "dialogs/stroke-style.h"
@@ -772,11 +773,11 @@ static SPObject *ink_extract_marker_name(gchar const *n);
  * when reimplementing this with Gtkmm.
  */
 static GtkWidget *
-sp_stroke_radio_button(GtkWidget *tb, char const *n, char const *xpm,
+sp_stroke_radio_button(GtkWidget *tb, char const *icon,
                        GtkWidget *hb, GtkWidget *spw,
                        gchar const *key, gchar const *data)
 {
-    g_assert(xpm != NULL);
+    g_assert(icon != NULL);
     g_assert(hb  != NULL);
     g_assert(spw != NULL);
 
@@ -789,12 +790,12 @@ sp_stroke_radio_button(GtkWidget *tb, char const *n, char const *xpm,
     gtk_widget_show(tb);
     gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(tb), FALSE);
     gtk_box_pack_start(GTK_BOX(hb), tb, FALSE, FALSE, 0);
-    gtk_object_set_data(GTK_OBJECT(spw), n, tb);
+    gtk_object_set_data(GTK_OBJECT(spw), icon, tb);
     gtk_object_set_data(GTK_OBJECT(tb), key, (gpointer*)data);
     gtk_signal_connect(GTK_OBJECT(tb), "toggled",
                        GTK_SIGNAL_FUNC(sp_stroke_style_any_toggled),
                        spw);
-    GtkWidget *px = gtk_image_new_from_stock(n, GTK_ICON_SIZE_LARGE_TOOLBAR);
+    GtkWidget *px = sp_icon_new_scaled(SP_ICON_SIZE_NOTEBOOK, icon);
     g_assert(px != NULL);
     gtk_widget_show(px);
     gtk_container_add(GTK_CONTAINER(tb), px);
@@ -944,7 +945,7 @@ sp_marker_list_from_doc (GtkWidget *m, SPDocument *current_doc, SPDocument *sour
     NRArena const *arena = NRArena::create();
     /* Create ArenaItem and set transform */
     unsigned const visionkey = sp_item_display_key_new(1);
-    NRArenaItem *root =  sp_item_invoke_show( SP_ITEM(SP_DOCUMENT_ROOT (sandbox)), (NRArena *) arena, visionkey, SP_ITEM_SHOW_PRINT );
+    NRArenaItem *root =  sp_item_invoke_show( SP_ITEM(SP_DOCUMENT_ROOT (sandbox)), (NRArena *) arena, visionkey, SP_ITEM_SHOW_DISPLAY );
 
     for (; ml != NULL; ml = ml->next) {
 
@@ -1010,23 +1011,23 @@ gchar const *buffer = "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:sodipodi=
 "  <defs id=\"defs\" />"
 
 "  <g id=\"marker-start\">"
-"    <path style=\"fill:none;stroke:black;stroke-width:1.7;marker-start:url(#sample);marker-mid:none;marker-end:none;\""
+"    <path style=\"fill:none;stroke:black;stroke-width:1.7;marker-start:url(#sample);marker-mid:none;marker-end:none\""
 "       d=\"M 12.5,13 L 25,13\" id=\"path1\" />"
-"    <rect style=\"fill:none;stroke:none;\" id=\"rect2\""
+"    <rect style=\"fill:none;stroke:none\" id=\"rect2\""
 "       width=\"25\" height=\"25\" x=\"0\" y=\"0\" />"
 "  </g>"
 
 "  <g id=\"marker-mid\">"
-"    <path style=\"fill:none;stroke:black;stroke-width:1.7;marker-start:none;marker-mid:url(#sample);marker-end:none;\""
+"    <path style=\"fill:none;stroke:black;stroke-width:1.7;marker-start:none;marker-mid:url(#sample);marker-end:none\""
 "       d=\"M 0,113 L 12.5,113 L 25,113\" id=\"path11\" />"
-"    <rect style=\"fill:none;stroke:none;\" id=\"rect22\""
+"    <rect style=\"fill:none;stroke:none\" id=\"rect22\""
 "       width=\"25\" height=\"25\" x=\"0\" y=\"100\" />"
 "  </g>"
 
 "  <g id=\"marker-end\">"
-"    <path style=\"fill:none;stroke:black;stroke-width:1.7;marker-start:none;marker-mid:none;marker-end:url(#sample);\""
+"    <path style=\"fill:none;stroke:black;stroke-width:1.7;marker-start:none;marker-mid:none;marker-end:url(#sample)\""
 "       d=\"M 0,213 L 12.5,213\" id=\"path111\" />"
-"    <rect style=\"fill:none;stroke:none;\" id=\"rect222\""
+"    <rect style=\"fill:none;stroke:none\" id=\"rect222\""
 "       width=\"25\" height=\"25\" x=\"0\" y=\"200\" />"
 "  </g>"
 
@@ -1082,7 +1083,7 @@ ink_marker_menu( GtkWidget *tbl, gchar *menu_id, SPDocument *sandbox)
         // find and load  markers.svg
         static SPDocument *markers_doc = NULL;
         char *markers_source = g_build_filename(INKSCAPE_MARKERSDIR, "/markers.svg", NULL);
-        if (g_file_test (markers_source, G_FILE_TEST_IS_REGULAR)) {
+        if (Inkscape::IO::file_test (markers_source, G_FILE_TEST_IS_REGULAR)) {
             markers_doc = sp_document_new(markers_source, FALSE, FALSE);
         }
         g_free(markers_source);
@@ -1275,7 +1276,7 @@ stroke_average_miterlimit (GSList const *objects)
 static gboolean stroke_width_set_unit(SPUnitSelector *,
                                                  SPUnit const *old,
                                                  SPUnit const *new_units,
-                                                 GObject *dlg)
+                                                 GObject *spw)
 {
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
 
@@ -1290,14 +1291,14 @@ static gboolean stroke_width_set_unit(SPUnitSelector *,
 
     GSList const *objects = selection->itemList();
 
-    if ((old->base == SP_UNIT_ABSOLUTE) &&
+    if ((old->base == SP_UNIT_ABSOLUTE || old->base == SP_UNIT_DEVICE) &&
        (new_units->base == SP_UNIT_DIMENSIONLESS)) {
 
         /* Absolute to percentage */
-        g_object_set_data (dlg, "update", GUINT_TO_POINTER (TRUE));
+        g_object_set_data (spw, "update", GUINT_TO_POINTER (TRUE));
 
-        GtkAdjustment *a = GTK_ADJUSTMENT(g_object_get_data (dlg, "width"));
-        float w = sp_units_get_points (a->value, old);
+        GtkAdjustment *a = GTK_ADJUSTMENT(g_object_get_data (spw, "width"));
+        float w = sp_units_get_pixels (a->value, *old);
 
         gdouble average = stroke_average_width (objects);
 
@@ -1306,22 +1307,22 @@ static gboolean stroke_width_set_unit(SPUnitSelector *,
 
         gtk_adjustment_set_value (a, 100.0 * w / average);
 
-        g_object_set_data (dlg, "update", GUINT_TO_POINTER (FALSE));
+        g_object_set_data (spw, "update", GUINT_TO_POINTER (FALSE));
         return TRUE;
 
     } else if ((old->base == SP_UNIT_DIMENSIONLESS) &&
-              (new_units->base == SP_UNIT_ABSOLUTE)) {
+              (new_units->base == SP_UNIT_ABSOLUTE || new_units->base == SP_UNIT_DEVICE)) {
 
         /* Percentage to absolute */
-        g_object_set_data (dlg, "update", GUINT_TO_POINTER (TRUE));
+        g_object_set_data (spw, "update", GUINT_TO_POINTER (TRUE));
 
-        GtkAdjustment *a = GTK_ADJUSTMENT(g_object_get_data (dlg, "width"));
+        GtkAdjustment *a = GTK_ADJUSTMENT(g_object_get_data (spw, "width"));
 
         gdouble average = stroke_average_width (objects);
 
-        gtk_adjustment_set_value (a, sp_points_get_units (0.01 * a->value * average, new_units));
+        gtk_adjustment_set_value (a, sp_pixels_get_units (0.01 * a->value * average, *new_units));
 
-        g_object_set_data (dlg, "update", GUINT_TO_POINTER (FALSE));
+        g_object_set_data (spw, "update", GUINT_TO_POINTER (FALSE));
         return TRUE;
     }
 
@@ -1370,7 +1371,10 @@ sp_stroke_style_line_widget_new(void)
     sp_dialog_defocus_on_enter(sb);
 
     gtk_box_pack_start(GTK_BOX(hb), sb, FALSE, FALSE, 0);
-    us = sp_unit_selector_new(SP_UNIT_ABSOLUTE);
+    us = sp_unit_selector_new(SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE);
+    SPDesktop *desktop = SP_ACTIVE_DESKTOP;
+    if (desktop)
+        sp_unit_selector_set_unit (SP_UNIT_SELECTOR(us), sp_desktop_get_default_unit (desktop));
     sp_unit_selector_add_unit(SP_UNIT_SELECTOR(us), &sp_unit_get_by_id(SP_UNIT_PERCENT), 0);
     g_signal_connect ( G_OBJECT (us), "set_unit", G_CALLBACK (stroke_width_set_unit), spw );
     gtk_widget_show(us);
@@ -1390,30 +1394,24 @@ sp_stroke_style_line_widget_new(void)
 
     tb = NULL;
 
-    char *path = g_build_filename(INKSCAPE_PIXMAPDIR, "/join_miter.xpm", NULL);
     tb = sp_stroke_radio_button(tb, INKSCAPE_STOCK_JOIN_MITER,
-                                path, hb, spw, "join", "miter");
-    g_free(path);
+                                hb, spw, "join", "miter");
 
     // TRANSLATORS: Miter join: joining lines with a sharp (pointed) corner.
     //  For an example, draw a triangle with a large stroke width and modify the
     //  "Join" option (in the Fill and Stroke dialog).
     gtk_tooltips_set_tip(tt, tb, _("Miter join"), NULL);
 
-    path = g_build_filename(INKSCAPE_PIXMAPDIR, "/join_round.xpm", NULL);
     tb = sp_stroke_radio_button(tb, INKSCAPE_STOCK_JOIN_ROUND,
-                                path, hb, spw, "join", "round");
-    g_free(path);
+                                hb, spw, "join", "round");
 
     // TRANSLATORS: Round join: joining lines with a rounded corner.
     //  For an example, draw a triangle with a large stroke width and modify the
     //  "Join" option (in the Fill and Stroke dialog).
     gtk_tooltips_set_tip(tt, tb, _("Round join"), NULL);
 
-    path = g_build_filename(INKSCAPE_PIXMAPDIR, "/join_bevel.xpm", NULL);
     tb = sp_stroke_radio_button(tb, INKSCAPE_STOCK_JOIN_BEVEL,
-                                path, hb, spw, "join", "bevel");
-    g_free(path);
+                                hb, spw, "join", "bevel");
 
     // TRANSLATORS: Bevel join: joining lines with a blunted (flattened) corner.
     //  For an example, draw a triangle with a large stroke width and modify the
@@ -1456,28 +1454,22 @@ sp_stroke_style_line_widget_new(void)
 
     tb = NULL;
 
-    path = g_build_filename(INKSCAPE_PIXMAPDIR, "/cap_butt.xpm", NULL);
     tb = sp_stroke_radio_button(tb, INKSCAPE_STOCK_CAP_BUTT,
-                                path, hb, spw, "cap", "butt");
-    g_free(path);
+                                hb, spw, "cap", "butt");
 
     // TRANSLATORS: Butt cap: the line shape does not extend beyond the end point
     //  of the line; the ends of the line are square
     gtk_tooltips_set_tip(tt, tb, _("Butt cap"), NULL);
 
-    path = g_build_filename(INKSCAPE_PIXMAPDIR, "/cap_round.xpm", NULL);
     tb = sp_stroke_radio_button(tb, INKSCAPE_STOCK_CAP_ROUND,
-                                path, hb, spw, "cap", "round");
-    g_free(path);
+                                hb, spw, "cap", "round");
 
     // TRANSLATORS: Round cap: the line shape extends beyond the end point of the
     //  line; the ends of the line are rounded
     gtk_tooltips_set_tip(tt, tb, _("Round cap"), NULL);
 
-    path = g_build_filename(INKSCAPE_PIXMAPDIR, "/cap_square.xpm", NULL);
     tb = sp_stroke_radio_button(tb, INKSCAPE_STOCK_CAP_SQUARE,
-                                path, hb, spw, "cap", "square");
-    g_free(path);
+                                hb, spw, "cap", "square");
 
     // TRANSLATORS: Square cap: the line shape extends beyond the end point of the
     //  line; the ends of the line are square
@@ -1557,7 +1549,6 @@ sp_stroke_style_line_widget_new(void)
                         GTK_SIGNAL_FUNC(sp_stroke_style_line_attr_changed),
                         NULL );
 
-    SPDesktop *desktop = inkscape_active_desktop();
     sp_stroke_style_line_update( SP_WIDGET(spw), desktop ? SP_DT_SELECTION(desktop) : NULL);
 
     return spw;
@@ -1727,7 +1718,7 @@ sp_stroke_style_line_update(SPWidget *spw, SPSelection *sel)
         sp_unit_selector_set_unit(SP_UNIT_SELECTOR(us), &sp_unit_get_by_id(SP_UNIT_PERCENT));
     } else {
         // only one object; no sense to keep percent, switch to absolute
-        if (unit->base != SP_UNIT_ABSOLUTE) {
+        if (unit->base != SP_UNIT_ABSOLUTE && unit->base != SP_UNIT_DEVICE) {
             // FIXME: use some other default absolute unit
             sp_unit_selector_set_unit(SP_UNIT_SELECTOR(us), &sp_unit_get_by_id(SP_UNIT_PT));
         }
@@ -1735,8 +1726,8 @@ sp_stroke_style_line_update(SPWidget *spw, SPSelection *sel)
 
     unit = sp_unit_selector_get_unit (SP_UNIT_SELECTOR (us));
 
-    if (unit->base == SP_UNIT_ABSOLUTE) {
-        sp_convert_distance(&avgwidth, SP_PS_UNIT, sp_unit_selector_get_unit(SP_UNIT_SELECTOR(us)));
+    if (unit->base == SP_UNIT_ABSOLUTE || unit->base == SP_UNIT_DEVICE) {
+        avgwidth = sp_pixels_get_units (avgwidth, *unit);
         gtk_adjustment_set_value(GTK_ADJUSTMENT(width), avgwidth);
     } else {
         gtk_adjustment_set_value(GTK_ADJUSTMENT(width), 100);
@@ -1818,10 +1809,8 @@ sp_stroke_style_line_update_repr(SPWidget *spw, SPRepr *repr)
         return;
     }
 
-    /* We need points */
-    gdouble swidth = style->stroke_width.computed / 1.25;
     SPUnit const *unit = sp_unit_selector_get_unit(SP_UNIT_SELECTOR(units));
-    sp_convert_distance(&swidth, SP_PS_UNIT, unit);
+    gdouble swidth = sp_pixels_get_units (style->stroke_width.computed, *unit);
     gtk_adjustment_set_value(GTK_ADJUSTMENT(width), swidth);
 
     /* Join */
@@ -1919,10 +1908,10 @@ sp_stroke_style_scale_line(SPWidget *spw)
         for (GSList const *i = items; i != NULL; i = i->next) {
             /* Set stroke width */
             double width;
-            if (unit->base == SP_UNIT_ABSOLUTE) {
-                sp_convert_distance( &width_typed, sp_unit_selector_get_unit(us), SP_PS_UNIT );
+            if (unit->base == SP_UNIT_ABSOLUTE || unit->base == SP_UNIT_DEVICE) {
+                width = sp_units_get_pixels (width_typed, *unit);
                 NR::Matrix i2d = sp_item_i2d_affine (SP_ITEM(i->data));
-                width = width_typed / expansion(i2d);
+                width = width / expansion(i2d);
             } else { // percentage
                 gdouble old_w = SP_OBJECT_STYLE (i->data)->stroke_width.computed;
                 width = old_w * width_typed / 100;
@@ -1948,7 +1937,7 @@ sp_stroke_style_scale_line(SPWidget *spw)
 
         g_free(dash);
 
-        if (unit->base != SP_UNIT_ABSOLUTE) {
+        if (unit->base != SP_UNIT_ABSOLUTE && unit->base != SP_UNIT_DEVICE) {
             // reset to 100 percent
             gtk_adjustment_set_value (wadj, 100.0);
         }
