@@ -16,15 +16,11 @@
 #include <gtk/gtkwidget.h>
 
 #include "forward.h"
-#include "helper/canvas-bpath.h"
+#include "display/canvas-bpath.h"
 
 GtkWidget *sp_stroke_style_paint_widget_new (void);
 GtkWidget *sp_stroke_style_line_widget_new (void);
 
-void sp_stroke_style_paint_system_color_set ( GtkWidget *widget, 
-                                              SPColor *color, 
-                                              float opacity );
-
 #endif
 
 /*
