@@ -6,7 +6,7 @@
  *   Bob Jamison
  *   Other dudes from The Inkscape Organization
  *
- * Copyright (C) 2004 The Inkscape Organization
+ * Copyright (C) 2004 Bob Jamison
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
@@ -27,7 +27,7 @@
 
 #include <dialogs/dialog-events.h>
 #include <gtk/gtkdialog.h> //for GTK_RESPONSE* types
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "interface.h"
 #include "verbs.h"
 #include "prefs-utils.h"
@@ -36,12 +36,9 @@
 
 #include <glib.h>
 
-namespace Inkscape
-{
-namespace UI
-{
-namespace Dialogs
-{
+namespace Inkscape {
+namespace UI {
+namespace Dialogs {
 
 
 //#########################################################################
@@ -92,7 +89,7 @@ class TraceDialogImpl : public TraceDialog, public Gtk::Dialog
     /**
      * This is the big almighty McGuffin
      */
-    Inkscape::Trace tracer;
+    Inkscape::Trace::Tracer tracer;
 
     /**
      * This does potrace processing
@@ -108,12 +105,13 @@ class TraceDialogImpl : public TraceDialog, public Gtk::Dialog
     void potracePreviewCallback();
 
     Gtk::Notebook   notebook;
+    Gtk::Tooltips   tips;
 
     //########## Potrace items
     Gtk::VBox             potraceBox;
     Gtk::RadioButtonGroup potraceGroup;
-    Gtk::CheckButton     potraceInvertButton;
-    Gtk::HBox               potraceInvertBox;
+    Gtk::CheckButton      potraceInvertButton;
+    Gtk::HBox             potraceInvertBox;
     Gtk::Button           *potraceOkButton;
     Gtk::Button           *potraceCancelButton;
 
@@ -125,6 +123,7 @@ class TraceDialogImpl : public TraceDialog, public Gtk::Dialog
     Gtk::Label            potraceBrightnessSpinnerLabel;
     Gtk::SpinButton       potraceBrightnessSpinner;
 
+
     //edge detection
     Gtk::Frame            potraceCannyFrame;
     Gtk::HBox             potraceCannyBox;
@@ -144,6 +143,25 @@ class TraceDialogImpl : public TraceDialog, public Gtk::Dialog
     Gtk::Label            potraceQuantNrColorLabel;
     Gtk::SpinButton       potraceQuantNrColorSpinner;
 
+    //multiple path scanning
+    Gtk::Frame            potraceMultiScanFrame;
+    Gtk::VBox             potraceMultiScanVBox;
+
+    Gtk::HBox             potraceMultiScanHBox1;
+    Gtk::RadioButton      potraceMultiScanBrightnessRadioButton;
+    Gtk::SpinButton       potraceMultiScanNrColorSpinner;
+
+    Gtk::HBox             potraceMultiScanHBox2;
+    Gtk::RadioButton      potraceMultiScanColorRadioButton;
+    Gtk::CheckButton      potraceMultiScanStackButton;
+
+    Gtk::HBox             potraceMultiScanHBox3;
+    Gtk::RadioButton      potraceMultiScanMonoRadioButton;
+    Gtk::Label            potraceMultiScanNrColorLabel;
+
+    Gtk::CheckButton      potraceMultiScanSmoothButton;
+
+
     //preview
     Gtk::Frame            potracePreviewFrame;
     Gtk::HBox             potracePreviewBox;
@@ -176,21 +194,38 @@ class TraceDialogImpl : public TraceDialog, public Gtk::Dialog
 void TraceDialogImpl::potraceProcess(bool do_i_trace)
 {
     //##### Get the tracer and engine
-    Inkscape::Potrace::PotraceTracingEngine pte;
+    Inkscape::Trace::Potrace::PotraceTracingEngine pte;
 
-    //##### Get the settings
+    /* inversion */
+    bool invert = potraceInvertButton.get_active();
+    pte.setInvert(invert);
+
+    //##### Get the single-scan settings
     /* which one? */
-    pte.setUseBrightness(potraceBrightnessRadioButton.get_active());
-    pte.setUseCanny(potraceCannyRadioButton.get_active());
-    pte.setUseQuantization(potraceQuantRadioButton.get_active());
+    if (potraceBrightnessRadioButton.get_active())
+        pte.setTraceType(Inkscape::Trace::Potrace::TRACE_BRIGHTNESS);
+    else if (potraceMultiScanBrightnessRadioButton.get_active())
+        pte.setTraceType(Inkscape::Trace::Potrace::TRACE_BRIGHTNESS_MULTI);
+    else if (potraceCannyRadioButton.get_active())
+        pte.setTraceType(Inkscape::Trace::Potrace::TRACE_CANNY);
+    else if (potraceQuantRadioButton.get_active())
+        pte.setTraceType(Inkscape::Trace::Potrace::TRACE_QUANT);
+    else if (potraceMultiScanColorRadioButton.get_active())
+        {
+        pte.setTraceType(Inkscape::Trace::Potrace::TRACE_QUANT_COLOR);
+        pte.setInvert(false);
+        }
+    else if (potraceMultiScanMonoRadioButton.get_active())
+        {
+        pte.setTraceType(Inkscape::Trace::Potrace::TRACE_QUANT_MONO);
+        pte.setInvert(false);
+        }
 
     /* brightness */
     double brightnessThreshold = potraceBrightnessSpinner.get_value();
     pte.setBrightnessThreshold(brightnessThreshold);
 
     /* canny */
-    //double cannyLowThreshold = potraceCannyLoSpinner.get_value();
-    //pte.setCannyLowThreshold(cannyLowThreshold);
     double cannyHighThreshold = potraceCannyHiSpinner.get_value();
     pte.setCannyHighThreshold(cannyHighThreshold);
 
@@ -198,9 +233,13 @@ void TraceDialogImpl::potraceProcess(bool do_i_trace)
     int quantNrColors = potraceQuantNrColorSpinner.get_value_as_int();
     pte.setQuantizationNrColors(quantNrColors);
 
-    /* inversion */
-    bool invert = potraceInvertButton.get_active();
-    pte.setInvert(invert);
+    //##### Get multiple-scan settings
+    int multiScanNrColors = potraceMultiScanNrColorSpinner.get_value_as_int();
+    pte.setMultiScanNrColors(multiScanNrColors);
+    bool do_i_stack = potraceMultiScanStackButton.get_active();
+    pte.setMultiScanStack(do_i_stack);
+    bool do_i_smooth = potraceMultiScanSmoothButton.get_active();
+    pte.setMultiScanSmooth(do_i_smooth);
 
     //##### Get intermediate bitmap image
     GdkPixbuf *pixbuf = tracer.getSelectedImage();
@@ -230,7 +269,7 @@ void TraceDialogImpl::potraceProcess(bool do_i_trace)
             potraceCancelButton->set_sensitive(true);
         if (potraceOkButton)
             potraceOkButton->set_sensitive(false);
-        tracer.convertImageToPath(&pte);
+        tracer.trace(&pte);
         if (potraceCancelButton)
             potraceCancelButton->set_sensitive(false);
         if (potraceOkButton)
@@ -357,12 +396,14 @@ TraceDialogImpl::TraceDialogImpl()
     potraceBrightnessRadioButton.set_label(_("Brightness"));
     potraceGroup = potraceBrightnessRadioButton.get_group();
     potraceBrightnessBox.pack_start(potraceBrightnessRadioButton, false, false, MARGIN);
+    tips.set_tip(potraceBrightnessRadioButton, _("Trace by a given brightness level"));
 
     potraceBrightnessSpinner.set_digits(3);
     potraceBrightnessSpinner.set_increments(0.01, 0.1);
     potraceBrightnessSpinner.set_range(0.0, 1.0);
     potraceBrightnessSpinner.set_value(0.45);
     potraceBrightnessBox.pack_end(potraceBrightnessSpinner, false, false, MARGIN);
+    tips.set_tip(potraceBrightnessSpinner, _("Brightness cutoff for black/white"));
 
     potraceBrightnessSpinnerLabel.set_label(_("Threshold:"));
     potraceBrightnessBox.pack_end(potraceBrightnessSpinnerLabel, false, false, MARGIN);
@@ -379,6 +420,7 @@ TraceDialogImpl::TraceDialogImpl()
     potraceCannyRadioButton.set_label(_("Optimal Edge Detection (Canny)"));
     potraceCannyRadioButton.set_group(potraceGroup);
     potraceCannyBox.pack_start(potraceCannyRadioButton, false, false, MARGIN);
+    tips.set_tip(potraceCannyRadioButton, _("Trace with edge detection by J. Canny's algorithm"));
     /*
     potraceCannyBox.pack_start(potraceCannySeparator);
     potraceCannyLoSpinnerLabel.set_label(_("Low"));
@@ -394,6 +436,7 @@ TraceDialogImpl::TraceDialogImpl()
     potraceCannyHiSpinner.set_range(0.0, 1.0);
     potraceCannyHiSpinner.set_value(0.65);
     potraceCannyBox.pack_end(potraceCannyHiSpinner, false, false, MARGIN);
+    tips.set_tip(potraceCannyHiSpinner, _("Brightness cutoff for adjacent pixels (determines edge thickness)"));
 
     potraceCannyHiSpinnerLabel.set_label(_("Threshold:"));
     potraceCannyBox.pack_end(potraceCannyHiSpinnerLabel, false, false, MARGIN);
@@ -412,12 +455,14 @@ TraceDialogImpl::TraceDialogImpl()
     potraceQuantRadioButton.set_label(_("Color Quantization"));
     potraceQuantRadioButton.set_group(potraceGroup);
     potraceQuantBox.pack_start(potraceQuantRadioButton, false, false, MARGIN);
+    tips.set_tip(potraceQuantRadioButton, _("Trace along the boundaries of reduced colors"));
 
     potraceQuantNrColorSpinner.set_digits(2);
     potraceQuantNrColorSpinner.set_increments(1.0, 4.0);
     potraceQuantNrColorSpinner.set_range(2.0, 64.0);
     potraceQuantNrColorSpinner.set_value(8.0);
     potraceQuantBox.pack_end(potraceQuantNrColorSpinner, false, false, MARGIN);
+    tips.set_tip(potraceQuantNrColorSpinner, _("The number of reduced colors"));
 
     potraceQuantNrColorLabel.set_label(_("Colors:"));
     potraceQuantBox.pack_end(potraceQuantNrColorLabel, false, false, MARGIN);
@@ -429,11 +474,66 @@ TraceDialogImpl::TraceDialogImpl()
     potraceQuantFrame.add(potraceQuantVBox);
     potraceBox.pack_start(potraceQuantFrame, false, false, 0);
   
+    /*#### Multiple scanning####*/
+    //----Hbox1
+    potraceMultiScanBrightnessRadioButton.set_label(_("Brightness"));
+    potraceMultiScanBrightnessRadioButton.set_group(potraceGroup);
+    potraceMultiScanHBox1.pack_start(potraceMultiScanBrightnessRadioButton, false, false, MARGIN);
+    tips.set_tip(potraceMultiScanBrightnessRadioButton, _("Trace the given number of brightness levels"));
+
+    potraceMultiScanNrColorSpinner.set_digits(2);
+    potraceMultiScanNrColorSpinner.set_increments(1.0, 4.0);
+    potraceMultiScanNrColorSpinner.set_range(2.0, 64.0);
+    potraceMultiScanNrColorSpinner.set_value(8.0);
+    potraceMultiScanHBox1.pack_end(potraceMultiScanNrColorSpinner, false, false, MARGIN);
+    potraceMultiScanNrColorLabel.set_label(_("Scans:"));
+    potraceMultiScanHBox1.pack_end(potraceMultiScanNrColorLabel, false, false, MARGIN);
+    tips.set_tip(potraceMultiScanNrColorSpinner, _("The desired number of scans"));
+
+    potraceMultiScanVBox.pack_start(potraceMultiScanHBox1, false, false, MARGIN);
+
+    //----Hbox2
+    potraceMultiScanColorRadioButton.set_label(_("Color"));
+    potraceMultiScanColorRadioButton.set_group(potraceGroup);
+    potraceMultiScanHBox2.pack_start(potraceMultiScanColorRadioButton, false, false, MARGIN);
+    tips.set_tip(potraceMultiScanColorRadioButton, _("Trace the given number of reduced colors"));
+
+
+    potraceMultiScanVBox.pack_start(potraceMultiScanHBox2, false, false, MARGIN);
+
+    //---Hbox3
+    potraceMultiScanMonoRadioButton.set_label(_("Monochrome"));
+    potraceMultiScanMonoRadioButton.set_group(potraceGroup);
+    potraceMultiScanHBox3.pack_start(potraceMultiScanMonoRadioButton, false, false, MARGIN);
+    tips.set_tip(potraceMultiScanMonoRadioButton, _("Same as Color, but convert result to grayscale"));
+
+    // TRANSLATORS: "Stack" is a verb here
+    potraceMultiScanStackButton.set_label(_("Stack"));
+    potraceMultiScanStackButton.set_active(true);
+    potraceMultiScanHBox3.pack_end(potraceMultiScanStackButton, false, false, MARGIN);
+    tips.set_tip(potraceMultiScanStackButton, _("Stack scans vertically (no gaps) or tile horizontally (usually with gaps)"));
+
+    // TRANSLATORS: "Smooth" is a verb here
+    potraceMultiScanSmoothButton.set_label(_("Smooth"));
+    potraceMultiScanSmoothButton.set_active(true);
+    potraceMultiScanHBox3.pack_end(potraceMultiScanSmoothButton, false, false, MARGIN);
+    tips.set_tip(potraceMultiScanSmoothButton, _("Apply Gaussian blur to the bitmap before tracing"));
+
+    potraceMultiScanVBox.pack_start(potraceMultiScanHBox3, false, false, MARGIN);
+
+    potraceMultiScanFrame.set_label(_("Multiple Scanning"));
+    //potraceQuantFrame.set_shadow_type(Gtk::SHADOW_NONE);
+    potraceMultiScanFrame.add(potraceMultiScanVBox);
+    potraceBox.pack_start(potraceMultiScanFrame, false, false, 0);
+  
     /*#### Preview ####*/
     potracePreviewButton.set_label(_("Preview"));
     potracePreviewButton.signal_clicked().connect( 
          sigc::mem_fun(*this, &TraceDialogImpl::potracePreviewCallback) );
     potracePreviewBox.pack_end(potracePreviewButton, false, false, 0);//do not expand
+    tips.set_tip(potracePreviewButton, _("Preview the result without actual tracing"));
+
+
     potracePreviewImage.set_size_request(100,100);
     //potracePreviewImage.set_alignment (Gtk::ALIGN_CENTER, Gtk::ALIGN_CENTER);
     potracePreviewBox.pack_start(potracePreviewImage, true, true, 0);
@@ -442,15 +542,16 @@ TraceDialogImpl::TraceDialogImpl()
     potracePreviewFrame.add(potracePreviewBox);
     potraceBox.pack_start(potracePreviewFrame, true, true, 0);
 
-    /*#### quantization ####*/
+    /*#### swap black and white ####*/
     potraceInvertButton.set_label(_("Invert"));
     potraceInvertButton.set_active(false);
     potraceInvertBox.pack_end(potraceInvertButton, false, false, MARGIN);
     potraceBox.pack_start(potraceInvertBox, false, false, MARGIN);
+    tips.set_tip(potraceInvertButton, _("Invert black and white regions for single traces"));
 
     /*#### Credits ####*/
     potraceCreditsLabel.set_text(
-         "Thanks to Peter Selinger, http://potrace.sourceforge.net"
+							 _("Thanks to Peter Selinger, http://potrace.sourceforge.net")
                          );
     potraceCreditsVBox.pack_start(potraceCreditsLabel, false, false, MARGIN);
     potraceCreditsFrame.set_label(_("Credits"));
@@ -473,8 +574,12 @@ TraceDialogImpl::TraceDialogImpl()
     //## The OK button
     potraceCancelButton = add_button(Gtk::Stock::STOP, GTK_RESPONSE_CANCEL);
     if (potraceCancelButton)
+        {
+        tips.set_tip((*potraceCancelButton), _("Abort a trace in progress"));
         potraceCancelButton->set_sensitive(false);
+        }
     potraceOkButton     = add_button(Gtk::Stock::OK,   GTK_RESPONSE_OK);
+    tips.set_tip((*potraceOkButton), _("Execute the trace"));
 
     show_all_children();
 
