@@ -13,14 +13,9 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <trace/trace.h>
-
-namespace Inkscape
-{
-namespace UI
-{
-namespace Dialogs
-{
+namespace Inkscape {
+namespace UI {
+namespace Dialogs {
 
 
 /**
@@ -29,13 +24,13 @@ namespace Dialogs
 class TraceDialog
 {
 
-    public:
+public:
     
 
     /**
      * Constructor
      */
-    TraceDialog() { trace = NULL; };
+    TraceDialog() {  };
 
 
     /**
@@ -69,17 +64,6 @@ class TraceDialog
      */
     static void showInstance();
 
-
-    void setTrace(Inkscape::Trace *val)
-        { trace = val; }
-
-    Inkscape::Trace *getTrace()
-        { return trace; }
-
-    private:
-
-    Inkscape::Trace *trace;
-
 };
 
 
