@@ -32,7 +32,7 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtkarrow.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/window.h"
 #include "macros.h"
 #include "../inkscape.h"
@@ -46,13 +46,13 @@
 #include "../sp-defs.h"
 #include "in-dt-coordsys.h"
 
-#include "../xml/repr-private.h"
 
 #include "../widgets/sp-xmlview-tree.h"
 #include "../widgets/sp-xmlview-content.h"
 #include "../widgets/sp-xmlview-attr-list.h"
 
 #include "../inkscape-stock.h"
+#include "widgets/icon.h"
 
 #include "dialog-events.h"
 #include "../prefs-utils.h"
@@ -299,8 +299,8 @@ sp_xml_tree_dialog (void)
                 NULL,
                 _("New element node"),
                 NULL,
-                gtk_image_new_from_stock ( INKSCAPE_STOCK_ADD_XML_ELEMENT_NODE,
-                                        GTK_ICON_SIZE_LARGE_TOOLBAR ),
+                sp_icon_new_scaled( SP_ICON_SIZE_NOTEBOOK, 
+                                    INKSCAPE_STOCK_ADD_XML_ELEMENT_NODE ),
                 G_CALLBACK (cmd_new_element_node),
                 NULL);
 
@@ -320,8 +320,8 @@ sp_xml_tree_dialog (void)
 
         button = gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
                 NULL, _("New text node"), NULL,
-                gtk_image_new_from_stock ( INKSCAPE_STOCK_ADD_XML_TEXT_NODE,
-                                           GTK_ICON_SIZE_LARGE_TOOLBAR ),
+                sp_icon_new_scaled( SP_ICON_SIZE_NOTEBOOK, 
+                             INKSCAPE_STOCK_ADD_XML_TEXT_NODE ),
                 G_CALLBACK (cmd_new_text_node),
                 NULL);
 
@@ -341,8 +341,8 @@ sp_xml_tree_dialog (void)
 
         button = gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
                 NULL, _("Duplicate node"), NULL,
-                gtk_image_new_from_stock ( INKSCAPE_STOCK_DUPLICATE_XML_NODE,
-                                           GTK_ICON_SIZE_LARGE_TOOLBAR ),
+                sp_icon_new_scaled( SP_ICON_SIZE_NOTEBOOK, 
+                             INKSCAPE_STOCK_DUPLICATE_XML_NODE ),
                 G_CALLBACK (cmd_duplicate_node),
                 NULL);
 
@@ -362,8 +362,8 @@ sp_xml_tree_dialog (void)
 
         button = gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
                 NULL, _("Delete node"), NULL,
-                gtk_image_new_from_stock ( INKSCAPE_STOCK_DELETE_XML_NODE,
-                                           GTK_ICON_SIZE_LARGE_TOOLBAR ),
+                sp_icon_new_scaled( SP_ICON_SIZE_NOTEBOOK, 
+                             INKSCAPE_STOCK_DELETE_XML_NODE ),
                                            G_CALLBACK (cmd_delete_node), NULL );
 
         gtk_signal_connect_while_alive (GTK_OBJECT (tree), "tree_select_row",
@@ -462,8 +462,8 @@ sp_xml_tree_dialog (void)
 
         button = gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
                 NULL, _("Delete attribute"), NULL,
-                gtk_image_new_from_stock (INKSCAPE_STOCK_DELETE_XML_ATTRIBUTE,
-                GTK_ICON_SIZE_LARGE_TOOLBAR),
+                sp_icon_new_scaled( SP_ICON_SIZE_NOTEBOOK, 
+                             INKSCAPE_STOCK_DELETE_XML_ATTRIBUTE ),
                 (GCallback) cmd_delete_attr, NULL);
 
         gtk_signal_connect_while_alive (GTK_OBJECT (attributes), "select_row",
@@ -764,13 +764,13 @@ set_tree_select (SPRepr * repr)
 void
 propagate_tree_select (SPRepr * repr)
 {
-    if (repr && SP_REPR_TYPE (repr) == SP_XML_ELEMENT_NODE) {
+    if (repr && repr->type() == SP_XML_ELEMENT_NODE) {
         sp_xmlview_attr_list_set_repr (attributes, repr);
     } else {
         sp_xmlview_attr_list_set_repr (attributes, NULL);
     }
 
-    if (repr && ( SP_REPR_TYPE (repr) == SP_XML_TEXT_NODE || SP_REPR_TYPE (repr) == SP_XML_COMMENT_NODE ) ) {
+    if (repr && ( repr->type() == SP_XML_TEXT_NODE || repr->type() == SP_XML_COMMENT_NODE ) ) {
         sp_xmlview_content_set_repr (content, repr);
     } else {
         sp_xmlview_content_set_repr (content, NULL);
@@ -799,7 +799,7 @@ set_dt_select (SPRepr *repr)
 
     SPObject *object;
     if (repr) {
-        while ( ( SP_REPR_TYPE(repr) != SP_XML_ELEMENT_NODE )
+        while ( ( repr->type() != SP_XML_ELEMENT_NODE )
                 && sp_repr_parent(repr) )
         {
             repr = sp_repr_parent(repr);
@@ -964,7 +964,7 @@ on_tree_select_row_enable_if_element ( GtkCTree * tree,
     SPRepr * repr;
     repr = sp_xmlview_tree_node_get_repr (SP_XMLVIEW_TREE (tree), node);
 
-    if (SP_REPR_TYPE (repr) == SP_XML_ELEMENT_NODE) {
+    if (repr->type() == SP_XML_ELEMENT_NODE) {
         gtk_widget_set_sensitive (GTK_WIDGET (data), TRUE);
     } else {
         gtk_widget_set_sensitive (GTK_WIDGET (data), FALSE);
@@ -980,7 +980,7 @@ on_tree_select_row_show_if_element ( GtkCTree * tree, GtkCTreeNode * node,
     SPRepr * repr;
     repr = sp_xmlview_tree_node_get_repr (SP_XMLVIEW_TREE (tree), node);
 
-    if (SP_REPR_TYPE (repr) == SP_XML_ELEMENT_NODE) {
+    if (repr->type() == SP_XML_ELEMENT_NODE) {
         gtk_widget_show (GTK_WIDGET (data));
     } else {
         gtk_widget_hide (GTK_WIDGET (data));
@@ -996,7 +996,7 @@ on_tree_select_row_show_if_text ( GtkCTree * tree, GtkCTreeNode * node,
     SPRepr * repr;
     repr = sp_xmlview_tree_node_get_repr (SP_XMLVIEW_TREE (tree), node);
 
-    if ( SP_REPR_TYPE (repr) == SP_XML_TEXT_NODE || SP_REPR_TYPE (repr) == SP_XML_COMMENT_NODE ) {
+    if ( repr->type() == SP_XML_TEXT_NODE || repr->type() == SP_XML_COMMENT_NODE ) {
         gtk_widget_show (GTK_WIDGET (data));
     } else {
         gtk_widget_hide (GTK_WIDGET (data));
@@ -1022,7 +1022,7 @@ xml_tree_node_mutable ( GtkCTreeNode * node )
     g_assert (repr);
 
     // don't let "defs" or "namedview" disappear
-    if ( !strcmp(sp_repr_name(repr),"defs") ||
+    if ( !strcmp(sp_repr_name(repr),"svg:defs") ||
          !strcmp(sp_repr_name(repr),"sodipodi:namedview") ) {
         return false;
     }
@@ -1161,6 +1161,9 @@ on_attr_select_row_set_value_content ( GtkCList *list, gint row, gint column,
     tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW (data));
     name = g_quark_to_string (sp_xmlview_attr_list_get_row_key (list, row));
     value = sp_repr_attr (selected_repr, name);
+    if (!value) {
+        value = "";
+    }
     gtk_text_buffer_set_text (tb, value, strlen (value));
 }
 
@@ -1175,15 +1178,16 @@ on_tree_select_row_enable_if_indentable ( GtkCTree * tree, GtkCTreeNode * node,
         SPRepr * repr, * prev;
         repr = sp_xmlview_tree_node_get_repr (SP_XMLVIEW_TREE (tree), node);
 
-        if ( repr->parent && repr != repr->parent->children ) {
-            g_assert (repr->parent->children);
+        SPRepr *parent=repr->parent();
+        if ( parent && repr != parent->firstChild() ) {
+            g_assert (parent->firstChild());
 
             // skip to the child just before the current repr
-            for ( prev = repr->parent->children ;
-                  prev && prev->next != repr ;
-                  prev = prev->next );
+            for ( prev = parent->firstChild() ;
+                  prev && prev->next() != repr ;
+                  prev = prev->next() );
 
-            if (prev && SP_REPR_TYPE (prev) == SP_XML_ELEMENT_NODE) {
+            if (prev && prev->type() == SP_XML_ELEMENT_NODE) {
                 indentable = TRUE;
             }
         }
@@ -1203,7 +1207,8 @@ on_tree_select_row_enable_if_not_first_child ( GtkCTree * tree,
     SPRepr * repr;
     repr = sp_xmlview_tree_node_get_repr (SP_XMLVIEW_TREE (tree), node);
 
-    if ( repr->parent && repr != repr->parent->children ) {
+    SPRepr *parent=repr->parent();
+    if ( parent && repr != parent->firstChild() ) {
         gtk_widget_set_sensitive (GTK_WIDGET (data), TRUE);
     } else {
         gtk_widget_set_sensitive (GTK_WIDGET (data), FALSE);
@@ -1220,7 +1225,8 @@ on_tree_select_row_enable_if_not_last_child ( GtkCTree * tree,
     SPRepr * repr;
     repr = sp_xmlview_tree_node_get_repr (SP_XMLVIEW_TREE (tree), node);
 
-    if ( repr->parent && repr->parent->parent && repr->next ) {
+    SPRepr *parent=repr->parent();
+    if ( parent && parent->parent() && repr->next() ) {
         gtk_widget_set_sensitive (GTK_WIDGET (data), TRUE);
     } else {
         gtk_widget_set_sensitive (GTK_WIDGET (data), FALSE);
@@ -1523,13 +1529,13 @@ cmd_raise_node (GtkObject * object, gpointer data)
 
     parent = sp_repr_parent (selected_repr);
     g_return_if_fail (parent != NULL);
-    g_return_if_fail (parent->children != selected_repr);
+    g_return_if_fail (parent->firstChild() != selected_repr);
 
     ref = NULL;
-    before = parent->children;
-    while (before && before->next != selected_repr) {
+    before = parent->firstChild() ;
+    while (before && before->next() != selected_repr) {
         ref = before;
-        before = before->next;
+        before = before->next();
     }
 
     sp_repr_change_order (parent, selected_repr, ref);
@@ -1547,10 +1553,10 @@ cmd_lower_node (GtkObject * object, gpointer data)
 {
     SPRepr * parent;
     g_assert (selected_repr != NULL);
-    g_return_if_fail (selected_repr->next != NULL);
+    g_return_if_fail (selected_repr->next() != NULL);
     parent = sp_repr_parent (selected_repr);
 
-    sp_repr_change_order (parent, selected_repr, selected_repr->next);
+    sp_repr_change_order (parent, selected_repr, selected_repr->next());
 
     sp_document_done (current_document);
 
@@ -1570,17 +1576,17 @@ cmd_indent_node (GtkObject * object, gpointer data)
     g_assert (repr != NULL);
     parent = sp_repr_parent (repr);
     g_return_if_fail (parent != NULL);
-    g_return_if_fail (parent->children != repr);
+    g_return_if_fail (parent->firstChild() != repr);
 
-    prev = parent->children;
-    while (prev && prev->next != repr) {
-        prev = prev->next;
+    prev = parent->firstChild();
+    while (prev && prev->next() != repr) {
+        prev = prev->next();
     }
     g_return_if_fail (prev != NULL);
-    g_return_if_fail (SP_REPR_TYPE (prev) == SP_XML_ELEMENT_NODE);
+    g_return_if_fail (prev->type() == SP_XML_ELEMENT_NODE);
 
-    if (prev->children) {
-        for ( ref = prev->children ; ref->next ; ref = ref->next );
+    if (prev->firstChild()) {
+        for ( ref = prev->firstChild() ; ref->next() ; ref = ref->next() );
     } else {
         ref = NULL;
     }
