@@ -15,13 +15,14 @@
 #include <string.h>
 #include <libnr/nr-blit.h>
 #include <gtk/gtksignal.h>
-#include "../helper/sp-canvas.h"
-#include "../helper/sp-canvas-util.h"
-#include "../helper/sp-marshal.h"
-#include "nr-arena.h"
-#include "nr-arena-group.h"
-#include "canvas-arena.h"
-#include "../prefs-utils.h"
+
+#include <display/sp-canvas.h>
+#include <display/sp-canvas-util.h>
+#include <helper/sp-marshal.h>
+#include <display/nr-arena.h>
+#include <display/nr-arena-group.h>
+#include <display/canvas-arena.h>
+#include <prefs-utils.h>
 
 enum {
 	ARENA_EVENT,
@@ -34,9 +35,9 @@ static void sp_canvas_arena_class_init(SPCanvasArenaClass *klass);
 static void sp_canvas_arena_init(SPCanvasArena *group);
 static void sp_canvas_arena_destroy(GtkObject *object);
 
-static void sp_canvas_arena_update (SPCanvasItem *item, double *affine, unsigned int flags);
+static void sp_canvas_arena_update (SPCanvasItem *item, NR::Matrix const &affine, unsigned int flags);
 static void sp_canvas_arena_render (SPCanvasItem *item, SPCanvasBuf *buf);
-static double sp_canvas_arena_point (SPCanvasItem *item, double x, double y, SPCanvasItem **actual_item);
+static double sp_canvas_arena_point (SPCanvasItem *item, NR::Point p, SPCanvasItem **actual_item);
 static gint sp_canvas_arena_event (SPCanvasItem *item, GdkEvent *event);
 
 static gint sp_canvas_arena_send_event (SPCanvasArena *arena, GdkEvent *event);
@@ -104,10 +105,14 @@ sp_canvas_arena_init (SPCanvasArena *arena)
 {
 	arena->sticky = FALSE;
 
-	arena->arena = (NRArena *) nr_object_new (NR_TYPE_ARENA);
-	arena->root = nr_arena_item_new (arena->arena, NR_TYPE_ARENA_GROUP);
+	arena->arena = NRArena::create();
+	arena->root = NRArenaGroup::create(arena->arena);
 	nr_arena_group_set_transparent (NR_ARENA_GROUP (arena->root), TRUE);
 
+#ifdef arena_item_tile_cache
+  arena->root->skipCaching=true;
+#endif
+  
 	arena->active = NULL;
 
 	nr_active_object_add_listener ((NRActiveObject *) arena->arena, (NRObjectEventVector *) &carenaev, sizeof (carenaev), arena);
@@ -116,9 +121,7 @@ sp_canvas_arena_init (SPCanvasArena *arena)
 static void
 sp_canvas_arena_destroy (GtkObject *object)
 {
-	SPCanvasArena *arena;
-
-	arena = SP_CANVAS_ARENA (object);
+	SPCanvasArena *arena = SP_CANVAS_ARENA (object);
 
 	if (arena->active) {
 		nr_object_unref ((NRObject *) arena->active);
@@ -142,23 +145,17 @@ sp_canvas_arena_destroy (GtkObject *object)
 }
 
 static void
-sp_canvas_arena_update (SPCanvasItem *item, double *affine, unsigned int flags)
+sp_canvas_arena_update (SPCanvasItem *item, NR::Matrix const &affine, unsigned int flags)
 {
-	SPCanvasArena *arena;
-	guint reset;
-
-	arena = SP_CANVAS_ARENA (item);
+	SPCanvasArena *arena = SP_CANVAS_ARENA (item);
 
 	if (((SPCanvasItemClass *) parent_class)->update)
 		(* ((SPCanvasItemClass *) parent_class)->update) (item, affine, flags);
 
-	memcpy (NR_MATRIX_D_TO_DOUBLE (&arena->gc.transform), affine, 6 * sizeof (double));
+	arena->gc.transform = affine;
 
-	if (flags & SP_CANVAS_UPDATE_AFFINE) {
-		reset = NR_ARENA_ITEM_STATE_ALL;
-	} else {
-		reset = NR_ARENA_ITEM_STATE_NONE;
-	}
+	guint reset;
+	reset = (flags & SP_CANVAS_UPDATE_AFFINE)? NR_ARENA_ITEM_STATE_ALL : NR_ARENA_ITEM_STATE_NONE;
 
 	nr_arena_item_invoke_update (arena->root, NULL, &arena->gc, NR_ARENA_ITEM_STATE_ALL, reset);
 
@@ -168,17 +165,16 @@ sp_canvas_arena_update (SPCanvasItem *item, double *affine, unsigned int flags)
 	item->y2 = arena->root->bbox.y1 + 1;
 
 	if (arena->cursor) {
-		NRArenaItem *new_arena;
 		/* Mess with enter/leave notifiers */
-		new_arena = nr_arena_item_invoke_pick (arena->root, arena->cx, arena->cy, nr_arena_global_delta, arena->sticky);
+		NRArenaItem *new_arena = nr_arena_item_invoke_pick (arena->root, arena->c, nr_arena_global_delta, arena->sticky);
 		if (new_arena != arena->active) {
 			GdkEventCrossing ec;
 			ec.window = GTK_WIDGET (item->canvas)->window;
 			ec.send_event = TRUE;
 			ec.subwindow = ec.window;
 			ec.time = GDK_CURRENT_TIME;
-			ec.x = arena->cx;
-			ec.y = arena->cy;
+			ec.x = arena->c[NR::X];
+			ec.y = arena->c[NR::Y];
 			/* fixme: */
 			if (arena->active) {
 				ec.type = GDK_LEAVE_NOTIFY;
@@ -196,14 +192,17 @@ sp_canvas_arena_update (SPCanvasItem *item, double *affine, unsigned int flags)
 	}
 }
 
+#ifdef arena_item_tile_cache
+extern void age_cache(void);
+#endif
+
 static void
 sp_canvas_arena_render (SPCanvasItem *item, SPCanvasBuf *buf)
 {
-	SPCanvasArena *arena;
 	gint bw, bh, sw, sh;
 	gint x, y;
 
-	arena = SP_CANVAS_ARENA (item);
+	SPCanvasArena *arena = SP_CANVAS_ARENA (item);
 
 	nr_arena_item_invoke_update (arena->root, NULL, &arena->gc,
 				     NR_ARENA_ITEM_STATE_BBOX | NR_ARENA_ITEM_STATE_RENDER,
@@ -214,7 +213,10 @@ sp_canvas_arena_render (SPCanvasItem *item, SPCanvasBuf *buf)
 		buf->is_bg = FALSE;
 		buf->is_buf = TRUE;
 	}
-
+  
+#ifdef arena_item_tile_cache
+  age_cache();
+#endif
 	bw = buf->rect.x1 - buf->rect.x0;
 	bh = buf->rect.y1 - buf->rect.y0;
 	if ((bw < 1) || (bh < 1)) return;
@@ -279,18 +281,15 @@ sp_canvas_arena_render (SPCanvasItem *item, SPCanvasBuf *buf)
 }
 
 static double
-sp_canvas_arena_point (SPCanvasItem *item, double x, double y, SPCanvasItem **actual_item)
+sp_canvas_arena_point (SPCanvasItem *item, NR::Point p, SPCanvasItem **actual_item)
 {
-	SPCanvasArena *arena;
-	NRArenaItem *picked;
-
-	arena = SP_CANVAS_ARENA (item);
+	SPCanvasArena *arena = SP_CANVAS_ARENA (item);
 
 	nr_arena_item_invoke_update (arena->root, NULL, &arena->gc,
 				     NR_ARENA_ITEM_STATE_BBOX | NR_ARENA_ITEM_STATE_PICK,
 				     NR_ARENA_ITEM_STATE_NONE);
 
-	picked = nr_arena_item_invoke_pick (arena->root, x, y, nr_arena_global_delta, arena->sticky);
+	NRArenaItem *picked = nr_arena_item_invoke_pick (arena->root, p, nr_arena_global_delta, arena->sticky);
 
 	arena->picked = picked;
 
@@ -305,14 +304,12 @@ sp_canvas_arena_point (SPCanvasItem *item, double x, double y, SPCanvasItem **ac
 static gint
 sp_canvas_arena_event (SPCanvasItem *item, GdkEvent *event)
 {
-	SPCanvasArena *arena;
 	NRArenaItem *new_arena;
-	gint ret;
 	/* fixme: This sucks, we have to handle enter/leave notifiers */
 
-	arena = SP_CANVAS_ARENA (item);
+	SPCanvasArena *arena = SP_CANVAS_ARENA (item);
 
-	ret = FALSE;
+	gint ret = FALSE;
 
 	switch (event->type) {
 	case GDK_ENTER_NOTIFY:
@@ -324,12 +321,11 @@ sp_canvas_arena_event (SPCanvasItem *item, GdkEvent *event)
 			arena->cursor = TRUE;
 
 			/* TODO ... event -> arena transform? */
-			arena->cx = event->crossing.x;
-			arena->cy = event->crossing.y;
+			arena->c = NR::Point(event->crossing.x, event->crossing.y);
 
 			/* fixme: Not sure abut this, but seems the right thing (Lauris) */
 			nr_arena_item_invoke_update (arena->root, NULL, &arena->gc, NR_ARENA_ITEM_STATE_PICK, NR_ARENA_ITEM_STATE_NONE);
-			arena->active = nr_arena_item_invoke_pick (arena->root, arena->cx, arena->cy, nr_arena_global_delta, arena->sticky);
+			arena->active = nr_arena_item_invoke_pick (arena->root, arena->c, nr_arena_global_delta, arena->sticky);
 			if (arena->active) nr_object_ref ((NRObject *) arena->active);
 			ret = sp_canvas_arena_send_event (arena, event);
 		}
@@ -344,12 +340,11 @@ sp_canvas_arena_event (SPCanvasItem *item, GdkEvent *event)
 		break;
 	case GDK_MOTION_NOTIFY:
 		/* TODO ... event -> arena transform? */
-		arena->cx = event->motion.x;
-		arena->cy = event->motion.y;
+		arena->c = NR::Point(event->motion.x, event->motion.y);
 
 		/* fixme: Not sure abut this, but seems the right thing (Lauris) */
 		nr_arena_item_invoke_update (arena->root, NULL, &arena->gc, NR_ARENA_ITEM_STATE_PICK, NR_ARENA_ITEM_STATE_NONE);
-		new_arena = nr_arena_item_invoke_pick (arena->root, arena->cx, arena->cy, nr_arena_global_delta, arena->sticky);
+		new_arena = nr_arena_item_invoke_pick (arena->root, arena->c, nr_arena_global_delta, arena->sticky);
 		if (new_arena != arena->active) {
 			GdkEventCrossing ec;
 			ec.window = event->motion.window;
@@ -385,9 +380,7 @@ sp_canvas_arena_event (SPCanvasItem *item, GdkEvent *event)
 static gint
 sp_canvas_arena_send_event (SPCanvasArena *arena, GdkEvent *event)
 {
-	gint ret;
-
-	ret = FALSE;
+	gint ret = FALSE;
 
 	/* Send event to arena */
 	gtk_signal_emit (GTK_OBJECT (arena), signals[ARENA_EVENT], arena->active, event, &ret);
