@@ -21,15 +21,19 @@
 #define SP_IS_CGRID_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), SP_TYPE_CGRID))
 
 
+/** \brief  All the variables that are tracked for a grid specific
+            canvas item. */
 struct SPCGrid : public SPCanvasItem{
-	NR::Point origin;
-	NR::Point spacing;
-	guint32 color;
-	guint32 empcolor;
-	gint empspacing;
-	bool scaled[2];
-
-	NR::Point ow, sw;
+	NR::Point origin;  /**< Origin of the grid */
+	NR::Point spacing; /**< Spacing between elements of the grid */
+	guint32 color;     /**< Color for normal lines */
+	guint32 empcolor;  /**< Color for emphisis lines */
+	gint empspacing;   /**< Spacing between emphisis lines */
+	bool scaled[2];    /**< Whether the grid is in scaled mode, which can
+					        be different in the X or Y direction, hense two
+						    variables */
+	NR::Point ow;      /**< Transformed origin by the affine for the zoom */
+	NR::Point sw;      /**< Transformed spacing by the affine for the zoom */
 };
 
 struct SPCGridClass {
