@@ -21,7 +21,6 @@
 
 static void nr_arena_group_class_init (NRArenaGroupClass *klass);
 static void nr_arena_group_init (NRArenaGroup *group);
-static void nr_arena_group_finalize (NRObject *object);
 
 static NRArenaItem *nr_arena_group_children (NRArenaItem *item);
 static void nr_arena_group_add_child (NRArenaItem *item, NRArenaItem *child, NRArenaItem *ref);
@@ -31,7 +30,7 @@ static void nr_arena_group_set_child_position (NRArenaItem *item, NRArenaItem *c
 static unsigned int nr_arena_group_update (NRArenaItem *item, NRRectL *area, NRGC *gc, unsigned int state, unsigned int reset);
 static unsigned int nr_arena_group_render (NRArenaItem *item, NRRectL *area, NRPixBlock *pb, unsigned int flags);
 static unsigned int nr_arena_group_clip (NRArenaItem *item, NRRectL *area, NRPixBlock *pb);
-static NRArenaItem *nr_arena_group_pick (NRArenaItem *item, double x, double y, double delta, unsigned int sticky);
+static NRArenaItem *nr_arena_group_pick (NRArenaItem *item, NR::Point p, double delta, unsigned int sticky);
 
 static NRArenaItemClass *parent_class;
 
@@ -61,7 +60,7 @@ nr_arena_group_class_init (NRArenaGroupClass *klass)
 
 	parent_class = (NRArenaItemClass *) ((NRObjectClass *) klass)->parent;
 
-	object_class->finalize = nr_arena_group_finalize;
+	object_class->cpp_ctor = NRObject::invoke_ctor<NRArenaGroup>;
 
 	item_class->children = nr_arena_group_children;
 	item_class->add_child = nr_arena_group_add_child;
@@ -80,30 +79,17 @@ nr_arena_group_init (NRArenaGroup *group)
 	group->children = NULL;
 	group->last = NULL;
 	nr_matrix_set_identity (&group->child_transform);
-}
+  
+#ifdef arena_item_tile_cache
+  group->skipCaching=true;
+#endif
 
-static void
-nr_arena_group_finalize (NRObject *object)
-{
-	NRArenaItem *item;
-	NRArenaGroup *group;
-
-	item = NR_ARENA_ITEM (object);
-	group = NR_ARENA_GROUP (object);
-
-	while (group->children) {
-		group->children = nr_arena_item_detach_unref (item, group->children);
-	}
-
-	((NRObjectClass *) (parent_class))->finalize (object);
 }
 
 static NRArenaItem *
 nr_arena_group_children (NRArenaItem *item)
 {
-	NRArenaGroup *group;
-
-	group = NR_ARENA_GROUP (item);
+	NRArenaGroup *group = NR_ARENA_GROUP (item);
 
 	return group->children;
 }
@@ -111,9 +97,7 @@ nr_arena_group_children (NRArenaItem *item)
 static void
 nr_arena_group_add_child (NRArenaItem *item, NRArenaItem *child, NRArenaItem *ref)
 {
-	NRArenaGroup *group;
-
-	group = NR_ARENA_GROUP (item);
+	NRArenaGroup *group = NR_ARENA_GROUP (item);
 
 	if (!ref) {
 		group->children = nr_arena_item_attach_ref (item, child, NULL, group->children);
@@ -129,9 +113,7 @@ nr_arena_group_add_child (NRArenaItem *item, NRArenaItem *child, NRArenaItem *re
 static void
 nr_arena_group_remove_child (NRArenaItem *item, NRArenaItem *child)
 {
-	NRArenaGroup *group;
-
-	group = NR_ARENA_GROUP (item);
+	NRArenaGroup *group = NR_ARENA_GROUP (item);
 
 	if (child == group->last) group->last = child->prev;
 
@@ -147,11 +129,7 @@ nr_arena_group_remove_child (NRArenaItem *item, NRArenaItem *child)
 static void
 nr_arena_group_set_child_position (NRArenaItem *item, NRArenaItem *child, NRArenaItem *ref)
 {
-	NRArenaGroup *group;
-
-	group = NR_ARENA_GROUP (item);
-
-	nr_arena_item_ref (child);
+	NRArenaGroup *group = NR_ARENA_GROUP (item);
 
 	if (child == group->last) group->last = child->prev;
 
@@ -169,24 +147,20 @@ nr_arena_group_set_child_position (NRArenaItem *item, NRArenaItem *child, NRAren
 
 	if (ref == group->last) group->last = child;
 
-	nr_arena_item_unref (child);
-
 	nr_arena_item_request_render (child);
 }
 
 static unsigned int
 nr_arena_group_update (NRArenaItem *item, NRRectL *area, NRGC *gc, unsigned int state, unsigned int reset)
 {
-	NRArenaGroup *group;
-	NRArenaItem *child;
-	unsigned int newstate, beststate;
+	unsigned int newstate;
 
-	group = NR_ARENA_GROUP (item);
+	NRArenaGroup *group = NR_ARENA_GROUP (item);
 
-	beststate = NR_ARENA_ITEM_STATE_ALL;
+	unsigned int beststate = NR_ARENA_ITEM_STATE_ALL;
 
-	for (child = group->children; child != NULL; child = child->next) {
-		NRGC cgc;
+	for (NRArenaItem *child = group->children; child != NULL; child = child->next) {
+		NRGC cgc(gc);
 		nr_matrix_multiply (&cgc.transform, &group->child_transform, &gc->transform);
 		newstate = nr_arena_item_invoke_update (child, area, &cgc, state, reset);
 		beststate = beststate & newstate;
@@ -194,7 +168,7 @@ nr_arena_group_update (NRArenaItem *item, NRRectL *area, NRGC *gc, unsigned int
 
 	if (beststate & NR_ARENA_ITEM_STATE_BBOX) {
 		nr_rect_l_set_empty (&item->bbox);
-		for (child = group->children; child != NULL; child = child->next) {
+		for (NRArenaItem *child = group->children; child != NULL; child = child->next) {
 			nr_rect_l_union (&item->bbox, &item->bbox, &child->bbox);
 		}
 	}
@@ -205,16 +179,12 @@ nr_arena_group_update (NRArenaItem *item, NRRectL *area, NRGC *gc, unsigned int
 static unsigned int
 nr_arena_group_render (NRArenaItem *item, NRRectL *area, NRPixBlock *pb, unsigned int flags)
 {
-	NRArenaGroup *group;
-	NRArenaItem *child;
-	unsigned int ret;
+	NRArenaGroup *group = NR_ARENA_GROUP (item);
 
-	group = NR_ARENA_GROUP (item);
-
-	ret = item->state;
+	unsigned int ret = item->state;
 
 	/* Just compose children into parent buffer */
-	for (child = group->children; child != NULL; child = child->next) {
+	for (NRArenaItem *child = group->children; child != NULL; child = child->next) {
 		ret = nr_arena_item_invoke_render (child, area, pb, flags);
 		if (ret & NR_ARENA_ITEM_STATE_INVALID) break;
 	}
@@ -225,16 +195,12 @@ nr_arena_group_render (NRArenaItem *item, NRRectL *area, NRPixBlock *pb, unsigne
 static unsigned int
 nr_arena_group_clip (NRArenaItem *item, NRRectL *area, NRPixBlock *pb)
 {
-	NRArenaGroup *group;
-	NRArenaItem *child;
-	unsigned int ret;
+	NRArenaGroup *group = NR_ARENA_GROUP (item);
 
-	group = NR_ARENA_GROUP (item);
-
-	ret = item->state;
+	unsigned int ret = item->state;
 
 	/* Just compose children into parent buffer */
-	for (child = group->children; child != NULL; child = child->next) {
+	for (NRArenaItem *child = group->children; child != NULL; child = child->next) {
 		ret = nr_arena_item_invoke_clip (child, area, pb);
 		if (ret & NR_ARENA_ITEM_STATE_INVALID) break;
 	}
@@ -243,16 +209,14 @@ nr_arena_group_clip (NRArenaItem *item, NRRectL *area, NRPixBlock *pb)
 }
 
 static NRArenaItem *
-nr_arena_group_pick (NRArenaItem *item, double x, double y, double delta, unsigned int sticky)
+nr_arena_group_pick (NRArenaItem *item, NR::Point p, double delta, unsigned int sticky)
 {
-	NRArenaGroup *group;
-	NRArenaItem *child, *picked;
+	NRArenaGroup *group = NR_ARENA_GROUP (item);
 
-	group = NR_ARENA_GROUP (item);
-
-	for (child = group->last; child != NULL; child = child->prev) {
-		picked = nr_arena_item_invoke_pick (child, x, y, delta, sticky);
-		if (picked) return (group->transparent) ? picked : item;
+	for (NRArenaItem *child = group->last; child != NULL; child = child->prev) {
+		NRArenaItem *picked = nr_arena_item_invoke_pick (child, p, delta, sticky);
+		if (picked)
+			return (group->transparent) ? picked : item;
 	}
 
 	return NULL;
