@@ -23,7 +23,7 @@
 #include <stdlib.h>
 #endif
 
-#include "xml/repr-private.h"
+#include "xml/repr.h"
 #include "xml/sp-repr-action-fns.h"
 #include "sp-object.h"
 #include "sp-item.h"
