@@ -22,7 +22,7 @@
 #include "xml/repr.h"
 #include "xml/sp-repr-action-fns.h"
 #include "helper/sp-marshal.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "inkscape-private.h"
 #include "inkscape_version.h"
 #include "sp-object-repr.h"
@@ -33,6 +33,7 @@
 #include "desktop.h"
 #include "version.h"
 #include "dir-util.h"
+#include "unit-constants.h"
 
 #include "display/nr-arena-item.h"
 #include "display/nr-arena.h"
@@ -146,6 +147,7 @@ sp_document_init (SPDocument *doc)
 	p = new SPDocumentPrivate();
 
 	p->iddef = g_hash_table_new (g_direct_hash, g_direct_equal);
+	p->reprdef = g_hash_table_new (g_direct_hash, g_direct_equal);
 
 	p->resources = g_hash_table_new (g_str_hash, g_str_equal);
 
@@ -210,6 +212,7 @@ sp_document_dispose (GObject *object)
 		}
 
 		if (priv->iddef) g_hash_table_destroy (priv->iddef);
+		if (priv->reprdef) g_hash_table_destroy (priv->reprdef);
 
 		if (doc->rdoc) sp_repr_document_unref (doc->rdoc);
 
@@ -295,16 +298,6 @@ sp_document_create (SPReprDoc *rdoc,
 	sp_repr_set_attr (rroot, "inkscape:version", INKSCAPE_VERSION);
 	/* fixme: Again, I moved these here to allow version determining in ::build (Lauris) */
 
-	/* A quick hack to get namespaces into doc */
-	sp_repr_set_attr (rroot, "xmlns", SP_SVG_NS_URI);
-	sp_repr_set_attr (rroot, "xmlns:sodipodi", SP_SODIPODI_NS_URI);
-	sp_repr_set_attr (rroot, "xmlns:inkscape", SP_INKSCAPE_NS_URI);
-	sp_repr_set_attr (rroot, "xmlns:xlink", SP_XLINK_NS_URI);
-	sp_repr_set_attr (rroot, "xmlns:rdf", SP_RDF_NS_URI);
-	sp_repr_set_attr (rroot, "xmlns:cc", SP_CC_NS_URI);
-	sp_repr_set_attr (rroot, "xmlns:dc", SP_DC_NS_URI);
-	/* End of quick hack */
-
 	/* Quick hack 2 - get default image size into document */
 	if (!sp_repr_attr (rroot, "width")) sp_repr_set_attr (rroot, "width", A4_WIDTH_STR);
 	if (!sp_repr_attr (rroot, "height")) sp_repr_set_attr (rroot, "height", A4_HEIGHT_STR);
@@ -347,21 +340,11 @@ sp_document_create (SPReprDoc *rdoc,
 		// clean up
 		sp_repr_unref (rnew);
 	}
-
-	// Create metadata if it doesn't already exist
-	if (!sp_item_group_get_child_by_name ((SPGroup *) document->root, NULL, "metadata")) {
-		// create repr
-		SPRepr * rnew = sp_repr_new ("metadata");
-		// insert into the document
-		sp_repr_add_child (rroot, rnew, NULL);
-		// clean up
-		sp_repr_unref (rnew);
-	}
-
+	
 	/* Defs */
 	if (!SP_ROOT (document->root)->defs) {
 		SPRepr *r;
-		r = sp_repr_new ("defs");
+		r = sp_repr_new ("svg:defs");
 		sp_repr_add_child (rroot, r, NULL);
 		sp_repr_unref (r);
 		g_assert (SP_ROOT (document->root)->defs);
@@ -406,7 +389,7 @@ sp_document_new (const gchar *uri, unsigned int advertize, unsigned int keepaliv
 		rroot = sp_repr_document_root (rdoc);
 		/* If xml file is not svg, return NULL without warning */
 		/* fixme: destroy document */
-		if (strcmp (sp_repr_name (rroot), "svg") != 0) return NULL;
+		if (strcmp (sp_repr_name (rroot), "svg:svg") != 0) return NULL;
 		s = g_strdup (uri);
 		p = strrchr (s, '/');
 		if (p) {
@@ -419,7 +402,7 @@ sp_document_new (const gchar *uri, unsigned int advertize, unsigned int keepaliv
 		}
 		g_free (s);
 	} else {
-		rdoc = sp_repr_document_new ("svg");
+		rdoc = sp_repr_document_new ("svg:svg");
 	}
 
 	if (make_new) {
@@ -455,7 +438,7 @@ sp_document_new_from_mem (const gchar *buffer, gint length, unsigned int adverti
 	rroot = sp_repr_document_root (rdoc);
 	/* If xml file is not svg, return NULL without warning */
 	/* fixme: destroy document */
-	if (strcmp (sp_repr_name (rroot), "svg") != 0) return NULL;
+	if (strcmp (sp_repr_name (rroot), "svg:svg") != 0) return NULL;
 
 	name = g_strdup_printf (_("Memory document %d"), ++doc_count);
 
@@ -493,7 +476,7 @@ gdouble sp_document_width(SPDocument *document)
 	g_return_val_if_fail (document->priv != NULL, 0.0);
 	g_return_val_if_fail (document->root != NULL, 0.0);
 
-	return SP_ROOT (document->root)->width.computed / 1.25;
+	return SP_ROOT (document->root)->width.computed;
 }
 
 gdouble sp_document_height(SPDocument *document)
@@ -503,7 +486,7 @@ gdouble sp_document_height(SPDocument *document)
 	g_return_val_if_fail (document->priv != NULL, 0.0);
 	g_return_val_if_fail (document->root != NULL, 0.0);
 
-	return SP_ROOT (document->root)->height.computed / 1.25;
+	return SP_ROOT (document->root)->height.computed;
 }
 
 void sp_document_set_uri(SPDocument *document, gchar const *uri)
@@ -562,55 +545,57 @@ sp_document_set_size_px (SPDocument *doc, gdouble width, gdouble height)
 {
 	g_return_if_fail (doc != NULL);
 	g_return_if_fail (SP_IS_DOCUMENT (doc));
-	g_return_if_fail (width > 0.001);
-	g_return_if_fail (height > 0.001);
 
-	g_signal_emit (G_OBJECT (doc), signals [RESIZED], 0, width / 1.25, height / 1.25);
+	g_signal_emit (G_OBJECT (doc), signals [RESIZED], 0, width, height);
 }
 
-void sp_document_def_id(SPDocument *document, gchar const *id, SPObject *object)
-{
+void SPDocument::bindObjectToId(gchar const *id, SPObject *object) {
 	GQuark idq = g_quark_from_string(id);
 
 	if (object) {
-		g_assert(g_hash_table_lookup(document->priv->iddef, GINT_TO_POINTER(idq)) == NULL);
-		g_hash_table_insert(document->priv->iddef, GINT_TO_POINTER(idq), object);
+		g_assert(g_hash_table_lookup(priv->iddef, GINT_TO_POINTER(idq)) == NULL);
+		g_hash_table_insert(priv->iddef, GINT_TO_POINTER(idq), object);
 	} else {
-		g_assert(g_hash_table_lookup(document->priv->iddef, GINT_TO_POINTER(idq)) != NULL);
-		g_hash_table_remove(document->priv->iddef, GINT_TO_POINTER(idq));
+		g_assert(g_hash_table_lookup(priv->iddef, GINT_TO_POINTER(idq)) != NULL);
+		g_hash_table_remove(priv->iddef, GINT_TO_POINTER(idq));
 	}
 
-	SPDocumentPrivate::IDChangedSignalMap &id_changed_signals = document->priv->id_changed_signals;
 	SPDocumentPrivate::IDChangedSignalMap::iterator pos;
 
-	pos = id_changed_signals.find(idq);
-	if ( pos != id_changed_signals.end() ) {
+	pos = priv->id_changed_signals.find(idq);
+	if ( pos != priv->id_changed_signals.end() ) {
 		if (!(*pos).second.empty()) {
 			(*pos).second.emit(object);
 		} else { // discard unused signal
-			id_changed_signals.erase(pos);
+			priv->id_changed_signals.erase(pos);
 		}
 	}
 }
 
-SigC::Connection
-sp_document_id_changed_connect(SPDocument *doc, const gchar *id,
-                               SPDocument::IDChangedSignal::slot_type slot)
-{
-	return doc->priv->id_changed_signals[g_quark_from_string(id)].connect(slot);
-}
-
-SPObject *SPDocument::getObjectById(const gchar *id)
-{
+SPObject *SPDocument::getObjectById(const gchar *id) {
 	g_return_val_if_fail (id != NULL, NULL);
 
 	GQuark idq = g_quark_from_string(id);
-	return (SPObject*)g_hash_table_lookup (this->priv->iddef, GINT_TO_POINTER(idq));
+	return (SPObject*)g_hash_table_lookup (priv->iddef, GINT_TO_POINTER(idq));
 }
 
-SPObject *SPDocument::getObjectByRepr(SPRepr *repr)
-{
-	return getObjectById(sp_repr_attr(repr, "id"));
+sigc::connection SPDocument::connectIdChanged(const gchar *id, SPDocument::IDChangedSignal::slot_type slot) {
+	return priv->id_changed_signals[g_quark_from_string(id)].connect(slot);
+}
+
+void SPDocument::bindObjectToRepr(SPRepr *repr, SPObject *object) {
+	if (object) {
+		g_assert(g_hash_table_lookup(priv->reprdef, repr) == NULL);
+		g_hash_table_insert(priv->reprdef, repr, object);
+	} else {
+		g_assert(g_hash_table_lookup(priv->reprdef, repr) != NULL);
+		g_hash_table_remove(priv->reprdef, repr);
+	}
+}
+
+SPObject *SPDocument::getObjectByRepr(SPRepr *repr) {
+	g_return_val_if_fail (repr != NULL, NULL);
+	return (SPObject*)g_hash_table_lookup(priv->reprdef, repr);
 }
 
 /* Object modification root handler */
@@ -647,8 +632,8 @@ sp_document_ensure_up_to_date (SPDocument *doc)
 			/* Set up viewport in case svg has it defined as percentages */
 			ctx.vp.x0 = 0.0;
 			ctx.vp.y0 = 0.0;
-			ctx.vp.x1 = 21.0 / 2.54 * 72.0 * 1.25;
-			ctx.vp.y1 = 29.7 / 2.54 * 72.0 * 1.25;
+			ctx.vp.x1 = 21.0 * PX_PER_CM; 
+			ctx.vp.y1 = 29.7 * PX_PER_CM;
 			nr_matrix_set_identity (&ctx.i2vp);
 			doc->root->updateDisplay((SPCtx *)&ctx, 0);
 		}
@@ -686,8 +671,8 @@ sp_document_idle_handler (gpointer data)
 		/* Set up viewport in case svg has it defined as percentages */
 		ctx.vp.x0 = 0.0;
 		ctx.vp.y0 = 0.0;
-		ctx.vp.x1 = 21.0 / 2.54 * 72.0 * 1.25;
-		ctx.vp.y1 = 29.7 / 2.54 * 72.0 * 1.25;
+		ctx.vp.x1 = 21.0 * PX_PER_CM;
+		ctx.vp.y1 = 29.7 * PX_PER_CM;
 		nr_matrix_set_identity (&ctx.i2vp);
 
 		gboolean saved = sp_document_get_undo_sensitive(doc);
@@ -859,8 +844,8 @@ find_item_at_point (unsigned int dkey, SPGroup *group, NR::Point const p, gboole
 }
 
 /**
-Returns the bottommost non-layer group from the descendants of group which is at point
-p, or NULL if none.
+Returns the topmost non-layer group from the descendants of group which is at point
+p, or NULL if none. Recurses into layers but not into groups.
  */
 SPItem*
 find_group_at_point (unsigned int dkey, SPGroup *group, NR::Point const p)
@@ -869,6 +854,12 @@ find_group_at_point (unsigned int dkey, SPGroup *group, NR::Point const p)
 
 	for (SPObject *o = sp_object_first_child(SP_OBJECT(group)) ; o != NULL ; o = SP_OBJECT_NEXT(o) ) {
 		if (!SP_IS_ITEM (o)) continue;
+		if (SP_IS_GROUP (o) && SP_GROUP (o)->effectiveLayerMode(dkey) == SPGroup::LAYER) {
+			SPItem *newseen = find_group_at_point (dkey, SP_GROUP (o), p);
+			if (newseen) {
+				seen = newseen;
+			}
+		}
 		if (SP_IS_GROUP (o) && SP_GROUP (o)->effectiveLayerMode(dkey) != SPGroup::LAYER ) {
 			SPItem *child = SP_ITEM(o);
 			NRArenaItem *arenaitem = sp_item_get_arenaitem(child, dkey);
@@ -920,8 +911,9 @@ sp_document_partial_items_in_box (SPDocument *document, unsigned int dkey, NRRec
 	                           dkey, box, overlaps);
 }
 
-SPItem*
-sp_document_item_at_point (SPDocument *document, unsigned int key, NR::Point p, gboolean into_groups, SPItem *upto)
+SPItem *
+sp_document_item_at_point(SPDocument *document, unsigned const key, NR::Point const p,
+			  gboolean const into_groups, SPItem *upto)
 {
 	g_return_val_if_fail (document != NULL, NULL);
 	g_return_val_if_fail (SP_IS_DOCUMENT (document), NULL);
