@@ -14,29 +14,43 @@
 
 #include <libnr/nr-point.h>
 
-#include "helper/helper-forward.h"
+#include "display/display-forward.h"
 #include "event-context.h"
 
 #define SP_TYPE_DROPPER_CONTEXT (sp_dropper_context_get_type ())
 #define SP_DROPPER_CONTEXT(obj) (GTK_CHECK_CAST ((obj), SP_TYPE_DROPPER_CONTEXT, SPDropperContext))
 #define SP_IS_DROPPER_CONTEXT(obj) (GTK_CHECK_TYPE ((obj), SP_TYPE_DROPPER_CONTEXT))
 
-typedef struct _SPDropperContext SPDropperContext;
-typedef struct _SPDropperContextClass SPDropperContextClass;
+class SPDropperContext;
+class SPDropperContextClass;
 
-struct _SPDropperContext {
+enum {
+      SP_DROPPER_PICK_VISIBLE,
+      SP_DROPPER_PICK_ACTUAL  
+};
+
+struct SPDropperContext {
 	SPEventContext event_context;
 
 	unsigned int dragging : 1;
 
 	SPCanvasItem *area;
 	NR::Point centre;
+
+	double R;
+	double G;
+	double B;
+	double alpha;
+
+	SPSelCue selcue;
 };
 
-struct _SPDropperContextClass {
+struct SPDropperContextClass {
 	SPEventContextClass parent_class;
 };
 
 GType sp_dropper_context_get_type (void);
 
+void sp_dropper_context_copy (SPEventContext *ec);
+
 #endif
