@@ -35,7 +35,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "svg/svg.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "display/curve.h"
 #include "display/canvas-bpath.h"
 #include "display/sodipodi-ctrl.h"
@@ -602,8 +602,8 @@ sp_dyna_draw_context_root_handler(SPEventContext *event_context,
         case GDK_KP_Left:
             if (!MOD__CTRL_ONLY) {
                 dc->width -= 0.01;
-                if (dc->width < 0.0) 
-                    dc->width = 0.0;
+                if (dc->width < 0.01) 
+                    dc->width = 0.01;
                 sp_ddc_update_toolbox (desktop, "altx-calligraphy", dc->width); 
                 ret = TRUE;
             }
@@ -660,7 +660,7 @@ set_to_accumulated(SPDynaDrawContext *dc)
 
         if (!dc->repr) {
             /* Create object */
-            SPRepr *repr = sp_repr_new("path");
+            SPRepr *repr = sp_repr_new("svg:path");
 
             /* Set style */
             sp_desktop_apply_style_tool (desktop, repr, "tools.calligraphic", false);
