@@ -61,5 +61,17 @@ enum {
 /* fill-rule */
 /* clip-rule */
 
+enum {
+	SP_CLONE_COMPENSATION_PARALLEL,
+	SP_CLONE_COMPENSATION_UNMOVED,
+	SP_CLONE_COMPENSATION_NONE
+};
+
+enum {
+	SP_CLONE_ORPHANS_UNLINK,
+	SP_CLONE_ORPHANS_DELETE,
+	SP_CLONE_ORPHANS_ASKME
+};
+
 #endif
 
