@@ -34,7 +34,7 @@
 #include "select-context.h"
 #include "file.h"
 #include "interface.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "selection-chemistry.h"
 #include "dialogs/desktop-properties.h"
 #include "macros.h"
@@ -570,18 +570,6 @@ sp_event_context_private_item_handler (SPEventContext *ec, SPItem *item, GdkEven
 	return ret;
 }
 
-static unsigned int
-sp_ec_repr_change_attr (SPRepr *repr, const gchar *key, const gchar *oldval, const gchar *newval, gpointer data)
-{
-	SPEventContext *ec;
-
-	ec = SP_EVENT_CONTEXT (data);
-
-	/* In theory we could verify values here */
-
-	return TRUE;
-}
-
 static void
 sp_ec_repr_attr_changed (SPRepr *repr, const gchar *key, const gchar *oldval, const gchar *newval, bool is_interactive, gpointer data)
 {
@@ -594,15 +582,10 @@ sp_ec_repr_attr_changed (SPRepr *repr, const gchar *key, const gchar *oldval, co
 }
 
 SPReprEventVector sp_ec_event_vector = {
-	NULL, /* Add child */
 	NULL, /* Child added */
-	NULL, /* Remove child */
 	NULL, /* Child removed */
-	sp_ec_repr_change_attr,
 	sp_ec_repr_attr_changed,
-	NULL, /* Change content */
 	NULL, /* Content changed */
-	NULL, /* Change_order */
 	NULL /* Order changed */
 };
 
