@@ -11,18 +11,20 @@
  * Authors:
  *   Ted Gould <ted@gould.cx>
  *
- * Copyright (C) 2002-2004 Authors
+ * Copyright (C) 2002-2005 Authors
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
 #include <config.h>
 
+#include <ostream>
+#include <fstream>
 #include <string.h>
 #include <stdlib.h>
 
 #include "xml/repr.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "dir-util.h"
 #include "inkscape.h"
 #include "sp-object.h"
@@ -34,12 +36,15 @@
 
 #include "db.h"
 #include "dependency.h"
+#include "timer.h"
 
 namespace Inkscape {
 namespace Extension {
 
 /* Inkscape::Extension::Extension */
 
+std::ofstream Extension::error_file;
+
 /**
     \return  none
     \brief   Constructs an Extension from a SPRepr
@@ -91,6 +96,7 @@ Extension::Extension (SPRepr * in_repr, Implementation::Implementation * in_imp)
         db.register_ext (this);
     }
 //  printf("%s\n", name);
+	timer = NULL;
 
     return;
 }
@@ -112,6 +118,8 @@ Extension::~Extension (void)
     sp_repr_unref(repr);
     g_free(id);
     g_free(name);
+	delete timer;
+	timer = NULL;
     /** \todo Need to do parameters here */
 
 	for (unsigned int i = 0 ; i < _deps.size(); i++) {
@@ -143,13 +151,30 @@ Extension::set_state (state_t in_state)
 			case STATE_LOADED:
 				if (imp->load(this))
 					_state = STATE_LOADED;
+
+				if (timer != NULL) {
+					delete timer;
+				}
+				timer = new ExpirationTimer(this);
+
 				break;
 			case STATE_UNLOADED:
+				// std::cout << "Unloading: " << name << std::endl;
 				imp->unload(this);
 				_state = STATE_UNLOADED;
+
+				if (timer != NULL) {
+					delete timer;
+					timer = NULL;
+				}
 				break;
 			case STATE_DEACTIVATED:
 				_state = STATE_DEACTIVATED;
+
+				if (timer != NULL) {
+					delete timer;
+					timer = NULL;
+				}
 				break;
 			default:
 				break;
@@ -187,29 +212,68 @@ Extension::loaded (void)
 	repr and an implemenation for this extension.  Then it checks all
 	of the dependencies to see if they pass.  Finally, it asks the
 	implmentation to do a check of itself.
+
+	On each check, if there is a failure, it will print a message to the
+	error log for that failure.  It is important to note that the function
+	keeps executing if it finds an error, to try and get as many of them
+	into the error log as possible.  This should help people debug
+	installations, and figure out what they need to get for the full
+	functionality of Inkscape to be available.
 */
 bool
 Extension::check (void)
 {
+	bool retval = true;
+
 	// static int i = 0;
 	// std::cout << "Checking module[" << i++ << "]: " << name << std::endl;
-	if (id == NULL)
-		return FALSE;
-	if (name == NULL)
-		return FALSE;
-	if (repr == NULL)
-		return FALSE;
-	if (imp == NULL)
-		return FALSE;
+
+	const char * inx_failure = _("  This is caused by an improper .inx file for this extension."
+		                         "  An improper .inx file could have been caused by a faulty installation of Inkscape.");
+	if (id == NULL) {
+		printFailure(Glib::ustring(_("an ID was not defined for it.")) + inx_failure);
+		retval = false;
+	}
+	if (name == NULL) {
+		printFailure(Glib::ustring(_("there was no name defined for it.")) + inx_failure);
+		retval = false;
+	}
+	if (repr == NULL) {
+		printFailure(Glib::ustring(_("the XML description of it got lost.")) + inx_failure);
+		retval = false;
+	}
+	if (imp == NULL) {
+		printFailure(Glib::ustring(_("no implementation was defined for the extension.")) + inx_failure);
+		retval = false;
+	}
 
 	for (unsigned int i = 0 ; i < _deps.size(); i++) {
 		if (_deps[i]->check() == FALSE) {
 			// std::cout << "Failed: " << *(_deps[i]) << std::endl;
-			return FALSE;
+			printFailure(Glib::ustring(_("a dependency was not met.")));
+			error_file << *_deps[i] << std::endl;
+			retval = false;
 		}
 	}
 
-	return imp->check(this);
+	if (retval)
+		return imp->check(this);
+	return retval;
+}
+
+/** \brief A quick function to print out a standard start of extension
+           errors in the log.
+	\param reason  A string explaining why this failed
+
+	Real simple, just put everything into \c error_file.
+*/
+void
+Extension::printFailure (Glib::ustring reason)
+{
+	error_file << _("Extension \"") << name << _("\" failed to load because ");
+	error_file << reason;
+	error_file << std::endl;
+	return;
 }
 
 /**
@@ -347,6 +411,16 @@ Extension::make_param (SPRepr * paramrepr)
             param->val.t_int = 0;
         }
 		param->val.t_int = prefs_get_int_attribute("extensions", param_name, (gint)param->val.t_int);
+    } else if (!strcmp(type, "float")) { 
+        param->type = Extension::PARAM_FLOAT;
+		// std::cout << "Float value: " << defaultval;
+        if (defaultval != NULL) {
+            param->val.t_float = atof(defaultval);
+        } else {
+            param->val.t_float = 0.0;
+        }
+		param->val.t_float = prefs_get_double_attribute("extensions", param_name, (gfloat)param->val.t_float);
+		// std::cout << " after: " << param->val.t_float << std::endl;
     } else if (!strcmp(type, "string")) { 
 		const gchar * temp_str;
         param->type = Extension::PARAM_STRING;
@@ -514,6 +588,40 @@ Extension::get_param_int (const gchar * name, const SPReprDoc * doc)
     return param->val.t_int;
 }
 
+/**
+    \return   The float value for the parameter specified
+    \brief    Gets a parameter identified by name with the float placed
+              in value.
+    \param    name    The name of the parameter to get
+	\param    doc    The document to look in for document specific parameters
+
+    To get the parameter to be used the function param_shared is called.
+    This function is inline so it shouldn't cause the stack to build
+    or anything like that.  If it can't find the parameter, it will
+    throw and exception - we aren't catching that because we want
+    the calling function to catch it.
+
+    Next up, the parameter that we got, we're making sure that it is
+    a float parameter.  If it isn't, then we throw a param_wrong_type
+    exception.
+    
+    Finally, if everything is okay, the float value that is stored in
+    the parameter is placed in value.
+*/
+float
+Extension::get_param_float (const gchar * name, const SPReprDoc * doc)
+{
+    Extension::param_t * param;
+    
+    param = Extension::param_shared(name, parameters);
+
+    if (param->type != Extension::PARAM_FLOAT) {
+        throw Extension::param_wrong_type();
+    }
+
+    return param->val.t_float;
+}
+
 /**
     \return   The passed in value
     \brief    Sets a parameter identified by name with the boolean
@@ -598,6 +706,48 @@ Extension::set_param_int (const gchar * name, int value, SPReprDoc * doc)
     return value;
 }
 
+/**
+    \return   The passed in value
+    \brief    Sets a parameter identified by name with the integer
+              in the parameter value.
+    \param    name    The name of the parameter to set
+    \param    value   The value to set the parameter to
+	\param    doc    The document to look in for document specific parameters
+
+    To get the parameter to be used the function param_shared is called.
+    This function is inline so it shouldn't cause the stack to build
+    or anything like that.  If it can't find the parameter, it will
+    throw and exception - we aren't catching that because we want
+    the calling function to catch it.
+
+    Next up, the parameter that we got, we're making sure that it is
+    a integer parameter.  If it isn't, then we throw a param_wrong_type
+    exception.
+    
+    Finally, if everything is okay, the integer value that was passed
+	in is placed in the param.
+*/
+float
+Extension::set_param_float (const gchar * name, float value, SPReprDoc * doc)
+{
+    Extension::param_t * param;
+	gchar * param_name;
+    
+    param = Extension::param_shared(name, parameters);
+
+    if (param->type != Extension::PARAM_FLOAT) {
+        throw Extension::param_wrong_type();
+    }
+
+    param->val.t_float = value;
+
+	param_name = g_strdup_printf("%s.%s", id, name);
+	prefs_set_double_attribute("extensions", param_name, value);
+	g_free(param_name);
+
+    return value;
+}
+
 /**
     \return   The passed in value
     \brief    Sets a parameter identified by name with the string
@@ -650,6 +800,28 @@ Extension::set_param_string (const gchar * name, const gchar * value, SPReprDoc
     return value;
 }
 
-}; /* namespace Extension */
-}; /* namespace Inkscape */
+/** \brief A function to open the error log file. */
+void
+Extension::error_file_open (void)
+{
+	gchar * ext_error_file = profile_path(EXTENSION_ERROR_LOG_FILENAME);
+	gchar * filename = g_filename_from_utf8( ext_error_file, -1, NULL, NULL, NULL );
+	error_file.open(filename);
+	if (!error_file.is_open()) {
+		g_warning(_("Could not create extension error log file '%s'"),
+		          filename);	
+	}
+	g_free(filename);
+	g_free(ext_error_file);
+};
+
+/** \brief A function to close the error log file. */
+void
+Extension::error_file_close (void)
+{
+	error_file.close();
+};
+
+}  /* namespace Extension */
+}  /* namespace Inkscape */
 
