@@ -9,20 +9,23 @@
  * Authors:
  *   Ted Gould <ted@gould.cx>
  *
- * Copyright (C) 2002-2004 Authors
+ * Copyright (C) 2002-2005 Authors
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
+#include <ostream>
+#include <fstream>
 #include <vector>
+#include <glibmm/ustring.h>
 #include "xml/repr.h"
-#include "xml/repr-private.h"
 #include <extension/extension-forward.h>
 
 /** The key that is used to identify that the I/O should be autodetected */
 #define SP_MODULE_KEY_AUTODETECT "autodetect"
 /** This is the key for the SVG input module */
 #define SP_MODULE_KEY_INPUT_SVG "org.inkscape.input.svg"
+#define SP_MODULE_KEY_INPUT_SVGZ "org.inkscape.input.svgz"
 /** Specifies the input module that should be used if none are selected */
 #define SP_MODULE_KEY_INPUT_DEFAULT SP_MODULE_KEY_AUTODETECT
 /** The key for outputing standard W3C SVG */
@@ -54,6 +57,9 @@
 /** Mime type for SVG */
 #define MIME_SVG "image/svg+xml"
 
+/** Name of the extension error file */
+#define EXTENSION_ERROR_LOG_FILENAME  "extension-errors.log"
+
 namespace Inkscape {
 namespace Extension {
 
@@ -76,10 +82,12 @@ private:
     gchar     *name;                      /**< A user friendly name for the Extension */
     state_t    _state;                    /**< Which state the Extension is currently in */
     std::vector<Dependency *>  _deps;     /**< Dependencies for this extension */
+    static std::ofstream error_file;      /**< This is the place where errors get reported */
 
 protected:
     SPRepr *repr;                         /**< The XML description of the Extension */
     Implementation::Implementation * imp; /**< An object that holds all the functions for making this work */
+    ExpirationTimer * timer;              /**< Timeout to unload after a given time */
 
 public:
                   Extension    (SPRepr * in_repr,
@@ -95,6 +103,7 @@ public:
     gchar *       get_name     (void);
     void          deactivate   (void);
     bool          deactivated  (void);
+    void          printFailure (Glib::ustring reason);
 
 
 /* Parameter Stuff */
@@ -111,6 +120,7 @@ private:
     enum param_type_t {
         PARAM_BOOL,   /**< Boolean parameter */
         PARAM_INT,    /**< Integer parameter */
+        PARAM_FLOAT,  /**< Float parameter */
         PARAM_STRING, /**< String parameter */
         PARAM_CNT     /**< How many types are there? */
     };
@@ -120,6 +130,7 @@ private:
     union param_switch_t {
         bool t_bool;      /**< To get a boolean use this */
         int  t_int;       /**< If you want an integer this is your variable */
+        float t_float;    /**< This guy stores the floating point numbers */
         gchar * t_string; /**< Strings are here */
     };
     /** The class that actually stores the value and type of the
@@ -149,6 +160,8 @@ public:
                                        const SPReprDoc *   doc = NULL);
     int              get_param_int    (const gchar * name,
                                        const SPReprDoc *   doc = NULL);
+    float            get_param_float  (const gchar * name,
+                                       const SPReprDoc *   doc = NULL);
     const gchar *    get_param_string (const gchar * name,
                                        const SPReprDoc *   doc = NULL);
     bool             set_param_bool   (const gchar * name,
@@ -157,9 +170,17 @@ public:
     int              set_param_int    (const gchar * name,
                                        int           value,
                                        SPReprDoc *   doc = NULL);
+    float            set_param_float  (const gchar * name,
+                                       float         value,
+                                       SPReprDoc *   doc = NULL);
     const gchar *    set_param_string (const gchar * name,
                                        const gchar * value,
                                        SPReprDoc *   doc = NULL);
+
+    /* Error file handling */
+public:
+    static void      error_file_open  (void);
+    static void      error_file_close (void);
 };
 
 
@@ -184,8 +205,8 @@ public:
 };
 */
 
-}; /* namespace Extension */
-}; /* namespace Inkscape */
+}  /* namespace Extension */
+}  /* namespace Inkscape */
 
 #endif /* __INK_EXTENSION_H__ */
 
