@@ -1,6 +1,6 @@
 /*
     Author:  Ted Gould <ted@gould.cx>
-    Copyright (c) 2003-2004
+    Copyright (c) 2003-2005
 
     This code is licensed under the GNU GPL.  See COPYING for details.
  
@@ -33,9 +33,6 @@ Implementation::load (Inkscape::Extension::Extension * module) {
 
 void 
 Implementation::unload (Inkscape::Extension::Extension * module) {
-	if (module->loaded()) {
-		return module->set_state(Inkscape::Extension::Extension::STATE_UNLOADED);
-	}
 	return;
 } /* Implementation::unload */
 
@@ -67,14 +64,13 @@ Implementation::save (Inkscape::Extension::Output * module, SPDocument * doc, co
 	return;
 } /* Implementation::save */
 
-GtkDialog *
-Implementation::prefs_effect (Inkscape::Extension::Effect * module) {
-
-	return NULL;
+Gdk::NativeWindow
+Implementation::prefs_effect (Inkscape::Extension::Effect * module, SPView * view) {
+	return (Gdk::NativeWindow)0;
 } /* Implementation::prefs_effect */
 
 void
-Implementation::effect (Inkscape::Extension::Effect * module, SPDocument * document) {
+Implementation::effect (Inkscape::Extension::Effect * module, SPView * document) {
 	/* throw filter_fail */
 	return;
 } /* Implementation::filter */
@@ -118,6 +114,12 @@ Implementation::release (Inkscape::Extension::Print * module)
 	return 0;
 }
 
+unsigned int
+Implementation::comment (Inkscape::Extension::Print * module, const char * comment)
+{
+	return 0;
+}
+
 unsigned int
 Implementation::fill (Inkscape::Extension::Print * module, const NRBPath *bpath, const NRMatrix *ctm, const SPStyle *style,
 			   const NRRect *pbox, const NRRect *dbox, const NRRect *bbox)
@@ -161,17 +163,17 @@ Implementation::textToPath(Inkscape::Extension::Print * ext)
 }
 
 
-}; /* namespace Implementation */
-}; /* namespace Extension */
-}; /* namespace Inkscape */
+}  /* namespace Implementation */
+}  /* namespace Extension */
+}  /* namespace Inkscape */
 
 /*
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
