@@ -22,8 +22,9 @@
 #include <glib.h>
 #include <string.h>
 
+#include <inkscape.h>
 #include <xml/repr.h>
-#include <helper/sp-intl.h>
+#include <glibmm/i18n.h>
 
 #include "extension/extension.h"
 #include "system.h"
@@ -42,6 +43,8 @@
 #include "internal/eps-out.h"
 #include "internal/gdkpixbuf-input.h"
 #include "prefs-utils.h"
+#include "error-file.h"
+#include "io/sys.h"
 
 namespace Inkscape {
 namespace Extension {
@@ -103,7 +106,6 @@ init (void)
 	Internal::PsOutput::init();
 	Internal::EpsOutput::init();
 	Internal::PrintPS::init();
-	Internal::GdkpixbufInput::init();
 #ifdef WITH_GNOME_PRINT
 	Internal::PrintGNOME::init();
 #endif
@@ -113,6 +115,12 @@ init (void)
 	Internal::PovOutput::init();
 
 	build_module_from_dir(INKSCAPE_EXTENSIONDIR);
+	
+	/* this is at the very end because it has several catch-alls
+	 * that are possibly over-ridden by other extensions (such as
+	 * svgz)
+	 */
+	Internal::GdkpixbufInput::init();
 
 	/* now we need to check and make sure everyone is happy */
 	check_extensions();
@@ -141,36 +149,44 @@ init (void)
 static void
 build_module_from_dir (const gchar * dirname)
 {
-	DIR * directory;
-	struct dirent * dentry;
+        if (!dirname) {
+            g_warning(_("Null external module directory name.  Modules will not be loaded."));
+            return;
+        }
 
-	directory = opendir(dirname);
-	if (directory == NULL) {
-		g_warning(_("Modules directory (%s) is unavailable.  External modules in that directory will not be loaded."), dirname);
+        //# Hopefully doing this the Glib way is portable
+        
+        GError *err;
+	GDir *directory = g_dir_open(dirname, 0, &err);
+	if (!directory) {
+		gchar *safeDir = Inkscape::IO::sanitizeString(dirname);
+		g_warning(_("Modules directory (%s) is unavailable.	 External modules in that directory will not be loaded."), safeDir);
+		g_free(safeDir);
 		return;
 	}
 
-	while ((dentry = readdir(directory)) != NULL) {
-		gchar * filename;
+        gchar *filename;
+	while ((filename = (gchar *)g_dir_read_name(directory)) != NULL) {
 
-		if (strlen(dentry->d_name) < strlen(SP_MODULE_EXTENSION)) {
+		if (strlen(filename) < strlen(SP_MODULE_EXTENSION)) {
 			continue;
 		}
 
-		if (strcmp(SP_MODULE_EXTENSION, dentry->d_name + (strlen(dentry->d_name) - strlen(SP_MODULE_EXTENSION)))) {
+		if (strcmp(SP_MODULE_EXTENSION, filename + (strlen(filename) - strlen(SP_MODULE_EXTENSION)))) {
 			continue;
 		}
 
-		filename = g_strdup_printf("%s/%s", INKSCAPE_EXTENSIONDIR, dentry->d_name);
-		build_from_file(filename);
-		g_free(filename);
+		gchar *pathname = g_strdup_printf("%s/%s", INKSCAPE_EXTENSIONDIR, filename);
+		build_from_file(pathname);
+		g_free(pathname);
 	}
 
-	closedir(directory);
+	g_dir_close(directory);
 
 	return;
 }
 
+
 static void
 check_extensions_internal (Extension * in_plug, gpointer in_data)
 {
@@ -189,14 +205,26 @@ static void
 check_extensions (void)
 {
 	int count = 1;
+	bool anyfail = false;
 	// int pass = 0;
+
+	Inkscape::Extension::Extension::error_file_open();
 	while (count != 0) {
 		// printf("Check extensions pass %d\n", pass++);
 		count = 0;
 		db.foreach(check_extensions_internal, (gpointer)&count);
+		if (count != 0) anyfail = true;
+	}
+	Inkscape::Extension::Extension::error_file_close();
+
+	if (anyfail) {
+		/* show dialog here */
+		Inkscape::Extension::ErrorFileNotice dialog;
+		dialog.run();
+		// std::cout << "Check the error log" << std::endl;
 	}
 
 	return;
 }
 
-}; }; /* namespace Inkscape::Extension */
+} } /* namespace Inkscape::Extension */
