@@ -35,7 +35,7 @@
 #include <libgnomeprintui/gnome-print-master-preview.h>
 #endif
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "enums.h"
 #include "document.h"
 #include "style.h"
@@ -392,9 +392,9 @@ PrintGNOME::init (void)
 	return;
 }
 
-}; /* namespace Internal */
-}; /* namespace Extension */
-}; /* namespace Inkscape */
+}  /* namespace Internal */
+}  /* namespace Extension */
+}  /* namespace Inkscape */
 
 
 // Remember to free the result!
