@@ -40,6 +40,7 @@ public:
 	/* Rendering methods */
 	virtual unsigned int bind (Inkscape::Extension::Print * module, const NRMatrix *transform, float opacity);
 	virtual unsigned int release (Inkscape::Extension::Print * module);
+	virtual unsigned int comment (Inkscape::Extension::Print * module, const char * comment);
 	virtual unsigned int fill (Inkscape::Extension::Print * module, const NRBPath *bpath, const NRMatrix *ctm, const SPStyle *style,
 			       const NRRect *pbox, const NRRect *dbox, const NRRect *bbox);
 	virtual unsigned int stroke (Inkscape::Extension::Print * module, const NRBPath *bpath, const NRMatrix *transform, const SPStyle *style,
@@ -50,8 +51,8 @@ public:
 	static void init (void);
 };
 
-}; /* namespace Internal */
-}; /* namespace Extension */
-}; /* namespace Inkscape */
+}  /* namespace Internal */
+}  /* namespace Extension */
+}  /* namespace Inkscape */
 
 #endif /* __INKSCAPE_EXTENSION_INTERNAL_PRINT_GNOME_H__ */
