@@ -76,4 +76,4 @@ PsOutput::init (void)
 	return;
 }
 
-};};}; /* namespace Inkscape, Extension, Implementation */
+} } }  /* namespace Inkscape, Extension, Implementation */
