@@ -16,15 +16,16 @@
 # include <config.h>
 #endif
 #include <string.h>
-#include <helper/sp-intl.h>
-#include <xml/repr.h>
-#include <sp-object.h>
-#include <document.h>
-#include <dir-util.h>
+#include <glibmm/i18n.h>
+#include "xml/repr.h"
+#include "sp-object.h"
+#include "document.h"
+#include "dir-util.h"
 #include "../implementation/implementation.h"
 #include "svg.h"
-#include <extension/system.h>
-#include <extension/output.h>
+#include "file.h"
+#include "extension/system.h"
+#include "extension/output.h"
 
 namespace Inkscape {
 namespace Extension {
@@ -46,7 +47,7 @@ void
 Svg::init(void)
 {
 	Inkscape::Extension::Extension * ext;
-	
+
 	/* SVG in */
     ext = Inkscape::Extension::build_from_mem(
 		"<inkscape-extension>\n"
@@ -61,6 +62,22 @@ Svg::init(void)
 			"</input>\n"
 		"</inkscape-extension>", new Svg());
 
+#ifdef WIN32
+    // with the new libxml DLL, it can automatically open compressed files
+    ext = Inkscape::Extension::build_from_mem(
+		"<inkscape-extension>\n"
+			"<name>SVGZ Input</name>\n"
+			"<id>" SP_MODULE_KEY_INPUT_SVGZ "</id>\n"
+                        "    <dependency type=\"extension\">" SP_MODULE_KEY_INPUT_SVG "</dependency>\n"
+			"<input>\n"
+				"<extension>.svgz</extension>\n"
+				"<mimetype>image/x-svgz</mimetype>\n"
+				"<filetypename>Compressed Inkscape SVG (*.svgz)</filetypename>\n"
+				"<filetypetooltip>Inkscape's native file format compressed with GZip</filetypetooltip>\n"
+			"</input>\n"
+		"</inkscape-extension>", new Svg());
+#endif
+
 	/* SVG out Inkscape */
     ext = Inkscape::Extension::build_from_mem(
 		"<inkscape-extension>\n"
@@ -136,7 +153,7 @@ Svg::save (Inkscape::Extension::Output *mod, SPDocument *doc, const gchar *uri)
 	g_return_if_fail(doc != NULL);
 	g_return_if_fail(uri != NULL);
 
-	gchar const *save_path = g_dirname (uri);
+	gchar *save_path = g_path_get_dirname (uri);
 
 	gboolean const spns =
 	  (!mod->get_id() || !strcmp (mod->get_id(), SP_MODULE_KEY_OUTPUT_SVG_INKSCAPE));
@@ -146,37 +163,14 @@ Svg::save (Inkscape::Extension::Output *mod, SPDocument *doc, const gchar *uri)
 	if (spns) {
 		repr = sp_document_repr_root (doc);
 	} else {
-		rdoc = sp_repr_document_new ("svg");
+		rdoc = sp_repr_document_new ("svg:svg");
 		repr = sp_repr_document_root (rdoc);
 		repr = sp_document_root (doc)->updateRepr(repr, SP_OBJECT_WRITE_BUILD);
 	}
 
-	GSList const *images = sp_document_get_resource_list (doc, "image");
-	for (GSList const *l = images; l != NULL; l = l->next) {
-		SPRepr *ir = SP_OBJECT_REPR (l->data);
+	Inkscape::IO::fixupHrefs( doc, save_path, spns );
 
-		// First try to figure out an absolute path to the asset
-		const gchar *href = sp_repr_attr (ir, "xlink:href");
-		if (spns && !g_path_is_absolute (href)) {
-			const gchar *absref = sp_repr_attr (ir, "sodipodi:absref");
-
-			if ( absref && g_file_test(absref, G_FILE_TEST_EXISTS) )
-			{
-				// only switch over if the absref is still valid
-				href = absref;
-			}
-		}
-
-		// Once we have an absolute path, convert it relative to the new location
-		if (href && g_path_is_absolute (href)) {
-			const gchar *relname = sp_relative_path_from_path (href, save_path);
-			sp_repr_set_attr (ir, "xlink:href", relname);
-		}
-// TODO next refinement is to make the first choice keeping the relative path as-is if
-//      based on the new save location it gives us a valid file.
-	}
-
-	gboolean const s = sp_repr_save_file (sp_repr_document (repr), uri);
+	gboolean const s = sp_repr_save_file (sp_repr_document (repr), uri, SP_SVG_NS_URI);
 	if (s == FALSE) {
 		throw Inkscape::Extension::Output::save_failed();
 	}
@@ -185,7 +179,20 @@ Svg::save (Inkscape::Extension::Output *mod, SPDocument *doc, const gchar *uri)
 		sp_repr_document_unref (rdoc);
 	}
 
+	g_free(save_path);
+
 	return;
 }
 
-};};}; /* namespace inkscape, module, implementation */
+} } }  /* namespace inkscape, module, implementation */
+
+/*
+  Local Variables:
+  mode:c++
+  c-file-style:"stroustrup"
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
+  indent-tabs-mode:nil
+  fill-column:99
+  End:
+*/
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
