@@ -18,7 +18,7 @@
 #include <string.h>
 
 #include <interface.h>
-#include <helper/sp-intl.h>
+#include <glibmm/i18n.h>
 #include <xml/repr.h>
 #include <document.h>
 #include <inkscape.h>
@@ -148,17 +148,21 @@ open_internal(Extension *in_plug, gpointer in_data)
         gchar const *filename = (gchar const *)parray[0];
         Input **pimod = (Input **)parray[1];
 
-        gchar const *ext = dynamic_cast<Input *>(in_plug)->get_extension();
+        // skip all the rest if we already found someone to open it
+        // since they're ordered by preference now.
+        if (!*pimod) {
+            gchar const *ext = dynamic_cast<Input *>(in_plug)->get_extension();
 
-        gchar *filenamelower = g_utf8_strdown(filename, -1);
-        gchar *extensionlower = g_utf8_strdown(ext, -1);
+            gchar *filenamelower = g_utf8_strdown(filename, -1);
+            gchar *extensionlower = g_utf8_strdown(ext, -1);
 
-        if (g_str_has_suffix(filenamelower, extensionlower)) {
-            *pimod = dynamic_cast<Input *>(in_plug);
+            if (g_str_has_suffix(filenamelower, extensionlower)) {
+                *pimod = dynamic_cast<Input *>(in_plug);
+            }
+
+            g_free(filenamelower);
+            g_free(extensionlower);
         }
-
-        g_free(filenamelower);
-        g_free(extensionlower);
     }
 
     return;
@@ -294,50 +298,26 @@ save_internal(Extension *in_plug, gpointer in_data)
         gchar const *filename = (gchar const *)parray[0];
         Output **pomod = (Output **)parray[1];
 
-        gchar const *ext = dynamic_cast<Output *>(in_plug)->get_extension();
+        // skip all the rest if we already found someone to save it
+        // since they're ordered by preference now.
+        if (!*pomod) {
+            gchar const *ext = dynamic_cast<Output *>(in_plug)->get_extension();
 
-        gchar *filenamelower = g_utf8_strdown(filename, -1);
-        gchar *extensionlower = g_utf8_strdown(ext, -1);
+            gchar *filenamelower = g_utf8_strdown(filename, -1);
+            gchar *extensionlower = g_utf8_strdown(ext, -1);
 
-        if (g_str_has_suffix(filenamelower, extensionlower)) {
-            *pomod = dynamic_cast<Output *>(in_plug);
+            if (g_str_has_suffix(filenamelower, extensionlower)) {
+                *pomod = dynamic_cast<Output *>(in_plug);
+            }
+
+            g_free(filenamelower);
+            g_free(extensionlower);
         }
-
-        g_free(filenamelower);
-        g_free(extensionlower);
     }
 
     return;
 }
 
-/**
- * \return   None
- * \brief    A function that can be attached to a menu item to
- *           execute a effect.
- * \param    object   unused (for prototype matching)
- * \param    key      Key of effect to be used
- *
- * This function just looks up the effect from the module database and then makes sure it is
- * loaded.  After that, it calls the effect function for the module.  Really, it is more of a
- * generic wrapper function.
- */
-void
-filter(GtkObject *object, gchar const *key)
-{
-    g_return_if_fail(key != NULL);
-
-    Effect *fmod = dynamic_cast<Effect *>(db.get(key));
-    g_return_if_fail(fmod != NULL);
-
-    fmod->set_state(Extension::STATE_LOADED);
-    g_return_if_fail(fmod->loaded());
-
-    SPDocument *doc = SP_DT_DOCUMENT(SP_ACTIVE_DESKTOP);
-    g_return_if_fail(doc != NULL);
-
-    return fmod->effect(doc);
-}
-
 Print *
 get_print(gchar const *key)
 {
@@ -414,12 +394,12 @@ build_from_reprdoc(SPReprDoc *doc, Implementation::Implementation *in_imp)
         switch (module_implementation_type) {
             case MODULE_EXTENSION: {
                 Implementation::Script *script = new Implementation::Script();
-                imp = dynamic_cast<Implementation::Implementation *>(script);
+                imp = static_cast<Implementation::Implementation *>(script);
                 break;
             }
             case MODULE_PLUGIN: {
                 Implementation::Plugin *plugin = new Implementation::Plugin();
-                imp = dynamic_cast<Implementation::Implementation *>(plugin);
+                imp = static_cast<Implementation::Implementation *>(plugin);
                 break;
             }
             default: {
@@ -496,8 +476,8 @@ build_from_mem(gchar const *buffer, Implementation::Implementation *in_imp)
     return ext;
 }
 
-}; }; /* namespace Inkscape::Extension */
 
+} } /* namespace Inkscape::Extension */
 
 /*
   Local Variables:
