@@ -25,12 +25,11 @@ namespace Extension {
 SPDocument *open(Extension *key, gchar const *filename);
 void save(Extension *key, SPDocument *doc, gchar const *filename,
           bool setextension, bool check_overwrite, bool official);
-void filter(GtkObject *object, gchar const *key);
 Print *get_print(gchar const *key);
 Extension *build_from_file(gchar const *filename);
 Extension *build_from_mem(gchar const *buffer, Implementation::Implementation *in_imp);
 
-}; }; /* namespace Inkscape::Extension */
+} } /* namespace Inkscape::Extension */
 
 #endif /* INKSCAPE_EXTENSION_SYSTEM_H__ */
 
