@@ -30,7 +30,6 @@
 #include <gtkmm.h>
 
 #include "macros.h"
-#include "xml/repr-private.h"
 #include "xml/repr-get-children.h"
 #include "document.h"
 #include "document-private.h"
@@ -39,7 +38,7 @@
 #include "dir-util.h"
 #include "helper/png-write.h"
 #include "dialogs/export.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "inkscape.h"
 #include "desktop.h"
 #include "selection.h"
@@ -64,15 +63,10 @@
 /* #include "extension/menu.h"  */
 #include "extension/system.h"
 
+#include "io/sys.h"
+
 #include "uri.h"
 
-#ifdef WIN32
-
-// For now to get at is_os_wide().
-#include "extension/internal/win32.h"
-using Inkscape::Extension::Internal::PrintWin32;
-#endif
-
 
 /**
  * 'Current' paths.  Used to remember which directory
@@ -88,37 +82,8 @@ static gchar *import_path = NULL;
 //#define INK_DUMP_FOPEN 1
 #undef INK_DUMP_FOPEN
 
-void ::dump_str( const gchar* str, const gchar* prefix );
-void ::dump_ustr( const Glib::ustring& ustr );
-
-
-extern guint update_in_progress;
-
-#define DEBUG_MESSAGE(key, ...) \
-{\
-    gint dump = prefs_get_int_attribute_limited("options.bulia", #key, 0, 0, 1);\
-    gint dumpD = prefs_get_int_attribute_limited("options.bulia", #key"D", 0, 0, 1);\
-    gint dumpD2 = prefs_get_int_attribute_limited("options.bulia", #key"D2", 0, 0, 1);\
-    dumpD &= ( (update_in_progress == 0) || dumpD2 );\
-    if ( dump )\
-    {\
-        g_message( __VA_ARGS__ );\
-\
-    }\
-    if ( dumpD )\
-    {\
-        GtkWidget *dialog = gtk_message_dialog_new (NULL,\
-                                                    GTK_DIALOG_DESTROY_WITH_PARENT,\
-                                                    GTK_MESSAGE_INFO,\
-                                                    GTK_BUTTONS_OK,\
-                                                    __VA_ARGS__\
-                                                    );\
-        g_signal_connect_swapped (dialog, "response",\
-                                  G_CALLBACK (gtk_widget_destroy),\
-                                  dialog);\
-        gtk_widget_show_all( dialog );\
-    }\
-}
+void dump_str(gchar const *str, gchar const *prefix);
+void dump_ustr(Glib::ustring const &ustr);
 
 
 /*######################
@@ -129,7 +94,7 @@ extern guint update_in_progress;
  * Create a blank document and add it to the desktop
  */
 void
-sp_file_new(const gchar *templ)
+sp_file_new(gchar const *templ)
 {
     SPDocument *doc = sp_document_new(templ, TRUE, TRUE, true);
     g_return_if_fail(doc != NULL);
@@ -143,13 +108,13 @@ sp_file_new(const gchar *templ)
 }
 
 void
-sp_file_new_default ()
+sp_file_new_default()
 {
     char *default_template = g_build_filename(INKSCAPE_TEMPLATESDIR, "/default.svg", NULL);
-    if (g_file_test (default_template, G_FILE_TEST_IS_REGULAR)) {
-        sp_file_new (default_template);
+    if (Inkscape::IO::file_test(default_template, G_FILE_TEST_IS_REGULAR)) {
+        sp_file_new(default_template);
     } else {
-        sp_file_new (NULL);
+        sp_file_new(NULL);
     }
 }
 
@@ -215,9 +180,11 @@ sp_file_open(gchar const *uri, Inkscape::Extension::Extension *key, bool add_to_
 
         return TRUE;
     } else {
-        gchar *text = g_strdup_printf(_("Failed to load the requested file %s"), uri);
+        gchar *safeUri = Inkscape::IO::sanitizeString(uri);
+        gchar *text = g_strdup_printf(_("Failed to load the requested file %s"), safeUri);
         sp_ui_error_dialog(text);
         g_free(text);
+        g_free(safeUri);
         return FALSE;
     }
 }
@@ -243,9 +210,8 @@ sp_file_revert_dialog()
         return;
     }
 
+    bool do_revert = true;
     if (sp_repr_attr(repr, "sodipodi:modified") != NULL) {
-        bool reverted = FALSE;
-
         gchar *text = g_strdup_printf(_("Changes will be lost!  Are you sure you want to reload document %s?"), uri);
 
         GtkWidget *dialog = gtk_message_dialog_new(
@@ -258,120 +224,103 @@ sp_file_revert_dialog()
         gtk_widget_destroy(dialog);
         g_free(text);
 
-        if (response == GTK_RESPONSE_YES) {
-            // allow overwriting of current document
-            doc->virgin=TRUE;
-            reverted = sp_file_open(uri,NULL);
-        }
-
-        if (reverted) {
-            desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Document reverted."));
-        }
-        else {
-            desktop->messageStack()->flash(Inkscape::ERROR_MESSAGE, _("Document not reverted."));
+        if (response != GTK_RESPONSE_YES) {
+            do_revert = false;
         }
     }
-    else {
-        desktop->messageStack()->flash(Inkscape::WARNING_MESSAGE, _("Document not modified.  No need to revert."));
+
+    bool reverted;
+    if (do_revert) {
+        // Allow overwriting of current document.
+        doc->virgin = TRUE;
+        reverted = sp_file_open(uri,NULL);
+    } else {
+        reverted = false;
+    }
+
+    if (reverted) {
+        desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Document reverted."));
+    } else {
+        desktop->messageStack()->flash(Inkscape::ERROR_MESSAGE, _("Document not reverted."));
     }
 }
 
-void dump_str( const gchar* str, const gchar* prefix )
+void dump_str(gchar const *str, gchar const *prefix)
 {
     Glib::ustring tmp;
     tmp = prefix;
     tmp += " [";
-    int total = strlen(str);
-    for ( int i = 0; i < total; i++ )
-    {
-        gchar* tmp2 = g_strdup_printf( " %02x", (0x0ff & str[i]) );
+    size_t const total = strlen(str);
+    for (unsigned i = 0; i < total; i++) {
+        gchar *const tmp2 = g_strdup_printf(" %02x", (0x0ff & str[i]));
         tmp += tmp2;
-        g_free( tmp2 );
+        g_free(tmp2);
     }
 
     tmp += "]";
-    g_message( tmp.c_str() );
+    g_message(tmp.c_str());
 }
 
-void ::dump_ustr( const Glib::ustring& ustr )
+void dump_ustr(Glib::ustring const &ustr)
 {
-    const char* cstr = ustr.c_str();
-    const char* data = ustr.data();
-    Glib::ustring::size_type byteLen = ustr.bytes();
-    Glib::ustring::size_type dataLen = ustr.length();
-    Glib::ustring::size_type cstrLen = strlen(cstr);
+    char const *cstr = ustr.c_str();
+    char const *data = ustr.data();
+    Glib::ustring::size_type const byteLen = ustr.bytes();
+    Glib::ustring::size_type const dataLen = ustr.length();
+    Glib::ustring::size_type const cstrLen = strlen(cstr);
 
     g_message("   size: %d\n   length: %d\n   bytes: %d\n    clen: %d", ustr.size(), dataLen, byteLen, cstrLen );
     g_message( "  ASCII? %s", (ustr.is_ascii() ? "yes":"no") );
     g_message( "  UTF-8? %s", (ustr.validate() ? "yes":"no") );
 
-    try
-    {
+    try {
         Glib::ustring tmp;
-        for ( Glib::ustring::size_type i = 0; i < ustr.bytes(); i++ )
-        {
+        for (Glib::ustring::size_type i = 0; i < ustr.bytes(); i++) {
             tmp = "    ";
-            if ( i < dataLen )
-            {
+            if (i < dataLen) {
                 Glib::ustring::value_type val = ustr.at(i);
                 gchar* tmp2 = g_strdup_printf( (((val & 0xff00) == 0) ? "  %02x" : "%04x"), val );
                 tmp += tmp2;
                 g_free( tmp2 );
-            }
-            else
-            {
+            } else {
                 tmp += "    ";
             }
 
-            if ( i < byteLen )
-            {
+            if (i < byteLen) {
                 int val = (0x0ff & data[i]);
-                gchar* tmp2 = g_strdup_printf( "    %02x", val );
+                gchar *tmp2 = g_strdup_printf("    %02x", val);
                 tmp += tmp2;
                 g_free( tmp2 );
-                if ( val > 32 && val < 127 )
-                {
+                if ( val > 32 && val < 127 ) {
                     tmp2 = g_strdup_printf( "   '%c'", (gchar)val );
                     tmp += tmp2;
                     g_free( tmp2 );
-                }
-                else
-                {
+                } else {
                     tmp += "    . ";
                 }
-            }
-            else
-            {
+            } else {
                 tmp += "       ";
             }
 
-            if ( i < cstrLen )
-            {
+            if ( i < cstrLen ) {
                 int val = (0x0ff & cstr[i]);
-                gchar* tmp2 = g_strdup_printf( "    %02x", val );
+                gchar* tmp2 = g_strdup_printf("    %02x", val);
                 tmp += tmp2;
-                g_free( tmp2 );
-                if ( val > 32 && val < 127 )
-                {
-                    tmp2 = g_strdup_printf( "   '%c'", (gchar)val );
+                g_free(tmp2);
+                if ( val > 32 && val < 127 ) {
+                    tmp2 = g_strdup_printf("   '%c'", (gchar) val);
                     tmp += tmp2;
                     g_free( tmp2 );
-                }
-                else
-                {
+                } else {
                     tmp += "    . ";
                 }
-            }
-            else
-            {
+            } else {
                 tmp += "            ";
             }
 
             g_message( tmp.c_str() );
         }
-    }
-    catch (...)
-    {
+    } catch (...) {
         g_message("XXXXXXXXXXXXXXXXXX Exception" );
     }
     g_message("---------------");
@@ -385,29 +334,27 @@ static Inkscape::UI::Dialogs::FileOpenDialog *openDialogInstance = NULL;
 void
 sp_file_open_dialog(gpointer object, gpointer data)
 {
-    gchar * open_path = NULL;
-    gchar * open_path2 = NULL;
+    gchar *open_path2 = NULL;
 
-    open_path = g_strdup(prefs_get_string_attribute("dialogs.open", "path"));
+    gchar *open_path = g_strdup(prefs_get_string_attribute("dialogs.open", "path"));
     if (open_path != NULL && open_path[0] == '\0') {
         g_free(open_path);
         open_path = NULL;
     }
-    if (open_path && !g_file_test(open_path, (GFileTest)(G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))) {
+    if (open_path && !Inkscape::IO::file_test(open_path, (GFileTest)(G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))) {
         g_free(open_path);
         open_path = NULL;
     }
     if (open_path == NULL)
         open_path = g_strconcat(g_get_home_dir(), G_DIR_SEPARATOR_S, NULL);
 
-    if (!openDialogInstance)
-        {
+    if (!openDialogInstance) {
         openDialogInstance =
               Inkscape::UI::Dialogs::FileOpenDialog::create(
                  (char const *)open_path,
                  Inkscape::UI::Dialogs::SVG_TYPES,
                  (char const *)_("Select file to open"));
-        }
+    }
     bool const success = openDialogInstance->show();
     gchar *fileName = ( success
                         ? g_strdup(openDialogInstance->getFilename())
@@ -424,28 +371,24 @@ sp_file_open_dialog(gpointer object, gpointer data)
 #ifdef INK_DUMP_FILENAME_CONV
         dump_str( fileName, "A file pre  is " );
 #endif
-        gchar *newFileName = g_filename_to_utf8( fileName,
-                                                 -1,
-                                                 &bytesRead,
-                                                 &bytesWritten,
-                                                 &error);
-        if ( newFileName != NULL )
-        {
+        gchar *newFileName = g_filename_to_utf8(fileName,
+                                                -1,
+                                                &bytesRead,
+                                                &bytesWritten,
+                                                &error);
+        if ( newFileName != NULL ) {
             g_free(fileName);
             fileName = newFileName;
 #ifdef INK_DUMP_FILENAME_CONV
             dump_str( fileName, "A file post is " );
 #endif
-        }
-        else
-        {
+        } else {
             // TODO: bulia, please look over
             g_warning( "ERROR CONVERTING OPEN FILENAME TO UTF-8" );
         }
 
 
-        if ( !g_utf8_validate(fileName, -1, NULL) )
-        {
+        if ( !g_utf8_validate(fileName, -1, NULL) ) {
             // TODO: bulia, please look over
             g_warning( "INPUT FILENAME IS NOT UTF-8" );
         }
@@ -477,32 +420,35 @@ sp_file_open_dialog(gpointer object, gpointer data)
 void
 sp_file_vacuum()
 {
-    SPDocument* doc = SP_ACTIVE_DOCUMENT;
+    SPDocument *doc = SP_ACTIVE_DOCUMENT;
     SPDefs *defs = SP_ROOT(SP_DOCUMENT_ROOT(doc))->defs;
 
     int before = 0;
     for (SPObject *i = sp_object_first_child(defs); i != NULL; i = SP_OBJECT_NEXT(i)) {
-        before ++;
+        before++;
     }
 
-    for ( SPObject* def = defs->firstChild () ;
-          def ; def = SP_OBJECT_NEXT (def) )
-    {
-
+    for (SPObject *def = defs->firstChild(); def; def = SP_OBJECT_NEXT(def)) {
         /* fixme: some inkscape-internal nodes in the future might not be collectable */
-        def->requestOrphanCollection ();
+        def->requestOrphanCollection();
     }
 
-    sp_document_done (doc);
+    sp_document_done(doc);
 
     int after = 0;
     for (SPObject *i = sp_object_first_child(defs); i != NULL; i = SP_OBJECT_NEXT(i)) {
-        after ++;
+        after++;
     }
 
     SPDesktop *dt = SP_ACTIVE_DESKTOP;
     if (before - after > 0) {
-        dt->messageStack()->flashF(Inkscape::NORMAL_MESSAGE,  _("Removed <b>%i</b> unused item(s) in &lt;defs&gt;."), before - after);
+        int diff = before - after;
+
+        dt->messageStack()->flashF(Inkscape::NORMAL_MESSAGE,
+                ngettext("Removed <b>%i</b> unused item in &lt;defs&gt;.",
+                         "Removed <b>%i</b> unused items in &lt;defs&gt;.",
+                         diff),
+                diff);
     } else {
         dt->messageStack()->flash(Inkscape::NORMAL_MESSAGE,  _("No unused items in &lt;defs&gt;."));
     }
@@ -528,16 +474,20 @@ file_save(SPDocument *doc, gchar const *uri, Inkscape::Extension::Extension *key
                                   saveas && prefs_get_int_attribute("dialogs.save_as", "append_extension", 1),
                                   saveas, TRUE); // save officially, with inkscape: attributes set
     } catch (Inkscape::Extension::Output::no_extension_found &e) {
-        gchar *text = g_strdup_printf(_("No Inkscape extension found to save document (%s).  This may have been caused by an unknown filename extension."), uri);
+        gchar *safeUri = Inkscape::IO::sanitizeString(uri);
+        gchar *text = g_strdup_printf(_("No Inkscape extension found to save document (%s).  This may have been caused by an unknown filename extension."), safeUri);
         SP_ACTIVE_DESKTOP->messageStack()->flash(Inkscape::ERROR_MESSAGE, _("Document not saved."));
         sp_ui_error_dialog(text);
         g_free(text);
+        g_free(safeUri);
         return FALSE;
     } catch (Inkscape::Extension::Output::save_failed &e) {
-        gchar *text = g_strdup_printf(_("File %s could not be saved."), uri);
+        gchar *safeUri = Inkscape::IO::sanitizeString(uri);
+        gchar *text = g_strdup_printf(_("File %s could not be saved."), safeUri);
         SP_ACTIVE_DESKTOP->messageStack()->flash(Inkscape::ERROR_MESSAGE, _("Document not saved."));
         sp_ui_error_dialog(text);
         g_free(text);
+        g_free(safeUri);
         return FALSE;
     } catch (Inkscape::Extension::Output::no_overwrite &e) {
         return sp_file_save_dialog(doc);
@@ -565,7 +515,7 @@ sp_file_save_dialog(SPDocument *doc)
     if (default_extension == NULL) {
         default_extension = prefs_get_string_attribute("dialogs.save_as", "default");
     }
-    // printf("Extension: %s\n", default_extension);
+    //g_warning("%s: extension name: '%s'", __FUNCTION__, default_extension);
 
     if (doc->uri == NULL) {
         int i = 1;
@@ -573,6 +523,7 @@ sp_file_save_dialog(SPDocument *doc)
         char *temp_filename;
 
         extension = dynamic_cast<Inkscape::Extension::Output *>(Inkscape::Extension::db.get(default_extension));
+        //g_warning("%s: extension ptr: 0x%x", __FUNCTION__, (unsigned int)extension);
         if (extension == NULL) {
             filename_extension = ".svg";
         } else {
@@ -584,7 +535,7 @@ sp_file_save_dialog(SPDocument *doc)
             g_free(save_path);
             save_path = NULL;
         }
-        if (save_path && !g_file_test(save_path, (GFileTest)(G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))) {
+        if (save_path && !Inkscape::IO::file_test(save_path, (GFileTest)(G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))) {
             g_free(save_path);
             save_path = NULL;
         }
@@ -594,7 +545,7 @@ sp_file_save_dialog(SPDocument *doc)
         save_loc = g_build_filename(save_path, temp_filename, NULL);
         g_free(temp_filename);
 
-        while (g_file_test(save_loc, G_FILE_TEST_EXISTS)) {
+        while (Inkscape::IO::file_test(save_loc, G_FILE_TEST_EXISTS)) {
             g_free(save_loc);
             temp_filename = g_strdup_printf(_("drawing-%d%s"), i++, filename_extension);
             save_loc = g_build_filename(save_path, temp_filename, NULL);
@@ -604,14 +555,16 @@ sp_file_save_dialog(SPDocument *doc)
         save_loc = g_strdup(doc->uri); /* \todo should use a getter */
     }
 
-    { // convert save_lock from utf-8 to locale
+    { // convert save_loc from utf-8 to locale
+      // is this needed any more, now that everything is handled in
+      // Inkscape::IO?
         gsize bytesRead = 0;
         gsize bytesWritten = 0;
         GError* error = NULL;
 #ifdef INK_DUMP_FILENAME_CONV
         dump_str( save_loc, "B file pre  is " );
 #endif
-        gchar* save_loc_local = g_filename_from_utf8 ( save_loc, -1, &bytesRead, &bytesWritten, &error);
+        gchar* save_loc_local = g_filename_from_utf8( save_loc, -1, &bytesRead, &bytesWritten, &error);
 
         if ( save_loc_local != NULL ) {
             g_free(save_loc);
@@ -620,12 +573,11 @@ sp_file_save_dialog(SPDocument *doc)
             dump_str( save_loc, "B file post is " );
 #endif
         } else {
-            g_warning( "Error converting save filename stored in the file to locale encoding.");
+            //g_warning( "Error converting save filename stored in the file to locale encoding.");
         }
     }
 
-    if (!saveDialogInstance)
-        {
+    if (!saveDialogInstance) {
         saveDialogInstance =
              Inkscape::UI::Dialogs::FileSaveDialog::create(
                  (char const *) save_loc,
@@ -633,7 +585,7 @@ sp_file_save_dialog(SPDocument *doc)
                  (char const *) _("Select file to save to"),
                  default_extension
             );
-        }
+    }
     bool success = saveDialogInstance->show();
     char *fileName = ( success
                        ? g_strdup(saveDialogInstance->getFilename())
@@ -642,7 +594,9 @@ sp_file_save_dialog(SPDocument *doc)
         saveDialogInstance->getSelectionType();
     g_free(save_loc);
     g_free(save_path);
-    if (!success) return success;
+    if (!success) {
+        return success;
+    }
 
     if (fileName && *fileName) {
         gsize bytesRead = 0;
@@ -651,34 +605,31 @@ sp_file_save_dialog(SPDocument *doc)
 #ifdef INK_DUMP_FILENAME_CONV
         dump_str( fileName, "C file pre  is " );
 #endif
-        gchar *newFileName = g_filename_to_utf8( fileName,
-                                                 -1,
-                                                 &bytesRead,
-                                                 &bytesWritten,
-                                                 &error);
-        if ( newFileName != NULL )
-        {
+        gchar *newFileName = g_filename_to_utf8(fileName,
+                                                -1,
+                                                &bytesRead,
+                                                &bytesWritten,
+                                                &error);
+        if ( newFileName != NULL ) {
             g_free(fileName);
             fileName = newFileName;
 #ifdef INK_DUMP_FILENAME_CONV
             dump_str( fileName, "C file post is " );
 #endif
-        }
-        else
-        {
+        } else {
             g_warning( "Error converting save filename to UTF-8." );
         }
 
-        if ( !g_utf8_validate(fileName, -1, NULL) )
-        {
+        if (!g_utf8_validate(fileName, -1, NULL)) {
             // TODO: bulia, please look over
             g_warning( "The filename is not UTF-8." );
         }
 
         success = file_save(doc, fileName, selectionType, TRUE);
 
-        if (success)
+        if (success) {
             prefs_set_recent_file(SP_DOCUMENT_URI(doc), SP_DOCUMENT_NAME(doc));
+        }
 
         save_path = g_dirname(fileName);
         prefs_set_string_attribute("dialogs.save_as", "path", save_path);
@@ -704,8 +655,9 @@ sp_file_save_document(SPDocument *doc)
 
     gchar const *fn = sp_repr_attr(repr, "sodipodi:modified");
     if (fn != NULL) {
-        if (doc->uri == NULL ||
-            sp_repr_attr(repr, "inkscape:output_extension") == NULL) {
+        if (doc->uri == NULL
+            || sp_repr_attr(repr, "inkscape:output_extension") == NULL)
+        {
             return sp_file_save_dialog(doc);
         } else {
             fn = g_strdup(doc->uri);
@@ -760,7 +712,9 @@ sp_file_save_as(gpointer object, gpointer data)
 void
 file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension *key)
 {
-    DEBUG_MESSAGE( fileImport, "file_import( in_doc:%p uri:[%s], key:%p", in_doc, uri, key );
+    SPDesktop *desktop = SP_ACTIVE_DESKTOP;
+
+    //DEBUG_MESSAGE( fileImport, "file_import( in_doc:%p uri:[%s], key:%p", in_doc, uri, key );
     SPDocument *doc;
     try {
         doc = Inkscape::Extension::open(key, uri);
@@ -786,14 +740,17 @@ file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension
         SPObject *in_defs = SP_DOCUMENT_DEFS(in_doc);
         SPObject *defs = SP_DOCUMENT_DEFS(doc);
         SPRepr *last_def = sp_repr_last_child(SP_OBJECT_REPR(in_defs));
-        for (SPObject *child = sp_object_first_child(defs); child != NULL; child = SP_OBJECT_NEXT(child) ) {
+        for (SPObject *child = sp_object_first_child(defs);
+             child != NULL; child = SP_OBJECT_NEXT(child))
+        {
             // FIXME: in case of id conflict, newly added thing will be re-ided and thus likely break a reference to it from imported stuff
             sp_repr_add_child(SP_OBJECT_REPR(in_defs), sp_repr_duplicate(SP_OBJECT_REPR(child)), last_def);
         }
 
         SPRepr *repr = sp_document_repr_root(doc);
         guint items_count = 0;
-        for (SPObject *child = sp_object_first_child(SP_DOCUMENT_ROOT(doc)); child != NULL; child = SP_OBJECT_NEXT(child) ) {
+        for (SPObject *child = sp_object_first_child(SP_DOCUMENT_ROOT(doc));
+             child != NULL; child = SP_OBJECT_NEXT(child)) {
             if (SP_IS_ITEM(child))
                 items_count ++;
         }
@@ -803,7 +760,7 @@ file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension
 
         if (style || items_count > 1) {
             // create group
-            SPRepr *newgroup = sp_repr_new("g");
+            SPRepr *newgroup = sp_repr_new("svg:g");
             sp_repr_set_attr(newgroup, "style", style);
 
             for (SPObject *child = sp_object_first_child(SP_DOCUMENT_ROOT(doc)); child != NULL; child = SP_OBJECT_NEXT(child) ) {
@@ -812,26 +769,50 @@ file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension
                 }
             }
 
-            new_obj = SP_DOCUMENT_ROOT(in_doc)->appendChildRepr(newgroup);
+            if (desktop) {
+                // Add it to the current layer
+                new_obj = desktop->currentLayer()->appendChildRepr(newgroup);
+            } else {
+                // There's no desktop (command line run?)
+                // FIXME: For such cases we need a document:: method to return the current layer
+                new_obj = SP_DOCUMENT_ROOT(in_doc)->appendChildRepr(newgroup);
+            }
+
             sp_repr_unref(newgroup);
         } else {
             // just add one item
             for (SPObject *child = sp_object_first_child(SP_DOCUMENT_ROOT(doc)); child != NULL; child = SP_OBJECT_NEXT(child) ) {
                 if (SP_IS_ITEM(child)) {
                     SPRepr *newitem = sp_repr_duplicate(SP_OBJECT_REPR(child));
-                    new_obj = SP_DOCUMENT_ROOT(in_doc)->appendChildRepr(newitem);
+
+                    if (desktop) {
+                        // Add it to the current layer
+                        new_obj = desktop->currentLayer()->appendChildRepr(newitem);
+                    } else {
+                        // There's no desktop (command line run?)
+                        // FIXME: For such cases we need a document:: method to return the current layer
+                        new_obj = SP_DOCUMENT_ROOT(in_doc)->appendChildRepr(newitem);
+                    }
+
                 }
             }
         }
 
         // select and move the imported item
         if (new_obj && SP_IS_ITEM(new_obj)) {
-            SPDesktop *desktop = SP_ACTIVE_DESKTOP;
             SPSelection *selection = SP_DT_SELECTION(desktop);
             selection->setItem(SP_ITEM(new_obj));
-            sp_document_ensure_up_to_date(SP_DT_DOCUMENT(desktop));
-            NR::Point m( sp_desktop_point(desktop) - selection->bounds().midpoint() );
-            sp_selection_move_relative(selection, m[NR::X], m[NR::Y]);
+
+            // To move the imported object, we must temporarily set the "transform pattern with
+            // object" option.
+            {
+                int const saved_pref = prefs_get_int_attribute("options.transform", "pattern", 1);
+                prefs_set_int_attribute("options.transform", "pattern", 1);
+                sp_document_ensure_up_to_date(SP_DT_DOCUMENT(desktop));
+                NR::Point m( sp_desktop_point(desktop) - selection->bounds().midpoint() );
+                sp_selection_move_relative(selection, m);
+                prefs_set_int_attribute("options.transform", "pattern", saved_pref);
+            }
         }
 
         sp_document_unref(doc);
@@ -859,14 +840,13 @@ sp_file_import(GtkWidget *widget)
     if (!SP_IS_DOCUMENT(doc))
         return;
 
-    if (!importDialogInstance)
-        {
+    if (!importDialogInstance) {
         importDialogInstance =
              Inkscape::UI::Dialogs::FileOpenDialog::create(
                  (char const *)import_path,
                  Inkscape::UI::Dialogs::IMPORT_TYPES,
                  (char const *)_("Select file to import"));
-        }
+    }
     bool success = importDialogInstance->show();
     char *fileName = ( success
                        ? g_strdup(importDialogInstance->getFilename())
@@ -887,23 +867,19 @@ sp_file_import(GtkWidget *widget)
                                                  &bytesRead,
                                                  &bytesWritten,
                                                  &error);
-        if ( newFileName != NULL )
-        {
+        if ( newFileName != NULL ) {
             g_free(fileName);
             fileName = newFileName;
 #ifdef INK_DUMP_FILENAME_CONV
             dump_str( fileName, "D file post is " );
 #endif
-        }
-        else
-        {
+        } else {
             // TODO: bulia, please look over
             g_warning( "ERROR CONVERTING OPEN FILENAME TO UTF-8" );
         }
 
 
-        if ( !g_utf8_validate(fileName, -1, NULL) )
-        {
+        if (!g_utf8_validate(fileName, -1, NULL)) {
             // TODO: bulia, please look over
             g_warning( "INPUT FILENAME IS NOT UTF-8" );
         }
@@ -942,7 +918,7 @@ struct SPEBP {
     guchar r, g, b, a;
     NRArenaItem *root; // the root arena item to show; it is assumed that all unneeded items are hidden
     guchar *px;
-    unsigned (*status) (float, void *);
+    unsigned (*status)(float, void *);
     void *data;
 };
 
@@ -1005,16 +981,21 @@ sp_export_get_rows(guchar const **rows, int row, int num_rows, void *data)
 Hide all items which are not listed in list, recursively, skipping groups and defs
 */
 void
-hide_other_items_recursively (SPObject *o, GSList *list, unsigned dkey)
+hide_other_items_recursively(SPObject *o, GSList *list, unsigned dkey)
 {
-    if (SP_IS_ITEM(o) && !SP_IS_DEFS(o) && !SP_IS_ROOT(o) && !SP_IS_GROUP(o) && !g_slist_find (list, o)) {
+    if (SP_IS_ITEM(o)
+        && !SP_IS_DEFS(o)
+        && !SP_IS_ROOT(o)
+        && !SP_IS_GROUP(o)
+        && !g_slist_find(list, o))
+    {
         sp_item_invoke_hide(SP_ITEM(o), dkey);
     }
 
      // recurse
-    if (!g_slist_find (list, o)) {
+    if (!g_slist_find(list, o)) {
         for (SPObject *child = sp_object_first_child(o) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
-            hide_other_items_recursively (child, list, dkey);
+            hide_other_items_recursively(child, list, dkey);
         }
     }
 }
@@ -1069,12 +1050,12 @@ sp_export_png_file(SPDocument *doc, gchar const *filename,
      */
 
     NRMatrix affine;
-    affine.c[0] = width / ((x1 - x0) * 1.25);
+    affine.c[0] = width / (x1 - x0);
     affine.c[1] = 0.0;
     affine.c[2] = 0.0;
-    affine.c[3] = height / ((y1 - y0) * 1.25);
-    affine.c[4] = -affine.c[0] * x0 * 1.25;
-    affine.c[5] = -affine.c[3] * y0 * 1.25;
+    affine.c[3] = height / (y1 - y0);
+    affine.c[4] = -affine.c[0] * x0;
+    affine.c[5] = -affine.c[3] * y0;
 
     //SP_PRINT_MATRIX("SVG2PNG", &affine);
 
@@ -1091,13 +1072,13 @@ sp_export_png_file(SPDocument *doc, gchar const *filename,
     unsigned dkey = sp_item_display_key_new(1);
 
     /* Create ArenaItems and set transform */
-    ebp.root = sp_item_invoke_show(SP_ITEM(sp_document_root(doc)), arena, dkey, SP_ITEM_SHOW_PRINT);
-    nr_arena_item_set_transform(NR_ARENA_ITEM (ebp.root), NR::Matrix (&affine));
+    ebp.root = sp_item_invoke_show(SP_ITEM(sp_document_root(doc)), arena, dkey, SP_ITEM_SHOW_DISPLAY);
+    nr_arena_item_set_transform(NR_ARENA_ITEM(ebp.root), NR::Matrix(&affine));
 
     // We show all and then hide all items we don't want, instead of showing only requested items,
     // because that would not work if the shown item references something in defs
     if (items_only) {
-        hide_other_items_recursively (sp_document_root(doc), items_only, dkey);
+        hide_other_items_recursively(sp_document_root(doc), items_only, dkey);
     }
 
     ebp.status = status;
@@ -1169,110 +1150,9 @@ sp_file_print_preview(gpointer object, gpointer data)
 
 }
 
-void Inkscape::IO::dump_fopen_call( char const *utf8name, char const *id )
-{
-#ifdef INK_DUMP_FOPEN
-    Glib::ustring str;
-    for ( int i = 0; utf8name[i]; i++ )
-    {
-        if ( utf8name[i] == '\\' )
-        {
-            str += "\\\\";
-        }
-        else if ( (utf8name[i] >= 0x20) && ((0x0ff & utf8name[i]) <= 0x7f) )
-        {
-            str += utf8name[i];
-        }
-        else
-        {
-            gchar tmp[32];
-            g_snprintf( tmp, sizeof(tmp), "\\x%02x", (0x0ff & utf8name[i]) );
-            str += tmp;
-        }
-    }
-    g_message( "fopen call %s for [%s]", id, str.data() );
-#endif
-}
-
-FILE *Inkscape::IO::fopen_utf8name( char const *utf8name, char const *mode )
-{
-    static gint counter = 0;
-    FILE* fp = NULL;
-
-    DEBUG_MESSAGE( dumpOne, "entering fopen_utf8name( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-
-#ifndef WIN32
-    DEBUG_MESSAGE( dumpOne, "           STEP 0              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-    gchar *filename = g_filename_from_utf8( utf8name, -1, NULL, NULL, NULL );
-    if ( filename )
-    {
-        DEBUG_MESSAGE( dumpOne, "           STEP 1              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        fp = std::fopen(filename, mode);
-        DEBUG_MESSAGE( dumpOne, "           STEP 2              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        g_free(filename);
-        DEBUG_MESSAGE( dumpOne, "           STEP 3              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        filename = 0;
-    }
-#else
-    Glib::ustring how( mode );
-    how.append("b");
-    DEBUG_MESSAGE( dumpOne, "   calling is_os_wide()       ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-    if ( PrintWin32::is_os_wide() )
-    {
-        DEBUG_MESSAGE( dumpOne, "           is_os_wide() true   ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        gunichar2 *wideName = g_utf8_to_utf16( utf8name, -1, NULL, NULL, NULL );
-        DEBUG_MESSAGE( dumpOne, "           STEP 1              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        if ( wideName )
-        {
-            DEBUG_MESSAGE( dumpOne, "           STEP 2              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-            gunichar2 *wideMode = g_utf8_to_utf16( how.c_str(), -1, NULL, NULL, NULL );
-            DEBUG_MESSAGE( dumpOne, "           STEP 3              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-            if ( wideMode )
-            {
-                DEBUG_MESSAGE( dumpOne, "           STEP 4              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-                fp = _wfopen( (wchar_t*)wideName, (wchar_t*)wideMode );
-                DEBUG_MESSAGE( dumpOne, "           STEP 5              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-                g_free( wideMode );
-                DEBUG_MESSAGE( dumpOne, "           STEP 6              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-                wideMode = 0;
-            }
-            else
-            {
-                DEBUG_MESSAGE( dumpOne, "           STEP 7              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-                g_message("Unable to convert mode from UTF-8 to UTF-16");
-            }
-            DEBUG_MESSAGE( dumpOne, "           STEP 8              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-            g_free( wideName );
-            DEBUG_MESSAGE( dumpOne, "           STEP 9              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-            wideName = 0;
-        }
-        else
-        {
-            DEBUG_MESSAGE( dumpOne, "           STEP A              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-            g_message("Unable to convert filename from UTF-8 to UTF-16");
-        }
-    }
-    else
-    {
-        DEBUG_MESSAGE( dumpOne, "           is_os_wide() false  ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        gchar *filename = g_filename_from_utf8( utf8name, -1, NULL, NULL, NULL );
-        DEBUG_MESSAGE( dumpOne, "           STEP 1              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        fp = std::fopen(filename, how.c_str());
-        DEBUG_MESSAGE( dumpOne, "           STEP 2              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        g_free(filename);
-        DEBUG_MESSAGE( dumpOne, "           STEP 3              ( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-        filename = 0;
-    }
-#endif
-
-    DEBUG_MESSAGE( dumpOne, "leaving fopen_utf8name( '%s', '%s' )[%d]", utf8name, mode, (counter++) );
-
-    return fp;
-}
-
 void Inkscape::IO::fixupHrefs( SPDocument *doc, const gchar *base, gboolean spns )
 {
-    g_message("Inkscape::IO::fixupHrefs( , [%s], )", base );
+    //g_message("Inkscape::IO::fixupHrefs( , [%s], )", base );
 
     if ( 0 ) {
         gchar const* things[] = {
@@ -1334,31 +1214,31 @@ void Inkscape::IO::fixupHrefs( SPDocument *doc, const gchar *base, gboolean spns
         g_message("+------");
     }
 
-    GSList const *images = sp_document_get_resource_list (doc, "image");
+    GSList const *images = sp_document_get_resource_list(doc, "image");
     for (GSList const *l = images; l != NULL; l = l->next) {
-        SPRepr *ir = SP_OBJECT_REPR (l->data);
+        SPRepr *ir = SP_OBJECT_REPR(l->data);
 
-        const gchar *href = sp_repr_attr (ir, "xlink:href");
+        const gchar *href = sp_repr_attr(ir, "xlink:href");
 
         // First try to figure out an absolute path to the asset
-        g_message("image href [%s]", href );
-        if (spns && !g_path_is_absolute (href)) {
-            const gchar *absref = sp_repr_attr (ir, "sodipodi:absref");
-            g_message("      absr [%s]", absref );
+        //g_message("image href [%s]", href );
+        if (spns && !g_path_is_absolute(href)) {
+            const gchar *absref = sp_repr_attr(ir, "sodipodi:absref");
+            //g_message("      absr [%s]", absref );
 
-            if ( absref && g_file_test(absref, G_FILE_TEST_EXISTS) )
+            if ( absref && Inkscape::IO::file_test(absref, G_FILE_TEST_EXISTS) )
             {
                 // only switch over if the absref is still valid
                 href = absref;
-                g_message("     copied absref to href");
+                //g_message("     copied absref to href");
             }
         }
 
         // Once we have an absolute path, convert it relative to the new location
-        if (href && g_path_is_absolute (href)) {
-            const gchar *relname = sp_relative_path_from_path (href, base);
-            g_message("     setting to [%s]", relname );
-            sp_repr_set_attr (ir, "xlink:href", relname);
+        if (href && g_path_is_absolute(href)) {
+            const gchar *relname = sp_relative_path_from_path(href, base);
+            //g_message("     setting to [%s]", relname );
+            sp_repr_set_attr(ir, "xlink:href", relname);
         }
 // TODO next refinement is to make the first choice keeping the relative path as-is if
 //      based on the new location it gives us a valid file.
