@@ -36,8 +36,8 @@
 #define g_marshal_value_peek_ulong(v)    (v)->data[0].v_ulong
 #define g_marshal_value_peek_int64(v)    (v)->data[0].v_int64
 #define g_marshal_value_peek_uint64(v)   (v)->data[0].v_uint64
-#define g_marshal_value_peek_enum(v)     (v)->data[0].v_int
-#define g_marshal_value_peek_flags(v)    (v)->data[0].v_uint
+#define g_marshal_value_peek_enum(v)     (v)->data[0].v_long
+#define g_marshal_value_peek_flags(v)    (v)->data[0].v_ulong
 #define g_marshal_value_peek_float(v)    (v)->data[0].v_float
 #define g_marshal_value_peek_double(v)   (v)->data[0].v_double
 #define g_marshal_value_peek_string(v)   (v)->data[0].v_pointer
@@ -48,13 +48,13 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* NONE:NONE (./sp-marshal.list:2) */
+/* NONE:NONE (./helper/sp-marshal.list:2) */
 
-/* NONE:UINT (./sp-marshal.list:3) */
+/* NONE:UINT (./helper/sp-marshal.list:3) */
 
-/* NONE:POINTER (./sp-marshal.list:4) */
+/* NONE:POINTER (./helper/sp-marshal.list:4) */
 
-/* NONE:POINTER,BOOLEAN (./sp-marshal.list:5) */
+/* NONE:POINTER,BOOLEAN (./helper/sp-marshal.list:5) */
 void
 sp_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                   GValue       *return_value,
@@ -91,7 +91,7 @@ sp_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* NONE:POINTER,UINT (./sp-marshal.list:6) */
+/* NONE:POINTER,UINT (./helper/sp-marshal.list:6) */
 void
 sp_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                GValue       *return_value,
@@ -128,7 +128,7 @@ sp_marshal_VOID__POINTER_UINT (GClosure     *closure,
             data2);
 }
 
-/* NONE:POINTER,DOUBLE (./sp-marshal.list:7) */
+/* NONE:POINTER,DOUBLE (./helper/sp-marshal.list:7) */
 void
 sp_marshal_VOID__POINTER_DOUBLE (GClosure     *closure,
                                  GValue       *return_value,
@@ -165,7 +165,7 @@ sp_marshal_VOID__POINTER_DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* NONE:DOUBLE,DOUBLE (./sp-marshal.list:8) */
+/* NONE:DOUBLE,DOUBLE (./helper/sp-marshal.list:8) */
 void
 sp_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                 GValue       *return_value,
@@ -202,7 +202,7 @@ sp_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* NONE:STRING,BOOL (./sp-marshal.list:9) */
+/* NONE:STRING,BOOL (./helper/sp-marshal.list:9) */
 void
 sp_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                  GValue       *return_value,
@@ -239,7 +239,7 @@ sp_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* BOOLEAN:NONE (./sp-marshal.list:10) */
+/* BOOLEAN:NONE (./helper/sp-marshal.list:10) */
 void
 sp_marshal_BOOLEAN__VOID (GClosure     *closure,
                           GValue       *return_value,
@@ -276,7 +276,7 @@ sp_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:UINT (./sp-marshal.list:11) */
+/* BOOLEAN:UINT (./helper/sp-marshal.list:11) */
 void
 sp_marshal_BOOLEAN__UINT (GClosure     *closure,
                           GValue       *return_value,
@@ -315,7 +315,7 @@ sp_marshal_BOOLEAN__UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:POINTER (./sp-marshal.list:12) */
+/* BOOLEAN:POINTER (./helper/sp-marshal.list:12) */
 void
 sp_marshal_BOOLEAN__POINTER (GClosure     *closure,
                              GValue       *return_value,
@@ -354,7 +354,7 @@ sp_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:POINTER,UINT (./sp-marshal.list:13) */
+/* BOOLEAN:POINTER,UINT (./helper/sp-marshal.list:13) */
 void
 sp_marshal_BOOLEAN__POINTER_UINT (GClosure     *closure,
                                   GValue       *return_value,
@@ -395,7 +395,7 @@ sp_marshal_BOOLEAN__POINTER_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:POINTER,POINTER (./sp-marshal.list:14) */
+/* BOOLEAN:POINTER,POINTER (./helper/sp-marshal.list:14) */
 void
 sp_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                      GValue       *return_value,
@@ -436,7 +436,7 @@ sp_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* INT:POINTER,POINTER (./sp-marshal.list:15) */
+/* INT:POINTER,POINTER (./helper/sp-marshal.list:15) */
 void
 sp_marshal_INT__POINTER_POINTER (GClosure     *closure,
                                  GValue       *return_value,
@@ -477,7 +477,7 @@ sp_marshal_INT__POINTER_POINTER (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-/* DOUBLE:POINTER,UINT (./sp-marshal.list:16) */
+/* DOUBLE:POINTER,UINT (./helper/sp-marshal.list:16) */
 void
 sp_marshal_DOUBLE__POINTER_UINT (GClosure     *closure,
                                  GValue       *return_value,
