@@ -18,7 +18,7 @@
 #include <glib/gmessages.h>
 #include <glib/gslist.h>
 #include <glib/gtypes.h>
-
+#include "sp-metric.h"
 
 
 /*
@@ -86,6 +86,8 @@ struct SPUnit {
 	SPUnitId unit_id; /* used as sanity check */
 	SPUnitBase base;
 	gdouble unittobase; /* how many base units in this unit */
+	SPMetric metric; // the corresponding SPMetric from sp-metrics.h
+
 	/* I am not absolutely sure, but seems that gettext can do the magic */
 	gchar const *name;
 	gchar const *abbr;
@@ -93,15 +95,10 @@ struct SPUnit {
 	gchar const *abbr_plural;
 };
 
-struct SPDistance {
-	const SPUnit *unit;
-	gdouble distance;
-};
-
-/* Base units are the ones used by gnome-print and paper descriptions */
-
-const SPUnit *sp_unit_get_identity (guint base);
 const SPUnit *sp_unit_get_by_abbreviation (const gchar *abbreviation);
+const gchar *sp_unit_get_abbreviation (const SPUnit *unit);
+gchar const *sp_unit_get_plural (SPUnit const *unit);
+SPMetric sp_unit_get_metric(SPUnit const *unit);
 
 extern SPUnit const sp_units[];
 
@@ -131,33 +128,12 @@ void sp_unit_free_list (GSList *units);
 /* Return TRUE if conversion is possible, FALSE if unit bases differ */
 gboolean sp_convert_distance (gdouble *distance, const SPUnit *from, const SPUnit *to);
 
-/* devicescale is device->absolute */
 /* If either one is NULL, transconverting to/from that base fails */
 /* Generic conversion between volatile units would be useless anyways */
-gdouble sp_convert_distance_full(gdouble const from_dist, SPUnit const &from, SPUnit const &to, gdouble const devicescale);
+gdouble sp_convert_distance_full(gdouble const from_dist, SPUnit const &from, SPUnit const &to);
 
 /* Some more convenience */
-/* Be careful to not mix bases */
-
-gdouble sp_distance_get_units (SPDistance *distance, const SPUnit *unit);
-gdouble sp_distance_get_points (SPDistance *distance);
-
-gdouble sp_points_get_units(gdouble const points, SPUnit const &unit);
-gdouble sp_units_get_points(gdouble const units, SPUnit const &unit);
-
-/* Deprecated.  Use SPUnit& version. */
-inline gdouble
-sp_points_get_units(gdouble const points, SPUnit const *unit)
-{
-	return sp_points_get_units(points, *unit);
-}
-
-/* Deprecated.  Use SPUnit& version. */
-inline gdouble
-sp_units_get_points(gdouble const units, SPUnit const *unit)
-{
-	return sp_units_get_points(units, *unit);
-}
-
+gdouble sp_units_get_pixels(gdouble const units, SPUnit const &unit);
+gdouble sp_pixels_get_units(gdouble const pixels, SPUnit const &unit);
 
 #endif 
