@@ -27,6 +27,11 @@
 #include <unistd.h>
 #define HAS_PROC_SELF_EXE  //to get path of executable
 #else
+
+// For now to get at is_os_wide().
+#include "extension/internal/win32.h"
+using Inkscape::Extension::Internal::PrintWin32;
+
 #include <direct.h>
 #define _WIN32_IE 0x0400
 #define HAS_SHGetSpecialFolderPath
@@ -45,9 +50,8 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkmessagedialog.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/sp-marshal.h"
-#include "xml/repr-private.h"
 #include "dialogs/debugdialog.h"
 
 #include "shortcuts.h"
@@ -61,13 +65,11 @@
 #include "inkscape.h"
 #include "inkscape-private.h"
 #include "prefs-utils.h"
+#include "xml/repr.h"
+#include "io/sys.h"
 
 #include "extension/init.h"
 
-#ifdef WIN32
-#define mkdir(d,m) _mkdir((d))
-#endif
-
 static Inkscape::Application *inkscape = NULL;
 
 /* Backbones of configuration xml data */
@@ -116,8 +118,6 @@ static void inkscape_init_preferences (Inkscape::Application *inkscape);
 
 static void inkscape_init_preferences (Inkscape::Application * inkscape);
 
-static gchar *profile_path(const char *filename);
-
 struct Inkscape::Application {
     GObject object;
     SPReprDoc *preferences;
@@ -400,7 +400,6 @@ inkscape_segv_handler (int signum)
 
     fprintf(stderr, "\nEmergency save activated!\n");
 
-    const gchar *home = g_get_home_dir ();
     time_t sptime = time (NULL);
     struct tm *sptm = localtime (&sptime);
     gchar sptstr[256];
@@ -440,21 +439,26 @@ inkscape_segv_handler (int signum)
             }
 
             if (!docname || !*docname) docname = "emergency";
-            g_snprintf (c, 1024, "%s/.inkscape/%.256s.%s.%d", home, docname, sptstr, count);
-            Inkscape::IO::dump_fopen_call(c, "E");
-            file = Inkscape::IO::fopen_utf8name(c, "w");
-            if (!file) {
-                g_snprintf (c, 1024, "%s/inkscape-%.256s.%s.%d", home, docname, sptstr, count);
-                Inkscape::IO::dump_fopen_call(c, "F");
-                file = Inkscape::IO::fopen_utf8name(c, "w");
-            }
+            // try saving to the profile location
+            g_snprintf (c, 1024, "%.256s.%s.%d", docname, sptstr, count);
+            gchar * location = profile_path(c);
+            Inkscape::IO::dump_fopen_call(location, "E");
+            file = Inkscape::IO::fopen_utf8name(location, "w");
+            g_free(location);
             if (!file) {
+                // try saving to /tmp
                 g_snprintf (c, 1024, "/tmp/inkscape-%.256s.%s.%d", docname, sptstr, count);
                 Inkscape::IO::dump_fopen_call(c, "G");
                 file = Inkscape::IO::fopen_utf8name(c, "w");
             }
+            if (!file) {
+                // try saving to the current directory
+                g_snprintf (c, 1024, "inkscape-%.256s.%s.%d", docname, sptstr, count);
+                Inkscape::IO::dump_fopen_call(c, "F");
+                file = Inkscape::IO::fopen_utf8name(c, "w");
+            }
             if (file) {
-                sp_repr_save_stream (sp_repr_document (repr), file);
+                sp_repr_save_stream (sp_repr_document (repr), file, SP_SVG_NS_URI);
                 savednames = g_slist_prepend (savednames, g_strdup (c));
                 fclose (file);
             } else {
@@ -606,18 +610,20 @@ inkscape_load_config (const gchar *filename, SPReprDoc *config, const gchar *ske
 		      const gchar *e_notsp, const gchar *warn)
 {
     gchar *fn = profile_path(filename);
-    if (!g_file_test(fn, G_FILE_TEST_EXISTS)) {
+    if (!Inkscape::IO::file_test(fn, G_FILE_TEST_EXISTS)) {
         /* No such file */
         inkscape_init_preferences (INKSCAPE);
         g_free (fn);
         return FALSE;
     }
 
-    if (!g_file_test(fn, G_FILE_TEST_IS_REGULAR)) {
+    if (!Inkscape::IO::file_test(fn, G_FILE_TEST_IS_REGULAR)) {
         /* Not a regular file */
-        GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notreg, fn, warn);
+        gchar *safeFn = Inkscape::IO::sanitizeString(fn);
+        GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notreg, safeFn, warn);
         gtk_dialog_run (GTK_DIALOG (w));
         gtk_widget_destroy (w);
+        g_free(safeFn);
         g_free (fn);
         return FALSE;
     }
@@ -625,19 +631,23 @@ inkscape_load_config (const gchar *filename, SPReprDoc *config, const gchar *ske
     SPReprDoc *doc = sp_repr_read_file (fn, NULL);
     if (doc == NULL) {
         /* Not an valid xml file */
-        GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notxml, fn, warn);
+        gchar *safeFn = Inkscape::IO::sanitizeString(fn);
+        GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notxml, safeFn, warn);
         gtk_dialog_run (GTK_DIALOG (w));
         gtk_widget_destroy (w);
+        g_free(safeFn);
         g_free (fn);
         return FALSE;
     }
 
     SPRepr *root = sp_repr_document_root (doc);
     if (strcmp (sp_repr_name (root), "inkscape")) {
-        GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notsp, fn, warn);
+        gchar *safeFn = Inkscape::IO::sanitizeString(fn);
+        GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notsp, safeFn, warn);
         gtk_dialog_run (GTK_DIALOG (w));
         gtk_widget_destroy (w);
         sp_repr_document_unref (doc);
+        g_free(safeFn);
         g_free (fn);
         return FALSE;
     }
@@ -712,7 +722,7 @@ inkscape_get_repr (Inkscape::Application *inkscape, const gchar *key)
         }
         
         SPRepr* child;
-        for (child = repr->children; child != NULL; child = child->next) {
+        for (child = repr->firstChild(); child != NULL; child = child->next()) {
             gchar const *id = sp_repr_attr (child, "id");
             if ((id) && (strlen (id) == len) && (!strncmp (id, s, len)))
             {
@@ -1103,14 +1113,16 @@ inkscape_init_config (SPReprDoc *doc, const gchar *config_name, const gchar *ske
 		      const gchar *warn)
 {
     gchar *dn = profile_path(NULL);
-    if (!g_file_test(dn, G_FILE_TEST_EXISTS)) {
-        if (mkdir (dn, S_IRWXU | S_IRGRP | S_IXGRP))
+    if (!Inkscape::IO::file_test(dn, G_FILE_TEST_EXISTS)) {
+        if (Inkscape::IO::mkdir_utf8name(dn))
         {
             if (inkscape->use_gui) {
-                /* Cannot create directory */
-                GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_mkdir, dn, warn);
+                // Cannot create directory
+                gchar *safeDn = Inkscape::IO::sanitizeString(dn);
+                GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_mkdir, safeDn, warn);
                 gtk_dialog_run (GTK_DIALOG (w));
                 gtk_widget_destroy (w);
+                g_free(safeDn);
                 g_free (dn);
                 return;
             } else {
@@ -1119,12 +1131,14 @@ inkscape_init_config (SPReprDoc *doc, const gchar *config_name, const gchar *ske
                 return;
             }
         }
-    } else if (!g_file_test(dn, G_FILE_TEST_IS_DIR)) {
+    } else if (!Inkscape::IO::file_test(dn, G_FILE_TEST_IS_DIR)) {
         if (inkscape->use_gui) {
-            /* Not a directory */
-            GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notdir, dn, warn);
+            // Not a directory
+            gchar *safeDn = Inkscape::IO::sanitizeString(dn);
+            GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notdir, safeDn, warn);
             gtk_dialog_run (GTK_DIALOG (w));
             gtk_widget_destroy (w);
+            g_free( safeDn );
             g_free (dn);
             return;
         } else {
@@ -1142,9 +1156,11 @@ inkscape_init_config (SPReprDoc *doc, const gchar *config_name, const gchar *ske
     if (!fh) {
         if (inkscape->use_gui) {
             /* Cannot create file */
-            GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_ccf, fn, warn);
+            gchar *safeFn = Inkscape::IO::sanitizeString(fn);
+            GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_ccf, safeFn, warn);
             gtk_dialog_run (GTK_DIALOG (w));
             gtk_widget_destroy (w);
+            g_free(safeFn);
             g_free (fn);
             return;
         } else {
@@ -1156,9 +1172,11 @@ inkscape_init_config (SPReprDoc *doc, const gchar *config_name, const gchar *ske
     if ( fwrite(skeleton, 1, skel_size, fh) != skel_size ) {
         if (inkscape->use_gui) {
             /* Cannot create file */
-            GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_cwf, fn, warn);
+            gchar *safeFn = Inkscape::IO::sanitizeString(fn);
+            GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_cwf, safeFn, warn);
             gtk_dialog_run (GTK_DIALOG (w));
             gtk_widget_destroy (w);
+            g_free(safeFn);
             g_free (fn);
             fclose(fh);
             return;
@@ -1230,16 +1248,63 @@ profile_path(const char *filename)
 {
     static const gchar *homedir = NULL;
     if (!homedir) {
-        homedir = g_get_home_dir();
 #ifdef HAS_SHGetSpecialFolderPath
-        if (!homedir) { //only try this is previous attempt fails
-            char pathBuf[MAX_PATH+1];
-            if (SHGetSpecialFolderPath(NULL, pathBuf, CSIDL_APPDATA, 1))
-                homedir = g_strdup(pathBuf);
+        // prefer c:\Documents and Settings\UserName\Application Data\ to
+        // c:\Documents and Settings\userName\; this
+        // closes bug #933461
+        if (!homedir) {
+            gchar * utf8Path = NULL;
+            if ( PrintWin32::is_os_wide() )
+            {
+                wchar_t pathBuf[MAX_PATH+1];
+                g_assert(sizeof(wchar_t) == sizeof(gunichar2));
+                if (SHGetSpecialFolderPathW(NULL, pathBuf, CSIDL_APPDATA, 1))
+                {
+                    utf8Path = g_utf16_to_utf8( (gunichar2*)(&pathBuf[0]), -1, NULL, NULL, NULL );
+                }
+            }
+            else
+            {
+                char pathBuf[MAX_PATH+1];
+                if (SHGetSpecialFolderPathA(NULL, pathBuf, CSIDL_APPDATA, 1))
+                {
+                    utf8Path = g_filename_to_utf8( pathBuf, -1, NULL, NULL, NULL );
+                }
+            }
+            if ( utf8Path )
+            {
+                homedir = utf8Path;
+            }
         }
 #endif
         if (!homedir) {
-            homedir = g_path_get_dirname(INKSCAPE->argv0);
+            homedir = g_get_home_dir();
+            if (!g_utf8_validate(homedir, -1, NULL)) {
+                g_warning( "g_get_home_dir() IS NOT UTF-8" );
+            }
+            gchar* utf8Path = g_filename_to_utf8( homedir, -1, NULL, NULL, NULL );
+            if ( utf8Path )
+            {
+                homedir = utf8Path;
+                if (!g_utf8_validate(homedir, -1, NULL)) {
+                    g_warning( "g_get_home_dir() post A IS NOT UTF-8" );
+                }
+            }
+        }
+        if (!homedir) {
+            gchar * path = g_path_get_dirname(INKSCAPE->argv0);
+            if (!g_utf8_validate(path, -1, NULL)) {
+                g_warning( "g_path_get_dirname() IS NOT UTF-8" );
+            }
+            gchar* utf8Path = g_filename_to_utf8( path, -1, NULL, NULL, NULL );
+            g_free(path);
+            if ( utf8Path )
+            {
+                homedir = utf8Path;
+                if (!g_utf8_validate(homedir, -1, NULL)) {
+                    g_warning( "g_get_home_dir() post B IS NOT UTF-8" );
+                }
+            }
         }
     }
     return g_build_filename(homedir, INKSCAPE_PROFILE_DIR, filename, NULL);
