@@ -23,6 +23,7 @@
 #include "inkscape.h"
 #include "inkscape-private.h"
 #include "extension/db.h"
+#include "extension/effect.h"
 #include "widgets/icon.h"
 #include "prefs-utils.h"
 #include "path-prefix.h"
@@ -48,16 +49,21 @@
 #include "sp-namedview.h"
 
 #include "dir-util.h"
-#include "xml/repr-private.h"
+#include "memeq.h"
 #include "helper/action.h"
 #include "helper/gnome-utils.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/window.h"
 
+#include "io/sys.h"
+
 #include "dialogs/dialog-events.h"
 
 #include "message-context.h"
 
+/* Define this to have an Effects menu in the menu bar. */
+// #define WITH_EFFECT_MENU 1
+
 /* forward declaration */
 static gint sp_ui_delete (GtkWidget *widget, GdkEvent *event, SPView *view);
 
@@ -74,10 +80,10 @@ static GtkTargetEntry ui_drop_target_entries [] = {
   {"image/svg",     0, SVG_DATA},
 };
 
-#define ENTRIES_SIZE(n) sizeof(n)/sizeof(n[0]) 
+#define ENTRIES_SIZE(n) sizeof(n)/sizeof(n[0])
 static guint nui_drop_target_entries = ENTRIES_SIZE(ui_drop_target_entries);
 static void sp_ui_import_files(gchar * buffer);
-static void sp_ui_import_one_file(gchar * filename);
+static void sp_ui_import_one_file(char const *filename);
 static void sp_ui_import_one_file_with_check(gpointer filename, gpointer unused);
 static void sp_ui_drag_data_received (GtkWidget * widget,
 				      GdkDragContext * drag_context,
@@ -117,7 +123,7 @@ sp_create_window (SPViewWidget *vw, gboolean editable)
 	gtk_box_pack_end (GTK_BOX (hb), GTK_WIDGET (vw), TRUE, TRUE, 0);
 	gtk_widget_show (GTK_WIDGET (vw));
 
-	gtk_drag_dest_set(w, 
+	gtk_drag_dest_set(w,
 			  GTK_DEST_DEFAULT_ALL,
 			  ui_drop_target_entries,
 			  nui_drop_target_entries,
@@ -189,7 +195,7 @@ sp_ui_close_view (GtkWidget * widget)
  *  open document view windows, attempting to close each in turn.  If the
  *  view has unsaved information, the user will be prompted to save,
  *  discard, or cancel.
- * 
+ *
  *  Returns FALSE if the user cancels the close_all operation, TRUE
  *  otherwise.
  */
@@ -268,21 +274,21 @@ sp_ui_menuitem_add_icon ( GtkWidget *item, gchar * icon_name )
 {
     GtkWidget *icon;
 
-    icon = sp_icon_new_scaled (16, icon_name);
+    icon = sp_icon_new_scaled (SP_ICON_SIZE_BUTTON, icon_name);
     gtk_widget_show (icon);
     gtk_image_menu_item_set_image ((GtkImageMenuItem *) item, icon);
 } // end of sp_ui_menu_add_icon
 
 /**
  * sp_ui_menu_append_item
- * 
+ *
  * Appends a UI item with specific info for Inkscape/Sodipodi.
  *
  */
 
 static GtkWidget *
-sp_ui_menu_append_item ( GtkMenu *menu, const gchar *stock, 
-                         const gchar *label, const gchar *tip, SPView *view, GCallback callback, 
+sp_ui_menu_append_item ( GtkMenu *menu, const gchar *stock,
+                         const gchar *label, const gchar *tip, SPView *view, GCallback callback,
                          gpointer data, gboolean with_mnemonic = TRUE )
 {
     GtkWidget *item;
@@ -290,8 +296,8 @@ sp_ui_menu_append_item ( GtkMenu *menu, const gchar *stock,
     if (stock) {
         item = gtk_image_menu_item_new_from_stock (stock, NULL);
     } else if (label) {
-        item = (with_mnemonic) 
-            ? gtk_image_menu_item_new_with_mnemonic (label) :      
+        item = (with_mnemonic)
+            ? gtk_image_menu_item_new_with_mnemonic (label) :
             gtk_image_menu_item_new_with_label (label);
     } else {
         item = gtk_separator_menu_item_new ();
@@ -337,6 +343,8 @@ sp_ui_menu_key_press (GtkMenuItem *item, GdkEventKey *event, void *data)
 static gchar const *
 sp_key_name (guint keyval)
 {
+    /* TODO: Compare with the definition of gtk_accel_label_refetch in gtk/gtkaccellabel.c (or
+       simply use GtkAccelLabel as the TODO comment in sp_ui_shortcut_string suggests). */
     gchar const *n = gdk_keyval_name (gdk_keyval_to_upper (keyval));
 
     if      (!strcmp (n, "asciicircum"))  return "^";
@@ -353,21 +361,51 @@ sp_key_name (guint keyval)
     else if (!strcmp (n, "numbersign" ))  return "#";
     else if (!strcmp (n, "bar" ))  return "|";
     else if (!strcmp (n, "slash" ))  return "/";
+    else if (!strcmp (n, "exclam" ))  return "!";
     else return n;
 }
 
 
+/**
+ * \param shortcut A GDK keyval OR'd with SP_SHORTCUT_blah_MASK values.
+ * \param c Points to a buffer at least 256 bytes long.
+ */
 void
-sp_ui_shortcut_string (unsigned int shortcut, gchar* c)
+sp_ui_shortcut_string(unsigned const shortcut, gchar *const c)
 {
-    const gchar *altStr, *ctrlStr, *shiftStr;
+    /* TODO: This function shouldn't exist.  Our callers should use GtkAccelLabel instead of
+     * a generic GtkLabel containing this string, and should call gtk_widget_add_accelerator.
+     * Will probably need to change sp_shortcut_invoke callers and sp_ui_menu_key_press.
+     *
+     * The existing gtk_label_new_with_mnemonic call can be replaced with
+     * g_object_new(GTK_TYPE_ACCEL_LABEL, NULL) followed by
+     * gtk_label_set_text_with_mnemonic(lbl, str).
+     */
+    static GtkAccelLabelClass const &accel_lbl_cls
+        = *(GtkAccelLabelClass const *) g_type_class_peek_static(GTK_TYPE_ACCEL_LABEL);
 
-    altStr   = (shortcut & SP_SHORTCUT_ALT_MASK    ) ? "Alt+"   : "";
-    ctrlStr  = (shortcut & SP_SHORTCUT_CONTROL_MASK) ? "Ctrl+"  : "";
-    shiftStr = (shortcut & SP_SHORTCUT_SHIFT_MASK  ) ? "Shift+" : "";
+    struct { unsigned test; char const *name; } const modifier_tbl[] = {
+        { SP_SHORTCUT_SHIFT_MASK,   accel_lbl_cls.mod_name_shift   },
+        { SP_SHORTCUT_CONTROL_MASK, accel_lbl_cls.mod_name_control },
+        { SP_SHORTCUT_ALT_MASK,     accel_lbl_cls.mod_name_alt     }
+    };
 
-    g_snprintf (c, 256, "%s%s%s%s", shiftStr, ctrlStr, altStr,
-         sp_key_name (shortcut & 0xffffff));
+    gchar *p = c;
+    gchar *end = p + 256;
+
+    for (unsigned i = 0; i < G_N_ELEMENTS(modifier_tbl); ++i) {
+        if ((shortcut & modifier_tbl[i].test)
+            && (p < end))
+        {
+            p += g_snprintf(p, end - p, "%s%s",
+                            modifier_tbl[i].name,
+                            accel_lbl_cls.mod_separator);
+        }
+    }
+    if (p < end) {
+        p += g_snprintf(p, end - p, "%s", sp_key_name(shortcut & 0xffffff));
+    }
+    end[-1] = '\0';  // snprintf doesn't guarantee to nul-terminate the string.
 }
 
 void
@@ -375,13 +413,13 @@ sp_ui_dialog_title_string (Inkscape::Verb * verb, gchar* c)
 {
     SPAction     *action;
     unsigned int shortcut;
-    gchar        *s; 
+    gchar        *s;
     gchar        key[256];
     gchar        *atitle;
 
     action = verb->get_action(NULL);
     if (!action)
-        return; 
+        return;
 
     atitle = sp_action_get_title (action);
 
@@ -401,7 +439,7 @@ sp_ui_dialog_title_string (Inkscape::Verb * verb, gchar* c)
 
 /**
  * sp_ui_menu_append_item_from_verb
- * 
+ *
  * Appends a custom menu UI from a verb.
  *
  */
@@ -426,15 +464,14 @@ sp_ui_menu_append_item_from_verb (GtkMenu *menu, Inkscape::Verb * verb, SPView *
         shortcut = sp_shortcut_get_primary (verb);
         if (shortcut) {
             gchar c[256];
-            GtkWidget *hb, *l;
             sp_ui_shortcut_string (shortcut, c);
-            hb = gtk_hbox_new (FALSE, 16);
-            l = gtk_label_new_with_mnemonic (action->name);
-            gtk_misc_set_alignment ((GtkMisc *) l, 0.0, 0.5);
-            gtk_box_pack_start ((GtkBox *) hb, l, TRUE, TRUE, 0);
-            l = gtk_label_new (c);
-            gtk_misc_set_alignment ((GtkMisc *) l, 1.0, 0.5);
-            gtk_box_pack_end ((GtkBox *) hb, l, FALSE, FALSE, 0);
+            GtkWidget *const hb = gtk_hbox_new(FALSE, 16);
+            GtkWidget *const name_lbl = gtk_label_new_with_mnemonic(action->name);
+            gtk_misc_set_alignment((GtkMisc *) name_lbl, 0.0, 0.5);
+            gtk_box_pack_start((GtkBox *) hb, name_lbl, TRUE, TRUE, 0);
+            GtkWidget *const accel_lbl = gtk_label_new(c);
+            gtk_misc_set_alignment((GtkMisc *) accel_lbl, 1.0, 0.5);
+            gtk_box_pack_end((GtkBox *) hb, accel_lbl, FALSE, FALSE, 0);
             gtk_widget_show_all (hb);
             item = gtk_image_menu_item_new ();
             gtk_container_add ((GtkContainer *) item, hb);
@@ -445,9 +482,9 @@ sp_ui_menu_append_item_from_verb (GtkMenu *menu, Inkscape::Verb * verb, SPView *
             sp_ui_menuitem_add_icon (item, action->image);
         }
         gtk_widget_set_events (item, GDK_KEY_PRESS_MASK);
-        g_signal_connect ( G_OBJECT (item), "activate", 
+        g_signal_connect ( G_OBJECT (item), "activate",
                            G_CALLBACK (sp_ui_menu_activate), action );
-        g_signal_connect ( G_OBJECT (item), "key_press_event", 
+        g_signal_connect ( G_OBJECT (item), "key_press_event",
                            G_CALLBACK (sp_ui_menu_key_press), (void *) verb);
 
         g_signal_connect ( G_OBJECT (item), "select", G_CALLBACK (sp_ui_menu_select_action), action );
@@ -484,28 +521,28 @@ sp_ui_menu_append_submenu (GtkMenu *fm, SPView *view, void (*fill_function)(GtkW
     gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), menu);
 }
 
- static void 
-checkitem_toggled(GtkCheckMenuItem *menuitem, gpointer user_data) 	 
- { 	 
+ static void
+checkitem_toggled(GtkCheckMenuItem *menuitem, gpointer user_data)
+ {
      const gchar *pref = (const gchar *) user_data;
      SPView *view = (SPView *) g_object_get_data (G_OBJECT (menuitem), "view");
 
      const gchar *pref_path;
      if (SP_DESKTOP(view)->is_fullscreen)
          pref_path = g_strconcat ("fullscreen.", pref, NULL);
-     else 
+     else
          pref_path = g_strconcat ("window.", pref, NULL);
 
-     gboolean checked = gtk_check_menu_item_get_active(menuitem); 	 
+     gboolean checked = gtk_check_menu_item_get_active(menuitem);
      prefs_set_int_attribute(pref_path, "state", checked);
 
      sp_desktop_widget_layout (SP_DESKTOP(view)->owner);
- } 	 
-  	 
- static gboolean 
-checkitem_update(GtkWidget *widget, GdkEventExpose *event, gpointer user_data) 	 
- { 	 
-     GtkCheckMenuItem *menuitem=GTK_CHECK_MENU_ITEM(widget); 	 
+ }
+
+ static gboolean
+checkitem_update(GtkWidget *widget, GdkEventExpose *event, gpointer user_data)
+ {
+     GtkCheckMenuItem *menuitem=GTK_CHECK_MENU_ITEM(widget);
 
      const gchar *pref = (const gchar *) user_data;
      SPView *view = (SPView *) g_object_get_data (G_OBJECT(menuitem), "view");
@@ -513,16 +550,16 @@ checkitem_update(GtkWidget *widget, GdkEventExpose *event, gpointer user_data)
      const gchar *pref_path;
      if (SP_DESKTOP(view)->is_fullscreen)
          pref_path = g_strconcat ("fullscreen.", pref, NULL);
-     else 
+     else
          pref_path = g_strconcat ("window.", pref, NULL);
 
-     gint ison = prefs_get_int_attribute_limited (pref_path, "state", 1, 0, 1); 	 
+     gint ison = prefs_get_int_attribute_limited (pref_path, "state", 1, 0, 1);
 
-     g_signal_handlers_block_by_func(G_OBJECT(menuitem), (gpointer)(GCallback)checkitem_toggled, user_data); 	 
-     gtk_check_menu_item_set_active(menuitem, ison); 	 
-     g_signal_handlers_unblock_by_func(G_OBJECT(menuitem), (gpointer)(GCallback)checkitem_toggled, user_data); 	 
+     g_signal_handlers_block_by_func(G_OBJECT(menuitem), (gpointer)(GCallback)checkitem_toggled, user_data);
+     gtk_check_menu_item_set_active(menuitem, ison);
+     g_signal_handlers_unblock_by_func(G_OBJECT(menuitem), (gpointer)(GCallback)checkitem_toggled, user_data);
 
-     return FALSE; 	 
+     return FALSE;
  }
 
 
@@ -570,18 +607,18 @@ sp_ui_menu_append_check_item_from_verb (GtkMenu *menu, SPView *view, const gchar
         item = gtk_check_menu_item_new ();
         gtk_container_add ((GtkContainer *) item, l);
     }
-  	 
-    gtk_widget_show(item);
-  	 
-    gtk_menu_shell_append(GTK_MENU_SHELL(menu), item); 	 
 
-    g_object_set_data (G_OBJECT (item), "view", (gpointer) view); 	 
-  	 
-    g_signal_connect( G_OBJECT(item), "toggled", (GCallback) callback_toggle, (void *) pref); 	 
+    gtk_widget_show(item);
+
+    gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
+
+    g_object_set_data (G_OBJECT (item), "view", (gpointer) view);
+
+    g_signal_connect( G_OBJECT(item), "toggled", (GCallback) callback_toggle, (void *) pref);
     g_signal_connect( G_OBJECT(item), "expose_event", (GCallback) callback_update, (void *) pref);
-	 
-    g_signal_connect ( G_OBJECT (item), "select", G_CALLBACK (sp_ui_menu_select), (gpointer) (action ? action->tip : tip)); 	 
-    g_signal_connect ( G_OBJECT (item), "deselect", G_CALLBACK (sp_ui_menu_deselect), NULL); 	 
+
+    g_signal_connect ( G_OBJECT (item), "select", G_CALLBACK (sp_ui_menu_select), (gpointer) (action ? action->tip : tip));
+    g_signal_connect ( G_OBJECT (item), "deselect", G_CALLBACK (sp_ui_menu_deselect), NULL);
 }
 
 static void
@@ -734,6 +771,7 @@ sp_ui_edit_menu (GtkMenu *menu, SPDocument *doc, SPView *view)
         Inkscape::Verb::get(SP_VERB_NONE),
         Inkscape::Verb::get(SP_VERB_EDIT_DUPLICATE),
         Inkscape::Verb::get(SP_VERB_EDIT_CLONE),
+        Inkscape::Verb::get(SP_VERB_DIALOG_CLONETILER),
         Inkscape::Verb::get(SP_VERB_EDIT_UNLINK_CLONE),
         Inkscape::Verb::get(SP_VERB_EDIT_CLONE_ORIGINAL),
         Inkscape::Verb::get(SP_VERB_SELECTION_CREATE_BITMAP),
@@ -747,6 +785,8 @@ sp_ui_edit_menu (GtkMenu *menu, SPDocument *doc, SPView *view)
 
         Inkscape::Verb::get(SP_VERB_NONE),
         Inkscape::Verb::get(SP_VERB_EDIT_SELECT_ALL),
+        Inkscape::Verb::get(SP_VERB_EDIT_SELECT_ALL_IN_ALL_LAYERS),
+        Inkscape::Verb::get(SP_VERB_EDIT_INVERT),
         Inkscape::Verb::get(SP_VERB_EDIT_DESELECT),
 
         Inkscape::Verb::get(SP_VERB_NONE),
@@ -771,7 +811,7 @@ sp_ui_layer_menu (GtkMenu *menu, SPDocument *doc, SPView *view)
         Inkscape::Verb::get(SP_VERB_LAYER_PREV),
 
         Inkscape::Verb::get(SP_VERB_NONE),
-        
+
         Inkscape::Verb::get(SP_VERB_LAYER_RAISE),
         Inkscape::Verb::get(SP_VERB_LAYER_LOWER),
         Inkscape::Verb::get(SP_VERB_LAYER_TO_TOP),
@@ -890,7 +930,8 @@ sp_ui_view_menu (GtkMenu *menu, SPDocument *doc, SPView *view)
 #endif /* HAVE_GTK_WINDOW_FULLSCREEN */
 
         Inkscape::Verb::get(SP_VERB_NONE),
-      Inkscape::Verb::get(SP_VERB_DIALOG_DEBUG),
+        Inkscape::Verb::get(SP_VERB_DIALOG_DEBUG),
+        Inkscape::Verb::get(SP_VERB_DIALOG_SCRIPT),
         Inkscape::Verb::get(SP_VERB_NONE),
 	Inkscape::Verb::get(SP_VERB_FILE_PREV_DESKTOP),
 	Inkscape::Verb::get(SP_VERB_FILE_NEXT_DESKTOP),
@@ -944,6 +985,43 @@ sp_ui_text_menu (GtkMenu *menu, SPDocument *doc, SPView *view)
     sp_ui_menu_append (menu, text_verbs, view);
 }
 
+#ifdef WITH_EFFECT_MENU
+/** Creates the effects menu.
+    \param  menu  The menu to append to.
+    \param  doc   Document being used.
+    \param  view  The view of the document this is being attached to.
+*/
+static void
+sp_ui_effect_menu (GtkMenu *menu, SPDocument *doc, SPView *view)
+{
+    static Inkscape::Verb * effect_verbs[] = {
+        Inkscape::Verb::get(SP_VERB_EFFECT_LAST),
+        Inkscape::Verb::get(SP_VERB_EFFECT_LAST_PREF),
+
+        Inkscape::Verb::get(SP_VERB_NONE),
+
+        Inkscape::Verb::get(SP_VERB_LAST)
+    };
+
+    sp_ui_menu_append (menu, effect_verbs, view);
+
+    Inkscape::Extension::DB::EffectList effectlist;
+    Inkscape::Extension::db.get_effect_list(effectlist);
+
+    for (Inkscape::Extension::DB::EffectList::iterator current_item = effectlist.begin();
+         current_item != effectlist.end(); current_item++) {
+         Inkscape::Extension::Effect * emod = *current_item;
+
+         Inkscape::Verb * verb = emod->get_verb();
+
+         if (verb != NULL)
+             sp_ui_menu_append_item_from_verb(GTK_MENU(menu), verb, view);
+    }
+
+    return;
+}
+#endif /* WITH_EFFECT_MENU */
+
 static void
 sp_ui_help_menu (GtkMenu *fm, SPDocument *doc, SPView *view)
 {
@@ -961,7 +1039,7 @@ sp_ui_help_menu (GtkMenu *fm, SPDocument *doc, SPView *view)
 	Inkscape::Verb::get(SP_VERB_TUTORIAL_CALLIGRAPHY),
 	Inkscape::Verb::get(SP_VERB_TUTORIAL_DESIGN),
 	Inkscape::Verb::get(SP_VERB_TUTORIAL_TIPS),
-	
+
 	Inkscape::Verb::get(SP_VERB_LAST)
     };
 
@@ -1024,7 +1102,7 @@ sp_ui_main_menubar (SPView *view)
 	sp_ui_layer_menu (GTK_MENU (menu), NULL, view);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (mitem), GTK_WIDGET (menu));
 	gtk_menu_shell_append (GTK_MENU_SHELL (mbar), mitem);
-	
+
 	mitem = gtk_menu_item_new_with_mnemonic (_("_Object"));
 	menu = gtk_menu_new ();
 	sp_ui_object_menu (GTK_MENU (menu), NULL, view);
@@ -1043,6 +1121,14 @@ sp_ui_main_menubar (SPView *view)
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (mitem), GTK_WIDGET (menu));
 	gtk_menu_shell_append (GTK_MENU_SHELL (mbar), mitem);
 
+#ifdef WITH_EFFECT_MENU
+	mitem = gtk_menu_item_new_with_mnemonic (_("Effects"));
+	menu = gtk_menu_new ();
+	sp_ui_effect_menu (GTK_MENU (menu), NULL, view);
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (mitem), GTK_WIDGET (menu));
+	gtk_menu_shell_append (GTK_MENU_SHELL (mbar), mitem);
+#endif
+
 	mitem = gtk_menu_item_new_with_mnemonic (_("_Help"));
 	menu = gtk_menu_new ();
 	sp_ui_help_menu (GTK_MENU (menu), NULL, view);
@@ -1142,7 +1228,7 @@ sp_ui_context_menu (SPView *view, SPItem *item)
 }
 
 /* Drag and Drop */
-void 
+void
 sp_ui_drag_data_received (GtkWidget * widget,
 			  GdkDragContext * drag_context,
 			  gint x, gint y,
@@ -1151,50 +1237,45 @@ sp_ui_drag_data_received (GtkWidget * widget,
 			  guint event_time,
 			  gpointer user_data)
 {
-	gchar * uri, * svgdata;
-	SPRepr * rdoc, * repr, * newgroup, * child;
-	SPReprDoc * rnewdoc;
-	SPDocument * doc;
-	const gchar *style;
-	
 	switch(info) {
 	case SVG_DATA:
-	case SVG_XML_DATA: 
-		svgdata = (gchar *)data->data;
+	case SVG_XML_DATA:
+            {
+		gchar *svgdata = (gchar *)data->data;
 
-		doc = SP_ACTIVE_DOCUMENT;
+		SPDocument *doc = SP_ACTIVE_DOCUMENT;
 
-		/* fixme: put into a function (sp_mem_import?) */
-		rdoc = sp_document_repr_root (doc);
-		
-		rnewdoc = sp_repr_read_mem (svgdata, data->length, SP_SVG_NS_URI);
+		SPReprDoc *rnewdoc = sp_repr_read_mem (svgdata, data->length, SP_SVG_NS_URI);
 
 		if (rnewdoc == NULL) {
 			sp_ui_error_dialog (_("Could not parse SVG data"));
 			return;
 		}
-	
-		repr = sp_repr_document_root (rnewdoc);
-		style = sp_repr_attr (repr, "style");
 
-		newgroup = sp_repr_new ("g");
+		SPRepr *repr = sp_repr_document_root (rnewdoc);
+		const gchar *style = sp_repr_attr (repr, "style");
+
+		SPRepr *newgroup = sp_repr_new ("svg:g");
 		sp_repr_set_attr (newgroup, "style", style);
 
-		for (child = repr->children; child != NULL; child = child->next) {
-			SPRepr * newchild;
-			newchild = sp_repr_duplicate (child);
+		for (SPRepr *child = repr->firstChild(); child != NULL; child = child->next()) {
+			SPRepr * newchild = sp_repr_duplicate (child);
 			sp_repr_append_child (newgroup, newchild);
 		}
 
 		sp_repr_document_unref (rnewdoc);
 
-                SP_DOCUMENT_ROOT(doc)->appendChildRepr(newgroup);
+            SPDesktop *desktop = SP_ACTIVE_DESKTOP;
+            // Add it to the current layer
+            desktop->currentLayer()->appendChildRepr(newgroup);
+
 		sp_repr_unref (newgroup);
 		sp_document_done (doc);
-		
+            }
+
 		break;
 	case URI_LIST:
-		uri = (gchar *)data->data;
+		gchar *uri = (gchar *)data->data;
 		sp_ui_import_files(uri);
 		break;
 	}
@@ -1215,109 +1296,37 @@ static void
 sp_ui_import_one_file_with_check(gpointer filename, gpointer unused)
 {
 	if (filename) {
-		if (strlen((gchar*)filename) > 2)
-			sp_ui_import_one_file((gchar*)filename);
+		if (strlen((char const *)filename) > 2)
+			sp_ui_import_one_file((char const *)filename);
 	}
 }
 
-/* Cut&Paste'ed from file.c:file_import_ok */
 static void
-sp_ui_import_one_file(gchar * filename)
+sp_ui_import_one_file(char const *filename)
 {
-	SPDocument * doc;
-	SPRepr * rdoc;
-	const gchar * e, * docbase, * relname;
-	SPRepr * repr;
-	SPReprDoc * rnewdoc;
+    SPDocument *doc = SP_ACTIVE_DOCUMENT;
+    if (!SP_IS_DOCUMENT(doc)) return;
 
-	doc = SP_ACTIVE_DOCUMENT;
-	if (!SP_IS_DOCUMENT(doc)) return;
-	
-	if (filename == NULL) return;  
+    if (filename == NULL) return;
 
-	rdoc = sp_document_repr_root (doc);
-
-	docbase = sp_repr_attr (rdoc, "sodipodi:docbase");
-	relname = sp_relative_path_from_path (filename, docbase);
-	/* fixme: this should be implemented with mime types */
-	e = sp_extension_from_path (filename);
-
-	if ((e == NULL) || (strcmp (e, "svg") == 0) || (strcmp (e, "xml") == 0)) {
-		SPRepr * newgroup;
-		const gchar * style;
-		SPRepr * child;
-
-		rnewdoc = sp_repr_read_file (filename, SP_SVG_NS_URI);
-		if (rnewdoc == NULL) return;
-		repr = sp_repr_document_root (rnewdoc);
-		style = sp_repr_attr (repr, "style");
-
-		newgroup = sp_repr_new ("g");
-		sp_repr_set_attr (newgroup, "style", style);
-
-		for (child = repr->children; child != NULL; child = child->next) {
-			SPRepr * newchild;
-			newchild = sp_repr_duplicate (child);
-			sp_repr_append_child (newgroup, newchild);
-		}
-
-		sp_repr_document_unref (rnewdoc);
-
-                SP_DOCUMENT_ROOT(doc)->appendChildRepr(newgroup);
-		sp_repr_unref (newgroup);
-		sp_document_done (doc);
-		return;
-	}
-
-	if ((strcmp (e, "png") == 0) ||
-	    (strcmp (e, "jpg") == 0) ||
-	    (strcmp (e, "jpeg") == 0) ||
-	    (strcmp (e, "bmp") == 0) ||
-	    (strcmp (e, "gif") == 0) ||
-	    (strcmp (e, "tiff") == 0) ||
-	    (strcmp (e, "xpm") == 0)) {
-		/* Try pixbuf */
-		GdkPixbuf *pb;
-		// TODO: bulia, please look over
-		gsize bytesRead = 0;
-		gsize bytesWritten = 0;
-		GError* error = NULL;
-		gchar* localFilename = g_filename_from_utf8 ( filename,
-													  -1,
-													  &bytesRead,
-													  &bytesWritten,
-													  &error);
-		pb = gdk_pixbuf_new_from_file (localFilename, NULL);
-		if (pb) {
-			/* We are readable */
-			repr = sp_repr_new ("image");
-			sp_repr_set_attr (repr, "xlink:href", relname);
-			sp_repr_set_attr (repr, "sodipodi:absref", filename);
-			sp_repr_set_double (repr, "width", gdk_pixbuf_get_width (pb));
-			sp_repr_set_double (repr, "height", gdk_pixbuf_get_height (pb));
-                        SP_DOCUMENT_ROOT(doc)->appendChildRepr(repr);
-			sp_repr_unref (repr);
-			sp_document_done (doc);
-			gdk_pixbuf_unref (pb);
-		}
-		if ( localFilename != NULL )
-		{
-			g_free (localFilename);
-		}
-	}
+    // Pass off to common implementation
+    // TODO might need to get the proper type of Inkscape::Extension::Extension
+    file_import( doc, filename, NULL );
 }
 
 void
 sp_ui_error_dialog (const gchar * message)
 {
 	GtkWidget *dlg;
-	
-	dlg = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, 
-			GTK_BUTTONS_CLOSE, message);
+	gchar *safeMsg = Inkscape::IO::sanitizeString(message);
+
+	dlg = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_CLOSE, safeMsg);
 	sp_transientize (dlg);
 	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
+	g_free(safeMsg);
 }
 
 bool
@@ -1330,7 +1339,7 @@ sp_ui_overwrite_file (const gchar * filename)
 	gchar * title;
 	gchar * text;
 
-	if (g_file_test(filename, G_FILE_TEST_EXISTS)) {
+	if (Inkscape::IO::file_test(filename, G_FILE_TEST_EXISTS)) {
 
 		title = g_strdup_printf(_("Overwrite %s"), filename);
 		dialog = gtk_dialog_new_with_buttons (title,
