@@ -10,8 +10,6 @@
  * This code is in public domain
  */
 
-typedef struct _NRPixBlock NRPixBlock;
-
 namespace NR {
 class Matrix;
 class Point;
@@ -21,6 +19,9 @@ class scale;
 class translate;
 }
 
+class NArtBpath;
+struct NRBPath;
+struct NRPixBlock;
 struct NRMatrix;
 struct NRPoint;
 struct NRRect;
