@@ -24,7 +24,7 @@ class Matrix;
 class Point {
 public:
     inline Point()
-    { }
+    { _pt[X] = _pt[Y] = 0; }
 
     inline Point(Coord x, Coord y) {
         _pt[X] = x;
@@ -94,13 +94,6 @@ public:
 
     void normalize();
 
-    __attribute__((__deprecated__)) operator NRPoint() const {
-        NRPoint nrp;
-        nrp.x = _pt[X];
-        nrp.y = _pt[Y];
-        return nrp;
-    }
-
     inline Point &operator+=(Point const &o) {
         for ( unsigned i = 0 ; i < 2 ; ++i ) {
             _pt[i] += o._pt[i];
@@ -128,14 +121,6 @@ public:
         }
         return *this;
     }
-  
-    __attribute__((__deprecated__))
-    Point &operator*=(Point const &s) {
-        for ( unsigned i = 0 ; i < 2 ; ++i ) {
-            _pt[i] *= s[i];
-        }
-        return *this;
-    }
 
     Point &operator*=(Matrix const &m);
 
