@@ -1,21 +1,23 @@
+/** \file */
 #include <libnr/nr-types.h>
 #include <glib.h>
 #include <math.h>
 
+#include "isnan.h" //temporary fix for isnan()
 
 /** Scales this vector to make it a unit vector (within rounding error).
- *
- *  Requires: *this != (0, 0).
- *	      Neither coordinate is NaN.
- *  Ensures: L2(*this) very near 1.0.
  *
  *  The current version tries to handle infinite coordinates gracefully,
  *  but it's not clear that any callers need that.
+ *
+ *  \pre *this != Point(0, 0).
+ *  \pre Neither coordinate is NaN.
+ *  \post L2(*this) very near 1.0.
  */
 void NR::Point::normalize() {
 	double len = hypot(_pt[0], _pt[1]);
 	g_return_if_fail(len != 0);
-	g_return_if_fail(!isnan(len));
+	g_return_if_fail(!isNaN(len));
 	static double const inf = 1e400;
 	if(len != inf) {
 		*this /= len;
