@@ -11,9 +11,11 @@
 #include <pango/pango.h>
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
+#include <glibmm/i18n.h> // _()
+
 /* Freetype2 */
 # include <pango/pangoft2.h>
 
@@ -312,6 +314,11 @@ font_factory::~font_factory(void)
 font_instance* font_factory::FaceFromDescr(const char* descr)
 {
 	PangoFontDescription* temp_descr=pango_font_description_from_string(descr);
+        // workaround for bug #1025565.
+        if (pango_font_description_get_family(temp_descr)==NULL) {
+            pango_font_description_set_family(temp_descr,descr);
+            //g_warning(_("Font '%s' didn't have a default family\n"),descr);
+        }
 	font_instance *res=Face(temp_descr);
 	pango_font_description_free(temp_descr);
 	return res;
@@ -325,7 +332,17 @@ font_instance* font_factory::Face(PangoFontDescription* descr, bool canFail)
 	
 	if ( loadedFaces.find(descr) == loadedFaces.end() ) {
 		// not yet loaded
-		PangoFont* nFace=pango_font_map_load_font(fontServer,fontContext,descr);
+		PangoFont* nFace=NULL;
+
+                // workaround for bug #1025565.
+                // fonts without families blow up Pango.
+                if (pango_font_description_get_family (descr)!=NULL) {
+		    nFace=pango_font_map_load_font(fontServer,fontContext,descr);
+                }
+                else {
+                    g_warning(_("Ignoring font without family that will crash Pango"));
+                }
+
 		if ( nFace ) {
 			// duplicate FcPattern, the hard way
 			res=new font_instance();
@@ -444,7 +461,7 @@ void font_factory::UnrefFace(font_instance* who)
 	if ( loadedFaces.find(who->descr) == loadedFaces.end() ) {
 		// not found
 		char* tc=pango_font_description_to_string(who->descr);
-		printf("unrefFace %x=%s: failed\n",(unsigned int)who,tc);
+		g_warning("unrefFace %x=%s: failed\n",(unsigned int)who,tc);
 		free(tc);
 	} else {
 		loadedFaces.erase(loadedFaces.find(who->descr));
@@ -600,4 +617,4 @@ void                  font_factory::AddInCache(font_instance* who)
  fill-column:99
  End:
  */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
