@@ -9,8 +9,9 @@
 #ifndef my_path
 #define my_path
 
+#include <vector>
 #include "LivarotDefs.h"
-
+#include "livarot/livarot-forward.h"
 #include "libnr/nr-point.h"
 
 /*
@@ -23,22 +24,6 @@
  * of the same path command can be reassembled in a command
  */
 
-// path description commands
-enum
-{
-  descr_moveto = 0,         // a moveto
-  descr_lineto = 1,         // a (guess what) lineto
-  descr_cubicto = 2,
-  descr_bezierto = 3,       // "beginning" of a quadratic bezier spline, will contain its endpoint (i know, it's bad...)
-  descr_arcto = 4,
-  descr_close = 5,
-  descr_interm_bezier = 6,  // control point of the bezier spline
-  descr_forced = 7,
-
-  descr_type_mask = 15      // the command no will be stored in a "flags" field, potentially with other info, so we need 
-                            // a mask to AND the field and extract the command
-};
-
 // polyline description commands
 enum
 {
@@ -55,7 +40,7 @@ class Shape;
 
 // a little structure you shouldnt pay attention to
 // created because the function invocation was starting to be 2 lines long
-typedef struct dashTo_info
+struct dashTo_info
 {
   double     nDashAbs;
   NR::Point prevP;
@@ -63,7 +48,7 @@ typedef struct dashTo_info
   NR::Point prevD;
   double     prevW;
   double     curW;
-} dashTo_info;
+};
 
 // path creation: 2 phases: first the path is given as a succession of commands (MoveTo, LineTo, CurveTo...); then it
 // is converted in a polyline
@@ -73,66 +58,6 @@ class Path
   friend class Shape;
 public:
 
-  // command list structures
-
-  // lineto: a point
-  typedef struct path_descr_moveto
-  {
-    NR::Point  p;
-  }
-  path_descr_moveto;
-
-  // lineto: a point
-  // MoveTos fit in this category
-  typedef struct path_descr_lineto
-  {
-    NR::Point  p;
-  }
-  path_descr_lineto;
-
-  // quadratic bezier curves: a set of control points, and an endpoint
-  typedef struct path_descr_bezierto
-  {
-    NR::Point    p;			// the endpoint's coordinates
-    int nb;             // number of control points, stored in the next path description commands
-  }
-  path_descr_bezierto;
-  typedef struct path_descr_intermbezierto
-  {
-    NR::Point    p;			// control point coordinates
-  }
-  path_descr_intermbezierto;
-
-  // cubic spline curve: 2 tangents and one endpoint
-  typedef struct path_descr_cubicto
-  {
-    NR::Point    p;
-    NR::Point    stD;
-    NR::Point    enD;
-  }
-  path_descr_cubicto;
-
-  // arc: endpoint, 2 radii and one angle, plus 2 booleans to choose the arc (svg style)
-  typedef struct path_descr_arcto
-  {
-    NR::Point    p;
-    double       rx,ry;
-    double       angle;
-    bool         large, clockwise;
-  }
-  path_descr_arcto;
-
-  
-  typedef struct path_descr
-  {
-    int    flags;         // most notably contains the path command no
-    int    associated;		// index in the polyline of the point that ends the path portion of this command
-    double tSt, tEn;
-    int    dStart;        // commands' data is stored in a separate array; dStart is the index of the 
-                          // start of the storage for this command
-  }
-  path_descr;
-
   // flags for the path construction
   enum
   {
@@ -149,56 +74,46 @@ public:
   int         pending_bezier_data;
   int         pending_moveto_cmd;
   int         pending_moveto_data;
-  // the path description:
-  // first the commands: an array of size descr_max containing descr_nb commands
-  int         descr_max, descr_nb;
-  path_descr  *descr_cmd;
-  // and an array of NR::Points, of size ddata_max, of which ddata_nb are used
-  // the choice of NR::Point is arbitrary, it could be anything, in fact
-  int         ddata_max,ddata_nb;
-  NR::Point   *descr_data;
+  // the path description
+  std::vector<PathDescr*> descr_cmd;
 
   // polyline storage: a series of coordinates (and maybe weights)
-  typedef struct path_lineto
-  {
-    int isMoveTo;
-    NR::Point  p;
-  }
-  path_lineto;
-  
-  // back data: info on where this polyline's segment comes from, ie wich command in the path description: "piece"
+  // also back data: info on where this polyline's segment comes from, ie wich command in the path description: "piece"
   // and what abcissis on the chunk of path for this command: "t"
   // t=0 means it's at the start of the command's chunk, t=1 it's at the end
-  typedef struct path_lineto_b:public path_lineto
+  struct path_lineto
   {
+    path_lineto(bool m, NR::Point pp) : isMoveTo(m), p(pp), piece(-1), t(0) {}
+    path_lineto(bool m, NR::Point pp, int pie, double tt) : isMoveTo(m), p(pp), piece(pie), t(tt) {}
+    
+    int isMoveTo;
+    NR::Point  p;
     int piece;
     double t;
-  }
-  path_lineto_b;
+  };
   
-  int     nbPt, maxPt, sizePt;
-  char    *pts;
+  std::vector<path_lineto> pts;
 
   bool back;
 
-  Path (void);
-  ~Path (void);
+  Path();
+  ~Path();
 
   // creation of the path description
-  void Reset (void);		// reset to the empty description
+  void Reset();		// reset to the empty description
   void Copy (Path * who);
 
   // the commands...
-  int ForcePoint (void);
-  int Close (void);
+  int ForcePoint();
+  int Close();
   int MoveTo ( NR::Point const &ip);
   int LineTo ( NR::Point const &ip);
   int CubicTo ( NR::Point const &ip,  NR::Point const &iStD,  NR::Point const &iEnD);
   int ArcTo ( NR::Point const &ip, double iRx, double iRy, double angle, bool iLargeArc, bool iClockwise);
   int IntermBezierTo ( NR::Point const &ip);	// add a quadratic bezier spline control point
   int BezierTo ( NR::Point const &ip);	// quadratic bezier spline to this point (control points can be added after this)
-  int TempBezierTo (void);	// start a quadratic bezier spline (control points can be added after this)
-  int EndBezierTo (void);
+  int TempBezierTo();	// start a quadratic bezier spline (control points can be added after this)
+  int EndBezierTo();
   int EndBezierTo ( NR::Point const &ip);	// ends a quadratic bezier spline (for curves started with TempBezierTo)
 
   // transforms a description in a polyline (for stroking and filling)
@@ -207,12 +122,10 @@ public:
   void ConvertEvenLines (double treshhold);	// decomposes line segments too, for later recomposition
   // same function for use when you want to later recompose the curves from the polyline
   void ConvertWithBackData (double treshhold);
-  // bad naughty evil useless function
-  void ConvertForOffset (double treshhold, Path * orig, double off_dec);
 
   // creation of the polyline (you can tinker with these function if you want)
   void SetBackData (bool nVal);	// has back data?
-  void ResetPoints (int expected = 0);	// resets to the empty polyline
+  void ResetPoints(); // resets to the empty polyline
   int AddPoint ( NR::Point const &iPt, bool mvto = false);	// add point
   int AddPoint ( NR::Point const &iPt, int ip, double it, bool mvto = false);
   int AddForcedPoint ( NR::Point const &iPt);	// add point
@@ -266,7 +179,10 @@ public:
   void  DashPolyline(float head,float tail,float body,int nbD,float *dashs,bool stPlain,float stOffset);
   
   //utilitaire pour inkscape
-  void  LoadArtBPath(void *iP,NR::Matrix &tr,bool doTransformation);
+  void  LoadArtBPath(void *iP,NR::Matrix const &tr,bool doTransformation);
+	void* MakeArtBPath();
+	
+	void  Transform(const NR::Matrix &trans);
   
   // decompose le chemin en ses sous-chemin
   // killNoSurf=true -> oublie les chemins de surface nulle
@@ -276,33 +192,31 @@ public:
   // conts= debut de chaque contour
   // nesting= parent de chaque contour
   Path**      SubPathsWithNesting(int &outNb,bool killNoSurf,int nbNest,int* nesting,int* conts);
-  // surface du chemin (considr comme ferm)
-  double      Surface(void);
+  // surface du chemin (considere comme ferme)
+  double      Surface();
   void        PolylineBoundingBox(double &l,double &t,double &r,double &b);
+  void        FastBBox(double &l,double &t,double &r,double &b);
   // longueur (totale des sous-chemins)
-  double      Length(void);
+  double      Length();
   
-  void             ConvertForcedToMoveTo(void);
-  void             ConvertForcedToVoid(void);
-  typedef struct cut_position {
+  void             ConvertForcedToMoveTo();
+  void             ConvertForcedToVoid();
+  struct cut_position {
     int          piece;
     float        t;
-  } cut_position;
+  };
   cut_position*    CurvilignToPosition(int nbCv,double* cvAbs,int &nbCut);
   
   // caution: not tested on quadratic b-splines, most certainly buggy
   void             ConvertPositionsToMoveTo(int nbPos,cut_position* poss);
   void             ConvertPositionsToForced(int nbPos,cut_position* poss);
 
-    void  Affiche(void);
+  void  Affiche();
+  char *svg_dump_path() const;
+
 private:
-    // path storage primitives
-  void AlloueDCmd (int addNb);
-  void AlloueDData (int addNb);
-  void ShiftDCmd(int at,int dec);
-  void ShiftDData(int at,int dec);
   // utilitary functions for the path contruction
-  void CancelBezier (void);
+  void CancelBezier ();
   void CloseSubpath();
   void InsertMoveTo (NR::Point const &iPt,int at);
   void InsertForcePoint (int at);
@@ -312,11 +226,9 @@ private:
   void InsertBezierTo (NR::Point const &iPt,int iNb,int at);
   void InsertIntermBezierTo (NR::Point const &iPt,int at);
   
-  int  DataPosForAfter(int cmd);
- 
   // creation of dashes: take the polyline given by spP (length spL) and dash it according to head, body, etc. put the result in
   // the polyline of this instance
-  void DashSubPath(int spL,char* spP,float head,float tail,float body,int nbD,float *dashs,bool stPlain,float stOffset);
+  void DashSubPath(int spL, int spP, std::vector<path_lineto> const &orig_pts, float head,float tail,float body,int nbD,float *dashs,bool stPlain,float stOffset);
 
   // Functions used by the conversion.
   // they append points to the polyline
@@ -334,14 +246,13 @@ private:
 		    int piece);
 
   // don't pay attention
-  typedef struct offset_orig
+  struct offset_orig
   {
     Path *orig;
     int piece;
     double tSt, tEn;
     double off_dec;
-  }
-  offset_orig;
+  };
   void DoArc ( NR::Point const &iS,  NR::Point const &iE, double rx, double ry,
 	      double angle, bool large, bool wise, double tresh, int piece,
 	      offset_orig & orig);
@@ -358,7 +269,7 @@ private:
 			     NR::Point const &iSd,  NR::Point const &iE,
 			     NR::Point const &iEd);
 
-  typedef struct outline_callback_data
+  struct outline_callback_data
   {
     Path *orig;
     int piece;
@@ -386,49 +297,41 @@ private:
       a;
     }
     d;
-  }
-  outline_callback_data;
+  };
 
   typedef void (outlineCallback) (outline_callback_data * data, double tol,  double width);
-  typedef struct outline_callbacks
+  struct outline_callbacks
   {
     outlineCallback *cubicto;
     outlineCallback *bezierto;
     outlineCallback *arcto;
-  }
-  outline_callbacks;
+  };
 
-  void SubContractOutline (Path * dest, outline_callbacks & calls,
+  void SubContractOutline (int off, int num_pd,
+			   Path * dest, outline_callbacks & calls,
 			   double tolerance, double width, JoinType join,
 			   ButtType butt, double miter, bool closeIfNeeded,
 			   bool skipMoveto, NR::Point & lastP, NR::Point & lastT);
-  void DoOutsideOutline (Path * dest, double width, JoinType join,
-			 ButtType butt, double miter, int &stNo, int &enNo);
-  void DoInsideOutline (Path * dest, double width, JoinType join,
-			ButtType butt, double miter, int &stNo, int &enNo);
-  void DoStroke (Shape * dest, bool doClose, double width, JoinType join,
-		 ButtType butt, double miter, bool justAdd = false);
-  void DoStroke (Shape * dest, bool doClose, double width, JoinType join,
-		 ButtType butt, double miter, int nbDash, one_dash * dashs,
-		 bool justAdd = false);
+  void DoStroke(int off, int N, Shape *dest, bool doClose, double width, JoinType join,
+		ButtType butt, double miter, bool justAdd = false);
+  void DoStroke(int off, int N, Shape *dest, bool doClose, double width, JoinType join,
+		ButtType butt, double miter, int nbDash, one_dash *dashs,
+		bool justAdd = false);
 
-  static void TangentOnSegAt (double at, NR::Point const &iS,
-			      path_descr_lineto & fin, NR::Point & pos, NR::Point & tgt,
-			      double &len);
-  static void TangentOnArcAt (double at, NR::Point const &iS,
-			      path_descr_arcto & fin, NR::Point & pos, NR::Point & tgt,
-			      double &len, double &rad);
-  static void TangentOnCubAt (double at, NR::Point const &iS,
-			      path_descr_cubicto & fin, bool before,
-			      NR::Point & pos, NR::Point & tgt, double &len, double &rad);
+  static void TangentOnSegAt(double at, NR::Point const &iS, PathDescrLineTo const &fin,
+			     NR::Point &pos, NR::Point &tgt, double &len);
+  static void TangentOnArcAt(double at, NR::Point const &iS, PathDescrArcTo const &fin,
+			     NR::Point &pos, NR::Point &tgt, double &len, double &rad);
+  static void TangentOnCubAt (double at, NR::Point const &iS, PathDescrCubicTo const &fin, bool before,
+			      NR::Point &pos, NR::Point &tgt, double &len, double &rad);
   static void TangentOnBezAt (double at, NR::Point const &iS,
-			      path_descr_intermbezierto & mid,
-			      path_descr_bezierto & fin, bool before,
+			      PathDescrIntermBezierTo & mid,
+			      PathDescrBezierTo & fin, bool before,
 			      NR::Point & pos, NR::Point & tgt, double &len, double &rad);
   static void OutlineJoin (Path * dest, NR::Point pos, NR::Point stNor, NR::Point enNor,
 			   double width, JoinType join, double miter);
 
-  static bool IsNulCurve (path_descr const * curD, NR::Point const &curX,NR::Point* ddata);
+  static bool IsNulCurve (std::vector<PathDescr*> const &cmd, int curD, NR::Point const &curX);
 
   static void RecStdCubicTo (outline_callback_data * data, double tol,
 			     double width, int lev);
@@ -446,8 +349,7 @@ private:
 		      NR::Point dir, int &leftNo, int &rightNo);
   static void DoJoin (Shape * dest, double width, JoinType join, NR::Point pos,
 		      NR::Point prev, NR::Point next, double miter, double prevL,
-		      double nextL, int &leftStNo, int &leftEnNo,
-		      int &rightStNo, int &rightEnNo);
+		      double nextL, int *stNo, int *enNo);
   static void DoLeftJoin (Shape * dest, double width, JoinType join, NR::Point pos,
 			  NR::Point prev, NR::Point next, double miter, double prevL,
 			  double nextL, int &leftStNo, int &leftEnNo,int pathID=-1,int pieceID=0,double tID=0.0);
@@ -462,12 +364,13 @@ private:
 		      int &lastLeft, int &lastRight, int nbDash,
 		      one_dash * dashs);
 
-  void DoCoalesce (Path * dest, double tresh);
-
-  void DoSimplify (double treshhold,int recLevel=0);
-  bool AttemptSimplify (double treshhold, path_descr_cubicto & res,int &worstP);
-  static bool FitCubic(NR::Point &start,path_descr_cubicto & res,double* Xk,double* Yk,double* Qk,double* tk,int nbPt);
-  typedef struct fitting_tables {
+  void DoSimplify(int off, int N, double treshhold);
+  bool AttemptSimplify(int off, int N, double treshhold, PathDescrCubicTo &res, int &worstP);
+  static bool FitCubic(NR::Point const &start,
+		       PathDescrCubicTo &res,
+		       double *Xk, double *Yk, double *Qk, double *tk, int nbPt);
+  
+  struct fitting_tables {
     int      nbPt,maxPt,inPt;
     double   *Xk;
     double   *Yk;
@@ -476,10 +379,10 @@ private:
     double   *lk;
     char     *fk;
     double   totLen;
-  } fitting_tables;
-  bool   AttemptSimplify (fitting_tables &data,double treshhold, path_descr_cubicto & res,int &worstP);
-  bool   ExtendFit(fitting_tables &data,double treshhold, path_descr_cubicto & res,int &worstP);
+  };
+  bool   AttemptSimplify (fitting_tables &data,double treshhold, PathDescrCubicTo & res,int &worstP);
+  bool   ExtendFit(int off, int N, fitting_tables &data,double treshhold, PathDescrCubicTo & res,int &worstP);
   double RaffineTk (NR::Point pt, NR::Point p0, NR::Point p1, NR::Point p2, NR::Point p3, double it);
-  void   FlushPendingAddition(Path* dest,path_descr &lastAddition,path_descr_cubicto &lastCubic,int lastAD);
+  void   FlushPendingAddition(Path* dest,PathDescr *lastAddition,PathDescrCubicTo &lastCubic,int lastAD);
 };
 #endif
