@@ -19,11 +19,11 @@ Shape::Plot (double ix, double iy, double ir, double mx, double my, bool doPoint
   fprintf(outFile,"<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\n");
   fprintf(outFile,"<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.0//EN\"\n");
   fprintf(outFile,"\"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd\">\n");
-  fprintf(outFile,"<svg\n");
+  fprintf(outFile,"<svg:svg\n");
   fprintf(outFile,"   id=\"svg1\"\n");
   fprintf(outFile,"   sodipodi:version=\"0.32\"\n");
   fprintf(outFile,"   inkscape:version=\"0.38cvs\"\n");
-  fprintf(outFile,"   xmlns=\"http://www.w3.org/2000/svg\"\n");
+  fprintf(outFile,"   xmlns:svg=\"http://www.w3.org/2000/svg\"\n");
   fprintf(outFile,"   xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\"\n");
   fprintf(outFile,"   xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\"\n");
   fprintf(outFile,"   xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n");
@@ -31,7 +31,7 @@ Shape::Plot (double ix, double iy, double ir, double mx, double my, bool doPoint
   fprintf(outFile,"   height=\"297mm\"\n");
   fprintf(outFile,"   sodipodi:docbase=\"/Volumes/Sancho/inkscapecvs\"\n");
   fprintf(outFile,"   sodipodi:docname=\"/Volumes/Sancho/inkscapecvs/modele.svg\">\n");
-  fprintf(outFile,"  <defs\n");
+  fprintf(outFile,"  <svg:defs\n");
   fprintf(outFile,"     id=\"defs3\" />\n");
   fprintf(outFile,"  <sodipodi:namedview\n");
   fprintf(outFile,"     id=\"base\"\n");
@@ -52,14 +52,14 @@ Shape::Plot (double ix, double iy, double ir, double mx, double my, bool doPoint
 		for (int i=0;i<numberOfPoints();i++) {
 			double   ph=(getPoint(i).x[0]-ix)*ir+mx;
 			double   pv=(getPoint(i).x[1]-iy)*ir+my;
-      fprintf(outFile,"     <circle cx=\"%f\" cy=\"%f\" r=\"5\" fill=\"none\" stroke=\"red\" stroke-width=\"0.25\" />\n",ph,pv); // localizing ok
+      fprintf(outFile,"     <svg:circle cx=\"%f\" cy=\"%f\" r=\"5\" fill=\"none\" stroke=\"red\" stroke-width=\"0.25\" />\n",ph,pv); // localizing ok
     }
 	}
   if ( pointsNo ) {
 		for (int i=0;i<numberOfPoints();i++) {
 			double   ph=(getPoint(i).x[0]-ix)*ir+mx;
 			double   pv=(getPoint(i).x[1]-iy)*ir+my;
-      fprintf(outFile,"     <text x=\"%f\" y=\"%f\" font-family=\"Monaco\" font-size=\"5\" fill=\"blue\" >\n",ph-2,pv+1); // localizing ok
+      fprintf(outFile,"     <svg:text x=\"%f\" y=\"%f\" font-family=\"Monaco\" font-size=\"5\" fill=\"blue\" >\n",ph-2,pv+1); // localizing ok
       fprintf(outFile,"%i\n",i);
       fprintf(outFile,"     </text>\n");
     }
@@ -76,9 +76,9 @@ Shape::Plot (double ix, double iy, double ir, double mx, double my, bool doPoint
 			if ( doDir ) {
 				double   endh=(9*eh+1*sh)/10;
 				double   endv=(9*ev+1*sv)/10;
-        fprintf(outFile,"     <line x1=\"%f\" y1=\"%f\" x2=\"%f\" y2=\"%f\" stroke=\"black\" stroke-width=\"0.5\" />\n",sh,sv,endh,endv); // localizing ok
+        fprintf(outFile,"     <svg:line x1=\"%f\" y1=\"%f\" x2=\"%f\" y2=\"%f\" stroke=\"black\" stroke-width=\"0.5\" />\n",sh,sv,endh,endv); // localizing ok
 			} else {
-        fprintf(outFile,"     <line x1=\"%f\" y1=\"%f\" x2=\"%f\" y2=\"%f\" stroke=\"black\" stroke-width=\"0.5\" />\n",sh,sv,eh,ev); // localizing ok
+        fprintf(outFile,"     <svg:line x1=\"%f\" y1=\"%f\" x2=\"%f\" y2=\"%f\" stroke=\"black\" stroke-width=\"0.5\" />\n",sh,sv,eh,ev); // localizing ok
 			}
 		}
 	}
@@ -91,7 +91,7 @@ Shape::Plot (double ix, double iy, double ir, double mx, double my, bool doPoint
 			double   sv=(getPoint(stP).x[1]-iy)*ir+my;
 			double   eh=(getPoint(enP).x[0]-ix)*ir+mx;
 			double   ev=(getPoint(enP).x[1]-iy)*ir+my;
-      fprintf(outFile,"     <text x=\"%f\" y=\"%f\" font-family=\"Monaco\" font-size=\"5\" fill=\"blue\" >\n",(sh+eh)/2+2,(sv+ev)/2); // localizing ok
+      fprintf(outFile,"     <svg:text x=\"%f\" y=\"%f\" font-family=\"Monaco\" font-size=\"5\" fill=\"blue\" >\n",(sh+eh)/2+2,(sv+ev)/2); // localizing ok
       fprintf(outFile,"%i\n",i);
       fprintf(outFile,"     </text>\n");
 		}
