@@ -59,6 +59,7 @@
 #include "slideshow.h"
 #include "color.h"
 #include "sp-item.h"
+#include "unit-constants.h"
 
 #include "svg/svg.h"
 
@@ -71,6 +72,8 @@
 #include "sp-object-repr.h"
 #include "xml/repr.h"
 
+#include "io/sys.h"
+
 #include <extension/extension.h>
 #include <extension/system.h>
 #include <extension/db.h>
@@ -80,7 +83,7 @@
 #endif
 #include "extension/init.h"
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 
 #ifndef HAVE_BIND_TEXTDOMAIN_CODESET
 #define bind_textdomain_codeset(p,c)
@@ -167,7 +170,7 @@ struct poptOption options[] = {
 
     {"export-dpi", 'd', 
      POPT_ARG_STRING, &sp_export_dpi, SP_ARG_EXPORT_DPI,
-     N_("The resolution used for exporting SVG into bitmap (default 72)"),
+     N_("The resolution used for exporting SVG into bitmap (default 90)"),
      N_("DPI")},
 
     {"export-area", 'a', 
@@ -232,7 +235,10 @@ main(int argc, char const **argv)
     gint result, i;
 
 #ifdef HAVE_FPSETMASK
-    fpsetmask(fpgetmask() & ~(FP_X_DZ|FP_X_INV));
+    /* This is inherited from Sodipodi code, where it was in #ifdef __FreeBSD__.  It's probably
+       safe to remove: the default mask is already 0 in C99, and in current FreeBSD according to
+       the fenv man page on www.freebsd.org, and in glibc according to (libc)FP Exceptions. */
+    fpsetmask(fpgetmask() & ~(FP_X_DZ | FP_X_INV));
 #endif
 
 #ifdef ENABLE_NLS
@@ -301,10 +307,6 @@ main(int argc, char const **argv)
         result = sp_main_console(argc, argv);
     }
 
-#ifdef HAVE_FPSETMASK
-    fpsetsticky(FP_X_DZ|FP_X_INV);
-    fpsetmask(FP_X_DZ|FP_X_INV);
-#endif
     return result;
 }
 
@@ -340,7 +342,7 @@ sp_main_gui(int argc, char const **argv)
 
     /* Set default icon */
     gchar *filename = (gchar *) g_build_filename (INKSCAPE_APPICONDIR, "inkscape.png", NULL);
-    if (g_file_test(filename, (GFileTest)(G_FILE_TEST_IS_REGULAR | G_FILE_TEST_IS_SYMLINK))) {
+    if (Inkscape::IO::file_test(filename, (GFileTest)(G_FILE_TEST_IS_REGULAR | G_FILE_TEST_IS_SYMLINK))) {
         gtk_window_set_default_icon_from_file(filename, NULL);
     }
     g_free (filename);
@@ -463,10 +465,10 @@ sp_main_console(int argc, char const **argv)
             if (sp_export_svg) {
                 SPReprDoc *rdoc;
                 SPRepr *repr;
-                rdoc = sp_repr_document_new("svg");
-                repr = sp_repr_document_root(rdoc);
+                rdoc = sp_repr_document_new("svg:svg");
+                repr = rdoc->root();
                 repr = sp_document_root(doc)->updateRepr(repr, SP_OBJECT_WRITE_BUILD);
-                sp_repr_save_file(sp_repr_document(repr), sp_export_svg);
+                sp_repr_save_file(repr->document(), sp_export_svg, SP_SVG_NS_URI);
             }
         }
         fl = g_slist_remove(fl, fl->data);
@@ -512,7 +514,7 @@ sp_do_export_png(SPDocument *doc)
             if (sp_export_use_hints) {
 
                 // retrieve export filename hint
-                const gchar *fn_hint = sp_repr_attr (SP_OBJECT_REPR (o), "inkscape:export-filename");
+                const gchar *fn_hint = SP_OBJECT_REPR(o)->attribute("inkscape:export-filename");
                 if (fn_hint) {
                     if (sp_export_png) {
                         g_warning ("Using export filename from the command line (--export-png). Filename hint %s is ignored.", fn_hint);
@@ -526,7 +528,7 @@ sp_do_export_png(SPDocument *doc)
                 }
 
                 // retrieve export dpi hints
-                const gchar *dpi_hint = sp_repr_attr (SP_OBJECT_REPR (o), "inkscape:export-xdpi"); // only xdpi, ydpi is always the same now
+                const gchar *dpi_hint = SP_OBJECT_REPR(o)->attribute("inkscape:export-xdpi"); // only xdpi, ydpi is always the same now
                 if (dpi_hint) {
                     if (sp_export_dpi || sp_export_width || sp_export_height) {
                         g_warning ("Using bitmap dimensions from the command line (--export-dpi, --export-width, or --export-height). DPI hint %s is ignored.", dpi_hint);
@@ -584,7 +586,7 @@ sp_do_export_png(SPDocument *doc)
 
     // default dpi
     if (dpi == 0.0)
-        dpi = 72.0;
+        dpi = PX_PER_IN;
 
     gint width = 0;
     gint height = 0;
@@ -595,7 +597,7 @@ sp_do_export_png(SPDocument *doc)
             g_warning("Export width %d out of range (1 - 65536). Nothing exported.", width);
             return;
         }
-        dpi = (gdouble) width * 72.0 / (area.x1 - area.x0);
+        dpi = (gdouble) width * PX_PER_IN / (area.x1 - area.x0);
     }
 
     if (sp_export_height) {
@@ -604,15 +606,15 @@ sp_do_export_png(SPDocument *doc)
             g_warning("Export height %d out of range (1 - 65536). Nothing exported.", width);
             return;
         }
-        dpi = (gdouble) height * 72.0 / (area.y1 - area.y0);
+        dpi = (gdouble) height * PX_PER_IN / (area.y1 - area.y0);
     }
 
     if (!sp_export_width) {
-        width = (gint) ((area.x1 - area.x0) * dpi / 72.0 + 0.5);
+        width = (gint) ((area.x1 - area.x0) * dpi / PX_PER_IN + 0.5);
     }
 
     if (!sp_export_height) {
-        height = (gint) ((area.y1 - area.y0) * dpi / 72.0 + 0.5);
+        height = (gint) ((area.y1 - area.y0) * dpi / PX_PER_IN + 0.5);
     }
 
     guint32 bgcolor = 0x00000000;
@@ -623,9 +625,9 @@ sp_do_export_png(SPDocument *doc)
     } else {
         // read from namedview
         SPRepr *nv = sp_repr_lookup_name (doc->rroot, "sodipodi:namedview");
-        if (nv && sp_repr_attr (nv, "pagecolor"))
-            bgcolor = sp_svg_read_color(sp_repr_attr (nv, "pagecolor"), 0xffffff00);
-        if (nv && sp_repr_attr (nv, "inkscape:pageopacity"))
+        if (nv && nv->attribute("pagecolor"))
+            bgcolor = sp_svg_read_color(nv->attribute("pagecolor"), 0xffffff00);
+        if (nv && nv->attribute("inkscape:pageopacity"))
             bgcolor |= SP_COLOR_F_TO_U(sp_repr_get_double_attribute (nv, "inkscape:pageopacity", 1.0));
     }
 
