@@ -17,7 +17,7 @@
 #include "macros.h"
 #include "xml/repr.h"
 #include "svg/svg.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "display/sp-canvas-util.h"
 #include "object-edit.h"
 #include "sp-path.h"
@@ -48,15 +48,10 @@ static gint sp_node_context_item_handler (SPEventContext * event_context, SPItem
 
 static void nodepath_event_attr_changed (SPRepr * repr, const gchar * name, const gchar * old_value, const gchar * new_value, bool is_interactive, gpointer data);
 static SPReprEventVector nodepath_repr_events = {
-	NULL, /* add_child */
 	NULL, /* child_added */
-	NULL, /* remove_child */
 	NULL, /* child_removed */
-	NULL, /* change_attr */
 	nodepath_event_attr_changed,
-	NULL, /* change_list */
 	NULL, /* content_changed */
-	NULL, /* change_order */
 	NULL  /* order_changed */
 };
 
@@ -139,16 +134,25 @@ sp_node_context_dispose (GObject *object)
 	nc->sel_changed_connection.disconnect();
 	nc->sel_changed_connection.~connection();
 
+	SPRepr *repr = NULL;
+	if (nc->nodepath) {
+		repr = nc->nodepath->repr;
+	} 
+	if (!repr && nc->knot_holder) {
+		repr = nc->knot_holder->repr;
+	}
+
+	if (repr) {
+		sp_repr_remove_listener_by_data (repr, ec);
+		sp_repr_unref (repr);
+	}
+
 	if (nc->nodepath) {
-		sp_repr_remove_listener_by_data (nc->nodepath->repr, ec);
-		sp_repr_unref (nc->nodepath->repr);
 		sp_nodepath_destroy (nc->nodepath);
 		nc->nodepath = NULL;
 	}
 
 	if (nc->knot_holder) {
-		sp_repr_remove_listener_by_data (nc->knot_holder->repr, ec);
-		sp_repr_unref (nc->knot_holder->repr);
 		sp_knot_holder_destroy (nc->knot_holder);
 		nc->knot_holder = NULL;
 	}
@@ -182,9 +186,8 @@ sp_node_context_setup (SPEventContext *ec)
 		if ( nc->nodepath) {
 			//point pack to parent in case nodepath is deleted
 			nc->nodepath->nodeContext = nc;
-		} else {
-			nc->knot_holder = sp_item_knot_holder (item, ec->desktop);
-		}
+		} 
+		nc->knot_holder = sp_item_knot_holder (item, ec->desktop);
 
 		if (nc->nodepath || nc->knot_holder) {
 			// setting listener
@@ -240,9 +243,8 @@ sp_node_context_selection_changed (SPSelection * selection, gpointer data)
 		nc->nodepath = sp_nodepath_new (desktop, item);
 		if (nc->nodepath) {
 			nc->nodepath->nodeContext = nc;
-		} else {
-			nc->knot_holder = sp_item_knot_holder (item, desktop);
 		}
+		nc->knot_holder = sp_item_knot_holder (item, desktop);
 
 		if (nc->nodepath || nc->knot_holder) {
 			// setting new listener
@@ -286,9 +288,7 @@ sp_nodepath_update_from_item (SPNodeContext *nc, SPItem *item)
 	nc->knot_holder = NULL;
 	if (item) {
 		nc->nodepath = sp_nodepath_new (desktop, item);
-		if (! nc->nodepath) {
-			nc->knot_holder = sp_item_knot_holder (item, desktop);
-		}
+         	nc->knot_holder = sp_item_knot_holder (item, desktop);
 	}
 	sp_nodepath_update_statusbar (nc->nodepath);
 }
@@ -393,7 +393,7 @@ sp_node_context_root_handler (SPEventContext * event_context, GdkEvent * event)
 {
 	SPDesktop *desktop = event_context->desktop;
 	SPNodeContext *nc = SP_NODE_CONTEXT(event_context);
-	double const nudge = prefs_get_double_attribute_limited("options.nudgedistance", "value", 2.8346457, 0, 1000); // default is 1 mm
+	double const nudge = prefs_get_double_attribute_limited("options.nudgedistance", "value", 2, 0, 1000); // in px
 	tolerance = prefs_get_int_attribute_limited ("options.dragtolerance", "value", 0, 0, 100);
 	int const snaps = prefs_get_int_attribute("options.rotationsnapsperpi", "value", 12);
 	double const offset = prefs_get_double_attribute_limited("options.defaultscale", "value", 2, 0, 1000);
@@ -469,6 +469,7 @@ sp_node_context_root_handler (SPEventContext * event_context, GdkEvent * event)
 			break;
 		case GDK_Delete:
 		case GDK_KP_Delete:
+		case GDK_BackSpace:		
 			// with any modifiers
 			sp_node_selected_delete ();
 			ret = TRUE;
