@@ -10,9 +10,12 @@
  * This code is in public domain
  */
 
+#include <sigc++/sigc++.h>
 #include "event-context.h"
+#include "forward.h"
 #include "nodepath.h"
-#include "knotholder.h"
+struct SPKnotHolder;
+class SPSelection;
 
 #define SP_TYPE_NODE_CONTEXT            (sp_node_context_get_type ())
 #define SP_NODE_CONTEXT(obj)            (GTK_CHECK_CAST ((obj), SP_TYPE_NODE_CONTEXT, SPNodeContext))
@@ -20,10 +23,10 @@
 #define SP_IS_NODE_CONTEXT(obj)         (GTK_CHECK_TYPE ((obj), SP_TYPE_NODE_CONTEXT))
 #define SP_IS_NODE_CONTEXT_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), SP_TYPE_NODE_CONTEXT))
 
-typedef struct _SPNodeContext SPNodeContext;
-typedef struct _SPNodeContextClass SPNodeContextClass;
+class SPNodeContext;
+class SPNodeContextClass;
 
-struct _SPNodeContext {
+struct SPNodeContext {
 	SPEventContext event_context;
 
 	guint drag : 1;
@@ -35,9 +38,13 @@ struct _SPNodeContext {
 	gboolean rightalt;
 	gboolean leftctrl;
 	gboolean rightctrl;
+
+	sigc::connection sel_changed_connection;
+
+	Inkscape::MessageContext *_node_message_context;
 };
 
-struct _SPNodeContextClass {
+struct SPNodeContextClass {
 	SPEventContextClass parent_class;
 };
 
