@@ -19,7 +19,7 @@
 #include "display/sp-canvas-util.h"
 #include "display/sp-ctrlline.h"
 #include "display/sodipodi-ctrl.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "libnr/n-art-bpath.h"
 #include "knot.h"
 #include "inkscape.h"
@@ -34,7 +34,6 @@
 #include "selection.h"
 #include "selection.h"
 #include "xml/repr.h"
-#include "xml/repr-private.h"
 #include "object-edit.h"
 #include "prefs-utils.h"
 #include "sp-flowtext.h"
@@ -400,10 +399,10 @@ static void update_object(Path::Path *np)
 
 static void update_repr_internal(Path::Path *np)
 {
-    SPRepr *repr = SP_OBJECT(np->path)->repr;
-
     g_assert(np);
 
+    SPRepr *repr = SP_OBJECT(np->path)->repr;
+
     SPCurve *curve = create_curve(np);
     gchar *typestr = create_typestr(np);
     gchar *svgpath = sp_svg_write_path(curve->bpath);
@@ -944,7 +943,11 @@ void Path::Path::selection(std::list<Node *> &l)
 
 void sp_nodepath_selected_align(Path::Path *nodepath, NR::Dim2 axis)
 {
-    if ( ! nodepath->selected->next ) {
+    if ( !nodepath || !nodepath->selected ) { // no nodepath, or no nodes selected
+        return;
+    }
+
+    if ( !nodepath->selected->next ) { // only one node selected
         return;
     }
     Path::Node *pNode = reinterpret_cast<Path::Node *>(nodepath->selected->data);
@@ -981,9 +984,14 @@ static bool operator<(NodeSort const &a, NodeSort const &b)
 
 void sp_nodepath_selected_distribute(Path::Path *nodepath, NR::Dim2 axis)
 {
-    if ( ! (nodepath->selected->next && nodepath->selected->next->next) ) {
+    if ( !nodepath || !nodepath->selected ) { // no nodepath, or no nodes selected
         return;
     }
+
+    if ( ! (nodepath->selected->next && nodepath->selected->next->next) ) { // less than 3 nodes selected
+        return;
+    }
+
     Path::Node *pNode = reinterpret_cast<Path::Node *>(nodepath->selected->data);
     std::vector<NodeSort> sorted;
     for (GList *l = nodepath->selected; l != NULL; l = l->next) {
@@ -1976,6 +1984,7 @@ gboolean node_key(GdkEvent *event)
     if ((event->type == GDK_KEY_PRESS) && !(event->key.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK))) {
         gint ret = FALSE;
         switch (event->key.keyval) {
+            // FIXME: this does not seem to work, the keys are stolen by tool contexts!
             case GDK_BackSpace:
                 np = active_node->subpath->nodepath;
                 sp_nodepath_node_destroy(active_node);
@@ -2217,9 +2226,9 @@ static void node_ctrl_grabbed(SPKnot *knot, guint state, gpointer data)
 
     // remember the origin of the control
     if (n->p.knot == knot) {
-        n->p.origin = Radial(n->p.pos - n->pos);
+        n->p.origin = n->p.pos - n->pos;
     } else if (n->n.knot == knot) {
-        n->n.origin = Radial(n->n.pos - n->pos);
+        n->n.origin = n->n.pos - n->pos;
     } else {
         g_assert_not_reached();
     }
@@ -2868,6 +2877,7 @@ static gchar const *sp_node_type_description(Path::Node *n)
             // TRANSLATORS: "cusp" means "sharp" (cusp node); see also the Advanced Tutorial
             return _("cusp");
         case Path::NODE_SMOOTH:
+            // TRANSLATORS: "smooth" is an adjective here
             return _("smooth");
         case Path::NODE_SYMM:
             return _("symmetric");
@@ -2899,17 +2909,26 @@ sp_nodepath_update_statusbar(Path::Path *nodepath)
         SPSelection *sel = nodepath->desktop->selection;
         if (!sel || sel->isEmpty()) {
             mc->setF(Inkscape::NORMAL_MESSAGE,
-                                                     _("Select one path object with selector first, then switch back to node tool."));
+                     _("Select one path object with selector first, then switch back to node tool."));
         } else {
             mc->setF(Inkscape::NORMAL_MESSAGE,
-                                                      _("<b>0</b> out of <b>%i</b> nodes selected. Click, Shift+click, or drag around nodes to select."), total);
+                     ngettext("<b>0</b> out of <b>%i</b> node selected. Click, Shift+click, or drag around nodes to select.",
+                              "<b>0</b> out of <b>%i</b> nodes selected. Click, Shift+click, or drag around nodes to select.",
+                              total),
+                     total);
         }
     } else if (selected == 1) {
         mc->setF(Inkscape::NORMAL_MESSAGE,
-                                                  _("<b>%i</b> of <b>%i</b> nodes selected; %s. %s."), selected, total, sp_node_type_description((Path::Node *) nodepath->selected->data), when_selected);
+                 ngettext("<b>%i</b> of <b>%i</b> node selected; %s. %s.",
+                          "<b>%i</b> of <b>%i</b> nodes selected; %s. %s.",
+                          total),
+                 selected, total, sp_node_type_description((Path::Node *) nodepath->selected->data), when_selected);
     } else {
         mc->setF(Inkscape::NORMAL_MESSAGE,
-                                                  _("<b>%i</b> of <b>%i</b> nodes selected. %s."), selected, total, when_selected);
+                 ngettext("<b>%i</b> of <b>%i</b> node selected. %s.",
+                          "<b>%i</b> of <b>%i</b> nodes selected. %s.",
+                          total),
+                 selected, total, when_selected);
     }
 }
 
