@@ -29,7 +29,7 @@
 #include "sp-path.h"
 
 #include "macros.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 
 #include "object-edit.h"
 
@@ -41,7 +41,6 @@
 #include <libnr/nr-matrix-ops.h>
 
 #include "xml/repr.h"
-#include "xml/repr-private.h"
 
 #define sp_round(v,m) (((v) < 0.0) ? ((ceil ((v) / (m) - 0.5)) * (m)) : ((floor ((v) / (m) + 0.5)) * (m)))
 
@@ -840,6 +839,8 @@ sp_spiral_outer_set (SPItem *item, const NR::Point &p, const NR::Point &origin,
 			spiral->rad = rad_new;
 			spiral->t0 = pow (r0 / spiral->rad, 1/spiral->exp);
 		}
+		if (!std::isfinite(spiral->t0)) spiral->t0 = 0.0;
+		spiral->t0 = CLAMP (spiral->t0, 0.0, 0.999);	
 	}
 
 	((SPObject *)spiral)->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
@@ -947,12 +948,12 @@ sp_pat_knot_holder (SPItem * item, SPKnotHolder *knot_holder)
     if ((SP_OBJECT(item)->style->fill.type == SP_PAINT_TYPE_PAINTSERVER)
         && SP_IS_PATTERN (SP_STYLE_FILL_SERVER (SP_OBJECT(item)->style)))
         {
-            sp_knot_holder_add_full (knot_holder, sp_pattern_xy_set, sp_pattern_xy_get, NULL, SP_KNOT_SHAPE_CIRCLE, SP_KNOT_MODE_XOR,
+            sp_knot_holder_add_full (knot_holder, sp_pattern_xy_set, sp_pattern_xy_get, NULL, SP_KNOT_SHAPE_CROSS, SP_KNOT_MODE_XOR,
             // TRANSLATORS: This refers to the pattern that's inside the object
 																		 _("<b>Move</b> the pattern fill inside the object"));
-            sp_knot_holder_add_full (knot_holder, sp_pattern_scale_set, sp_pattern_scale_get, NULL, SP_KNOT_SHAPE_DIAMOND, SP_KNOT_MODE_XOR,
+            sp_knot_holder_add_full (knot_holder, sp_pattern_scale_set, sp_pattern_scale_get, NULL, SP_KNOT_SHAPE_SQUARE, SP_KNOT_MODE_XOR,
 																		 _("<b>Scale</b> the pattern fill uniformly"));
-            sp_knot_holder_add_full (knot_holder, sp_pattern_angle_set, sp_pattern_angle_get, NULL, SP_KNOT_SHAPE_DIAMOND, SP_KNOT_MODE_XOR,
+            sp_knot_holder_add_full (knot_holder, sp_pattern_angle_set, sp_pattern_angle_get, NULL, SP_KNOT_SHAPE_CIRCLE, SP_KNOT_MODE_XOR,
 																		 _("<b>Rotate</b> the pattern fill; with <b>Ctrl</b> to snap angle"));
         }
 }
