@@ -36,13 +36,14 @@ sp_object_menu (SPObject *object, SPDesktop *desktop, GtkMenu *menu)
 #include <gtk/gtkmenuitem.h>
 #include <gtk/gtksignal.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 
 #include "sp-item-group.h"
 #include "sp-anchor.h"
 #include "sp-image.h"
 #include "sp-rect.h"
 #include "sp-star.h"
+#include "sp-ellipse.h"
 #include "sp-spiral.h"
 
 #include "document.h"
@@ -68,6 +69,7 @@ static void sp_image_menu (SPObject *object, SPDesktop *desktop, GtkMenu *menu);
 static void sp_shape_menu (SPObject *object, SPDesktop *desktop, GtkMenu *menu);
 static void sp_rect_menu (SPObject *object, SPDesktop *desktop, GtkMenu *menu);
 static void sp_star_menu (SPObject *object, SPDesktop *desktop, GtkMenu *menu);
+static void sp_ellipse_menu (SPObject *object, SPDesktop *desktop, GtkMenu *menu);
 static void sp_spiral_menu (SPObject *object, SPDesktop *desktop, GtkMenu *menu);
 
 static void
@@ -84,6 +86,7 @@ sp_object_type_menu (GType type, SPObject *object, SPDesktop *desktop, GtkMenu *
 		g_hash_table_insert (t2m, GUINT_TO_POINTER (SP_TYPE_SHAPE), (void*)sp_shape_menu);
 		g_hash_table_insert (t2m, GUINT_TO_POINTER (SP_TYPE_RECT), (void*)sp_rect_menu);
 		g_hash_table_insert (t2m, GUINT_TO_POINTER (SP_TYPE_STAR), (void*)sp_star_menu);
+		g_hash_table_insert (t2m, GUINT_TO_POINTER (SP_TYPE_GENERICELLIPSE), (void*)sp_ellipse_menu);
 		g_hash_table_insert (t2m, GUINT_TO_POINTER (SP_TYPE_SPIRAL), (void*)sp_spiral_menu);
 	}
 	handler = (void (*)(SPObject*, SPDesktop*, GtkMenu*))g_hash_table_lookup (t2m, GUINT_TO_POINTER (type));
@@ -95,7 +98,6 @@ sp_object_type_menu (GType type, SPObject *object, SPDesktop *desktop, GtkMenu *
 static void sp_item_properties (GtkMenuItem *menuitem, SPItem *item);
 static void sp_item_select_this (GtkMenuItem *menuitem, SPItem *item);
 static void sp_item_reset_transformation (GtkMenuItem *menuitem, SPItem *item);
-static void sp_item_toggle_sensitivity (GtkMenuItem *menuitem, SPItem *item);
 static void sp_item_create_link (GtkMenuItem *menuitem, SPItem *item);
 static void sp_item_create_text_shape (GtkMenuItem *menuitem, SPItem *item);
 
@@ -106,7 +108,6 @@ sp_item_menu (SPObject *object, SPDesktop *desktop, GtkMenu *m)
 {
 	SPItem *item;
 	GtkWidget *w;
-	gboolean insensitive;
 
 	item = (SPItem *) object;
 
@@ -135,12 +136,6 @@ sp_item_menu (SPObject *object, SPDesktop *desktop, GtkMenu *m)
 	gtk_signal_connect (GTK_OBJECT (w), "activate", GTK_SIGNAL_FUNC (sp_item_reset_transformation), item);
 	gtk_widget_show (w);
 	gtk_menu_append (GTK_MENU (m), w);
-	/* Toggle sensitivity */
-	insensitive = (sp_repr_attr (SP_OBJECT_REPR (item), "sodipodi:insensitive") != NULL);
-	w = gtk_menu_item_new_with_mnemonic (insensitive ? _("Make s_ensitive") : _("Make i_nsensitive"));
-	gtk_signal_connect (GTK_OBJECT (w), "activate", GTK_SIGNAL_FUNC (sp_item_toggle_sensitivity), item);
-	gtk_widget_show (w);
-	gtk_menu_append (GTK_MENU (m), w);
 	/* Create link */
 	w = gtk_menu_item_new_with_mnemonic (_("_Create Link"));
 	gtk_object_set_data (GTK_OBJECT (w), "desktop", desktop);
@@ -196,24 +191,6 @@ sp_item_reset_transformation (GtkMenuItem * menuitem, SPItem * item)
 	sp_document_done (SP_OBJECT_DOCUMENT (item));
 }
 
-static void
-sp_item_toggle_sensitivity (GtkMenuItem * menuitem, SPItem * item)
-{
-	const gchar * val;
-
-	g_assert (SP_IS_ITEM (item));
-
-	/* fixme: reprs suck */
-	val = sp_repr_attr (SP_OBJECT_REPR (item), "sodipodi:insensitive");
-	if (val != NULL) {
-		val = NULL;
-	} else {
-		val = "1";
-	}
-	sp_repr_set_attr (SP_OBJECT_REPR (item), "sodipodi:insensitive", val);
-	sp_document_done (SP_OBJECT_DOCUMENT (item));
-}
-
 
 static void
 sp_item_create_text_shape (GtkMenuItem *menuitem, SPItem *item)
@@ -228,12 +205,12 @@ sp_item_create_text_shape (GtkMenuItem *menuitem, SPItem *item)
 		return;
 	}
 
-    SPRepr *root_repr = sp_repr_new ("flowRoot");
+    SPRepr *root_repr = sp_repr_new ("svg:flowRoot");
     sp_repr_append_child (SP_OBJECT_REPR (SP_OBJECT_PARENT (item)), root_repr);
     SPObject *root_object = doc->getObjectByRepr(root_repr);
     g_return_if_fail (SP_IS_FLOWTEXT (root_object));
 
-    SPRepr *region_repr = sp_repr_new ("flowRegion");
+    SPRepr *region_repr = sp_repr_new ("svg:flowRegion");
     sp_repr_append_child (root_repr, region_repr);
     SPObject *object = doc->getObjectByRepr(region_repr);
     g_return_if_fail (SP_IS_FLOWREGION (object));
@@ -245,7 +222,7 @@ sp_item_create_text_shape (GtkMenuItem *menuitem, SPItem *item)
     GSList *reprs = g_slist_copy((GSList *) selection->reprList());
     for (GSList *i = reprs; i; i = i->next) {
          if (!SP_IS_IMAGE(doc->getObjectByRepr((SPRepr *)i->data))){
-            clone = sp_repr_new("use");
+            clone = sp_repr_new("svg:use");
             sp_repr_set_attr(clone, "x", "0");
             sp_repr_set_attr(clone, "y", "0");
             sp_repr_set_attr(clone, "xlink:href", g_strdup_printf("#%s", sp_repr_attr((SPRepr *)i->data, "id")));
@@ -256,12 +233,12 @@ sp_item_create_text_shape (GtkMenuItem *menuitem, SPItem *item)
 
     }
 
-    SPRepr *div_repr = sp_repr_new ("flowDiv");
+    SPRepr *div_repr = sp_repr_new ("svg:flowDiv");
     sp_repr_append_child (root_repr, div_repr);
     SPObject *div_object = doc->getObjectByRepr(div_repr);
     g_return_if_fail (SP_IS_FLOWDIV (div_object));
 
-    SPRepr *para_repr = sp_repr_new ("flowPara");
+    SPRepr *para_repr = sp_repr_new ("svg:flowPara");
     sp_repr_append_child (div_repr, para_repr);
     object = doc->getObjectByRepr(para_repr);
     g_return_if_fail (SP_IS_FLOWPARA (object));
@@ -286,7 +263,7 @@ sp_item_create_link (GtkMenuItem *menuitem, SPItem *item)
 	g_return_if_fail (desktop != NULL);
 	g_return_if_fail (SP_IS_DESKTOP (desktop));
 
-	SPRepr *repr = sp_repr_new ("a");
+	SPRepr *repr = sp_repr_new ("svg:a");
 	sp_repr_add_child (SP_OBJECT_REPR (SP_OBJECT_PARENT (item)), repr, SP_OBJECT_REPR (item));
 	SPObject *object = SP_OBJECT_DOCUMENT (item)->getObjectByRepr(repr);
 	g_return_if_fail (SP_IS_ANCHOR (object));
@@ -518,6 +495,34 @@ sp_star_star_properties (GtkMenuItem *menuitem, SPAnchor *anchor)
 	sp_object_attributes_dialog (SP_OBJECT (anchor), "SPStar");
 }
 
+
+/* SPEllipse */
+
+static void sp_ellipse_ellipse_properties (GtkMenuItem *menuitem, SPAnchor *anchor);
+
+static void
+sp_ellipse_menu (SPObject *object, SPDesktop *desktop, GtkMenu *m)
+{
+	SPItem *item;
+	GtkWidget *w;
+
+	item = (SPItem *) object;
+
+	/* Link dialog */
+	w = gtk_menu_item_new_with_mnemonic (_("Ellipse _Properties"));
+	gtk_object_set_data (GTK_OBJECT (w), "desktop", desktop);
+	gtk_signal_connect (GTK_OBJECT (w), "activate", GTK_SIGNAL_FUNC (sp_ellipse_ellipse_properties), item);
+	gtk_widget_show (w);
+	gtk_menu_append (GTK_MENU (m), w);
+}
+
+static void
+sp_ellipse_ellipse_properties (GtkMenuItem *menuitem, SPAnchor *anchor)
+{
+	sp_object_attributes_dialog (SP_OBJECT (anchor), "SPEllipse");
+}
+
+
 /* SPSpiral */
 
 static void sp_spiral_spiral_properties (GtkMenuItem *menuitem, SPAnchor *anchor);
