@@ -18,10 +18,9 @@
 #include <string.h>
 #include "libnr/nr-macros.h"
 #include "xml/repr.h"
-#include "xml/repr-private.h"
 #include "svg/svg.h"
 #include "display/curve.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "sp-object.h"
 #include "sp-path.h"
 #include "sp-text.h"
@@ -67,9 +66,9 @@ sp_selected_path_combine (void)
 		}
 	}
 
-	SPRepr *parent = SP_OBJECT_REPR ((SPItem *) items->data)->parent;
+	SPRepr *parent = SP_OBJECT_REPR ((SPItem *) items->data)->parent();
 	for (GSList *i = items; i != NULL; i = i->next) {
-		if ( SP_OBJECT_REPR ((SPItem *) i->data)->parent != parent ) {
+		if ( SP_OBJECT_REPR ((SPItem *) i->data)->parent() != parent ) {
 		    desktop->messageStack()->flash(Inkscape::ERROR_MESSAGE, _("You cannot combine objects from <b>different groups</b> or <b>layers</b>."));
 		    return;
 		}
@@ -120,7 +119,7 @@ sp_selected_path_combine (void)
 
 	g_slist_free (items);
 
-	SPRepr *repr = sp_repr_new ("path");
+	SPRepr *repr = sp_repr_new ("svg:path");
 
 	// restore id
 	sp_repr_set_attr (repr, "id", id);
@@ -177,7 +176,7 @@ sp_selected_path_break_apart (void)
 
 		did = true;
 
-		SPRepr *parent = SP_OBJECT_REPR (item)->parent;
+		SPRepr *parent = SP_OBJECT_REPR (item)->parent();
 		gint pos = sp_repr_position (SP_OBJECT_REPR (item));
 		const char *id = sp_repr_attr (SP_OBJECT_REPR (item), "id");
 
@@ -200,7 +199,7 @@ sp_selected_path_break_apart (void)
 		for (GSList *l = g_slist_reverse(list); l != NULL; l = l->next) {
 			curve = (SPCurve *) l->data;
 
-			SPRepr *repr = sp_repr_new ("path");
+			SPRepr *repr = sp_repr_new ("svg:path");
 			sp_repr_set_attr (repr, "style", style);
 
 			gchar *str = sp_svg_write_path (curve->bpath);
@@ -274,7 +273,7 @@ sp_selected_path_to_curves0 (gboolean interactive, guint32 text_grouping_policy)
 		// remember the position of the item
 		gint pos = sp_repr_position (SP_OBJECT_REPR (item));
 		// remember parent
-		SPRepr *parent = SP_OBJECT_REPR (item)->parent;
+		SPRepr *parent = SP_OBJECT_REPR (item)->parent();
 		// remember id
 		const char *id = sp_repr_attr (SP_OBJECT_REPR (item), "id");
 
@@ -320,7 +319,7 @@ sp_selected_item_to_curved_repr(SPItem * item, guint32 text_grouping_policy)
 	if (!curve)
 	  return NULL;
 	
-	SPRepr *repr = sp_repr_new ("path");
+	SPRepr *repr = sp_repr_new ("svg:path");
 	/* Transformation */
 	sp_repr_set_attr (repr, "transform", 
 			  sp_repr_attr (SP_OBJECT_REPR (item), "transform"));
@@ -341,7 +340,7 @@ sp_selected_item_to_curved_repr(SPItem * item, guint32 text_grouping_policy)
 void
 sp_path_cleanup (SPPath *path)
 {
-	if (strcmp (sp_repr_name (SP_OBJECT_REPR (path)), "path"))
+	if (strcmp (sp_repr_name (SP_OBJECT_REPR (path)), "svg:path"))
 	  return;
 
 	SPStyle *style = SP_OBJECT_STYLE (path);
