@@ -26,7 +26,7 @@
 #include "display/sp-canvas.h"
 #include "display/sp-ctrlline.h"
 #include "display/sodipodi-ctrl.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "libnr/n-art-bpath.h"
 
 static void sp_pen_context_class_init(SPPenContextClass *klass);
@@ -367,6 +367,12 @@ static gint
 pen_handle_motion_notify(SPPenContext *const pc, GdkEventMotion const &mevent)
 {
     gint ret = FALSE;
+
+    if (mevent.state & GDK_BUTTON2_MASK || mevent.state & GDK_BUTTON3_MASK) {
+        // allow middle-button scrolling
+        return FALSE;
+    }
+
     NR::Point const event_w(mevent.x,
                             mevent.y);
     if (pen_within_tolerance) {
@@ -385,7 +391,7 @@ pen_handle_motion_notify(SPPenContext *const pc, GdkEventMotion const &mevent)
     if ( ( mevent.state & GDK_BUTTON1_MASK ) && !pc->grab ) {
         /* Grab mouse, so release will not pass unnoticed */
         pc->grab = SP_CANVAS_ITEM(dt->acetate);
-        sp_canvas_item_grab(pc->grab, ( GDK_BUTTON_PRESS_MASK   |
+        sp_canvas_item_grab(pc->grab, ( GDK_KEY_PRESS_MASK | GDK_BUTTON_PRESS_MASK   |
                                         GDK_BUTTON_RELEASE_MASK |
                                         GDK_POINTER_MOTION_MASK  ),
                             NULL, mevent.time);
