@@ -38,16 +38,13 @@ static char const preferences_skeleton[] =
 "       borderopacity=\"1.0\"\n"
 "       inkscape:pageopacity=\"0.0\"\n"
 "       inkscape:pageshadow=\"2\"\n"
-"       inkscape:zoom=\"0.43415836\"\n"
-"       inkscape:cx=\"305.259528\"\n"
-"       inkscape:cy=\"417.849475\"\n"
 "       inkscape:window-width=\"640\"\n"
 "       inkscape:window-height=\"480\" />\n"
 "  </group>\n"
 "\n"
 "  <group id=\"tools\"\n"
 "         style=\"fill:none;fill-opacity:0.75;\n"
-"                 stroke:black;stroke-opacity:1;stroke-width:1pt;stroke-linejoin:miter;stroke-linecap:butt;\">\n"
+"                 stroke:black;stroke-opacity:1;stroke-width:1px;stroke-linejoin:miter;stroke-linecap:butt;\">\n"
 "    <group id=\"shapes\" style=\"fill-rule:evenodd;\" selcue=\"1\">\n"
 "      <eventcontext id=\"rect\" style=\"fill:blue;\" usecurrent=\"1\"/>\n"
 "      <eventcontext id=\"arc\" style=\"fill:red;\" end=\"0\" start=\"0\" usecurrent=\"1\"/>\n"
@@ -56,8 +53,8 @@ static char const preferences_skeleton[] =
 "    </group>\n"
 "    <group id=\"freehand\"\n"
 "         style=\"fill:none;fill-rule:evenodd;stroke:black;stroke-opacity:1;stroke-linejoin:miter;stroke-linecap:butt;\">\n"
-"      <eventcontext id=\"pencil\" tolerance=\"4.0\" selcue=\"1\" style=\"stroke-width:1pt;\" usecurrent=\"0\"/>\n"
-"      <eventcontext id=\"pen\" mode=\"drag\" selcue=\"1\" style=\"stroke-width:0.25pt;\" usecurrent=\"0\"/>\n"
+"      <eventcontext id=\"pencil\" tolerance=\"4.0\" selcue=\"1\" style=\"stroke-width:1px;\" usecurrent=\"0\"/>\n"
+"      <eventcontext id=\"pen\" mode=\"drag\" selcue=\"1\" style=\"stroke-width:1px;\" usecurrent=\"0\"/>\n"
 "    </group>\n"
 "    <eventcontext id=\"calligraphic\" style=\"fill:black;fill-opacity:1;fill-rule:nonzero;stroke:none;\"\n"
 "                       mass=\"0.02\" drag=\"1\" angle=\"30\" width=\"0.15\" thinning=\"0.1\" flatness=\"0.9\"  usecurrent=\"0\"/>\n"
@@ -129,9 +126,12 @@ static char const preferences_skeleton[] =
 "    <group id=\"save_as\" default=\"\" append_extension=\"1\" path=\"\"/>\n"
 "    <group id=\"open\" path=\"\"/>\n"
 "    <group id=\"debug\" redirect=\"0\"/>\n"
+"    <group id=\"clonetiler\" />\n"
+"    <group id=\"extension-error\" show-on-startup=\"1\"/>\n"
 "  </group>\n"
 "  <group id=\"printing\">\n"
 "    <settings id=\"ps\"/>\n"
+"    <group id=\"debug\" add-label-comments=\"0\"/>\n"
 "  </group>\n"
 "\n"
 "  <group id=\"options\">\n"
@@ -142,7 +142,7 @@ static char const preferences_skeleton[] =
 "    <group id=\"savewindowgeometry\" value=\"1\"/>\n"
 "    <group id=\"defaultoffsetwidth\" value=\"2\"/>\n"
 "    <group id=\"defaultscale\" value=\"2\"/>\n"
-"    <group id=\"maxrecentdocuments\" value=\"20\"/>\n"
+"    <group id=\"maxrecentdocuments\" value=\"36\"/>\n"
 "    <group id=\"zoomincrement\" value=\"1.414213562\"/>\n"
 "    <group id=\"keyscroll\" value=\"10\"/>\n"
 "    <group id=\"wheelscroll\" value=\"40\"/>\n"
