@@ -18,7 +18,7 @@
 #include <libnr/nr-matrix.h>
 #include <libnr/nr-pixblock.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "enums.h"
 #include "document.h"
 #include "sp-item.h"
@@ -60,6 +60,12 @@ sp_print_release (SPPrintContext *ctx)
 	return ctx->module->release();
 }
 
+unsigned int
+sp_print_comment(SPPrintContext *ctx, const char * comment)
+{
+	return ctx->module->comment(comment);
+}
+
 unsigned int
 sp_print_fill (SPPrintContext *ctx, const NRBPath *bpath, const NRMatrix *ctm, const SPStyle *style,
 	       const NRRect *pbox, const NRRect *dbox, const NRRect *bbox)
@@ -114,7 +120,7 @@ sp_print_preview_document (SPDocument *doc)
 		mod->base = SP_ITEM (sp_document_root (doc));
 		mod->arena = NRArena::create();
 		mod->dkey = sp_item_display_key_new (1);
-		mod->root = sp_item_invoke_show (mod->base, mod->arena, mod->dkey, SP_ITEM_SHOW_PRINT);
+		mod->root = sp_item_invoke_show (mod->base, mod->arena, mod->dkey, SP_ITEM_SHOW_DISPLAY);
 		/* Print document */
 		ret = mod->begin (doc);
 		sp_item_invoke_print (mod->base, &context);
@@ -156,7 +162,7 @@ sp_print_document (SPDocument *doc, unsigned int direct)
 		mod->base = SP_ITEM (sp_document_root (doc));
 		mod->arena = NRArena::create();
 		mod->dkey = sp_item_display_key_new (1);
-		mod->root = sp_item_invoke_show (mod->base, mod->arena, mod->dkey, SP_ITEM_SHOW_PRINT);
+		mod->root = sp_item_invoke_show (mod->base, mod->arena, mod->dkey, SP_ITEM_SHOW_DISPLAY);
 		/* Print document */
 		ret = mod->begin (doc);
 		sp_item_invoke_print (mod->base, &context);
@@ -196,7 +202,7 @@ sp_print_document_to_file (SPDocument *doc, const gchar *filename)
 	mod->base = SP_ITEM (sp_document_root (doc));
 	mod->arena = NRArena::create();
 	mod->dkey = sp_item_display_key_new (1);
-	mod->root = sp_item_invoke_show (mod->base, mod->arena, mod->dkey, SP_ITEM_SHOW_PRINT);
+	mod->root = sp_item_invoke_show (mod->base, mod->arena, mod->dkey, SP_ITEM_SHOW_DISPLAY);
 	/* Print document */
 	ret = mod->begin (doc);
 	sp_item_invoke_print (mod->base, &context);
