@@ -36,7 +36,7 @@
 #include "rect-context.h"
 #include "sp-desktop-widget.h"
 #include "sp-metrics.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "object-edit.h"
 #include "knotholder.h"
 #include "xml/repr.h"
@@ -171,15 +171,10 @@ static void shape_event_attr_changed(SPRepr *repr,
 }
 
 static SPReprEventVector shape_repr_events = {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     shape_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
@@ -332,7 +327,8 @@ static gint sp_rect_context_root_handler(SPEventContext *event_context, GdkEvent
             rc->center = button_dt;
             namedview_free_snap_all_types(event_context->desktop->namedview, rc->center);
             sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
-                                ( GDK_BUTTON_RELEASE_MASK       |
+                                ( GDK_KEY_PRESS_MASK | 
+                                  GDK_BUTTON_RELEASE_MASK       |
                                   GDK_POINTER_MOTION_MASK       |
                                   GDK_POINTER_MOTION_HINT_MASK  |
                                   GDK_BUTTON_PRESS_MASK ),
@@ -471,7 +467,7 @@ static void sp_rect_drag(SPRectContext &rc, NR::Point const pt, guint state)
         }
 
         /* Create object */
-        SPRepr *repr = sp_repr_new("rect");
+        SPRepr *repr = sp_repr_new("svg:rect");
 
         /* Set style */
         sp_desktop_apply_style_tool (desktop, repr, "tools.shapes.rect", false);
@@ -557,8 +553,8 @@ static void sp_rect_drag(SPRectContext &rc, NR::Point const pt, guint state)
     }
 
     // status text
-    GString *xs = SP_PT_TO_METRIC_STRING(fabs( x1 - x0 ), SP_DEFAULT_METRIC);
-    GString *ys = SP_PT_TO_METRIC_STRING(fabs( y1 - y0 ), SP_DEFAULT_METRIC);
+    GString *xs = SP_PX_TO_METRIC_STRING(fabs( x1 - x0 ), sp_desktop_get_default_metric(desktop));
+    GString *ys = SP_PX_TO_METRIC_STRING(fabs( y1 - y0 ), sp_desktop_get_default_metric(desktop));
     rc._message_context->setF(Inkscape::NORMAL_MESSAGE, _("<b>Rectangle</b>: %s x %s; with <b>Ctrl</b> to make square or integer-ratio rectangle; with <b>Shift</b> to draw around the starting point"), xs->str, ys->str);
     g_string_free(xs, FALSE);
     g_string_free(ys, FALSE);
