@@ -14,8 +14,10 @@
  * Released under GNU GPL
  */
 
+#include <sigc++/sigc++.h>
 #include "event-context.h"
-#include "knotholder.h"
+#include "libnr/nr-point.h"
+struct SPKnotHolder;
 
 #define SP_TYPE_RECT_CONTEXT            (sp_rect_context_get_type ())
 #define SP_RECT_CONTEXT(obj)            (GTK_CHECK_CAST ((obj), SP_TYPE_RECT_CONTEXT, SPRectContext))
@@ -23,22 +25,25 @@
 #define SP_IS_RECT_CONTEXT(obj)         (GTK_CHECK_TYPE ((obj), SP_TYPE_RECT_CONTEXT))
 #define SP_IS_RECT_CONTEXT_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), SP_TYPE_RECT_CONTEXT))
 
-typedef struct _SPRectContext SPRectContext;
-typedef struct _SPRectContextClass SPRectContextClass;
+class SPRectContext;
+class SPRectContextClass;
 
-struct _SPRectContext {
-	SPEventContext event_context;
+struct SPRectContext : public SPEventContext {
 	SPItem *item;
 	NR::Point center;
 
 	SPKnotHolder *knot_holder;
 	SPRepr *repr;
 	
-  	gdouble rx_ratio;	/* roundness ratio (x direction) */
-  	gdouble ry_ratio;	/* roundness ratio (y direction) */
+  	gdouble rx;	/* roundness radius (x direction) */
+  	gdouble ry;	/* roundness radius (y direction) */
+
+	sigc::connection sel_changed_connection;
+
+	Inkscape::MessageContext *_message_context;
 };
 
-struct _SPRectContextClass {
+struct SPRectContextClass {
 	SPEventContextClass parent_class;
 };
 
