@@ -8,14 +8,14 @@
 #include <approx-equal.h>
 
 void satisfied_guide_cns(SPDesktop const &desktop,
-                         int const n_snappoints, NR::Point const snappoints[],
+                         std::vector<NR::Point> const &snappoints,
                          std::vector<SPGuideConstraint> &cns)
 {
     g_assert(SP_IS_DESKTOP(&desktop));
     SPNamedView const &nv = *desktop.namedview;
     for (GSList const *l = nv.guides; l != NULL; l = l->next) {
         SPGuide &g = *SP_GUIDE(l->data);
-        for (int i = 0; i < n_snappoints; ++i) {
+        for (unsigned int i = 0; i < snappoints.size(); ++i) {
             if (approx_equal(dot(g.normal, snappoints[i]), g.position)) {
                 cns.push_back(SPGuideConstraint(&g, i));
             }
