@@ -30,7 +30,7 @@
 #include "pixmaps/cursor-select-m.xpm"
 #include "pixmaps/cursor-select-d.xpm"
 #include "pixmaps/handles.xpm"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "widgets/spw-utilities.h"
 #include "message-context.h"
 
@@ -224,13 +224,18 @@ sp_select_context_abort(SPEventContext *event_context)
             sc->dragging = FALSE;
             drag_escaped = 1;
 
-            // only undo if the item is still valid
-            if (SP_OBJECT_DOCUMENT( SP_OBJECT(sc->item))) {
-              sp_document_undo(SP_DT_DOCUMENT(desktop));
-            }
-
             if (sc->item) {
+                // only undo if the item is still valid
+                if (SP_OBJECT_DOCUMENT( SP_OBJECT(sc->item))) {
+                    sp_document_undo(SP_DT_DOCUMENT(desktop));
+                }
+
                 sp_object_unref( SP_OBJECT(sc->item), NULL);
+            } else if (sc->button_press_ctrl) {
+                // NOTE:  This is a workaround to a bug.
+                // When the ctrl key is held, sc->item is not defined
+                // so in this case (only), we skip the object doc check
+                sp_document_undo(SP_DT_DOCUMENT(desktop));
             }
             sc->item = NULL;
 
@@ -446,13 +451,12 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
     SPItem *item_at_point = NULL, *group_at_point = NULL, *item_in_group = NULL;
     gint ret = FALSE;
     NRRect b;
-    GSList *l;
 
     SPDesktop *desktop = event_context->desktop;
     SPSelectContext *sc = SP_SELECT_CONTEXT(event_context);
     SPSelTrans *seltrans = sc->_seltrans;
     SPSelection *selection = SP_DT_SELECTION(desktop);
-    gdouble const nudge = prefs_get_double_attribute_limited("options.nudgedistance", "value", 2.8346457, 0, 1000); // default is 1 mm
+    gdouble const nudge = prefs_get_double_attribute_limited("options.nudgedistance", "value", 2, 0, 1000); // in px
     gdouble const offset = prefs_get_double_attribute_limited("options.defaultscale", "value", 2, 0, 1000);
     tolerance = prefs_get_int_attribute_limited("options.dragtolerance", "value", 0, 0, 100);
     int const snaps = prefs_get_int_attribute("options.rotationsnapsperpi", "value", 12);
@@ -597,23 +601,15 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                         sp_rubberband_stop();
                         sp_sel_trans_reset_state(seltrans);
                         // find out affected items:
-                        l = sp_document_items_in_box(SP_DT_DOCUMENT(desktop), desktop->dkey, &b);
+                        GSList *items = sp_document_items_in_box(SP_DT_DOCUMENT(desktop), desktop->dkey, &b);
                         if (event->button.state & GDK_SHIFT_MASK) {
                             // with shift, add to selection
-                            while (l) {
-                                item = SP_ITEM(l->data);
-                                if (selection->includesItem(item)) {
-                                    // Uncomment if you want toggle behavior for shift-rubberband.
-                                    //selection->removeItem(item);
-                                } else {
-                                    selection->addItem(item);
-                                }
-                                l = g_slist_remove(l, item);
-                            }
+                            selection->addList (items);
                         } else {
                             // without shift, simply select anew
-                            selection->setItemList(l);
+                            selection->setItemList (items);
                         }
+                        g_slist_free (items);
                     } else { // it was just a click, or a too small rubberband
                         sp_rubberband_stop();
                         if (sc->button_press_shift && !rb_escaped && !drag_escaped) {
@@ -631,7 +627,11 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                                 item = sp_select_context_find_item (desktop, NR::Point(event->button.x, event->button.y), event->button.state, FALSE);
                             }
 
-                            // if there's both a group and an item at point, deselect group to prevent double selection
+                            // if there's both a group and an item at point, deselect group to
+                            // prevent double selection. FIXME: this only prevents double select for
+                            // top-level groups and bottom-level objects, but fails if a mid-level
+                            // group is selected without entering the top-level as a layer (though
+                            // this currently only possible by XML editor)
                             if (group) {
                                 if (selection->includesItem(group)) {
                                     selection->removeItem(group);
@@ -917,8 +917,8 @@ static void sp_selection_moveto(SPSelTrans *seltrans, NR::Point const &xy, guint
     sp_sel_trans_transform(seltrans, move, norm);
 
     // status text
-    GString *xs = SP_PT_TO_METRIC_STRING(dxy[X], SP_DEFAULT_METRIC);
-    GString *ys = SP_PT_TO_METRIC_STRING(dxy[Y], SP_DEFAULT_METRIC);
+    GString *xs = SP_PX_TO_METRIC_STRING(dxy[X], sp_desktop_get_default_metric(desktop));
+    GString *ys = SP_PX_TO_METRIC_STRING(dxy[Y], sp_desktop_get_default_metric(desktop));
     seltrans->messageContext().setF(Inkscape::NORMAL_MESSAGE, _("<b>Move</b> by %s, %s; with <b>Ctrl</b> to restrict to horizontal/vertical; with <b>Shift</b> to disable snapping"), xs->str, ys->str);
     g_string_free(xs, TRUE);
     g_string_free(ys, TRUE);
