@@ -13,6 +13,7 @@
  */
 
 #include "event-context.h"
+#include "selection-describer.h"
 #include "seltrans.h"
 
 #define SP_TYPE_SELECT_CONTEXT            (sp_select_context_get_type ())
@@ -21,21 +22,24 @@
 #define SP_IS_SELECT_CONTEXT(obj)         (GTK_CHECK_TYPE ((obj), SP_TYPE_SELECT_CONTEXT))
 #define SP_IS_SELECT_CONTEXT_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), SP_TYPE_SELECT_CONTEXT))
 
-typedef struct _SPSelectContext SPSelectContext;
-typedef struct _SPSelectContextClass SPSelectContextClass;
+class SPSelectContext;
+class SPSelectContextClass;
 
-struct _SPSelectContext {
-	SPEventContext event_context;
+namespace Inkscape { class MessageContext; }
+
+struct SPSelectContext : public SPEventContext {
 	guint dragging : 1;
 	guint moved : 1;
-	guint button_press_shift : 1;
-	guint button_press_ctrl : 1;
+	bool button_press_shift;
+	bool button_press_ctrl;
+	bool button_press_alt;
 	SPItem *item;
 	SPCanvasItem *grabbed;
-	SPSelTrans seltrans;
+	SPSelTrans *_seltrans;
+	Inkscape::SelectionDescriber *_describer;
 };
 
-struct _SPSelectContextClass {
+struct SPSelectContextClass {
 	SPEventContextClass parent_class;
 };
 
