@@ -46,9 +46,8 @@
 #include "desktop-handles.h"
 #include "interface.h"
 #include "toolbox.h"
-#include "xml/repr-private.h"
 #include "helper/gnome-utils.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "widgets/sp-widget.h"
 #include "helper/unit-menu.h"
 #include "helper/units.h"
@@ -106,7 +105,7 @@ sp_selection_layout_widget_update(SPWidget *spw, SPSelection *sel)
                 };
                 for (unsigned i = 0; i < G_N_ELEMENTS(keyval); ++i) {
                     GtkAdjustment *a = (GtkAdjustment *) gtk_object_get_data(GTK_OBJECT(spw), keyval[i].key);
-                    gtk_adjustment_set_value(a, sp_points_get_units(keyval[i].val, &unit));
+                    gtk_adjustment_set_value(a, sp_pixels_get_units(keyval[i].val, unit));
                 }
             }
 
@@ -170,18 +169,18 @@ sp_object_layout_any_value_changed(GtkAdjustment *adj, SPWidget *spw)
 
     gdouble x0, y0, x1, y1, xrel, yrel;
 
-    if (unit.base == SP_UNIT_ABSOLUTE) {
+    if (unit.base == SP_UNIT_ABSOLUTE || unit.base == SP_UNIT_DEVICE) {
         GtkAdjustment *a;
         a = (GtkAdjustment *) gtk_object_get_data(GTK_OBJECT(spw), "X");
-        x0 = sp_units_get_points(a->value, unit);
+        x0 = sp_units_get_pixels (a->value, unit);
         a = (GtkAdjustment *) gtk_object_get_data(GTK_OBJECT(spw), "Y");
-        y0 = sp_units_get_points(a->value, unit);
+        y0 = sp_units_get_pixels (a->value, unit);
         a = (GtkAdjustment *) gtk_object_get_data(GTK_OBJECT(spw), "width");
-        x1 = x0 + sp_units_get_points(a->value, unit);
-        xrel = sp_units_get_points(a->value, unit) / bbox.extent(NR::X);
+        x1 = x0 + sp_units_get_pixels (a->value, unit);
+        xrel = sp_units_get_pixels (a->value, unit) / bbox.extent(NR::X);
         a = (GtkAdjustment *) gtk_object_get_data(GTK_OBJECT(spw), "height");
-        y1 = y0 + sp_units_get_points(a->value, unit);
-        yrel = sp_units_get_points(a->value, unit) / bbox.extent(NR::Y);
+        y1 = y0 + sp_units_get_pixels (a->value, unit);
+        yrel = sp_units_get_pixels (a->value, unit) / bbox.extent(NR::Y);
     } else {
         GtkAdjustment *a;
         a = (GtkAdjustment *) gtk_object_get_data(GTK_OBJECT(spw), "X");
@@ -287,7 +286,7 @@ static gboolean aux_set_unit(SPUnitSelector *,
     if (selection->isEmpty())
         return FALSE;
 
-    if ((old->base == SP_UNIT_ABSOLUTE)
+    if ((old->base == SP_UNIT_ABSOLUTE || old->base == SP_UNIT_DEVICE)
         && (new_units->base == SP_UNIT_DIMENSIONLESS))
     {
 
@@ -299,22 +298,22 @@ static gboolean aux_set_unit(SPUnitSelector *,
         GtkAdjustment *aw = GTK_ADJUSTMENT(g_object_get_data(dlg, "width"));
         GtkAdjustment *ah = GTK_ADJUSTMENT(g_object_get_data(dlg, "height"));
 
-        double const x = sp_units_get_points(ax->value, old);
-        double const y = sp_units_get_points(ay->value, old);
-        double const w = sp_units_get_points(aw->value, old);
-        double const h = sp_units_get_points(ah->value, old);
+        double const x = sp_units_get_pixels (ax->value, *old);
+        double const y = sp_units_get_pixels (ay->value, *old);
+        double const w = sp_units_get_pixels (aw->value, *old);
+        double const h = sp_units_get_pixels (ah->value, *old);
 
         NR::Rect bbox = selection->bounds();
 
-        gtk_adjustment_set_value(ax, 100.0 * x / bbox.min()[NR::X]);
-        gtk_adjustment_set_value(ay, 100.0 * y / bbox.min()[NR::Y]);
-        gtk_adjustment_set_value(aw, 100.0 * w / bbox.extent(NR::X));
-        gtk_adjustment_set_value(ah, 100.0 * h / bbox.extent(NR::Y));
+        gtk_adjustment_set_value(ax, fabs(bbox.min()[NR::X]) > 1e-6? 100.0 * x / bbox.min()[NR::X] : 100.0);
+        gtk_adjustment_set_value(ay, fabs(bbox.min()[NR::Y]) > 1e-6? 100.0 * y / bbox.min()[NR::Y] : 100.0);
+        gtk_adjustment_set_value(aw, fabs(bbox.extent(NR::X)) > 1e-6? 100.0 * w / bbox.extent(NR::X) : 100.0);
+        gtk_adjustment_set_value(ah, fabs(bbox.extent(NR::Y)) > 1e-6? 100.0 * h / bbox.extent(NR::Y) : 100.0);
 
         g_object_set_data(dlg, "update", GUINT_TO_POINTER(FALSE));
         return TRUE;
     } else if ((old->base == SP_UNIT_DIMENSIONLESS)
-               && (new_units->base == SP_UNIT_ABSOLUTE)) {
+               && (new_units->base == SP_UNIT_ABSOLUTE || new_units->base == SP_UNIT_DEVICE)) {
 
         /* Percentage to absolute */
         g_object_set_data(dlg, "update", GUINT_TO_POINTER(TRUE));
@@ -326,10 +325,10 @@ static gboolean aux_set_unit(SPUnitSelector *,
 
         NR::Rect bbox = selection->bounds();
 
-        gtk_adjustment_set_value(ax, sp_points_get_units(0.01 * ax->value * bbox.min()[NR::X], new_units));
-        gtk_adjustment_set_value(ay, sp_points_get_units(0.01 * ay->value * bbox.min()[NR::Y], new_units));
-        gtk_adjustment_set_value(aw, sp_points_get_units(0.01 * aw->value * bbox.extent(NR::X), new_units));
-        gtk_adjustment_set_value(ah, sp_points_get_units(0.01 * ah->value * bbox.extent(NR::Y), new_units));
+        gtk_adjustment_set_value(ax, sp_pixels_get_units(0.01 * ax->value * bbox.min()[NR::X], *new_units));
+        gtk_adjustment_set_value(ay, sp_pixels_get_units(0.01 * ay->value * bbox.min()[NR::Y], *new_units));
+        gtk_adjustment_set_value(aw, sp_pixels_get_units(0.01 * aw->value * bbox.extent(NR::X), *new_units));
+        gtk_adjustment_set_value(ah, sp_pixels_get_units(0.01 * ah->value * bbox.extent(NR::Y), *new_units));
 
         g_object_set_data(dlg, "update", GUINT_TO_POINTER(FALSE));
         return TRUE;
@@ -389,9 +388,10 @@ sp_select_toolbox_new(SPDesktop *desktop)
     gtk_object_set_data(GTK_OBJECT(spw), "frame", vb);
 
     // Create the units menu.
-    GtkWidget *us = sp_unit_selector_new(SP_UNIT_ABSOLUTE);
+    GtkWidget *us = sp_unit_selector_new(SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE);
     sp_unit_selector_setsize(us, AUX_OPTION_MENU_WIDTH, AUX_OPTION_MENU_HEIGHT);
     sp_unit_selector_add_unit(SP_UNIT_SELECTOR(us), &sp_unit_get_by_id(SP_UNIT_PERCENT), 0);
+    sp_unit_selector_set_unit (SP_UNIT_SELECTOR(us), sp_desktop_get_default_unit (desktop));
     g_signal_connect(G_OBJECT(us), "set_unit", G_CALLBACK(aux_set_unit), spw);
 
     // four spinbuttons
