@@ -23,8 +23,6 @@
 #include <gtkmm.h>
 
 #include "svg/svg.h"
-#include "xml/repr-private.h"
-#include "xml/repr-private.h"
 #include "document.h"
 #include "inkscape.h"
 #include "desktop.h"
@@ -41,7 +39,7 @@
 #include "sp-tspan.h"
 #include "text-context.h"
 #include "dropper-context.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "display/sp-canvas.h"
 #include "path-chemistry.h"
 #include "desktop-affine.h"
@@ -55,6 +53,7 @@
 #include "libnr/nr-scale-translate-ops.h"
 #include "libnr/nr-translate-matrix-ops.h"
 #include "libnr/nr-translate-scale-ops.h"
+#include "xml/repr.h"
 #include "style.h"
 #include "document-private.h"
 #include "sp-gradient.h"
@@ -137,11 +136,13 @@ void sp_selection_duplicate()
 
     selection->clear();
 
-    SPRepr *parent = ((SPRepr *) reprs->data)->parent;
+    SPRepr *parent = ((SPRepr *) reprs->data)->parent();
     gboolean sort = TRUE;
     for (GSList *i = reprs->next; i; i = i->next) {
-        if ((((SPRepr *) i->data)->parent) != parent) {
-            // We can duplicate items from different parents, but we cannot do sorting in this case
+        if ((((SPRepr *) i->data)->parent()) != parent) {
+            // We can duplicate items from different parents, but we need not do sorting in this
+            // case because dupes will remain in their own parents. FIXME: However, we need to sort those
+            // subsets of selection which are siblings (how?).
             sort = FALSE;
         }
     }
@@ -152,7 +153,7 @@ void sp_selection_duplicate()
     GSList *newsel = NULL;
 
     while (reprs) {
-        parent = ((SPRepr *) reprs->data)->parent;
+        parent = ((SPRepr *) reprs->data)->parent();
         SPRepr *copy = sp_repr_duplicate((SPRepr *) reprs->data);
 
         sp_repr_append_child(parent, copy);
@@ -190,26 +191,28 @@ void sp_edit_clear_all()
 }
 
 GSList *
-get_all_items (GSList *list, SPObject *from, SPDesktop *desktop, bool onlyvisible, bool onlysensitive)
+get_all_items (GSList *list, SPObject *from, SPDesktop *desktop, bool onlyvisible, bool onlysensitive, const GSList *exclude)
 {
     for (SPObject *child = sp_object_first_child(SP_OBJECT(from)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
         if (SP_IS_ITEM(child) &&
             !desktop->isLayer(SP_ITEM(child)) &&
             (!onlysensitive || !SP_ITEM(child)->isLocked()) && 
-            (!onlyvisible || !desktop->itemIsHidden(SP_ITEM(child))) )
+            (!onlyvisible || !desktop->itemIsHidden(SP_ITEM(child))) &&
+            (!exclude || !g_slist_find ((GSList *) exclude, child))
+            )
         {
             list = g_slist_prepend (list, SP_ITEM(child));
         }
 
         if (SP_IS_ITEM(child) && desktop->isLayer(SP_ITEM(child))) {
-            list = get_all_items (list, child, desktop, onlyvisible, onlysensitive);
+            list = get_all_items (list, child, desktop, onlyvisible, onlysensitive, exclude);
         }
     }
 
     return list;
 }
 
-void sp_edit_select_all()
+void sp_edit_select_all_full (bool force_all_layers, bool invert)
 {
     SPDesktop *dt = SP_ACTIVE_DESKTOP;
     if (!dt)
@@ -225,7 +228,12 @@ void sp_edit_select_all()
 
     GSList *items = NULL;
 
-    if (inlayer) {
+    const GSList *exclude = NULL;
+    if (invert) {
+        exclude = selection->itemList();
+    }
+
+    if (inlayer && !force_all_layers) {
 
         if ( (onlysensitive && SP_ITEM(dt->currentLayer())->isLocked()) ||
              (onlyvisible && dt->itemIsHidden(SP_ITEM(dt->currentLayer()))) )
@@ -239,7 +247,9 @@ void sp_edit_select_all()
             if (item && (!onlysensitive || !item->isLocked())) {
                 if (!onlyvisible || !dt->itemIsHidden(item)) {
                     if (!dt->isLayer(item)) {
-                        items = g_slist_prepend (items, item); // leave it in the list
+                        if (!invert || !g_slist_find ((GSList *) exclude, item)) {
+                            items = g_slist_prepend (items, item); // leave it in the list
+                        }
                     }
                 }
             }
@@ -248,15 +258,37 @@ void sp_edit_select_all()
         g_slist_free (all_items);
 
     } else {
-        items = get_all_items (NULL, dt->currentRoot(), dt, onlyvisible, onlysensitive);
+        items = get_all_items (NULL, dt->currentRoot(), dt, onlyvisible, onlysensitive, exclude);
     }
 
+    selection->setList (items);
+
     if (items) {
-        selection->setList (items);
         g_slist_free (items);
     }
 }
 
+void sp_edit_select_all ()
+{
+    sp_edit_select_all_full (false, false);
+}
+
+void sp_edit_select_all_in_all_layers ()
+{
+    sp_edit_select_all_full (true, false);
+}
+
+void sp_edit_invert ()
+{
+    sp_edit_select_all_full (false, true);
+}
+
+void sp_edit_invert_in_all_layers ()
+{
+    sp_edit_select_all_full (true, true);
+}
+
+
 static void
 sp_group_cleanup(SPGroup *group)
 {
@@ -277,7 +309,7 @@ sp_group_cleanup(SPGroup *group)
     }
 
 
-    if (!strcmp(sp_repr_name(SP_OBJECT_REPR(group)), "g")) {
+    if (!strcmp(sp_repr_name(SP_OBJECT_REPR(group)), "svg:g")) {
         gint numitems;
         numitems = 0;
         for (SPObject *child = sp_object_first_child(SP_OBJECT(group)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
@@ -329,9 +361,9 @@ void sp_selection_group()
 
     // Check if all selected objects have common parent.
     GSList *reprs = g_slist_copy((GSList *) selection->reprList());
-    SPRepr *parent = ((SPRepr *) reprs->data)->parent;
+    SPRepr *parent = ((SPRepr *) reprs->data)->parent();
     for (GSList *i = reprs->next; i; i = i->next) {
-        if ((((SPRepr *) i->data)->parent) != parent) {
+        if ((((SPRepr *) i->data)->parent()) != parent) {
             desktop->messageStack()->flash(Inkscape::ERROR_MESSAGE, _("You cannot group objects from <b>different groups</b> or <b>layers</b>."));
             return;
         }
@@ -346,7 +378,7 @@ void sp_selection_group()
     // Remember the position of the topmost object.
     gint topmost = sp_repr_position((SPRepr *) g_slist_last(p)->data);
 
-    SPRepr *group = sp_repr_new("g");
+    SPRepr *group = sp_repr_new("svg:g");
 
     while (p) {
         SPRepr *spnew;
@@ -394,7 +426,7 @@ void sp_selection_ungroup()
         SPItem *group = (SPItem *) items->data;
 
         /* We do not allow ungrouping <svg> etc. (lauris) */
-        if (strcmp(sp_repr_name(SP_OBJECT_REPR(group)), "g") && strcmp(sp_repr_name(SP_OBJECT_REPR(group)), "switch")) {
+        if (strcmp(sp_repr_name(SP_OBJECT_REPR(group)), "svg:g") && strcmp(sp_repr_name(SP_OBJECT_REPR(group)), "svg:switch")) {
             // keep the non-group item in the new selection
             new_select = g_slist_prepend(new_select, group);
             continue;
@@ -693,7 +725,7 @@ void sp_copy_gradient (SPGradient *gradient)
     while (ref) { 
         // climb up the refs, copying each one in the chain
         SPRepr *grad_repr =sp_repr_duplicate (SP_OBJECT_REPR(ref));
-        defs_clipboard = g_slist_prepend(defs_clipboard, grad_repr);
+        defs_clipboard = g_slist_prepend (defs_clipboard, grad_repr);
 
         ref = ref->ref->getObject();
     }
@@ -706,7 +738,7 @@ void sp_copy_pattern (SPPattern *pattern)
     while (ref) {
         // climb up the refs, copying each one in the chain
         SPRepr *pattern_repr = sp_repr_duplicate(SP_OBJECT_REPR(ref));
-        defs_clipboard = g_slist_prepend(defs_clipboard, pattern_repr);
+        defs_clipboard = g_slist_prepend (defs_clipboard, pattern_repr);
 
         // items in the pattern may also use gradients and other patterns, so we need to recurse here as well
         for (SPObject *child = sp_object_first_child(SP_OBJECT(ref)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
@@ -722,7 +754,7 @@ void sp_copy_pattern (SPPattern *pattern)
 void sp_copy_marker (SPMarker *marker)
 {
     SPRepr *marker_repr = sp_repr_duplicate(SP_OBJECT_REPR(marker));
-    defs_clipboard = g_slist_prepend(defs_clipboard, marker_repr);
+    defs_clipboard = g_slist_prepend (defs_clipboard, marker_repr);
 }
 
 
@@ -789,7 +821,7 @@ take_style_from_item (SPItem *item)
         (SP_IS_TEXT (item) && SP_OBJECT(item)->children && SP_OBJECT(item)->children->next == NULL)) {
         // if this is a text with exactly one tspan child, merge the style of that tspan as well
         // If this is a group, merge the style of its first child
-        SPCSSAttr *temp = sp_css_attr_from_style (sp_object_last_child (item), SP_STYLE_FLAG_IFSET);
+        SPCSSAttr *temp = sp_css_attr_from_style (item->lastChild(), SP_STYLE_FLAG_IFSET);
         sp_repr_css_merge (css, temp);
         sp_repr_css_attr_unref (temp);
     }
@@ -798,7 +830,7 @@ take_style_from_item (SPItem *item)
         css = sp_css_attr_unset_text (css);
     }
 
-    // FIXME: also transform gradient/pattern fills
+    // FIXME: also transform gradient/pattern fills, by forking?
     double ex = NR::expansion(sp_item_i2doc_affine(item));
     if (ex != 1.0) {
         css = sp_css_attr_scale (css, ex);
@@ -828,7 +860,7 @@ void sp_selection_copy()
         return;
     }
 
-    const GSList *items = (GSList *) selection->itemList();
+    const GSList *items = g_slist_copy ((GSList *) selection->itemList());
 
     // 0. Copy text to system clipboard
     // FIXME: for non-texts, put serialized XML as text to the clipboard; 
@@ -860,27 +892,15 @@ void sp_selection_copy()
         sp_copy_stuff_used_by_item (SP_ITEM (i->data), items);
     }
 
-    GSList *reprs = g_slist_copy ((GSList *) selection->reprList());
-
     // 2.  Store style:
     if (style_clipboard) {
         sp_repr_css_attr_unref (style_clipboard);
     }
-    SPItem *item = SP_ITEM (items->data);
+    SPItem *item = SP_ITEM (items->data); // take from the first selected item
     style_clipboard = take_style_from_item (item);
 
     // 3.  Sort items:
-    SPRepr *parent = ((SPRepr *) reprs->data)->parent;
-    gboolean sort = TRUE;
-    for (GSList *i = reprs->next; i; i = i->next) {
-         if ((((SPRepr *) i->data)->parent) != parent) {
-             // We can copy items from different parents, but we cannot do sorting in this case
-             sort = FALSE;
-         }
-     }
-
-     if (sort)
-        reprs = g_slist_sort(reprs, (GCompareFunc) sp_repr_compare_position);
+    items = g_slist_sort((GSList *) items, (GCompareFunc) sp_object_compare_position);
 
     // 4.  Copy item reprs:
     //clear old clipboard 
@@ -889,19 +909,34 @@ void sp_selection_copy()
         clipboard = g_slist_remove(clipboard, clipboard->data);
     }
 
-    while (reprs != NULL) {
-        SPRepr *repr = (SPRepr *) reprs->data;
-        reprs = g_slist_remove (reprs, repr);
-        SPCSSAttr *css = sp_repr_css_attr_inherited(repr, "style");
+    for (GSList *i = (GSList *) items; i != NULL; i = i->next) {
+
+        SPRepr *repr = SP_OBJECT_REPR (i->data);
+
         SPRepr *copy = sp_repr_duplicate(repr);
+
+        // copy complete inherited style
+        SPCSSAttr *css = sp_repr_css_attr_inherited(repr, "style");
         sp_repr_css_set(copy, css, "style");
         sp_repr_css_attr_unref(css);
 
+        // copy complete accummulated transform
+        NR::Matrix full_t = sp_item_i2doc_affine(SP_ITEM(i->data));
+        // (we're dealing with unattached repr, so we write to its attr instead of using sp_item_set_transform)
+        gchar affinestr[80]; 
+        if (sp_svg_transform_write(affinestr, 79, full_t)) {
+            sp_repr_set_attr (copy, "transform", affinestr);
+        } else {
+            sp_repr_set_attr (copy, "transform", NULL);
+        }
+
         clipboard = g_slist_prepend(clipboard, copy);
     }
 
     clipboard = g_slist_reverse(clipboard);
     defs_clipboard = g_slist_reverse(defs_clipboard);
+
+    g_slist_free ((GSList *) items);
 }
 
 /**
@@ -913,8 +948,8 @@ paste_defs (SPDocument *doc)
     for (GSList *gl = defs_clipboard; gl != NULL; gl = gl->next) {
         SPDefs *defs= (SPDefs *) SP_DOCUMENT_DEFS(doc);
         SPRepr *repr = (SPRepr *) gl->data;
-        SPObject *exists = doc->getObjectByRepr(repr);
-        if (!exists){
+        gchar const *id = sp_repr_attr(repr, "id");
+        if (!id || !doc->getObjectById(id)) {
             SPRepr *copy = sp_repr_duplicate(repr);
             sp_repr_add_child(SP_OBJECT_REPR(defs), copy, NULL);
             sp_repr_unref(copy);
@@ -960,6 +995,24 @@ void sp_selection_paste(bool in_place)
     for (GSList *l = clipboard; l != NULL; l = l->next) {
         SPRepr *repr = (SPRepr *) l->data;
         SPRepr *copy = sp_repr_duplicate(repr);
+
+        // premultiply the item transform by the accumulated parent transform in the paste layer
+        NR::Matrix local = sp_item_i2doc_affine(SP_ITEM(desktop->currentLayer()));
+        if (!local.test_identity()) {
+            gchar const *t_str = sp_repr_attr (copy, "transform");
+            NR::Matrix item_t (NR::identity());
+            if (t_str)
+                sp_svg_transform_read(t_str, &item_t);
+            item_t *= local.inverse();
+            // (we're dealing with unattached repr, so we write to its attr instead of using sp_item_set_transform)
+            gchar affinestr[80];
+            if (sp_svg_transform_write(affinestr, 79, item_t)) {
+                sp_repr_set_attr (copy, "transform", affinestr);
+            } else {
+                sp_repr_set_attr (copy, "transform", NULL);
+            }
+        }
+
         desktop->currentLayer()->appendChildRepr(copy);
         copied = g_slist_append(copied, copy);
         sp_repr_unref(copy);
@@ -982,7 +1035,7 @@ void sp_selection_paste(bool in_place)
         desktop->namedview->grid_snapper.setDistance(NR_HUGE);
         namedview_free_snap(desktop->namedview, Snapper::SNAP_POINT, m);
         desktop->namedview->grid_snapper.setDistance(curr_gridsnap);
-        sp_selection_move_relative(selection, m[NR::X], m[NR::Y]);
+        sp_selection_move_relative(selection, m);
     }
 
     sp_document_done(SP_DT_DOCUMENT(desktop));
@@ -1020,7 +1073,7 @@ void sp_selection_apply_affine(SPSelection *selection, NR::Matrix const &affine,
     if (selection->isEmpty())
         return;
 
-    for (GSList const *l = selection->itemList(); l != NULL; l = l-> next) {
+    for (GSList const *l = selection->itemList(); l != NULL; l = l->next) {
         SPItem *item = SP_ITEM(l->data);
 
 #if 0 /* Re-enable this once persistent guides have a graphical indication.
@@ -1107,7 +1160,7 @@ void sp_selection_scale_relative(SPSelection *selection, NR::Point const &align,
     if (selection->isEmpty())
         return;
 
-    // don't try to scale above 1 Mpt, it won't display properly and will crash sooner or later anyway
+    // don't try to scale above 1 Mpx, it won't display properly and will crash sooner or later anyway
     NR::Rect const bbox(selection->bounds());
     if ( bbox.extent(NR::X) * scale[NR::X] > 1e6  ||
          bbox.extent(NR::Y) * scale[NR::Y] > 1e6 )
@@ -1143,6 +1196,11 @@ sp_selection_skew_relative(SPSelection *selection, NR::Point const &align, doubl
     sp_selection_apply_affine(selection, final);
 }
 
+void sp_selection_move_relative(SPSelection *selection, NR::Point const &move)
+{
+    sp_selection_apply_affine(selection, NR::Matrix(NR::translate(move)));
+}
+
 void sp_selection_move_relative(SPSelection *selection, double dx, double dy)
 {
     sp_selection_apply_affine(selection, NR::Matrix(NR::translate(dx, dy)));
@@ -1586,7 +1644,7 @@ sp_selection_clone()
     SPRepr *sel_repr = SP_OBJECT_REPR(selection->singleItem());
     SPRepr *parent = sp_repr_parent(sel_repr);
 
-    SPRepr *clone = sp_repr_new("use");
+    SPRepr *clone = sp_repr_new("svg:use");
     sp_repr_set_attr(clone, "x", "0");
     sp_repr_set_attr(clone, "y", "0");
     sp_repr_set_attr(clone, "xlink:href", g_strdup_printf("#%s", sp_repr_attr(sel_repr, "id")));
@@ -1721,30 +1779,22 @@ sp_selection_tile(bool apply)
     NR::Rect r = selection->bounds();
     NR::Point move_p = NR::Point(0, sp_document_height(document)) - (r.min() + NR::Point (0, r.extent(NR::Y)));
     move_p[NR::Y] = -move_p[NR::Y];
-    move_p *= 1.25;
     NR::Matrix move = NR::Matrix (NR::translate (move_p));
 
-    GSList *reprs = g_slist_copy((GSList *) selection->reprList());
+    GSList *items = g_slist_copy((GSList *) selection->itemList());
 
-    SPRepr *parent = ((SPRepr *) reprs->data)->parent;
-    gboolean sort = TRUE;
-    for (GSList *i = reprs->next; i; i = i->next) {
-        if ((((SPRepr *) i->data)->parent) != parent) {
-            // We can tile items from different parents, but we cannot do sorting in this case
-            sort = FALSE;
-        }
-    }
+    items = g_slist_sort (items, (GCompareFunc) sp_object_compare_position);
 
-    if (sort)
-        reprs = g_slist_sort(reprs, (GCompareFunc) sp_repr_compare_position);
+    // bottommost object, after sorting
+    SPObject *parent = SP_OBJECT_PARENT (items->data);
 
     // remember the position of the first item
-    gint pos = sp_repr_position ((SPRepr *) reprs->data);
+    gint pos = sp_repr_position (SP_OBJECT_REPR (items->data));
 
     // create a list of duplicates
     GSList *repr_copies = NULL;
-    for (GSList *i = reprs; i != NULL; i = i->next) {
-        SPRepr *dup = sp_repr_duplicate (((SPRepr *) i->data));
+    for (GSList *i = items; i != NULL; i = i->next) {
+        SPRepr *dup = sp_repr_duplicate ((SP_OBJECT_REPR (i->data)));
         repr_copies = g_slist_prepend (repr_copies, dup);
     }
     
@@ -1755,26 +1805,22 @@ sp_selection_tile(bool apply)
 
     if (apply) {
         // delete objects so that their clones don't get alerted; this object will be restored shortly 
-        for (GSList *i = reprs; i != NULL; i = i->next) {
-            SPObject *item = document->getObjectByRepr(((SPRepr *) i->data));
+        for (GSList *i = items; i != NULL; i = i->next) {
+            SPObject *item = SP_OBJECT (i->data);
             item->deleteObject (false);
         }
 
-        SPRepr *rect = sp_repr_new ("rect");
+        SPRepr *rect = sp_repr_new ("svg:rect");
         sp_repr_set_attr (rect, "style", g_strdup_printf("stroke:none;fill:url(#%s)", pat_id));
         sp_repr_set_double (rect, "width", bounds.extent(NR::X));
         sp_repr_set_double (rect, "height", bounds.extent(NR::Y));
         sp_repr_set_double (rect, "x", bounds.min()[NR::X]);
         sp_repr_set_double (rect, "y", bounds.min()[NR::Y]);
 
-        SPItem *rectangle = NULL;    
-        if (sort) { // restore parent and position
-            sp_repr_append_child (parent, rect);
-            sp_repr_set_position_absolute (rect, pos > 0 ? pos : 0);
-            rectangle = (SPItem *) SP_DT_DOCUMENT (desktop)->getObjectByRepr(rect);
-        } else { // just add to the current layer
-            rectangle = SP_ITEM(desktop->currentLayer()->appendChildRepr(rect));
-        } 
+        // restore parent and position
+        sp_repr_append_child (SP_OBJECT_REPR (parent), rect);
+        sp_repr_set_position_absolute (rect, pos > 0 ? pos : 0);
+        SPItem *rectangle = (SPItem *) SP_DT_DOCUMENT (desktop)->getObjectByRepr(rect);
 
         sp_repr_unref (rect);
 
@@ -1782,6 +1828,8 @@ sp_selection_tile(bool apply)
         selection->setItem (rectangle);
     }
 
+    g_slist_free (items);
+
     sp_document_done (document);
 }
 
@@ -1941,7 +1989,7 @@ sp_selection_create_bitmap_copy ()
 
 
     // Calculate the matrix that will be applied to the image so that it exactly overlaps the source objects
-    NR::Matrix eek = NR::scale(0.8, -0.8) * NR::translate(0, sp_document_height(document));
+    NR::Matrix eek = NR::scale(1, -1) * NR::translate(0, sp_document_height(document));
     NR::Matrix t = NR::scale (1/res, -1/res) * NR::translate (bbox.x0, bbox.y1) * eek.inverse(); 
 
     // Do the export
@@ -1965,7 +2013,7 @@ sp_selection_create_bitmap_copy ()
     GdkPixbuf *pb = gdk_pixbuf_new_from_file (filepath, NULL);
     if (pb) {
         // Create the repr for the image
-        SPRepr * repr = sp_repr_new ("image");
+        SPRepr * repr = sp_repr_new ("svg:image");
         sp_repr_set_attr (repr, "xlink:href", filename);
         sp_repr_set_attr (repr, "sodipodi:absref", filepath);
         sp_repr_set_double (repr, "width", gdk_pixbuf_get_width (pb));
