@@ -23,7 +23,11 @@ void sp_selection_cleanup();
 void sp_selection_delete();
 void sp_selection_duplicate();
 void sp_edit_clear_all();
+
 void sp_edit_select_all();
+void sp_edit_select_all_in_all_layers ();
+void sp_edit_invert ();
+void sp_edit_invert_in_all_layers ();
 
 void sp_selection_clone();
 void sp_selection_unlink();
@@ -53,6 +57,7 @@ void sp_selection_scale_absolute (SPSelection *selection, double x0, double x1,
 void sp_selection_scale_relative(SPSelection *selection, NR::Point const &align, NR::scale const &scale);
 void sp_selection_rotate_relative (SPSelection *selection, NR::Point const &center, gdouble angle);
 void sp_selection_skew_relative (SPSelection *selection, NR::Point const &align, double dx, double dy);
+void sp_selection_move_relative (SPSelection *selection, NR::Point const &move);
 void sp_selection_move_relative (SPSelection *selection, double dx, double dy);
 
 void sp_selection_rotate_90_cw (void);
