@@ -206,6 +206,7 @@ sp_shortcut_init ()
 
 	sp_shortcut_set (GDK_Delete, Inkscape::Verb::get(SP_VERB_EDIT_DELETE), true);
 	sp_shortcut_set (GDK_KP_Delete, Inkscape::Verb::get(SP_VERB_EDIT_DELETE), false);
+	sp_shortcut_set (GDK_BackSpace, Inkscape::Verb::get(SP_VERB_EDIT_DELETE), false);
 
 	sp_shortcut_set (SP_SHORTCUT_CONTROL_MASK | GDK_d, Inkscape::Verb::get(SP_VERB_EDIT_DUPLICATE), true);
 	sp_shortcut_set (SP_SHORTCUT_CONTROL_MASK | GDK_D, Inkscape::Verb::get(SP_VERB_EDIT_DUPLICATE), false);
@@ -270,6 +271,15 @@ sp_shortcut_init ()
 	sp_shortcut_set (SP_SHORTCUT_CONTROL_MASK | GDK_a, Inkscape::Verb::get(SP_VERB_EDIT_SELECT_ALL), true);
 	sp_shortcut_set (SP_SHORTCUT_CONTROL_MASK | GDK_A, Inkscape::Verb::get(SP_VERB_EDIT_SELECT_ALL), false);
 
+	sp_shortcut_set (SP_SHORTCUT_ALT_MASK | SP_SHORTCUT_CONTROL_MASK | GDK_a, Inkscape::Verb::get(SP_VERB_EDIT_SELECT_ALL_IN_ALL_LAYERS), true);
+	sp_shortcut_set (SP_SHORTCUT_ALT_MASK | SP_SHORTCUT_CONTROL_MASK | GDK_A, Inkscape::Verb::get(SP_VERB_EDIT_SELECT_ALL_IN_ALL_LAYERS), false);
+
+	sp_shortcut_set (GDK_exclam, Inkscape::Verb::get(SP_VERB_EDIT_INVERT), true);
+	sp_shortcut_set (SP_SHORTCUT_SHIFT_MASK | GDK_exclam, Inkscape::Verb::get(SP_VERB_EDIT_INVERT), false);
+
+	sp_shortcut_set (SP_SHORTCUT_ALT_MASK | GDK_exclam, Inkscape::Verb::get(SP_VERB_EDIT_INVERT_IN_ALL_LAYERS), true);
+	sp_shortcut_set (SP_SHORTCUT_ALT_MASK | SP_SHORTCUT_SHIFT_MASK | GDK_exclam, Inkscape::Verb::get(SP_VERB_EDIT_INVERT_IN_ALL_LAYERS), false);
+
 	sp_shortcut_set (SP_SHORTCUT_CONTROL_MASK | GDK_g, Inkscape::Verb::get(SP_VERB_SELECTION_GROUP), true);
 	sp_shortcut_set (SP_SHORTCUT_CONTROL_MASK | GDK_G, Inkscape::Verb::get(SP_VERB_SELECTION_GROUP), false);
 
