@@ -16,9 +16,9 @@
  * flips in
  */
 
-#include "xml/repr-private.h"
 #include "sp-object-repr.h"
 #include "sp-defs.h"
+#include "xml/repr.h"
 
 static void sp_defs_class_init(SPDefsClass *dc);
 static void sp_defs_init(SPDefs *defs);
@@ -133,7 +133,7 @@ static SPRepr *sp_defs_write(SPObject *object, SPRepr *repr, guint flags)
     if (flags & SP_OBJECT_WRITE_BUILD) {
         
         if (!repr) {
-            repr = sp_repr_new("defs");
+            repr = sp_repr_new("svg:defs");
         }
         
         GSList *l = NULL;
