@@ -28,7 +28,7 @@
 #include "style.h"
 #include "version.h"
 #include "display/curve.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 
 #include "sp-ellipse.h"
 
@@ -137,12 +137,14 @@ sp_genericellipse_update (SPObject *object, SPCtx *ctx, guint flags)
 {
 	if (flags & (SP_OBJECT_MODIFIED_FLAG | SP_OBJECT_STYLE_MODIFIED_FLAG | SP_OBJECT_VIEWPORT_MODIFIED_FLAG)) {
 		SPGenericEllipse *ellipse = (SPGenericEllipse *) object;
-		SPStyle *style = object->style;
-		double const d = 1.0 / NR_MATRIX_DF_EXPANSION (&((SPItemCtx *) ctx)->i2vp);
-		sp_svg_length_update (&ellipse->cx, style->font_size.computed, style->font_size.computed * 0.5, d);
-		sp_svg_length_update (&ellipse->cy, style->font_size.computed, style->font_size.computed * 0.5, d);
-		sp_svg_length_update (&ellipse->rx, style->font_size.computed, style->font_size.computed * 0.5, d);
-		sp_svg_length_update (&ellipse->ry, style->font_size.computed, style->font_size.computed * 0.5, d);
+		SPStyle const *style = object->style;
+		double const d = 1.0 / NR_MATRIX_DF_EXPANSION(&((SPItemCtx const *) ctx)->i2vp);
+		double const em = style->font_size.computed;
+		double const ex = em * 0.5; // fixme: get from pango or libnrtype
+		sp_svg_length_update(&ellipse->cx, em, ex, d);
+		sp_svg_length_update(&ellipse->cy, em, ex, d);
+		sp_svg_length_update(&ellipse->rx, em, ex, d);
+		sp_svg_length_update(&ellipse->ry, em, ex, d);
 		sp_shape_set_shape ((SPShape *) object);
 	}
 
@@ -287,7 +289,7 @@ static SPRepr *sp_genericellipse_write (SPObject *object, SPRepr *repr, guint fl
 
 	if (flags & SP_OBJECT_WRITE_EXT) {
 		if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-			repr = sp_repr_new ("path");
+			repr = sp_repr_new ("svg:path");
 		}
 
 		sp_repr_set_double (repr, "sodipodi:cx", ellipse->cx.computed);
@@ -379,7 +381,7 @@ sp_ellipse_write (SPObject *object, SPRepr *repr, guint flags)
 	ellipse = SP_GENERICELLIPSE (object);
 
 	if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-		repr = sp_repr_new ("ellipse");
+		repr = sp_repr_new ("svg:ellipse");
 	}
 
 	sp_repr_set_double (repr, "cx", ellipse->cx.computed);
@@ -530,7 +532,7 @@ sp_circle_write (SPObject *object, SPRepr *repr, guint flags)
 	ellipse = SP_GENERICELLIPSE (object);
 
 	if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-		repr = sp_repr_new ("circle");
+		repr = sp_repr_new ("svg:circle");
 	}
 
 	sp_repr_set_double (repr, "cx", ellipse->cx.computed);
@@ -732,7 +734,7 @@ sp_arc_write (SPObject *object, SPRepr *repr, guint flags)
 	SPArc *arc = SP_ARC (object);
 
 	if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-		repr = sp_repr_new ("path");
+		repr = sp_repr_new ("svg:path");
 	}
 
 	if (flags & SP_OBJECT_WRITE_EXT) {
