@@ -18,7 +18,6 @@
 #include "libnr/nr-matrix.h"
 #include "libnr/nr-point.h"
 #include "xml/repr.h"
-#include "xml/repr-private.h"
 
 #include "sp-flowdiv.h"
 #include "sp-flowregion.h"
@@ -50,6 +49,24 @@
 
 #include <pango/pango.h>
 
+// FIXME: move all these to ancestor class of both text and flowtext
+
+gint
+sp_flowtext_get_length (SPFlowtext *text)
+{
+    if ( text->f_src == NULL ) text->UpdateFlowSource();
+    one_flow_src *cur = &text->contents;
+    gint length = 0;
+    while (cur) {
+			length += cur->ucs4_en-cur->ucs4_st;
+			cur = cur->next;
+    }
+
+    return length;
+}
+
+// END of ancestor stuff
+
 static void sp_flowtext_class_init(SPFlowtextClass *klass);
 static void sp_flowtext_init(SPFlowtext *group);
 static void sp_flowtext_dispose(GObject *object);
@@ -280,7 +297,7 @@ static SPRepr *
 sp_flowtext_write(SPObject *object, SPRepr *repr, guint flags)
 {
     if ( flags & SP_OBJECT_WRITE_BUILD ) {
-        if ( repr == NULL ) repr = sp_repr_new("flowRoot");
+        if ( repr == NULL ) repr = sp_repr_new("svg:flowRoot");
         GSList *l = NULL;
         for (SPObject *child = sp_object_first_child(object) ; child != NULL ; child = SP_OBJECT_NEXT(child) ) {
             SPRepr *c_repr = NULL;
@@ -343,12 +360,10 @@ sp_flowtext_print(SPItem *item, SPPrintContext *ctx)
     if ( group->f_res ) group->f_res->Print(ctx, &pbox, &dbox, &bbox, ctm);
 }
 
-static gchar *sp_flowtext_description(SPItem * /*item*/)
-{
-    //g_return_val_if_fail(SP_IS_FLOWTEXT(item), NULL);
 
-    //return g_strdup_printf(_("Text flow"));
-    return g_strdup_printf("<b>Flowed text</b>");
+static gchar *sp_flowtext_description(SPItem *item)
+{
+    return g_strdup_printf("<b>Flowed text</b> (%d characters)", sp_flowtext_get_length (SP_FLOWTEXT (item)));
 }
 
 static NRArenaItem *
@@ -431,6 +446,7 @@ static void FlowReLink(SPObject *object, one_flow_src *&after, one_flow_src *fro
     }
 
     // special cases
+
     if ( SP_IS_FLOWDIV(object) ) {
         mine = &(SP_FLOWDIV(object)->fin);
         mine->Link(after, from);
@@ -440,6 +456,7 @@ static void FlowReLink(SPObject *object, one_flow_src *&after, one_flow_src *fro
         mine->Link(after, from);
         after = mine;
     }
+
 }
 
 void SPFlowtext::UpdateFlowSource()
@@ -449,12 +466,13 @@ void SPFlowtext::UpdateFlowSource()
 
     one_flow_src *last = NULL;
     FlowReLink(SP_OBJECT(this), last, NULL);
+  
     contents.DoPositions(false);
+  
     contents.DoFill(f_src);
-
+  
     f_src->Prepare();
-    //f_src->Affiche();
-}
+}  
 
 void SPFlowtext::UpdateFlowDest()
 {
@@ -588,8 +606,8 @@ void convert_to_text(void)
 
     selection->clear();
 
-    SPRepr *parent = SP_OBJECT_REPR(object)->parent;
-    SPRepr *repr = sp_repr_new("text");
+    SPRepr *parent = SP_OBJECT_REPR(object)->parent();
+    SPRepr *repr = sp_repr_new("svg:text");
     sp_repr_set_attr(repr, "style", sp_repr_attr(SP_OBJECT_REPR(object), "style"));
     sp_repr_append_child(parent, repr);
     // add a tspan for each chunk of the flow
@@ -599,7 +617,7 @@ void convert_to_text(void)
         if ( comp->chunks[i].rtl ) chunk_spc = -chunk_spc;
         for (int j = comp->chunks[i].s_st; j < comp->chunks[i].s_en; j++) {
             if ( comp->spans[j].l_st < comp->spans[j].l_en && comp->spans[j].c_style && comp->spans[j].c_style->with_style ) {
-                SPRepr *srepr = sp_repr_new("tspan");
+                SPRepr *srepr = sp_repr_new("svg:tspan");
                 // set the good font family (may differ if pango needed a different one)
                 gchar *nstyle = NULL;
                 text_style *curS = comp->spans[j].c_style;
@@ -609,6 +627,9 @@ void convert_to_text(void)
                 {
                     char *savFam = curSPS->text->font_family.value;
                     curS->with_style->text->font_family.value = (gchar*)curFam;
+                    /* TODO: Decide what to do wrt 0.0 vs normal.  Which should we prefer?  (Their
+                       rendering behaviour differs only when doing justification, which inkscape
+                       currently never does.) */
                     SPILength sav_spc = curSPS->text->letterspacing;
                     SPIEnum sav_anc = curSPS->text_anchor;
                     curSPS->text->letterspacing.set = 1;
@@ -651,8 +672,8 @@ void convert_to_text(void)
 
                         for (int k = comp->spans[j].l_st; k<comp->spans[j].l_en; k++) {
                             int u4_l = 0, u8_l = comp->letters[k].t_en-comp->letters[k].t_st;
-                            for (char *p = comp->chars+comp->letters[k].t_st; p && *p; p = g_utf8_next_char(p)) {
-                                int d= ((int)p)-((int)comp->chars);
+                            for (char *p = &comp->chars[comp->letters[k].t_st]; p && *p; p = g_utf8_next_char(p)) {
+                                int d= ((int)p)-((int)(&comp->chars[0]));
                                 d-=comp->letters[k].t_st;
                                 if ( d >= u8_l ) break;
                                 u4_l++;
@@ -681,8 +702,8 @@ void convert_to_text(void)
 
                         for (int k = comp->spans[j].l_st; k<comp->spans[j].l_en; k++) {
                             int u4_l = 0, u8_l = comp->letters[k].t_en-comp->letters[k].t_st;
-                            for (char *p = comp->chars+comp->letters[k].t_st; p && *p; p = g_utf8_next_char(p)) {
-                                int d = ((int)p)-((int)comp->chars);
+                            for (char *p = &comp->chars [comp->letters[k].t_st]; p && *p; p = g_utf8_next_char(p)) {
+                                int d = ((int)p)-((int)(&comp->chars[0]));
                                 d -= comp->letters[k].t_st;
                                 if ( d >= u8_l ) break;
                                 u4_l++;
@@ -706,7 +727,7 @@ void convert_to_text(void)
                 int t_en = comp->letters[comp->spans[j].l_en-1].t_en;
                 char savC = comp->chars[t_en];
                 comp->chars[t_en] = 0;
-                SPRepr *rstr = sp_xml_document_createTextNode(sp_repr_document(repr), comp->chars+t_st);
+                SPRepr *rstr = sp_repr_new_text(&comp->chars[t_st]);
                 comp->chars[t_en] = savC;
                 sp_repr_append_child(srepr, rstr);
                 sp_repr_unref(rstr);
