@@ -31,11 +31,12 @@
 #include "document.h"
 #include "dialogs/object-attributes.h"
 #include "sp-image.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include <libnr/nr-matrix-ops.h>
 #include <xml/repr.h>
 
 #include "file.h"
+#include "io/sys.h"
 #include <png.h>
 
 /*
@@ -76,10 +77,8 @@ extern "C"
 
 }
 
-namespace Inkscape
-{
-namespace IO
-{
+namespace Inkscape {
+namespace IO {
 
 class PushPull
 {
@@ -594,7 +593,7 @@ sp_image_write (SPObject *object, SPRepr *repr, guint flags)
 	image = SP_IMAGE (object);
 
 	if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-		repr = sp_repr_new ("image");
+		repr = sp_repr_new ("svg:image");
 	}
 
 	sp_repr_set_attr (repr, "xlink:href", image->href);
