@@ -13,6 +13,7 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
+#include <map>
 #include "sp-item.h"
 
 #define SP_TYPE_GROUP            (sp_group_get_type ())
@@ -21,26 +22,38 @@
 #define SP_IS_GROUP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SP_TYPE_GROUP))
 #define SP_IS_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SP_TYPE_GROUP))
 
-typedef enum _SPGroupMode {
-	SP_GROUP_MODE_GROUP,
-	SP_GROUP_MODE_LAYER
-} SPGroupMode;
+struct SPGroup : public SPItem {
+	enum LayerMode { GROUP, LAYER };
 
-struct _SPGroup {
-	SPItem item;
-	SPGroupMode mode;
+	LayerMode _layer_mode;
+	std::map<unsigned int, LayerMode> _display_modes;
+
+	LayerMode layerMode() const { return _layer_mode; }
+	void setLayerMode(LayerMode mode);
+
+	LayerMode effectiveLayerMode(unsigned int display_key) const {
+		if ( _layer_mode == LAYER ) {
+			return LAYER;
+		} else {
+			return layerDisplayMode(display_key);
+		}
+	}
+
+	LayerMode layerDisplayMode(unsigned int display_key) const;
+	void setLayerDisplayMode(unsigned int display_key, LayerMode mode);
+
+private:
+	void _updateLayerMode(unsigned int display_key=0);
 };
 
-struct _SPGroupClass {
+struct SPGroupClass {
 	SPItemClass parent_class;
 };
 
 GType sp_group_get_type (void);
 
-void sp_item_group_ungroup (SPGroup *group, GSList **children);
+void sp_item_group_ungroup (SPGroup *group, GSList **children, bool do_done = true);
 
-SPGroupMode sp_item_group_get_mode (SPGroup *group);
-void sp_item_group_set_mode (SPGroup *group, SPGroupMode mode);
 
 GSList *sp_item_group_item_list (SPGroup *group);
 SPObject *sp_item_group_get_child_by_name (SPGroup *group, SPObject *ref, const gchar *name);
