@@ -32,7 +32,7 @@
 
 #include "selection.h"
 #include "style.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "sp-root.h"
 #include "sp-anchor.h"
 #include "sp-clippath.h"
@@ -57,7 +57,6 @@
 #include "util/reverse-list.h"
 
 #include "xml/repr.h"
-#include "xml/repr-private.h"
 
 #define noSP_ITEM_DEBUG_IDLE
 
@@ -69,7 +68,6 @@ static void sp_item_release(SPObject *object);
 static void sp_item_set(SPObject *object, unsigned key, gchar const *value);
 static void sp_item_update(SPObject *object, SPCtx *ctx, guint flags);
 static SPRepr *sp_item_write(SPObject *object, SPRepr *repr, guint flags);
-static void sp_item_set_item_transform(SPItem *item, NR::Matrix const &transform);
 
 static gchar *sp_item_private_description(SPItem *item);
 static void sp_item_private_snappoints(SPItem const *item, SnapPointsIter p);
@@ -125,7 +123,6 @@ sp_item_init(SPItem *item)
     SPObject *object = SP_OBJECT(item);
 
     item->sensitive = TRUE;
-    item->printable = TRUE;
 
     item->transform = NR::identity();
 
@@ -167,6 +164,7 @@ bool SPItem::isLocked() const {
 void SPItem::setLocked(bool locked) {
     sp_repr_set_attr(SP_OBJECT_REPR(this), "sodipodi:insensitive",
                      ( locked ? "1" : NULL ));
+    updateRepr();
 }
 
 bool SPItem::isHidden() const {
@@ -175,7 +173,7 @@ bool SPItem::isHidden() const {
 
 void SPItem::setHidden(bool hide) {
     style->display.set = TRUE;
-    style->display.value = ( hide ? SP_CSS_DISPLAY_NONE : SP_CSS_DISPLAY_BLOCK );
+    style->display.value = ( hide ? SP_CSS_DISPLAY_NONE : SP_CSS_DISPLAY_INLINE );
     style->display.computed = style->display.value;
     style->display.inherit = FALSE;
     updateRepr();
@@ -212,7 +210,7 @@ SPItem::isExplicitlyHidden() const
 void
 SPItem::setExplicitlyHidden(bool const val) {
     this->style->display.set = val;
-    this->style->display.value = ( val ? SP_CSS_DISPLAY_NONE : SP_CSS_DISPLAY_BLOCK );
+    this->style->display.value = ( val ? SP_CSS_DISPLAY_NONE : SP_CSS_DISPLAY_INLINE );
     this->style->display.computed = this->style->display.value;
     this->updateRepr();
 }
@@ -384,14 +382,6 @@ sp_item_set(SPObject *object, unsigned key, gchar const *value)
                 nr_arena_item_set_sensitive(v->arenaitem, item->sensitive);
             }
             break;
-        case SP_ATTR_SODIPODI_NONPRINTABLE:
-            item->printable = !value;
-            for (SPItemView *v = item->display; v != NULL; v = v->next) {
-                if (v->flags & SP_ITEM_SHOW_PRINT) {
-                    nr_arena_item_set_visible(v->arenaitem, item->printable);
-                }
-            }
-            break;
         case SP_ATTR_STYLE:
             sp_style_read_from_object(object->style, object);
             object->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG | SP_OBJECT_STYLE_MODIFIED_FLAG);
@@ -519,7 +509,12 @@ sp_item_write(SPObject *object, SPRepr *repr, guint flags)
     }
 
     if (SP_OBJECT_PARENT(object)) {
-        gchar *s = sp_style_write_difference(SP_OBJECT_STYLE(object), SP_OBJECT_STYLE(SP_OBJECT_PARENT(object)));
+        gchar *s = NULL;
+        if (SP_IS_ITEM(SP_OBJECT_PARENT(object))) { // items have style, figure out the difference
+            s = sp_style_write_difference (SP_OBJECT_STYLE(object), SP_OBJECT_STYLE(SP_OBJECT_PARENT(object)));
+        } else { // e.g. the parent may be styleless defs
+            s = sp_style_write_string (SP_OBJECT_STYLE(object), SP_STYLE_FLAG_IFSET);
+        }
         if (s) {
             sp_repr_set_attr(repr, "style", (*s) ? s : NULL);
             g_free(s);
@@ -634,7 +629,7 @@ void sp_item_snappoints(SPItem const *item, SnapPointsIter p)
 void
 sp_item_invoke_print(SPItem *item, SPPrintContext *ctx)
 {
-    if (item->printable) {
+    if (!item->isHidden()) {
         if (((SPItemClass *) G_OBJECT_GET_CLASS(item))->print) {
             if (!item->transform.test_identity()
                 || SP_OBJECT_STYLE(item)->opacity.value != SP_SCALE24_MAX)
@@ -704,9 +699,6 @@ sp_item_invoke_show(SPItem *item, NRArena *arena, unsigned key, unsigned flags)
         nr_arena_item_set_opacity(ai, SP_SCALE24_TO_FLOAT(SP_OBJECT_STYLE(item)->opacity.value));
         nr_arena_item_set_visible(ai, !item->isHidden());
         nr_arena_item_set_sensitive(ai, item->sensitive);
-        if (flags & SP_ITEM_SHOW_PRINT) {
-            nr_arena_item_set_visible(ai, item->printable);
-        }
         if (item->clip_ref->getObject()) {
             NRArenaItem *ac;
             if (!item->display->arenaitem->key) NR_ARENA_ITEM_SET_KEY(item->display->arenaitem, sp_item_display_key_new(3));
@@ -932,8 +924,12 @@ sp_item_event(SPItem *item, SPEvent *event)
     return FALSE;
 }
 
-/** Sets item private transform (not propagated to repr). */
-static void sp_item_set_item_transform(SPItem *item, NR::Matrix const &transform)
+/**
+ * Sets item private transform (not propagated to repr), without compensating stroke widths,
+ * gradients, patterns as sp_item_write_transform does.
+ */
+void
+sp_item_set_item_transform(SPItem *item, NR::Matrix const &transform)
 {
     g_return_if_fail(item != NULL);
     g_return_if_fail(SP_IS_ITEM(item));
@@ -1074,7 +1070,7 @@ NR::Matrix sp_item_i2d_affine(SPItem const *item)
     g_assert(SP_IS_ITEM(item));
 
     NR::Matrix const ret( sp_item_i2doc_affine(item)
-                          * NR::scale(0.8, -0.8)
+                          * NR::scale(1, -1)
                           * NR::translate(0, sp_document_height(SP_OBJECT_DOCUMENT(item))) );
 #ifdef NDEBUG
     NRMatrix tst;
@@ -1091,7 +1087,7 @@ NR::Matrix sp_item_i2r_affine(SPItem const *item)
     g_assert(SP_IS_ITEM(item));
 
     NR::Matrix const ret( sp_item_i2root_affine(item)
-                          * NR::scale(0.8, -0.8)
+                          * NR::scale(1, -1)
                           * NR::translate(0, sp_document_height(SP_OBJECT_DOCUMENT(item))) );
     return ret;
 }
@@ -1105,7 +1101,7 @@ NRMatrix *sp_item_i2d_affine(SPItem const *item, NRMatrix *affine)
     sp_item_i2doc_affine(item, affine);
 
     NRMatrix doc2dt;
-    nr_matrix_set_scale(&doc2dt, 0.8, -0.8);
+    nr_matrix_set_scale(&doc2dt, 1, -1);
     doc2dt.c[5] = sp_document_height(SP_OBJECT_DOCUMENT(item));
 
     nr_matrix_multiply(affine, affine, &doc2dt);
@@ -1123,7 +1119,7 @@ void sp_item_set_i2d_affine(SPItem *item, NR::Matrix const &i2dt)
         dt2p = sp_item_i2d_affine((SPItem *) SP_OBJECT_PARENT(item)).inverse();
     } else {
         dt2p = ( NR::translate(0, -sp_document_height(SP_OBJECT_DOCUMENT(item)))
-                 * NR::scale(1.25, -1.25) );
+                 * NR::scale(1, -1) );
     }
 
     NR::Matrix const i2p( i2dt * dt2p );
