@@ -39,11 +39,9 @@
 
 #include "isnan.h" //temp fox for isnan().  include last
 
-#define PTPERMM (72.0 / 25.4)
-
-#define DEFAULTTOLERANCE 5.0
-#define DEFAULTGRIDCOLOR 0x3f3fff2f
-#define DEFAULTGRIDEMPCOLOR 0x3f3fff52
+#define DEFAULTTOLERANCE 0.4
+#define DEFAULTGRIDCOLOR 0x3f3fff25
+#define DEFAULTGRIDEMPCOLOR 0x3f3fff60
 #define DEFAULTGRIDEMPSPACING 5
 #define DEFAULTGUIDECOLOR 0x0000ff7f
 #define DEFAULTGUIDEHICOLOR 0xff00007f
@@ -142,6 +140,7 @@ sp_namedview_build (SPObject * object, SPDocument * document, SPRepr * repr)
 	if (((SPObjectClass *) (parent_class))->build)
 		(* ((SPObjectClass *) (parent_class))->build) (object, document, repr);
 
+	sp_object_read_attr (object, "inkscape:document-units");
 	sp_object_read_attr (object, "viewonly");
 	sp_object_read_attr (object, "showgrid");
 	sp_object_read_attr (object, "showguides");
@@ -222,8 +221,6 @@ sp_namedview_set (SPObject *object, unsigned int key, const gchar *value)
 	SPNamedView *nv = SP_NAMEDVIEW(object);
 
 	SPUnit const * const pt = &sp_unit_get_by_id(SP_UNIT_PT);
-	SPUnit const * const px = &sp_unit_get_by_id(SP_UNIT_PX);
-	SPUnit const * const mm = &sp_unit_get_by_id(SP_UNIT_MM);
 
 	switch (key) {
 	case SP_ATTR_VIEWONLY:
@@ -233,6 +230,13 @@ sp_namedview_set (SPObject *object, unsigned int key, const gchar *value)
 	case SP_ATTR_SHOWGRID:
 		nv->showgrid = sp_str_to_bool (value);
 		sp_namedview_setup_grid (nv);
+		if (!nv->showgrid) { // grid goes off, disable snaps even if they are turned on
+			nv->grid_snapper.setSnapTo(Snapper::BBOX_POINT, false);
+			nv->grid_snapper.setSnapTo(Snapper::SNAP_POINT, false);
+		} else { // grid goes on, enable snaps if they are turned on
+			nv->grid_snapper.setSnapTo(Snapper::BBOX_POINT, nv->snap_grid_bbox);
+			nv->grid_snapper.setSnapTo(Snapper::SNAP_POINT, nv->snap_grid_point);
+		}
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_SHOWGUIDES:
@@ -241,11 +245,18 @@ sp_namedview_set (SPObject *object, unsigned int key, const gchar *value)
 		} else {
 			nv->showguides = sp_str_to_bool (value);
 		}
+		if (!nv->showguides) { // guides go off, disable snaps even if they are turned on
+			nv->guide_snapper.setSnapTo(Snapper::BBOX_POINT, false);
+			nv->guide_snapper.setSnapTo(Snapper::SNAP_POINT, false);
+		} else { // guides go on, enable snaps if they are turned on
+			nv->guide_snapper.setSnapTo(Snapper::BBOX_POINT, nv->snap_guide_bbox);
+			nv->guide_snapper.setSnapTo(Snapper::SNAP_POINT, nv->snap_guide_point);
+		}
 		sp_namedview_setup_guides (nv);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_GRIDTOLERANCE:
-		nv->gridtoleranceunit = px;
+		nv->gridtoleranceunit = nv->doc_units;
 		nv->gridtolerance = DEFAULTTOLERANCE;
 		if (value) {
 			sp_nv_read_length (value, SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE, &nv->gridtolerance, &nv->gridtoleranceunit);
@@ -253,7 +264,7 @@ sp_namedview_set (SPObject *object, unsigned int key, const gchar *value)
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_GUIDETOLERANCE:
-		nv->guidetoleranceunit = px;
+		nv->guidetoleranceunit = nv->doc_units;
 		nv->guidetolerance = DEFAULTTOLERANCE;
 		if (value) {
 			sp_nv_read_length (value, SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE, &nv->guidetolerance, &nv->guidetoleranceunit);
@@ -264,12 +275,12 @@ sp_namedview_set (SPObject *object, unsigned int key, const gchar *value)
 	case SP_ATTR_GRIDORIGINY:
 	{
 		unsigned const d = (key == SP_ATTR_GRIDORIGINY);
-		nv->gridunit = mm;
+		nv->gridunit = nv->doc_units;
 		nv->gridorigin[d] = 0.0;
 		if (value) {
-			sp_nv_read_length (value, SP_UNIT_ABSOLUTE, &nv->gridorigin[d], &nv->gridunit);
+			sp_nv_read_length (value, SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE, &nv->gridorigin[d], &nv->gridunit);
 		}
-		sp_convert_distance (&nv->gridorigin[d], nv->gridunit, pt);
+		nv->gridorigin[d] = sp_units_get_pixels (nv->gridorigin[d], *(nv->gridunit));
 		sp_namedview_setup_grid (nv);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
@@ -278,12 +289,12 @@ sp_namedview_set (SPObject *object, unsigned int key, const gchar *value)
 	case SP_ATTR_GRIDSPACINGY:
 	{
 		unsigned const d = (key == SP_ATTR_GRIDSPACINGY);
-		nv->gridunit = mm;
-		nv->gridspacing[d] = 5.0;
+		nv->gridunit = nv->doc_units;
+		nv->gridspacing[d] = 1.0;
 		if (value) {
-			sp_nv_read_length (value, SP_UNIT_ABSOLUTE, &nv->gridspacing[d], &nv->gridunit);
+			sp_nv_read_length (value, SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE, &nv->gridspacing[d], &nv->gridunit);
 		}
-		sp_convert_distance (&nv->gridspacing[d], nv->gridunit, pt);
+		nv->gridspacing[d] = sp_units_get_pixels (nv->gridspacing[d], *(nv->gridunit));
 		sp_namedview_setup_grid (nv);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
@@ -425,25 +436,52 @@ sp_namedview_set (SPObject *object, unsigned int key, const gchar *value)
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_INKSCAPE_GRID_BBOX:
-		nv->grid_snapper.setSnapTo(Snapper::BBOX_POINT, sp_str_to_bool(value));
-		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
-		break;
-	case SP_ATTR_INKSCAPE_GUIDE_BBOX:
-		nv->guide_snapper.setSnapTo(Snapper::BBOX_POINT, sp_str_to_bool(value));
+		nv->snap_grid_bbox = (value) ? sp_str_to_bool (value) : TRUE;
+		nv->grid_snapper.setSnapTo(Snapper::BBOX_POINT, nv->showgrid && nv->snap_grid_bbox);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_INKSCAPE_GRID_POINTS:
-		nv->grid_snapper.setSnapTo(Snapper::SNAP_POINT, sp_str_to_bool(value));
+		nv->snap_grid_point = (value) ? sp_str_to_bool (value) : FALSE;
+		nv->grid_snapper.setSnapTo(Snapper::SNAP_POINT, nv->showgrid && nv->snap_grid_point);
+		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
+		break;
+	case SP_ATTR_INKSCAPE_GUIDE_BBOX:
+		nv->snap_guide_bbox = (value) ? sp_str_to_bool (value) : TRUE;
+		nv->guide_snapper.setSnapTo(Snapper::BBOX_POINT, nv->showguides && nv->snap_guide_bbox);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_INKSCAPE_GUIDE_POINTS:
-		nv->guide_snapper.setSnapTo(Snapper::SNAP_POINT, sp_str_to_bool(value));
+		nv->snap_guide_point = (value) ? sp_str_to_bool (value) : FALSE;
+		nv->guide_snapper.setSnapTo(Snapper::SNAP_POINT, nv->showguides && nv->snap_guide_point);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_INKSCAPE_CURRENT_LAYER:
 		nv->default_layer_id = value ? g_quark_from_string(value) : 0;
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
+	case SP_ATTR_INKSCAPE_DOCUMENT_UNITS: {
+		SPUnit const *new_unit = pt; // old documents were pretty much pt-based, so leave it as the default
+		if (value) {
+			SPUnit const *const req_unit = sp_unit_get_by_abbreviation(value);
+			if ( req_unit == NULL ) {
+				g_warning("Unrecognized unit `%s'", value);
+				/* fixme: Document errors should be reported in the status bar or
+				 * the like (e.g. as per
+				 * http://www.w3.org/TR/SVG11/implnote.html#ErrorProcessing); g_log
+				 * should be only for programmer errors. */
+			} else if ( req_unit->base == SP_UNIT_ABSOLUTE ||
+				    req_unit->base == SP_UNIT_DEVICE     ) {
+				new_unit = req_unit;
+			} else {
+				g_warning("Document units must be absolute like `mm', `pt' or `px', but found `%s'",
+					  value);
+				/* fixme: Don't use g_log (see above). */
+			}
+		}
+		nv->doc_units = new_unit;
+		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
+		break;
+	}
 	default:
 		if (((SPObjectClass *) (parent_class))->set)
 			((SPObjectClass *) (parent_class))->set (object, key, value);
@@ -538,17 +576,16 @@ sp_namedview_write (SPObject *object, SPRepr *repr, guint flags)
 }
 
 void
-sp_namedview_show (SPNamedView * nv, gpointer desktop)
+sp_namedview_show(SPNamedView *const nv, SPDesktop *const desktop)
 {
-	SPDesktop * dt;
 	GSList * l, *v;
 	SPCanvasItem * item;
 
-	dt = SP_DESKTOP (desktop);
-
 	for (l = nv->guides; l != NULL; l = l->next) {
-		sp_guide_show (SP_GUIDE (l->data), dt->guides, (GCallback)sp_dt_guide_event);
-		if (dt->guides_active) sp_guide_sensitize (SP_GUIDE (l->data), SP_DT_CANVAS (dt), TRUE);
+		sp_guide_show(SP_GUIDE(l->data), desktop->guides, (GCallback)sp_dt_guide_event);
+		if (desktop->guides_active) {
+			sp_guide_sensitize(SP_GUIDE(l->data), SP_DT_CANVAS(desktop), TRUE);
+		}
 		if (nv->showguides) {
 			for (v = SP_GUIDE (l->data)->views; v != NULL; v = v->next) {
 				sp_canvas_item_show (SP_CANVAS_ITEM (v->data));
@@ -562,7 +599,7 @@ sp_namedview_show (SPNamedView * nv, gpointer desktop)
 
 	nv->views = g_slist_prepend (nv->views, desktop);
 
-	item = sp_canvas_item_new (SP_DT_GRID (dt), SP_TYPE_CGRID, NULL);
+	item = sp_canvas_item_new (SP_DT_GRID(desktop), SP_TYPE_CGRID, NULL);
 	// since we're keeping a copy, we need to bump up the ref count
 	gtk_object_ref (GTK_OBJECT(item));
 	nv->gridviews = g_slist_prepend (nv->gridviews, item);
@@ -595,7 +632,9 @@ sp_namedview_window_from_document (SPDesktop *desktop)
 			&& nv->cx != HUGE_VAL && !isNaN (nv->cx) 
 			&& nv->cy != HUGE_VAL && !isNaN (nv->cy)) {
 		sp_desktop_zoom_absolute (desktop, nv->cx, nv->cy, nv->zoom);
-	} 
+	} else if (SP_DT_DOCUMENT(desktop)) { // document without saved zoom, zoom to its page
+		sp_desktop_zoom_page (desktop);
+	}
 
 	// cancel any history of zooms up to this point
 	if (desktop->zooms_past) {
@@ -661,9 +700,8 @@ sp_namedview_document_from_window (SPDesktop *desktop)
 }
 
 void
-sp_namedview_hide (SPNamedView * nv, gpointer desktop)
+sp_namedview_hide(SPNamedView *const nv, SPDesktop *const desktop)
 {
-	SPDesktop * dt;
 	GSList * l;
 
 	g_assert (nv != NULL);
@@ -672,16 +710,16 @@ sp_namedview_hide (SPNamedView * nv, gpointer desktop)
 	g_assert (SP_IS_DESKTOP (desktop));
 	g_assert (g_slist_find (nv->views, desktop));
 
-	dt = SP_DESKTOP (desktop);
-
 	for (l = nv->guides; l != NULL; l = l->next) {
-		sp_guide_hide (SP_GUIDE (l->data), SP_DT_CANVAS (dt));
+		sp_guide_hide(SP_GUIDE(l->data), SP_DT_CANVAS(desktop));
 	}
 
 	nv->views = g_slist_remove (nv->views, desktop);
 
 	for (l = nv->gridviews; l != NULL; l = l->next) {
-		if (SP_CANVAS_ITEM (l->data)->canvas == SP_DT_CANVAS (dt)) break;
+		if (SP_CANVAS_ITEM(l->data)->canvas == SP_DT_CANVAS(desktop)) {
+			break;
+		}
 	}
 
 	g_assert (l);
@@ -742,7 +780,6 @@ sp_namedview_toggle_guides (SPDocument *doc, SPRepr *repr)
 	sp_document_set_undo_sensitive(doc, FALSE);
 
 	sp_repr_set_boolean (repr, "showguides", v);
-	sp_repr_set_boolean (repr, "inkscape:guide-bbox", v);
 
 	sp_repr_set_attr (doc->rroot, "sodipodi:modified", "true");
 	sp_document_set_undo_sensitive(doc, saved);
@@ -759,7 +796,6 @@ sp_namedview_toggle_grid (SPDocument *doc, SPRepr *repr)
 	sp_document_set_undo_sensitive(doc, FALSE);
 
 	sp_repr_set_boolean (repr, "showgrid", v);
-	sp_repr_set_boolean (repr, "inkscape:grid-bbox", v);
 
 	sp_repr_set_attr (doc->rroot, "sodipodi:modified", "true");
 	sp_document_set_undo_sensitive(doc, saved);
