@@ -12,9 +12,9 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "xml/repr-private.h"
 #include "sp-object-group.h"
 #include "sp-object-repr.h"
+#include "xml/repr.h"
 
 static void sp_objectgroup_class_init (SPObjectGroupClass *klass);
 static void sp_objectgroup_init (SPObjectGroup *objectgroup);
@@ -108,7 +108,7 @@ sp_objectgroup_write (SPObject *object, SPRepr *repr, guint flags)
 
 	if (flags & SP_OBJECT_WRITE_BUILD) {
 		GSList *l;
-		if (!repr) repr = sp_repr_new ("g");
+		if (!repr) repr = sp_repr_new ("svg:g");
 		l = NULL;
 		for ( child = sp_object_first_child(object) ; child != NULL ; child = SP_OBJECT_NEXT(child) ) {
 			crepr = child->updateRepr(NULL, flags);
