@@ -45,7 +45,7 @@
 #include "sp-flowregion.h"
 #include "sp-flowtext.h"
 #include "sp-object-repr.h"
-#include "xml/repr-private.h"
+#include "xml/repr.h"
 
 enum NameType { REPR_NAME, SODIPODI_TYPE };
 static unsigned const N_NAME_TYPES = SODIPODI_TYPE + 1;
@@ -75,9 +75,9 @@ sp_object_repr_build_tree (SPDocument *document, SPRepr *repr)
 GType
 sp_repr_type_lookup (SPRepr *repr)
 {
-	if ( repr->type == SP_XML_TEXT_NODE ) {
+	if ( repr->type() == SP_XML_TEXT_NODE ) {
 		return SP_TYPE_STRING;
-	} else if ( repr->type == SP_XML_ELEMENT_NODE ) {
+	} else if ( repr->type() == SP_XML_ELEMENT_NODE ) {
 		gchar const * const type_name = sp_repr_attr(repr, "sodipodi:type");
 		return ( type_name
 			 ? name_to_gtype(SODIPODI_TYPE, type_name)
@@ -94,43 +94,43 @@ populate_dtables()
 {
 	struct NameTypeEntry { char const *const name; GType const type_id; };
 	NameTypeEntry const repr_name_entries[] = {
-		{ "a", SP_TYPE_ANCHOR },
-		{ "animate", SP_TYPE_ANIMATE },
-		{ "circle", SP_TYPE_CIRCLE },
-		{ "clipPath", SP_TYPE_CLIPPATH },
-		{ "defs", SP_TYPE_DEFS },
-		{ "ellipse", SP_TYPE_ELLIPSE },
+		{ "svg:a", SP_TYPE_ANCHOR },
+		{ "svg:animate", SP_TYPE_ANIMATE },
+		{ "svg:circle", SP_TYPE_CIRCLE },
+		{ "svg:clipPath", SP_TYPE_CLIPPATH },
+		{ "svg:defs", SP_TYPE_DEFS },
+		{ "svg:ellipse", SP_TYPE_ELLIPSE },
 		/* Note: flow* elements are proposed additions for SVG 1.2, they aren't in
 		   SVG 1.1. */
-		{ "flowDiv", SP_TYPE_FLOWDIV },
-		{ "flowLine", SP_TYPE_FLOWLINE },
-		{ "flowPara", SP_TYPE_FLOWPARA },
-		{ "flowRegion", SP_TYPE_FLOWREGION },
-		{ "flowRegionBreak", SP_TYPE_FLOWREGIONBREAK },
-		{ "flowRegionExclude", SP_TYPE_FLOWREGIONEXCLUDE },
-		{ "flowRoot", SP_TYPE_FLOWTEXT },
-		{ "flowSpan", SP_TYPE_FLOWTSPAN },
-		{ "g", SP_TYPE_GROUP },
-		{ "image", SP_TYPE_IMAGE },
-		{ "line", SP_TYPE_LINE },
-		{ "linearGradient", SP_TYPE_LINEARGRADIENT },
-		{ "marker", SP_TYPE_MARKER },
-		{ "mask", SP_TYPE_MASK },
-		{ "metadata", SP_TYPE_METADATA },
-		{ "path", SP_TYPE_PATH },
-		{ "pattern", SP_TYPE_PATTERN },
-		{ "polygon", SP_TYPE_POLYGON },
-		{ "polyline", SP_TYPE_POLYLINE },
-		{ "radialGradient", SP_TYPE_RADIALGRADIENT },
-		{ "rect", SP_TYPE_RECT },
-		{ "stop", SP_TYPE_STOP },
-		{ "svg", SP_TYPE_ROOT },
-		{ "switch", SP_TYPE_GROUP },
-		{ "symbol", SP_TYPE_SYMBOL },
-		{ "text", SP_TYPE_TEXT },
-		{ "textPath", SP_TYPE_TEXTPATH },
-		{ "tspan", SP_TYPE_TSPAN },
-		{ "use", SP_TYPE_USE }
+		{ "svg:flowDiv", SP_TYPE_FLOWDIV },
+		{ "svg:flowLine", SP_TYPE_FLOWLINE },
+		{ "svg:flowPara", SP_TYPE_FLOWPARA },
+		{ "svg:flowRegion", SP_TYPE_FLOWREGION },
+		{ "svg:flowRegionBreak", SP_TYPE_FLOWREGIONBREAK },
+		{ "svg:flowRegionExclude", SP_TYPE_FLOWREGIONEXCLUDE },
+		{ "svg:flowRoot", SP_TYPE_FLOWTEXT },
+		{ "svg:flowSpan", SP_TYPE_FLOWTSPAN },
+		{ "svg:g", SP_TYPE_GROUP },
+		{ "svg:image", SP_TYPE_IMAGE },
+		{ "svg:line", SP_TYPE_LINE },
+		{ "svg:linearGradient", SP_TYPE_LINEARGRADIENT },
+		{ "svg:marker", SP_TYPE_MARKER },
+		{ "svg:mask", SP_TYPE_MASK },
+		{ "svg:metadata", SP_TYPE_METADATA },
+		{ "svg:path", SP_TYPE_PATH },
+		{ "svg:pattern", SP_TYPE_PATTERN },
+		{ "svg:polygon", SP_TYPE_POLYGON },
+		{ "svg:polyline", SP_TYPE_POLYLINE },
+		{ "svg:radialGradient", SP_TYPE_RADIALGRADIENT },
+		{ "svg:rect", SP_TYPE_RECT },
+		{ "svg:stop", SP_TYPE_STOP },
+		{ "svg:svg", SP_TYPE_ROOT },
+		{ "svg:switch", SP_TYPE_GROUP },
+		{ "svg:symbol", SP_TYPE_SYMBOL },
+		{ "svg:text", SP_TYPE_TEXT },
+		{ "svg:textPath", SP_TYPE_TEXTPATH },
+		{ "svg:tspan", SP_TYPE_TSPAN },
+		{ "svg:use", SP_TYPE_USE }
 	};
 	NameTypeEntry const sodipodi_name_entries[] = {
 		{ "arc", SP_TYPE_ARC },
