@@ -11,21 +11,25 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <stdlib.h>
-#include <string.h>
+#include <cstring>
 #include <list>
 
 #include "helper/sp-marshal.h"
-#include "xml/repr-private.h"
 #include "xml/sp-repr-event-vector.h"
 #include "attributes.h"
 #include "document.h"
 #include "style.h"
 #include "sp-object-repr.h"
 #include "sp-root.h"
+#include "xml/repr.h"
 
 #include "sp-object.h"
 #include "algorithms/longest-common-suffix.h"
+using std::memcpy;
+using std::strchr;
+using std::strcmp;
+using std::strlen;
+using std::strstr;
 
 #define noSP_OBJECT_DEBUG_CASCADE
 
@@ -57,7 +61,6 @@ static SPRepr *sp_object_private_write (SPObject *object, SPRepr *repr, guint fl
 
 /* Real handlers of repr signals */
 
-static unsigned int sp_object_repr_change_attr (SPRepr *repr, const gchar *key, const gchar *oldval, const gchar *newval, gpointer data);
 static void sp_object_repr_attr_changed (SPRepr *repr, const gchar *key, const gchar *oldval, const gchar *newval, bool is_interactive, gpointer data);
 
 static void sp_object_repr_content_changed (SPRepr *repr, const gchar *oldcontent, const gchar *newcontent, gpointer data);
@@ -74,15 +77,10 @@ guint update_in_progress = 0; // guard against update-during-update
 enum {RELEASE, MODIFIED, LAST_SIGNAL};
 
 SPReprEventVector object_event_vector = {
-	NULL, /* Add child */
 	sp_object_repr_child_added,
-	NULL, /* Remove child */
 	sp_object_repr_child_removed,
-	sp_object_repr_change_attr,
 	sp_object_repr_attr_changed,
-	NULL, /* Change content */
 	sp_object_repr_content_changed,
-	NULL, /* change_order */
 	sp_object_repr_order_changed
 };
 
@@ -155,7 +153,7 @@ sp_object_init (SPObject * object)
 	object->hrefcount = 0;
 	object->_total_hrefcount = 0;
 	object->document = NULL;
-	object->children = NULL;
+	object->children = object->_last_child = NULL;
 	object->parent = object->next = NULL;
 	object->repr = NULL;
 	object->id = NULL;
@@ -293,6 +291,44 @@ SPObject const *SPObject::nearestCommonAncestor(SPObject const *object) const {
 	return longest_common_suffix<SPObject::ConstParentIterator>(this, object, NULL, &same_objects);
 }
 
+const SPObject *AncestorSon (SPObject const *obj, SPObject const *ancestor) {
+    if (obj == NULL || ancestor == NULL)
+        return NULL;
+    if (SP_OBJECT_PARENT (obj) == ancestor)
+        return obj;
+    return AncestorSon (SP_OBJECT_PARENT (obj), ancestor);
+}
+
+
+/** 
+ * Works for different-parent objects, so long as they have a common ancestor. Return value:
+ *    0    positions are equivalent
+ *    1    first object's position is greater than the second
+ *   -1    first object's position is less than the second
+ */
+int
+sp_object_compare_position(SPObject const *first, SPObject const *second)
+{
+	if (first == second) return 0;
+
+	SPObject const *ancestor = first->nearestCommonAncestor(second);
+	if (ancestor == NULL) return 0; // cannot compare, no common ancestor!
+
+	// we have an object and its ancestor (should not happen when sorting selection)
+	if (ancestor == first)
+		return 1;
+	if (ancestor == second)
+		return -1;
+
+	SPObject const *to_first = AncestorSon (first, ancestor);
+	SPObject const *to_second = AncestorSon (second, ancestor);
+
+	g_assert (SP_OBJECT_PARENT(to_second) == SP_OBJECT_PARENT(to_first));
+
+	return sp_repr_compare_position(SP_OBJECT_REPR(to_first), SP_OBJECT_REPR(to_second));
+}
+
+
 SPObject *SPObject::appendChildRepr(SPRepr *repr) {
 	if (!SP_OBJECT_IS_CLONED(this)) {
 		sp_repr_append_child(SP_OBJECT_REPR(this), repr);
@@ -387,65 +423,72 @@ void SPObject::deleteObject(bool propagate, bool propagate_descendants)
  */
 
 void
-sp_object_attach_reref (SPObject *parent, SPObject *object, SPObject *next)
+sp_object_attach_reref (SPObject *parent, SPObject *object, SPObject *prev)
 {
 	g_return_if_fail (parent != NULL);
 	g_return_if_fail (SP_IS_OBJECT (parent));
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (SP_IS_OBJECT (object));
-	g_return_if_fail (!next || SP_IS_OBJECT (next));
+	g_return_if_fail (!prev || SP_IS_OBJECT (prev));
+	g_return_if_fail (!prev || prev->parent == parent);
 	g_return_if_fail (!object->parent);
-	g_return_if_fail (!object->next);
-
-	SPObject **ref;
-	for ( ref = &parent->children ; *ref ; ref = &(*ref)->next ) {
-		if ( *ref == next ) {
-			break;
-		}
-	}
-	if ( *ref != next ) {
-		g_critical("sp_object_attach_reref: next is not a child of parent");
-	}
 
 	sp_object_ref (object, parent);
 	g_object_unref (G_OBJECT (object));
 	object->parent = parent;
 	parent->_updateTotalHRefCount(object->_total_hrefcount);
 
+	SPObject *next;
+	if (prev) {
+		next = prev->next;
+		prev->next = object;
+	} else {
+		next = parent->children;
+		parent->children = object;
+	}
 	object->next = next;
-	*ref = object;
+	if (!next) {
+		parent->_last_child = object;
+	}
 }
 
-void sp_object_reorder(SPObject *object, SPObject *next)
-{
+void sp_object_reorder(SPObject *object, SPObject *prev) {
 	g_return_if_fail(object != NULL);
 	g_return_if_fail(SP_IS_OBJECT(object));
 	g_return_if_fail(object->parent != NULL);
-	g_return_if_fail(object != next);
-	g_return_if_fail(!next || SP_IS_OBJECT(next));
-	g_return_if_fail(!next || next->parent == object->parent);
+	g_return_if_fail(object != prev);
+	g_return_if_fail(!prev || SP_IS_OBJECT(prev));
+	g_return_if_fail(!prev || prev->parent == object->parent);
 
-	SPObject *parent = object->parent;
-	SPObject **ref;
-	SPObject **old_ref = NULL;
-	SPObject **new_ref = NULL;
-	for ( ref = &parent->children ; *ref ; ref = &(*ref)->next ) {
-		if ( *ref == object ) {
-			old_ref = ref;
-		}
-		if ( *ref == next ) {
-			new_ref = ref;
-		}
-	}
-	if ( !new_ref && !next ) {
-		new_ref = ref;
-	}
-	g_assert(old_ref != NULL);
-	g_assert(new_ref != NULL);
+	SPObject * const parent=object->parent;
 
-	*old_ref = object->next;
-	object->next = *new_ref;
-	*new_ref = object;
+	SPObject *old_prev=NULL;
+	for ( SPObject *child = parent->children ; child && child != object ;
+	      child = child->next )
+	{
+		old_prev = child;
+	}
+
+	SPObject *next=object->next;
+	if (old_prev) {
+		old_prev->next = next;
+	} else {
+		parent->children = next;
+	}
+	if (!next) {
+		parent->_last_child = old_prev;
+	}
+	if (prev) {
+		next = prev->next;
+		prev->next = object;
+	} else {
+		next = parent->children;
+		parent->children = object;
+	}
+	object->next = next;
+	if (!next) {
+		parent->_last_child = object;
+	}
 }
 
 void sp_object_detach (SPObject *parent, SPObject *object) {
@@ -455,15 +498,23 @@ void sp_object_detach (SPObject *parent, SPObject *object) {
 	g_return_if_fail (SP_IS_OBJECT (object));
 	g_return_if_fail (object->parent == parent);
 
-	SPObject **ref;
-	for ( ref = &parent->children ; *ref ; ref = &(*ref)->next ) {
-		if ( *ref == object ) {
-			break;
-		}
+	SPObject *prev=NULL;
+	for ( SPObject *child = parent->children ; child && child != object ;
+	      child = child->next )
+	{
+		prev = child;
+	}
+
+	SPObject *next=object->next;
+	if (prev) {
+		prev->next = next;
+	} else {
+		parent->children = next;
+	}
+	if (!next) {
+		parent->_last_child = prev;
 	}
-	g_assert(*ref == object);
 
-	*ref = object->next;
 	object->next = NULL;
 	object->parent = NULL;
 
@@ -483,21 +534,6 @@ void sp_object_detach_unref (SPObject *parent, SPObject *object)
 	sp_object_unref(object, parent);
 }
 
-SPObject *sp_object_first_child(SPObject *parent)
-{
-	return parent->children;
-}
-
-SPObject *sp_object_last_child(SPObject *parent)
-{
-	if (!sp_object_first_child(parent))
-		return NULL;
-	SPObject *child;
-	for (child = sp_object_first_child(parent); SP_OBJECT_NEXT (child); child = SP_OBJECT_NEXT (child)) 
-		;
-	return child;
-}
-
 SPObject *sp_object_get_child_by_repr(SPObject *object, SPRepr *repr)
 {
 	g_return_val_if_fail(object != NULL, NULL);
@@ -521,14 +557,7 @@ static void sp_object_child_added (SPObject * object, SPRepr * child, SPRepr * r
 	}
 	SPObject *ochild = SP_OBJECT(g_object_new(type, 0));
 	SPObject *prev = ref ? sp_object_get_child_by_repr(object, ref) : NULL;
-	if (prev) {
-		sp_object_attach_reref(object, ochild, SP_OBJECT_NEXT(prev));
-	} else {
-		if (ref) {
-			g_critical("Unable to find previous child; adding new child out of order");
-		}
-		sp_object_attach_reref(object, ochild, sp_object_first_child(object));
-	}
+	sp_object_attach_reref(object, ochild, prev);
 
 	sp_object_invoke_build(ochild, object->document, child, SP_OBJECT_IS_CLONED(object));
 }
@@ -547,14 +576,7 @@ static void sp_object_order_changed (SPObject * object, SPRepr * child, SPRepr *
 	SPObject *ochild = sp_object_get_child_by_repr(object, child);
 	g_return_if_fail(ochild != NULL);
 	SPObject *prev = new_ref ? sp_object_get_child_by_repr(object, new_ref) : NULL;
-	if (prev) {
-		sp_object_reorder(ochild, SP_OBJECT_NEXT(prev));
-	} else {
-		if (new_ref) {
-			g_critical("Unable to find new previous child; reordering child to start of list");
-		}
-		sp_object_reorder(ochild, sp_object_first_child(object));
-	}
+	sp_object_reorder(ochild, prev);
 }
 
 static void sp_object_release(SPObject *object)
@@ -579,13 +601,13 @@ sp_object_build (SPObject * object, SPDocument * document, SPRepr * repr)
 	sp_object_read_attr (object, "inkscape:label");
 	sp_object_read_attr (object, "inkscape:collect");
 
-        for (SPRepr *rchild = repr->children; rchild != NULL; rchild = rchild->next) {
+        for (SPRepr *rchild = repr->firstChild() ; rchild != NULL; rchild = rchild->next()) {
 		GType type = sp_repr_type_lookup (rchild);
 		if (!type) {
 			continue;
 		}
 		SPObject *child = SP_OBJECT(g_object_new (type, 0));
-		sp_object_attach_reref (object, child, NULL);
+		sp_object_attach_reref (object, child, object->lastChild());
 		sp_object_invoke_build (child, document, rchild, SP_OBJECT_IS_CLONED (object));
 	}
 }
@@ -612,24 +634,24 @@ sp_object_invoke_build (SPObject * object, SPDocument * document, SPRepr * repr,
 	sp_repr_ref (repr);
 	object->cloned = cloned;
 
-	/* If we are not cloned, force unique id */
 	if (!SP_OBJECT_IS_CLONED (object)) {
-		const gchar *id = sp_repr_attr (object->repr, "id");
-		gchar *realid = sp_object_get_unique_id (object, id);
-		g_assert (realid != NULL);
+		object->document->bindObjectToRepr(object->repr, object);
 
-		sp_document_def_id (object->document, realid, object);
-		object->id = realid;
+		if ( object->repr->type() == SP_XML_ELEMENT_NODE ) {
+			/* If we are not cloned, force unique id */
+			const gchar *id = sp_repr_attr (object->repr, "id");
+			gchar *realid = sp_object_get_unique_id (object, id);
+			g_assert (realid != NULL);
 
-		/* Redefine ID, if required */
-		if ((id == NULL) || (strcmp (id, realid) != 0)) {
-			gboolean undo_sensitive=sp_document_get_undo_sensitive(document);
-			sp_document_set_undo_sensitive(document, FALSE);
-			int ret = sp_repr_set_attr (object->repr, "id", realid);
-			sp_document_set_undo_sensitive(document, undo_sensitive);
+			object->document->bindObjectToId(realid, object);
+			object->id = realid;
 
-			if (!ret) {
-				g_error ("Update id %s to unique id %s has been vetoed; cannot maintain SPObject <-> SPRepr binding", id, realid);
+			/* Redefine ID, if required */
+			if ((id == NULL) || (strcmp (id, realid) != 0)) {
+				gboolean undo_sensitive=sp_document_get_undo_sensitive(document);
+				sp_document_set_undo_sensitive(document, FALSE);
+				sp_repr_set_attr(object->repr, "id", realid);
+				sp_document_set_undo_sensitive(document, undo_sensitive);
 			}
 		}
 	} else {
@@ -666,12 +688,16 @@ sp_object_invoke_release (SPObject *object)
 	g_assert (object->hrefcount == 0);
 
 	if (!SP_OBJECT_IS_CLONED (object)) {
-		g_assert (object->id);
-		sp_document_def_id (object->document, object->id, NULL);
+		if (object->id) {
+			object->document->bindObjectToId(object->id, NULL);
+		}
 		g_free (object->id);
-		g_free (object->_default_label);
 		object->id = NULL;
+
+		g_free (object->_default_label);
 		object->_default_label = NULL;
+
+		object->document->bindObjectToRepr(object->repr, NULL);
 	} else {
 		g_assert (!object->id);
 	}
@@ -721,27 +747,41 @@ static void
 sp_object_private_set (SPObject *object, unsigned int key, const gchar *value)
 {
 	g_assert (SP_IS_DOCUMENT (object->document));
-	/* fixme: rething that cloning issue */
-	g_assert (SP_OBJECT_IS_CLONED (object) || object->id != NULL);
 	g_assert (key != SP_ATTR_INVALID);
 
 	switch (key) {
 	case SP_ATTR_ID:
-		if (!SP_OBJECT_IS_CLONED (object)) {
-			g_assert (value != NULL);
-			g_assert (strcmp ((const char*)value, object->id));
-			g_assert (!object->document->getObjectById((const char*)value));
-			sp_document_def_id (object->document, object->id, NULL);
-			g_free (object->id);
-			object->id = g_strdup ((const char*)value);
-			sp_document_def_id (object->document, object->id, object);
+		if ( !SP_OBJECT_IS_CLONED (object) && object->repr->type() == SP_XML_ELEMENT_NODE ) {
+			SPObject *conflict=NULL;
+			if (value) {
+				conflict = object->document->getObjectById((const char *)value);
+			}
+			if ( conflict && conflict != object ) {
+				sp_object_ref(conflict, NULL);
+				// give the conflicting object a new ID
+				gchar *new_conflict_id = sp_object_get_unique_id(conflict, NULL);
+				sp_repr_set_attr(SP_OBJECT_REPR(conflict), "id", new_conflict_id);
+				g_free(new_conflict_id);
+				sp_object_unref(conflict, NULL);
+			}
+
+			if (object->id) {
+				object->document->bindObjectToId(object->id, NULL);
+				g_free (object->id);
+			} else {
+				g_message("id binding restored on bound object %s", value);
+			}
+
+			if (value) {
+				object->id = g_strdup ((const char*)value);
+				object->document->bindObjectToId(object->id, object);
+			} else {
+				g_warning("id binding cleared on bound object %s", object->id);
+				object->id = NULL;
+			}
+
 			g_free(object->_default_label);
 			object->_default_label = NULL;
-		} else {
-			// This warning fires when the id is changed on the original of an SPUse, because the SPUse is updated from the same repr.
-			// The child of an SPUse has a cloned flag set - I have little idea of what it is used for.
-			// Anyway, the warning is useless, because the child has no repr of its own, and therefore no id conflict may ensue in XML.
-			//g_warning ("ID of cloned object changed, so document is out of sync");
 		}
 		break;
 	case SP_ATTR_INKSCAPE_LABEL:
@@ -800,8 +840,6 @@ sp_object_read_attr (SPObject *object, const gchar *key)
 
 	g_assert (SP_IS_DOCUMENT (object->document));
 	g_assert (object->repr != NULL);
-	/* fixme: rething that cloning issue */
-	g_assert (SP_OBJECT_IS_CLONED (object) || object->id != NULL);
 
 	unsigned int keyid = sp_attribute_lookup (key);
 	if (keyid != SP_ATTR_INVALID) {
@@ -812,40 +850,6 @@ sp_object_read_attr (SPObject *object, const gchar *key)
 	}
 }
 
-static unsigned int
-sp_object_repr_change_attr (SPRepr *repr, const gchar *key, const gchar *oldval, const gchar *newval, gpointer data)
-{
-	SPObject *object = SP_OBJECT (data);
-	g_assert(SP_OBJECT_REPR(object) == repr);
-
-	if (SP_OBJECT_IS_CLONED(object)) {
-		// in general clones should not concern themselves with
-		// validating repr changes; that should be left to the
-		// "original" SPObject
-		return TRUE;
-	}
-
-	if (strcmp ((const char*)key, "id") == 0) {
-		if (!newval) {
-			// this will get cleared up when we no longer force
-			// ids on reprs (and institute direct mapping between
-			// SPObjects and SPReprs)
-			// g_warning("Attempt to clear id of bound SPRepr (%p)", repr);
-			return FALSE;
-		}
-		SPObject *defid = object->document->getObjectById(newval);
-		// it's nominally ok if we don't collide with anyone
-		if ( defid && defid != object ) {
-			g_critical("The id '%s' is already claimed by SPObject %p", newval, defid);
-			return FALSE;
-		} else {
-			return TRUE;
-		}
-	} else {
-		return TRUE;
-	}
-}
-
 static void
 sp_object_repr_attr_changed (SPRepr *repr, const gchar *key, const gchar *oldval, const gchar *newval, bool is_interactive, gpointer data)
 {
@@ -1020,6 +1024,8 @@ SPObject::updateDisplay(SPCtx *ctx, unsigned int flags)
 void
 SPObject::requestModified(unsigned int flags)
 {
+	g_return_if_fail( this->document != NULL );
+
 	/* PARENT_MODIFIED is computed later on and is not intended to be
 	 * "manually" queued */
 	g_return_if_fail (!(flags & SP_OBJECT_PARENT_MODIFIED_FLAG));
@@ -1151,12 +1157,12 @@ sp_object_removeAttribute (SPObject *object, const gchar *key, SPException *ex)
 static gchar *
 sp_object_get_unique_id (SPObject * object, const gchar * id)
 {
-	static gint count = 0;
+	static unsigned long count = 0;
 
 	g_assert (SP_IS_OBJECT (object));
 	g_assert (SP_IS_DOCUMENT (object->document));
 
-	count++;
+	count ++;
 
 	const gchar *name = sp_repr_name (object->repr);
 	g_assert (name != NULL);
@@ -1166,29 +1172,23 @@ sp_object_get_unique_id (SPObject * object, const gchar * id)
 		name = local + 1;
 	}
 
-	gint len = strlen (name) + 17;
-	gchar *b = (gchar*) alloca (len);
-	g_assert (b != NULL);
-	gchar *realid = NULL;
-
 	if (id != NULL) {
 		if (object->document->getObjectById(id) == NULL) {
-			realid = g_strdup (id);
-			g_assert (realid != NULL);
+			return g_strdup(id);
 		}
 	}
 
-	while (realid == NULL) {
-		g_snprintf (b, len, "%s%d", name, count);
-		if (object->document->getObjectById(b) == NULL) {
-			realid = g_strdup (b);
-			g_assert (realid != NULL);
-		} else {
-			count++;
-		}
-	}
-
-	return realid;
+	size_t const name_len = strlen(name);
+	size_t const buflen = name_len + (sizeof(count) * 10 / 4) + 1;
+	gchar *const buf = (gchar *) g_malloc(buflen);
+	memcpy(buf, name, name_len);
+	gchar *const count_buf = buf + name_len;
+	size_t const count_buflen = buflen - name_len;
+	do {
+		++count;
+		g_snprintf(count_buf, count_buflen, "%lu", count);
+	} while ( object->document->getObjectById(buf) != NULL );
+	return buf;
 }
 
 /* Style */
@@ -1196,14 +1196,22 @@ sp_object_get_unique_id (SPObject * object, const gchar * id)
 const gchar *
 sp_object_get_style_property (SPObject *object, const gchar *key, const gchar *def)
 {
+	/* fixme: Use proper CSS parsing.  The current version is buggy in a number of
+	   situations where key is a substring of the style string other than as a property
+	   name (including where key is a substring of a property name), and is
+	   also buggy in its handling of inheritance for properties that aren't inherited
+	   by default. */
 	g_return_val_if_fail (object != NULL, NULL);
 	g_return_val_if_fail (SP_IS_OBJECT (object), NULL);
 	g_return_val_if_fail (key != NULL, NULL);
 
 	const gchar *style = sp_repr_attr (object->repr, "style");
 	if (style) {
-		gint len = strlen (key);
-		for (gchar *p = strstr (style, key); p; p = strstr (style, key)) {
+		size_t const len = strlen(key);
+		char const *p;
+		while ( (p = strstr(style, key))
+		        != NULL )
+		{
 			p += len;
 			while ((*p <= ' ') && *p) p++;
 			if (*p++ != ':') break;
