@@ -16,7 +16,7 @@
 
 #include "sp-shape.h"
 
-
+#include <sigc++/sigc++.h>
 
 #define SP_TYPE_OFFSET            (sp_offset_get_type ())
 #define SP_OFFSET(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), SP_TYPE_OFFSET, SPOffset))
@@ -24,13 +24,11 @@
 #define SP_IS_OFFSET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SP_TYPE_OFFSET))
 #define SP_IS_OFFSET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SP_TYPE_OFFSET))
 
-typedef struct _SPOffset SPOffset;
-typedef struct _SPOffsetClass SPOffsetClass;
-
-struct _SPOffset
-{
-  SPShape shape;
+class SPOffset;
+class SPOffsetClass;
+class SPUseReference;
 
+struct SPOffset : public SPShape {
   /*
    * offset is defined by curve and radius
    * the original curve is kept as a path in a sodipodi:original attribute
@@ -39,15 +37,26 @@ struct _SPOffset
   void *originalPath; // will be a livarot Path, just don't declare it here to please the gcc linker
   char *original;     // SVG description of the source path
   float rad;			/* offset radius */
-  char *sourceObject; // id of the source object for linked offsets
-  SPRepr *sourceRepr; // the repr associated with that id
-  bool   sourceDirty;
 
+	// for interactive setting of the radius
   bool knotSet;
   NR::Point knot;
+	
+	bool           sourceDirty;
+	bool           isUpdating;
+
+	gchar					 *sourceHref;
+	SPUseReference *sourceRef;
+  SPRepr         *sourceRepr; // the repr associated with that id
+	SPObject			 *sourceObject;
+	
+	gulong           _modified_connection;
+	sigc::connection _delete_connection;
+	sigc::connection _changed_connection;
+	sigc::connection _transformed_connection;
 };
 
-struct _SPOffsetClass
+struct SPOffsetClass
 {
   SPShapeClass parent_class;
 };
@@ -59,5 +68,6 @@ GType sp_offset_get_type (void);
 double sp_offset_distance_to_original (SPOffset * offset, NR::Point px);
 void sp_offset_top_point (SPOffset * offset, NR::Point *px);
 
+SPItem *sp_offset_get_source (SPOffset *offset);
 
 #endif
