@@ -28,7 +28,7 @@
 #include <libnr/nr-matrix-fns.h>
 #include <libnr/nr-matrix-ops.h>
 
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "svg/svg.h"
 #include "xml/repr.h"
 #include "attributes.h"
@@ -122,7 +122,9 @@ sp_nodes_in_path(SPPath *path)
 static gchar *
 sp_path_description(SPItem * item)
 {
-    return g_strdup_printf(_("<b>Path</b> (%i nodes)"), sp_nodes_in_path(SP_PATH(item)));
+    int count = sp_nodes_in_path(SP_PATH(item));
+    return g_strdup_printf(ngettext("<b>Path</b> (%i node)",
+                                    "<b>Path</b> (%i nodes)",count), count);
 }
 
 /**
@@ -165,7 +167,7 @@ sp_path_build(SPObject *object, SPDocument *document, SPRepr *repr)
     /* d is a required attribute */
     gchar const *d = sp_object_getAttribute(object, "d", NULL);
     if (d == NULL) {
-        sp_object_set(object, sp_attribute_lookup("d"), strdup(""));
+        sp_object_set(object, sp_attribute_lookup("d"), "");
     }
 
     /* Are these calls actually necessary? */
@@ -280,7 +282,7 @@ sp_path_write(SPObject *object, SPRepr *repr, guint flags)
     SPShape *shape = (SPShape *) object;
 
     if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-        repr = sp_repr_new("path");
+        repr = sp_repr_new("svg:path");
     }
 
     if ( shape->curve != NULL ) {
