@@ -23,7 +23,6 @@
 #include <libnr/nr-translate-matrix-ops.h>
 #include <gtk/gtksignal.h>
 #include "macros.h"
-#include "xml/repr-private.h"
 #include "svg/svg.h"
 #include "display/nr-arena.h"
 #include "display/nr-arena-group.h"
@@ -35,6 +34,7 @@
 #include "document-private.h"
 #include "uri.h"
 #include "sp-pattern.h"
+#include "xml/repr.h"
 
 /*
  * Pattern
@@ -451,7 +451,7 @@ pattern_chain (SPPattern *pattern)
 	SPDocument *document = SP_OBJECT_DOCUMENT (pattern);
 	SPRepr *defsrepr = SP_OBJECT_REPR (SP_DOCUMENT_DEFS (document));
 
-	SPRepr *repr = sp_repr_new ("pattern");
+	SPRepr *repr = sp_repr_new ("svg:pattern");
 	sp_repr_set_attr(repr, "inkscape:collect", "always");
 	gchar *parent_ref = g_strconcat ("#", sp_repr_attr(SP_OBJECT_REPR(pattern), "id"), NULL);
 	sp_repr_set_attr (repr, "xlink:href",  parent_ref);
@@ -507,7 +507,7 @@ pattern_tile (GSList *reprs, NR::Rect bounds, SPDocument *document, NR::Matrix t
 {
 	SPRepr *defsrepr = SP_OBJECT_REPR (SP_DOCUMENT_DEFS (document));
 
-	SPRepr *repr = sp_repr_new ("pattern");
+	SPRepr *repr = sp_repr_new ("svg:pattern");
 	sp_repr_set_attr (repr, "patternUnits", "userSpaceOnUse");
 	sp_repr_set_double (repr, "width", bounds.extent(NR::X));
 	sp_repr_set_double (repr, "height", bounds.extent(NR::Y));
@@ -772,7 +772,11 @@ sp_pattern_painter_new (SPPaintServer *ps, NR::Matrix const &full_transform, NR:
 			pp->cached_bbox.y0=0;
 			pp->cached_bbox.x1=tr_width;
 			pp->cached_bbox.y1=tr_height;
-			nr_pixblock_setup (&pp->cached_tile,NR_PIXBLOCK_MODE_R8G8B8A8N, pp->cached_bbox.x0, pp->cached_bbox.y0, pp->cached_bbox.x1, pp->cached_bbox.y1,TRUE);		
+
+			if (pp->use_cached_tile) {
+				nr_pixblock_setup (&pp->cached_tile,NR_PIXBLOCK_MODE_R8G8B8A8N, pp->cached_bbox.x0, pp->cached_bbox.y0, pp->cached_bbox.x1, pp->cached_bbox.y1,TRUE);
+			}
+
 			pp->pa2ca.c[0]=((double)tr_width)/(one_tile.x1-one_tile.x0);
 			pp->pa2ca.c[1]=0;
 			pp->pa2ca.c[2]=0;
