@@ -12,14 +12,13 @@
 #define SP_IS_POLYLINE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SP_TYPE_POLYLINE))
 #define SP_IS_POLYLINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SP_TYPE_POLYLINE))
 
-typedef struct _SPPolyLine SPPolyLine;
-typedef struct _SPPolyLineClass SPPolyLineClass;
+class SPPolyLine;
+class SPPolyLineClass;
 
-struct _SPPolyLine {
-	SPShape shape;
+struct SPPolyLine : public SPShape {
 };
 
-struct _SPPolyLineClass {
+struct SPPolyLineClass {
 	SPShapeClass parent_class;
 };
 
