@@ -25,12 +25,10 @@
 #define SP_IS_RECT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SP_TYPE_RECT))
 #define SP_IS_RECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SP_TYPE_RECT))
 
-typedef struct _SPRect SPRect;
-typedef struct _SPRectClass SPRectClass;
-
-struct _SPRect {
-	SPShape shape;
+class SPRect;
+class SPRectClass;
 
+struct SPRect : public SPShape {
 	SPSVGLength x;
 	SPSVGLength y;
 	SPSVGLength width;
@@ -39,7 +37,7 @@ struct _SPRect {
 	SPSVGLength ry;
 };
 
-struct _SPRectClass {
+struct SPRectClass {
 	SPShapeClass parent_class;
 };
 
@@ -53,6 +51,11 @@ void sp_rect_position_set (SPRect * rect, gdouble x, gdouble y, gdouble width, g
 void sp_rect_set_rx(SPRect * rect, gboolean set, gdouble value);
 void sp_rect_set_ry(SPRect * rect, gboolean set, gdouble value);
 
+void sp_rect_set_visible_rx (SPRect *rect, gdouble rx);
+void sp_rect_set_visible_ry (SPRect *rect, gdouble ry);
+gdouble sp_rect_get_visible_rx (SPRect *rect);
+gdouble sp_rect_get_visible_ry (SPRect *rect);
 
+void sp_rect_compensate_rxry (SPRect *rect, NR::Matrix xform);
 
 #endif
