@@ -123,7 +123,7 @@ sp_root_init (SPRoot *root)
 	  root->version.sodipodi = root->original.sodipodi = zero_version;
 
 	sp_svg_length_unset (&root->x, SP_SVG_UNIT_NONE, 0.0, 0.0);
-	sp_svg_length_unset (&root->height, SP_SVG_UNIT_NONE, 0.0, 0.0);
+	sp_svg_length_unset (&root->y, SP_SVG_UNIT_NONE, 0.0, 0.0);
 	sp_svg_length_unset (&root->width, SP_SVG_UNIT_PERCENT, 1.0, 1.0);
 	sp_svg_length_unset (&root->height, SP_SVG_UNIT_PERCENT, 1.0, 1.0);
 
@@ -594,18 +594,12 @@ sp_root_write (SPObject *object, SPRepr *repr, guint flags)
 	SPRoot *root = SP_ROOT (object);
 
 	if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-		repr = sp_repr_new ("svg");
+		repr = sp_repr_new ("svg:svg");
 	}
 
-	sp_repr_set_attr (repr, "xmlns", "http://www.w3.org/2000/svg");
-	sp_repr_set_attr (repr, "xmlns:xlink", "http://www.w3.org/1999/xlink");
-
 	if (flags & SP_OBJECT_WRITE_EXT) {
 		gchar *version;
 
-		sp_repr_set_attr (repr, "xmlns:sodipodi", SP_SODIPODI_NS_URI);
-		sp_repr_set_attr (repr, "xmlns:inkscape", SP_INKSCAPE_NS_URI);
-
 		sp_repr_set_attr (repr, "sodipodi:version", SODIPODI_VERSION);
 
 		version = sp_version_to_string (root->version.inkscape);
