@@ -25,9 +25,7 @@
 #include "sp-item-group.h"
 #include "version.h"
 
-struct _SPRoot {
-	SPGroup group;
-
+struct SPRoot : public SPGroup {
 	struct {
 		SPVersion svg, sodipodi, inkscape;
 	} version, original;
@@ -53,7 +51,7 @@ struct _SPRoot {
 	SPDefs *defs;
 };
 
-struct _SPRootClass {
+struct SPRootClass {
 	SPGroupClass parent_class;
 };
 
