@@ -25,7 +25,7 @@
 #include "display/bezier-utils.h"
 #include "display/curve.h"
 #include "dialogs/object-attributes.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "xml/repr.h"
 
 #include "sp-spiral.h"
@@ -66,7 +66,7 @@ sp_spiral_get_type (void)
 			(GInstanceInitFunc) sp_spiral_init,
 			NULL,	/* value_table */
 		};
-		spiral_type = g_type_register_static (SP_TYPE_SHAPE, "SPSPiral", &spiral_info, (GTypeFlags)0);
+		spiral_type = g_type_register_static (SP_TYPE_SHAPE, "SPSpiral", &spiral_info, (GTypeFlags)0);
 	}
 	return spiral_type;
 }
@@ -130,7 +130,7 @@ sp_spiral_write (SPObject *object, SPRepr *repr, guint flags)
 	SPSpiral *spiral = SP_SPIRAL (object);
 
 	if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-		repr = sp_repr_new ("path");
+		repr = sp_repr_new ("svg:path");
 	}
 
 	if (flags & SP_OBJECT_WRITE_EXT) {
@@ -267,6 +267,8 @@ sp_spiral_update (SPObject *object, SPCtx *ctx, guint flags)
 static gchar *
 sp_spiral_description (SPItem * item)
 {
+	// TRANSLATORS: since turn count isn't an integer, please adjust the
+	// string as needed to deal with an localized plural forms.
 	return g_strdup_printf (_("<b>Spiral</b> with %3f turns"), SP_SPIRAL(item)->revo);
 }
 
@@ -366,7 +368,7 @@ sp_spiral_set_shape (SPShape *shape)
 	SPCurve *c = sp_curve_new ();
 	
 #ifdef SPIRAL_VERBOSE
-	g_print ("ex=%g, revo=%g, rad=%g, arg=%g, t0=%g\n",
+	g_print ("cx=%g, cy=%g, exp=%g, revo=%g, rad=%g, arg=%g, t0=%g\n",
 		 spiral->cx,
 		 spiral->cy,
 		 spiral->exp,
@@ -418,7 +420,7 @@ sp_spiral_position_set       (SPSpiral          *spiral,
 	spiral->revo       = revo;
 	spiral->rad        = MAX (rad, 0.001);
 	spiral->arg        = arg;
-	spiral->t0         = t0;
+	spiral->t0         = CLAMP(t0, 0.0, 0.999);
 	
 	((SPObject *)spiral)->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
 }
@@ -446,7 +448,7 @@ NR::Point sp_spiral_get_xy (SPSpiral const *spiral, gdouble t)
 	g_assert (t >= 0.0);
 	/* Any callers passing -ve t will have a bug for non-integral values of exp. */
 
-	double const rad = spiral->rad * pow(t, spiral->exp);
+	double const rad = spiral->rad * pow(t, (double) spiral->exp);
 	double const arg = 2.0 * M_PI * spiral->revo * t + spiral->arg;
 
 	return NR::Point(rad * cos (arg) + spiral->cx,
@@ -524,7 +526,7 @@ sp_spiral_get_polar (SPSpiral const *spiral, gdouble t, gdouble *rad, gdouble *a
 	g_return_if_fail (SP_IS_SPIRAL(spiral));
 
 	if (rad)
-		*rad = spiral->rad * pow(t, spiral->exp);
+		*rad = spiral->rad * pow(t, (double) spiral->exp);
 	if (arg)
 		*arg = 2.0 * M_PI * spiral->revo * t + spiral->arg;
 }
