@@ -25,7 +25,7 @@
 #include "desktop-affine.h"
 #include "dialogs/object-attributes.h"
 #include "display/curve.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "xml/repr.h"
 #include "libnr/nr-point.h"
 #include "libnr/nr-point-fns.h"
@@ -136,7 +136,7 @@ sp_star_write (SPObject *object, SPRepr *repr, guint flags)
 	SPStar *star = SP_STAR (object);
 
 	if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-		repr = sp_repr_new ("path");
+		repr = sp_repr_new ("svg:path");
 	}
 
 	if (flags & SP_OBJECT_WRITE_EXT) {
@@ -280,11 +280,19 @@ sp_star_update (SPObject *object, SPCtx *ctx, guint flags)
 static gchar *
 sp_star_description (SPItem *item)
 {
-	SPStar *star = SP_STAR (item);
+    SPStar *star = SP_STAR (item);
 
-	if (star->flatsided == false )
-	return g_strdup_printf (_("<b>Star</b> with %d vertices"), star->sides);
-	else return g_strdup_printf (_("<b>Polygon</b> with %d vertices"), star->sides);
+    // while there will never be less than 3 vertices, we still need to
+    // make calls to ngettext because the pluralization may be different
+    // for various numbers >=3.  The singular form is used as the index.
+    if (star->flatsided == false )
+	return g_strdup_printf (ngettext("<b>Star</b> with %d vertex",
+				         "<b>Star</b> with %d vertices",
+					 star->sides), star->sides);
+    else
+        return g_strdup_printf (ngettext("<b>Polygon</b> with %d vertex",
+				         "<b>Polygon</b> with %d vertices",
+					 star->sides), star->sides);
 }
 
 /**
