@@ -50,8 +50,7 @@
 #include <glib.h>
 //#include <gtk/gtk.h>
 
-#include "helper/sp-intl.h"
-#include "xml/repr-private.h"
+#include <glibmm/i18n.h>
 #include "svg/svg.h"
 #include "svg/stringstream.h"
 #include "display/curve.h"
@@ -60,17 +59,22 @@
 #include "attributes.h"
 #include "document.h"
 #include "desktop.h"
+#include "fontsize-expansion.h"
 #include "style.h"
 #include "version.h"
 #include "inkscape.h"
 #include "view.h"
 #include "print.h"
+#include "sp-metrics.h"
+#include "xml/repr.h"
 
 #include "sp-shape.h"
 #include "sp-text.h"
 #include "sp-tspan.h"
 #include "sp-string.h"
 
+#include "text-editing.h"
+
 //#include "sp-use-reference.h"
 //#include "prefs-utils.h"
 
@@ -96,7 +100,7 @@ static NRArenaItem *sp_text_show (SPItem *item, NRArena *arena, unsigned key, un
 static void sp_text_hide (SPItem *item, unsigned key);
 static char *sp_text_description (SPItem *item);
 static void sp_text_snappoints(SPItem const *item, SnapPointsIter p);
-//static NR::Matrix sp_text_set_transform(SPItem *item, NR::Matrix const &xform);
+static NR::Matrix sp_text_set_transform(SPItem *item, NR::Matrix const &xform);
 static void sp_text_print (SPItem *item, SPPrintContext *gpc);
 
 static void sp_text_request_relayout (SPText *text, guint flags);
@@ -151,7 +155,7 @@ sp_text_class_init (SPTextClass *classname)
     item_class->hide = sp_text_hide;
     item_class->description = sp_text_description;
     item_class->snappoints = sp_text_snappoints;
-//    item_class->set_transform = sp_text_set_transform;
+    item_class->set_transform = sp_text_set_transform;
     item_class->print = sp_text_print;
 }
 
@@ -349,9 +353,14 @@ sp_text_write (SPObject *object, SPRepr *repr, guint flags)
 {
     SPText *text = SP_TEXT (object);
 
+    // when stamping, _write is called on the newly created object before _set_shape, so we need to
+    // reflow here too (bug 1077559)
+    if (flags & SP_OBJECT_WRITE_EXT)
+        text->UpdateFlowSource();
+
     if (flags & SP_OBJECT_WRITE_BUILD) {
         if (!repr)
-            repr = sp_repr_new ("text");
+            repr = sp_repr_new ("svg:text");
         GSList *l = NULL;
         for (SPObject *child = sp_object_first_child(object) ; child != NULL ; child = SP_OBJECT_NEXT(child) ) {
             SPRepr *crepr = NULL;
@@ -360,7 +369,7 @@ sp_text_write (SPObject *object, SPRepr *repr, guint flags)
             } else if (SP_IS_TEXTPATH (child)) {
                 crepr = child->updateRepr(NULL, flags);
             } else {
-                crepr = sp_xml_document_createTextNode (sp_repr_document (repr), SP_STRING_TEXT (child));
+                crepr = sp_repr_new_text(SP_STRING_TEXT (child));
             }
             if (crepr) l = g_slist_prepend (l, crepr);
         }
@@ -475,10 +484,12 @@ sp_text_description(SPItem *item)
         n = _("<no name found>");
     }
 
+    GString *xs = SP_PX_TO_METRIC_STRING(style->font_size.computed, sp_desktop_get_default_metric(SP_ACTIVE_DESKTOP));
+
     if (SP_IS_TEXT_TEXTPATH(item)) {
-        return g_strdup_printf (_("<b>Text on path</b> (%s, %.5gpt). Use <b>Shift+D</b> to look up the path"), n, style->font_size.computed );
+        return g_strdup_printf (_("<b>Text on path</b> (%s, %s)"), n, xs->str);
     } else {
-        return g_strdup_printf (_("<b>Text</b> (%s, %.5gpt)"), n, style->font_size.computed );
+        return g_strdup_printf (_("<b>Text</b> (%s, %s)"), n, xs->str);
     }
 }
 
@@ -534,7 +545,7 @@ sp_text_set_shape (SPText *text)
             for (int j = 0; j < text->f_res->nbChunk; j++) {
                 if ( text->f_res->chunks[j].mommy == text->f_src->elems[i].text ) {
                     // found
-                    cur=text->f_res->chunks+j;
+                    cur=&(text->f_res->chunks[j]);
                     break;
                 }
             }
@@ -587,7 +598,7 @@ sp_text_set_shape (SPText *text)
             for (int j = 0; j < text->f_res->nbChunk; j++) {
                 if ( text->f_res->chunks[j].mommy == text->f_src->elems[i].text ) {
                     // found
-                    cur = text->f_res->chunks + j;
+                    cur = &(text->f_res->chunks[j]);
                     cur_no = j;
                     break;
                 }
@@ -686,15 +697,124 @@ static void sp_text_snappoints(SPItem const *item, SnapPointsIter p)
     }
 }
 
-#if 0 /* set_transform disabled for now (2004-10-13). */
+void
+sp_text_adjust_fontsize_recursive (SPItem *item, double ex)
+{
+    SPStyle *style = SP_OBJECT_STYLE (item);
+
+    if (style && !NR_DF_TEST_CLOSE (ex, 1.0, NR_EPSILON)) {
+        style->font_size.computed *= ex;
+        if (style->text) {
+            style->text->letterspacing.computed *= ex;
+            style->text->wordspacing.computed *= ex;
+        }
+        SP_OBJECT(item)->updateRepr();
+    }
+
+    for (SPObject *o = SP_OBJECT(item)->children; o != NULL; o = o->next) {
+        if (SP_IS_ITEM(o))
+            sp_text_adjust_fontsize_recursive (SP_ITEM(o), ex);
+    }
+}
+
+void
+sp_text_adjust_coords_recursive (SPItem *item, NR::Matrix const &m, double ex)
+{
+    div_flow_src *contents = NULL; 
+    SPSVGLength *x = NULL, *y = NULL;
+    // if someone knows how to make this less ugly, you're welcome:
+    if (SP_IS_TSPAN(item)) {
+        contents = &(SP_TSPAN(item)->contents);
+        x = &(SP_TSPAN(item)->x);
+        y = &(SP_TSPAN(item)->y);
+    } else if (SP_IS_TEXT(item)) {
+        contents = &(SP_TEXT(item)->contents);
+        x = &(SP_TEXT(item)->x);
+        y = &(SP_TEXT(item)->y);
+    }
+
+    if (contents) {
+        if (!(SP_IS_TSPAN(item) && SP_TSPAN(item)->role == SP_TSPAN_ROLE_LINE)) {
+            // Do not touch x/y for line tspans, because they will get updated automatically from parent
+
+            /* Recalculate x/y lists */
+            contents->TransformXY (m, SP_IS_TEXT(item));
+            if ( contents->nb_x > 0 ) {
+                *x = contents->x_s[0];
+                x->set = 1;
+            } else {
+                x->set = 0;
+            }
+            if ( contents->nb_y > 0 ) {
+                *y = contents->y_s[0];
+                y->set = 1;
+            } else {
+                y->set = 0;
+            }
+        }
+
+        /* Recalculate dx/dy lists */
+        if (SP_IS_TEXT(item)) {
+            // ScaleDXDY will update the kerns in the entire chain of linked flow_src's of the text
+            // object, therefore we call it only once for the root <text> but not for tspans
+            contents->ScaleDXDY (ex);
+        }
+    }
+
+    for (SPObject *o = SP_OBJECT(item)->children; o != NULL; o = o->next) {
+        if (SP_IS_ITEM(o))
+            sp_text_adjust_coords_recursive (SP_ITEM(o), m, ex);
+    }
+}
+
 static NR::Matrix
 sp_text_set_transform (SPItem *item, NR::Matrix const &xform)
 {
+    SPText *text = SP_TEXT(item);
+
+    // we cannot optimize textpath because changing its fontsize will break its match to the path
+    if (SP_IS_TEXT_TEXTPATH (text))
+        return xform;
+
+    /* This function takes care of scaling & translation only, we return whatever parts we can't
+       handle. */
+
+// TODO: pjrm tried to use fontsize_expansion(xform) here and it works for text in that font size
+// is scaled more intuitively when scaling non-uniformly; however this necessitated using
+// fontsize_expansion instead of expansion in other places too, where it was not appropriate
+// (e.g. it broke stroke width on copy/pasting of style from horizontally stretched to vertically
+// stretched shape). Using fontsize_expansion only here broke setting the style via font
+// dialog. This needs to be investigated further.
+    double const ex = NR::expansion(xform); 
+    if (ex == 0) {
+        return xform;
+    }
+
+    NR::Matrix ret(NR::transform(xform));
+    ret[0] /= ex;
+    ret[1] /= ex;
+    ret[2] /= ex;
+    ret[3] /= ex;
+
+    // Adjust x/y, dx/dy
+    sp_text_adjust_coords_recursive (item, xform * ret.inverse(), ex);
+
+    // Adjust font size
+    sp_text_adjust_fontsize_recursive (item, ex);
+
+    // Adjust stroke width
+    sp_shape_adjust_stroke(item, ex);
+
+    // Adjust pattern fill
+    sp_shape_adjust_pattern(item, xform * ret.inverse());
+
+    // Adjust gradient fill
+    sp_shape_adjust_gradient(item, xform * ret.inverse());
+
     item->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG | SP_TEXT_LAYOUT_MODIFIED_FLAG);
 
-    return xform;
+    return ret;
 }
-#endif
 
 static void
 sp_text_print (SPItem *item, SPPrintContext *ctx)
@@ -715,15 +835,6 @@ sp_text_print (SPItem *item, SPPrintContext *ctx)
 }
 
 
-
-int
-sp_text_is_empty (SPText *text)
-{
-    int tlen=sp_text_get_length(text);
-    if ( tlen > 0 ) return FALSE;
-    return TRUE;
-}
-
 gchar *
 sp_text_get_string_multiline (SPText *text)
 {
@@ -755,8 +866,8 @@ sp_text_set_repr_text_multiline(SPText *text, gchar const *str)
     gchar *content = g_strdup (str);
 
     sp_repr_set_content (SP_OBJECT_REPR (text), "");
-    while (repr->children) {
-        sp_repr_remove_child (repr, repr->children);
+    while (repr->firstChild()) {
+        repr->removeChild(repr->firstChild());
     }
 
     NR::Point cp(text->x.computed, text->y.computed);
@@ -768,7 +879,7 @@ sp_text_set_repr_text_multiline(SPText *text, gchar const *str)
             if (e) *e = ' '; // no lines for textpath, replace newlines with spaces
         } else {
             if (e) *e = '\0'; // create a tspan for each line
-            SPRepr *rtspan = sp_repr_new ("tspan");
+            SPRepr *rtspan = sp_repr_new ("svg:tspan");
             sp_repr_set_double (rtspan, "x", cp[NR::X]);
             sp_repr_set_double (rtspan, "y", cp[NR::Y]);
             if (style->writing_mode.computed == SP_CSS_WRITING_MODE_TB) {
@@ -777,7 +888,7 @@ sp_text_set_repr_text_multiline(SPText *text, gchar const *str)
                 cp[NR::Y] += style->font_size.computed;
             }
             sp_repr_set_attr (rtspan, "sodipodi:role", "line");
-            SPRepr *rstr = sp_xml_document_createTextNode (sp_repr_document (repr), p);
+            SPRepr *rstr = sp_repr_new_text(p);
             sp_repr_add_child (rtspan, rstr, NULL);
             sp_repr_unref(rstr);
             sp_repr_append_child (repr, rtspan);
@@ -786,7 +897,7 @@ sp_text_set_repr_text_multiline(SPText *text, gchar const *str)
         p = (e) ? e + 1 : NULL;
     }
     if (is_textpath) { 
-        SPRepr *rstr = sp_xml_document_createTextNode (sp_repr_document (repr), content);
+        SPRepr *rstr = sp_repr_new_text(content);
         sp_repr_add_child (repr, rstr, NULL);
         sp_repr_unref(rstr);
     }
@@ -820,20 +931,6 @@ sp_text_request_relayout (SPText *text, guint flags)
 }
 
 
-gint
-sp_text_get_length (SPText *text)
-{
-    if ( text->f_src == NULL ) text->UpdateFlowSource();
-    one_flow_src *cur = &text->contents;
-    gint length = 0;
-    while (cur) {
-			length += cur->ucs4_en-cur->ucs4_st;
-			cur = cur->next;
-    }
-    return length;
-}
-
-
 SPTSpan *
 sp_text_append_line(SPText *text)
 {
@@ -855,7 +952,7 @@ sp_text_append_line(SPText *text)
     }
 
     /* Create <tspan> */
-    SPRepr *rtspan = sp_repr_new ("tspan");
+    SPRepr *rtspan = sp_repr_new ("svg:tspan");
     if (style->writing_mode.computed == SP_CSS_WRITING_MODE_TB) {
         /* fixme: real line height */
         /* fixme: What to do with mixed direction tspans? */
@@ -868,7 +965,7 @@ sp_text_append_line(SPText *text)
     sp_repr_set_attr (rtspan, "sodipodi:role", "line");
 
     /* Create TEXT */
-    SPRepr *rstring = sp_xml_document_createTextNode (sp_repr_document (rtspan), "");
+    SPRepr *rstring = sp_repr_new_text("");
     sp_repr_add_child (rtspan, rstring, NULL);
     sp_repr_unref (rstring);
     /* Append to text */
@@ -897,9 +994,9 @@ sp_text_insert_line (SPText *text, gint i_ucs4_pos)
 
     if ( into == NULL ) {
         // it's a 'append line' in fact
-        SPRepr*   rtspan = sp_repr_new ("tspan");
+        SPRepr*   rtspan = sp_repr_new ("svg:tspan");
         sp_repr_set_attr (rtspan, "sodipodi:role", "line");
-        SPRepr*   rstring = sp_xml_document_createTextNode (sp_repr_document (rtspan), "");
+        SPRepr*   rstring = sp_repr_new_text("");
         sp_repr_add_child (rtspan, rstring, NULL);
         sp_repr_unref (rstring);
         sp_repr_append_child (SP_OBJECT_REPR (text), rtspan);
@@ -920,13 +1017,13 @@ sp_text_insert_line (SPText *text, gint i_ucs4_pos)
                     // just in case
                     //sp_repr_set_attr (into_repr, "sodipodi:role", "line");
                     // create the new tspan
-                    SPRepr*   rtspan = sp_repr_new ("tspan");
+                    SPRepr*   rtspan = sp_repr_new ("svg:tspan");
                     sp_repr_set_attr (rtspan, "sodipodi:role", "line");
                     SPRepr*   rstring = NULL;
                     if ( into_obj->utf8_st < into_obj->utf8_en ) {
-                        rstring=sp_xml_document_createTextNode (sp_repr_document (rtspan), into_obj->cleaned_up.utf8_text+(utf8_pos-into_obj->utf8_st));
+                        rstring=sp_repr_new_text(into_obj->cleaned_up.utf8_text+(utf8_pos-into_obj->utf8_st));
                     } else {
-                        rstring=sp_xml_document_createTextNode (sp_repr_document (rtspan), NULL);
+                        rstring=sp_repr_new_text("");
                     }
                     sp_repr_add_child (rtspan, rstring, NULL);
                     sp_repr_unref (rstring);
@@ -1003,8 +1100,8 @@ sp_text_insert_line (SPText *text, gint i_ucs4_pos)
 
             } else if ( into->dad->Type() == txt_text ) {
                 // special case
-                SPRepr*   firstspan = sp_repr_new ("tspan");
-                SPRepr*   rtspan = sp_repr_new ("tspan");
+                SPRepr*   firstspan = sp_repr_new ("svg:tspan");
+                SPRepr*   rtspan = sp_repr_new ("svg:tspan");
                 sp_repr_set_attr (firstspan, "sodipodi:role", "line");
                 sp_repr_set_attr (rtspan, "sodipodi:role", "line");
                 SPRepr*   firststring =NULL;
@@ -1012,12 +1109,12 @@ sp_text_insert_line (SPText *text, gint i_ucs4_pos)
                 if ( into_obj->utf8_st < into_obj->utf8_en ) {
                     char savC=into_obj->cleaned_up.utf8_text[utf8_pos-into_obj->utf8_st];
                     into_obj->cleaned_up.utf8_text[utf8_pos-into_obj->utf8_st]=0;
-                    firststring = sp_xml_document_createTextNode (sp_repr_document (firstspan), into_obj->cleaned_up.utf8_text);
+                    firststring = sp_repr_new_text(into_obj->cleaned_up.utf8_text);
                     into_obj->cleaned_up.utf8_text[utf8_pos-into_obj->utf8_st]=savC;
-                    rstring = sp_xml_document_createTextNode (sp_repr_document (rtspan), into_obj->cleaned_up.utf8_text+(utf8_pos-into_obj->utf8_st));
+                    rstring = sp_repr_new_text(into_obj->cleaned_up.utf8_text+(utf8_pos-into_obj->utf8_st));
                 } else {
-                    firststring = sp_xml_document_createTextNode (sp_repr_document (firstspan), NULL);
-                    rstring = sp_xml_document_createTextNode (sp_repr_document (rtspan), NULL);
+                    firststring = sp_repr_new_text("");
+                    rstring = sp_repr_new_text("");
                 }
                 sp_repr_add_child (rtspan, rstring, NULL);
                 sp_repr_unref (rstring);
@@ -1042,9 +1139,9 @@ sp_text_insert_line (SPText *text, gint i_ucs4_pos)
         } else if ( into->Type() == txt_firstline || into->Type() == txt_tline ) {
             // insert a new empty tspan in front of this one
             if ( into->dad ) {
-                SPRepr*   rtspan = sp_repr_new ("tspan");
+                SPRepr*   rtspan = sp_repr_new ("svg:tspan");
                 sp_repr_set_attr (rtspan, "sodipodi:role", "line");
-                SPRepr*   rstring = sp_xml_document_createTextNode (sp_repr_document (rtspan), "");
+                SPRepr*   rstring = sp_repr_new_text("");
                 SPObject* prec=NULL;
                 for (SPObject* child = sp_object_first_child(into->dad->me) ; child != NULL ; child = SP_OBJECT_NEXT(child) ) {
                     if ( child == into->me ) break;
@@ -1078,264 +1175,6 @@ sp_text_append (SPText */*text*/, gchar const */*utf8*/)
     return 0;
 }
 
-/**
- * \pre \a utf8[] is valid UTF-8 text.
- */
-gint
-sp_text_insert(SPText *text, gint i_ucs4_pos, gchar const *utf8)
-{
-    if ( g_utf8_validate(utf8,-1,NULL) != TRUE ) {
-        g_warning("Trying to insert invalid utf8");
-        return i_ucs4_pos;
-    }
- 	int utf8_pos=text->contents.Do_UCS4_2_UTF8(i_ucs4_pos);
-   //printf("insert %s at %i\n",utf8,pos);
-    int  utf8_len=strlen(utf8);
-    int  ucs4_len=0;
-    for (gchar const *p = utf8; *p; p = g_utf8_next_char(p)) {
-        ucs4_len++;
-    }
-    if ( text->f_src == NULL ) { // no source text?
-        return i_ucs4_pos;
-    }
-    if ( text->f_res == NULL ) {
-        // no output but some input means: totally empty text
-        int  ucs4_pos=0;
-        one_flow_src* into=text->contents.Locate(0,ucs4_pos,true,false,true);
-        if ( into && into->Type() == flw_text ) {
-            // found our guy
-            bool done=false;
-            into->Insert(0,ucs4_pos,utf8,utf8_len,ucs4_len,done);
-            SP_OBJECT(text)->updateRepr(SP_OBJECT_REPR(SP_OBJECT(text)),SP_OBJECT_WRITE_EXT);
-            SP_OBJECT(text)->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
-            return ucs4_len;
-        }
-        return i_ucs4_pos;
-    }
-
-    // round to the letter granularity
-    int    c_st=-1,s_st=-1,l_st=-1;
-    bool   l_start_st=false,l_end_st=false;
-    text->f_res->OffsetToLetter(utf8_pos,c_st,s_st,l_st,l_start_st,l_end_st);
-    if ( l_st < 0 ) return i_ucs4_pos;
-    text->f_res->LetterToOffset(c_st,s_st,l_st,l_start_st,l_end_st,utf8_pos);
-    //utf8_pos=text->f_res->letters[l_st].utf8_offset;
-    int  ucs4_pos=text->f_res->letters[l_st].ucs4_offset;
-
-    one_flow_src* cur=&text->contents;
-    bool  done=false;
-    while ( cur && done == false ) {
-        cur->Insert(utf8_pos,ucs4_pos,utf8,utf8_len,ucs4_len,done);
-        cur=cur->next;
-    }
-    SP_OBJECT(text)->updateRepr(SP_OBJECT_REPR(SP_OBJECT(text)),SP_OBJECT_WRITE_EXT);
-    SP_OBJECT(text)->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
-    return i_ucs4_pos+ucs4_len;
-}
-
-SPObject *
-object_prev_sibling(SPObject *child)      // TEMPORARY, until spobject provides this
-{
-    SPObject *parent = SP_OBJECT_PARENT(child);
-    for ( SPObject *i = sp_object_first_child(parent) ; i; i = SP_OBJECT_NEXT(i) ) {
-        if (i->next == child)
-            return i;
-    }
-    return NULL;
-}
-
-
-gint
-sp_text_delete (SPText *text, gint i_start, gint i_end)
-{
-    int start = text->contents.Do_UCS4_2_UTF8(i_start);
-    int end = text->contents.Do_UCS4_2_UTF8(i_end);
- 	//printf("delete %i -> %i\n",start,end);
-
-    if ( text->f_src == NULL || text->f_res == NULL ) 
-        return i_start;
-
-    // round to the letter granularity
-    int    c_st=-1, s_st=-1, l_st=-1;
-    int    c_en=-1, s_en=-1, l_en=-1;
-    bool   l_start_st=false, l_end_st=false;
-    bool   l_start_en=false, l_end_en=false;
-    text->f_res->OffsetToLetter(start, c_st, s_st, l_st, l_start_st, l_end_st);
-    text->f_res->OffsetToLetter(end, c_en, s_en, l_en, l_start_en, l_end_en);
-    if ( l_start_st == false && l_end_st == false ) l_start_st=true;
-    if ( l_start_en == false && l_end_en == false ) l_end_en=true;
-    if ( l_st < 0 || l_en < 0 || l_st > l_en ) return i_start;
-    if ( l_st == l_en && ( l_start_st == l_start_en || l_end_st == l_end_en ) ) return i_start;
-    text->f_res->LetterToOffset(c_st, s_st, l_st, l_start_st, l_end_st, start);
-    text->f_res->LetterToOffset(c_en, s_en, l_en, l_start_en, l_end_en, end);
-
-    // Find the last ofc
-    one_flow_src* last=NULL;
-    for (one_flow_src* cur=&text->contents; cur; cur=cur->next) {
-        last=cur;
-    }
-
-    // list of line tspans that are to be merged
-    GSList *lines_to_merge = NULL;
-
-    for (one_flow_src* cur=last; cur; cur=cur->prev) {
-        if (start <= cur->utf8_st && end >= cur->utf8_en && 
-            SP_IS_TSPAN(cur->me) && SP_TSPAN(cur->me)->role != SP_TSPAN_ROLE_UNSPECIFIED) {
-            // If the delete range fully covers this ofc and it comes from a line tspan, remember to merge it
-            lines_to_merge = g_slist_prepend (lines_to_merge, cur->me);
-        }
-        // only those ofc's that overlap the delete range will be affected:
-        cur->Delete(start, end);
-    }
-
-    SP_OBJECT(text)->updateRepr(SP_OBJECT_REPR(SP_OBJECT(text)),SP_OBJECT_WRITE_EXT);
-
-    for (GSList *i = lines_to_merge; i; i = i->next) {
-        SPObject *prev = object_prev_sibling (SP_OBJECT (i->data));
-        if (prev && SP_IS_TSPAN(prev) && SP_TSPAN(prev)->role != SP_TSPAN_ROLE_UNSPECIFIED) {
-            // If the line to be merged has a prev sibling and it's also a line,
-            for (SPObject *child = sp_object_first_child(SP_OBJECT(i->data)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
-                // copy all children to it
-                SPRepr *copy = sp_repr_duplicate (SP_OBJECT_REPR (child));
-                sp_repr_append_child(SP_OBJECT_REPR(prev), copy);
-                sp_repr_unref (copy);
-            }
-            // delete line to be merged
-            SP_OBJECT(i->data)->deleteObject();
-        }
-    }
-    g_slist_free (lines_to_merge);
-
-    SP_OBJECT(text)->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
-    return i_start;
-}
-
-gint
-sp_text_up (SPText *text, gint i_position)
-{
-    int position=text->contents.Do_UCS4_2_UTF8(i_position);
-
-   if ( text->f_res == NULL ) return i_position;
-    int    c_p=-1,s_p=-1,l_p=-1;
-    bool   l_start=false,l_end=false;
-    text->f_res->OffsetToLetter(position,c_p,s_p,l_p,l_start,l_end);
-
-    if ( c_p >= 0 ) {
-        int l_o = l_p - text->f_res->chunks[c_p].l_st;
-        if ( l_end ) {
-            l_end=false;
-            l_o++;
-        }
-        c_p--;
-        if ( c_p < 0 ) {
-            c_p=0;
-            if ( text->f_res->chunks[c_p].l_st < text->f_res->chunks[c_p].l_en ) l_p=text->f_res->chunks[c_p].l_st; else l_p=0;
-        } else {
-            if ( text->f_res->chunks[c_p].l_st < text->f_res->chunks[c_p].l_en ) {
-                l_p=text->f_res->chunks[c_p].l_st+l_o;
-                if ( l_p >= text->f_res->chunks[c_p].l_en ) l_p=text->f_res->chunks[c_p].l_en-1;
-            } else l_p=text->f_res->chunks[c_p].l_st;
-        }
-        int   res=position;
-        text->f_res->LetterToOffset(c_p,s_p,l_p,l_start,l_end,res);
-        return text->contents.Do_UTF8_2_UCS4(res);
-    }
-    return i_position;
-}
-
-gint
-sp_text_down (SPText *text, gint i_position)
-{
-	int position=text->contents.Do_UCS4_2_UTF8(i_position);
-    if ( text->f_res == NULL ) return i_position;
-    int    c_p=-1,s_p=-1,l_p=-1;
-    bool   l_start=false,l_end=false;
-    text->f_res->OffsetToLetter(position,c_p,s_p,l_p,l_start,l_end);
-    if ( c_p >= 0 ) {
-        int c_o=l_p-text->f_res->chunks[c_p].l_st;
-        if ( l_end ) {l_end=false;c_o++;}
-        c_p++;
-        if ( c_p >= text->f_res->nbChunk ) {
-            c_p=text->f_res->nbChunk-1;
-            if ( text->f_res->chunks[c_p].l_st < text->f_res->chunks[c_p].l_en ) l_p=text->f_res->chunks[c_p].l_en; else l_p=text->f_res->nbLetter;
-        } else {
-            if ( text->f_res->chunks[c_p].l_st < text->f_res->chunks[c_p].l_en ) {
-                l_p=text->f_res->chunks[c_p].l_st+c_o;
-                if ( l_p >= text->f_res->chunks[c_p].l_en ) l_p=text->f_res->chunks[c_p].l_en-1;
-            } else l_p=text->f_res->nbLetter;
-        }
-        int   res=position;
-        text->f_res->LetterToOffset(c_p,s_p,l_p,l_start,l_end,res);
-        return text->contents.Do_UTF8_2_UCS4(res);
-    }
-    return i_position;
-}
-
-gint
-sp_text_start_of_line (SPText *text, gint i_position)
-{
- 	int position=text->contents.Do_UCS4_2_UTF8(i_position);
-   if ( text->f_res == NULL ) return i_position;
-    int    c_p=-1,s_p=-1,l_p=-1;
-    bool   l_start=false,l_end=false;
-    text->f_res->OffsetToLetter(position,c_p,s_p,l_p,l_start,l_end);
-    if ( c_p >= 0 ) {
-        if ( l_p >= 0 ) {
-            l_p=text->f_res->chunks[c_p].l_st;
-        }
-        l_start=true;
-        l_end=false;
-        int   res=position;
-        text->f_res->LetterToOffset(c_p,s_p,l_p,l_start,l_end,res);
-        return text->contents.Do_UTF8_2_UCS4(res);
-    }
-    return i_position;
-}
-
-gint
-sp_text_end_of_line (SPText *text, gint i_position)
-{
- 	int position=text->contents.Do_UCS4_2_UTF8(i_position);
-   if ( text->f_res == NULL ) return i_position;
-    int    c_p=-1,s_p=-1,l_p=-1;
-    bool   l_start=false,l_end=false;
-    text->f_res->OffsetToLetter(position,c_p,s_p,l_p,l_start,l_end);
-    if ( c_p >= 0 ) {
-        if ( l_p >= 0 ) {
-            l_p=text->f_res->chunks[c_p].l_en-1;
-        }
-        l_start=true; // otherwise ends up at beginning of next line
-        l_end=false;
-				if ( c_p >= text->f_res->nbChunk-1 ) {l_start=false;l_end=true;}
-        int   res=position;
-        text->f_res->LetterToOffset(c_p,s_p,l_p,l_start,l_end,res);
-        return text->contents.Do_UTF8_2_UCS4(res);
-    }
-    return i_position;
-}
-void
-sp_text_get_cursor_coords (SPText *text, gint i_position, NR::Point &p0, NR::Point &p1)
-{
-	int position=text->contents.Do_UCS4_2_UTF8(i_position);
-    p0=p1=NR::Point(text->x.computed,text->y.computed);
-    if ( text->f_res == NULL ) return;
-    int c_p = -1, s_p = -1, l_p = -1;
-    bool l_start = false, l_end = false;
-    //printf("letter at offset %i : ",position);
-    text->f_res->OffsetToLetter(position,c_p,s_p,l_p,l_start,l_end);
-    //printf(" c=%i s=%i l=%i st=%i en=%i ",c_p,s_p,l_p,(l_start)?1:0,(l_end)?1:0);
-    if ( l_p >= 0 ) {
-        double npx,npy,npa,nps;
-        text->f_res->LetterToPosition(c_p,s_p,l_p,l_start,l_end,npx,npy,nps,npa);
-        p0=NR::Point(npx,npy);
-        p1=NR::Point(-sin(npa),cos(npa));
-        p1=p0-nps*p1;
-        //printf(" -> coord %f %f \n",npx,npy);
-    } else {
-        //printf("none\n");
-    }
-}
-
 static SPObject *
 sp_text_get_child_by_position (SPText *text, gint i_ucs4_pos)
 {
@@ -1350,33 +1189,9 @@ sp_text_get_child_by_position (SPText *text, gint i_ucs4_pos)
     return NULL;
 }
 
-guint
-sp_text_get_position_by_coords (SPText *text, NR::Point &i_p)
-{
-    if ( text->f_res == NULL ) return 0;
-    NR::Matrix  im=sp_item_i2d_affine(SP_ITEM(text));
-    im=im.inverse();
-    NR::Point p = i_p * im;
-    int    c_p=-1,s_p=-1,l_p=-1;
-    bool   l_start=false,l_end=false;
-    //printf("letter at position %f %f : ",p[0],p[1]);
-    text->f_res->PositionToLetter(p[0],p[1],c_p,s_p,l_p,l_start,l_end);
-    if ( l_p >= 0 || c_p >= 0 ) {
-        //printf(" c=%i s=%i l=%i st=%i en=%i ",c_p,s_p,l_p,(l_start)?1:0,(l_end)?1:0);
-        int position=0;
-        text->f_res->LetterToOffset(c_p,s_p,l_p,l_start,l_end,position);
-        //printf(" -> offset %i \n",position);
-        return text->contents.Do_UTF8_2_UCS4(position);
-    } else {
-        //printf("none\n");
-    }
-    return 0;
-}
-
 void
 sp_adjust_kerning_screen (SPText *text, gint i_position, SPDesktop *desktop, NR::Point by)
 {
-	int position=text->contents.Do_UCS4_2_UTF8(i_position);
     if ( text->f_src == NULL ) return;
     one_flow_src* cur=&text->contents;
 
@@ -1392,11 +1207,11 @@ sp_adjust_kerning_screen (SPText *text, gint i_position, SPDesktop *desktop, NR:
     by_x.value=by_x.computed=by[0];
     by_y.value=by_y.computed=by[1];
     while ( cur ) {
-        cur->AddValue(position,by_x,2,true);
-        cur->AddValue(position,by_y,3,true);
+        cur->AddValue(i_position, by_x, 2, true, false);
+        cur->AddValue(i_position, by_y, 3, true, false);
         cur=cur->next;
     }
-    SP_OBJECT(text)->updateRepr(SP_OBJECT_REPR(SP_OBJECT(text)),SP_OBJECT_WRITE_EXT);
+    SP_OBJECT(text)->updateRepr();
     SP_OBJECT(text)->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
 }
 
@@ -1423,6 +1238,8 @@ sp_adjust_tspan_letterspacing_screen(SPText *text, gint i_position, SPDesktop *d
     SPStyle *style = SP_OBJECT_STYLE (child);
 
     // calculate real value
+    /* TODO: Consider calculating val unconditionally, i.e. drop the first `if' line, and
+       get rid of the `else val = 0.0'.  Similarly below and in sp-string.cpp. */
     if (style->text->letterspacing.value != 0 && style->text->letterspacing.computed == 0) { // set in em or ex
         if (style->text->letterspacing.unit == SP_CSS_UNIT_EM) {
             val = style->font_size.computed * style->text->letterspacing.value;
@@ -1437,16 +1254,14 @@ sp_adjust_tspan_letterspacing_screen(SPText *text, gint i_position, SPDesktop *d
 
     // divide increment by zoom and by the number of characters in the line,
     // so that the entire line is expanded by by pixels, no matter what its length
-    gdouble zoom = SP_DESKTOP_ZOOM (desktop);
-    gdouble zby = by / (zoom * (nb_let > 1 ? nb_let - 1 : 1));
-
-    // divide increment by matrix expansion
-    NR::Matrix t = sp_item_i2doc_affine (SP_ITEM(child));
-    zby = zby / NR::expansion(t);
-
+    gdouble const zoom = SP_DESKTOP_ZOOM(desktop);
+    gdouble const zby = (by
+                         / (zoom * (nb_let > 1 ? nb_let - 1 : 1))
+                         / NR::expansion(sp_item_i2doc_affine(SP_ITEM(child))));
     val += zby;
 
     // set back value
+    style->text->letterspacing_normal = FALSE;
     if (style->text->letterspacing.value != 0 && style->text->letterspacing.computed == 0) { // set in em or ex
         if (style->text->letterspacing.unit == SP_CSS_UNIT_EM) {
             style->text->letterspacing.value = val / style->font_size.computed;
