@@ -20,7 +20,7 @@
 #include <libnr/nr-matrix.h>
 #include <libnr/nr-matrix-ops.h>
 #include "libnr/nr-matrix-translate-ops.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "svg/svg.h"
 #include "display/nr-arena-group.h"
 #include "attributes.h"
@@ -30,10 +30,10 @@
 #include "uri-references.h"
 #include "macros.h"
 #include "xml/repr.h"
-#include "xml/repr-private.h"
 #include "sp-item.h"
 #include "enums.h"
 #include "prefs-utils.h"
+#include "style.h"
 #include "sp-use.h"
 #include "sp-use-reference.h"
 
@@ -253,7 +253,7 @@ sp_use_write(SPObject *object, SPRepr *repr, guint flags)
     SPUse *use = SP_USE(object);
 
     if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
-        repr = sp_repr_new("use");
+        repr = sp_repr_new("svg:use");
     }
 
     if (((SPObjectClass *) (parent_class))->write) {
@@ -305,7 +305,7 @@ sp_use_description(SPItem *item)
     SPUse *use = SP_USE(item);
 
     if (use->child) {
-        return g_strdup_printf(_("<b>Clone</b> of: %s. Use <b>Shift+D</b> to look up original"),
+        return g_strdup_printf(_("<b>Clone</b> of: %s"),
                                sp_item_description(SP_ITEM(use->child)));
     } else {
         return g_strdup(_("<b>Orphaned clone</b>"));
@@ -491,7 +491,7 @@ sp_use_href_changed(SPObject *old_ref, SPObject *ref, SPUse *use)
             g_return_if_fail(type > G_TYPE_NONE);
             if (g_type_is_a(type, SP_TYPE_ITEM)) {
                 use->child = (SPObject*) g_object_new(type, 0);
-                sp_object_attach_reref(SP_OBJECT(use), use->child, NULL);
+                sp_object_attach_reref(SP_OBJECT(use), use->child, use->lastChild());
                 sp_object_invoke_build(use->child, SP_OBJECT(use)->document, childrepr, TRUE);
 
                 for (SPItemView *v = item->display; v != NULL; v = v->next) {
@@ -623,6 +623,22 @@ sp_use_unlink(SPUse *use)
     // add the duplicate repr just after the existing one
     sp_repr_add_child(parent, copy, repr);
 
+    // retrieve the SPItem of the resulting repr
+    SPObject *unlinked = document->getObjectByRepr(copy);
+
+    // merge style from the use
+    SPStyle *unli_sty = SP_OBJECT_STYLE (unlinked);
+    SPStyle *use_sty = SP_OBJECT_STYLE (use);
+    sp_style_merge_from_parent (unli_sty, use_sty);
+    // special case for opacity: it is not inherited per the spec, but since use's opacity affected
+    // its display, we must not lose it after unlinking
+    unli_sty->opacity.value = SP_SCALE24_FROM_FLOAT (
+        SP_SCALE24_TO_FLOAT (unli_sty->opacity.value) * SP_SCALE24_TO_FLOAT (use_sty->opacity.value));
+    if (unli_sty->opacity.value != SP_SCALE24_MAX) {
+        unli_sty->opacity.set = TRUE;
+    }
+    SP_OBJECT (unlinked)->updateRepr();
+
     // hold onto our SPObject and repr for now
     sp_object_ref(SP_OBJECT(use), NULL);
     sp_repr_ref(repr);
@@ -635,8 +651,13 @@ sp_use_unlink(SPUse *use)
     sp_repr_set_attr(copy, "id", sp_repr_attr(repr, "id"));
     sp_repr_unref(repr);
 
-    // retrieve the SPItem of the resulting repr
-    SPObject *unlinked = document->getObjectByRepr(copy);
+    // remove tiled clone attrs
+    sp_repr_set_attr(copy, "inkscape:tiled-clone-of", NULL);
+    sp_repr_set_attr(copy, "inkscape:tile-w", NULL);
+    sp_repr_set_attr(copy, "inkscape:tile-h", NULL);
+    sp_repr_set_attr(copy, "inkscape:tile-cx", NULL);
+    sp_repr_set_attr(copy, "inkscape:tile-cy", NULL);
+
     // establish the succession and let go of our object
     SP_OBJECT(use)->setSuccessor(unlinked);
     sp_object_unref(SP_OBJECT(use), NULL);
