@@ -13,36 +13,51 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
+#include <sigc++/sigc++.h>
 #include "svg/svg-types.h"
 #include "sp-item.h"
 
 
-
 #define SP_TYPE_USE            (sp_use_get_type ())
 #define SP_USE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), SP_TYPE_USE, SPUse))
 #define SP_USE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), SP_TYPE_USE, SPUseClass))
 #define SP_IS_USE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SP_TYPE_USE))
 #define SP_IS_USE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SP_TYPE_USE))
 
-typedef struct _SPUse SPUse;
-typedef struct _SPUseClass SPUseClass;
+class SPUse;
+class SPUseClass;
+class SPUseReference;
 
-struct _SPUse {
-	SPItem item;
+struct SPUse : public SPItem {
+	// item built from the original's repr (the visible clone)
+	// relative to the SPUse itself, it is treated as a child, similar to a grouped item relative to its group
 	SPObject *child;
+
+	// SVG attrs
 	SPSVGLength x;
 	SPSVGLength y;
 	SPSVGLength width;
 	SPSVGLength height;
 	gchar *href;
+
+	// the reference to the original object
+	SPUseReference *ref;
+
+	// a sigc connection for delete notifications
+	sigc::connection _delete_connection;
+	sigc::connection _changed_connection;
+
+	// a sigc connection for transformed signal, used to do move compensation
+	sigc::connection _transformed_connection;
 };
 
-struct _SPUseClass {
+struct SPUseClass {
 	SPItemClass parent_class;
 };
 
 GType sp_use_get_type (void);
 
-
+SPItem *sp_use_unlink (SPUse *use);
+SPItem *sp_use_get_original (SPUse *use);
 
 #endif
