@@ -40,7 +40,7 @@
 #include "spiral-context.h"
 #include "sp-desktop-widget.h"
 #include "sp-metrics.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "object-edit.h"
 #include "knotholder.h"
 #include "xml/repr.h"
@@ -170,15 +170,10 @@ static void shape_event_attr_changed (SPRepr * repr, const gchar * name, const g
 }
 
 static SPReprEventVector shape_repr_events = {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     shape_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
@@ -300,7 +295,7 @@ sp_spiral_context_root_handler (SPEventContext * event_context, GdkEvent * event
 			/* Snap center to nearest magnetic point */
 			namedview_free_snap (event_context->desktop->namedview, Snapper::SNAP_POINT, sc->center);
 			sp_canvas_item_grab (SP_CANVAS_ITEM (desktop->acetate),
-						GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
+						GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
 						NULL, event->button.time);
 			ret = TRUE;
 		}
@@ -431,7 +426,7 @@ sp_spiral_drag (SPSpiralContext * sc, NR::Point p, guint state)
         }
 
 		/* Create object */
-		SPRepr *repr = sp_repr_new ("path");
+		SPRepr *repr = sp_repr_new ("svg:path");
              sp_repr_set_attr (repr, "sodipodi:type", "spiral");
 
 		/* Set style */
@@ -467,7 +462,7 @@ sp_spiral_drag (SPSpiralContext * sc, NR::Point p, guint state)
 		       /*t0*/ sc->t0);
 	
 	/* status text */
-	GString *rads = SP_PT_TO_METRIC_STRING (rad, SP_DEFAULT_METRIC);
+	GString *rads = SP_PX_TO_METRIC_STRING(rad, sp_desktop_get_default_metric(desktop));
 	sc->_message_context->setF(Inkscape::NORMAL_MESSAGE, _("<b>Spiral</b>: radius %s, angle %5g; with <b>Ctrl</b> to snap angle"), 
 														 rads->str, sp_round ((arg + 2.0*M_PI*spiral->revo)*180/M_PI, 0.0001));
 	g_string_free (rads, FALSE);
