@@ -23,6 +23,7 @@
 #include "svg/stringstream.h"
 #include "sp-path.h"
 #include "sp-text.h"
+#include "sp-item-group.h"
 #include "style.h"
 #include "inkscape.h"
 #include "document.h"
@@ -33,7 +34,7 @@
 #include "splivarot.h"
 #include "display/canvas-bpath.h"
 #include "display/curve.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "view.h"
 #include "prefs-utils.h"
 
@@ -41,19 +42,14 @@
 #include "libnr/nr-matrix.h"
 #include "libnr/nr-point.h"
 #include "xml/repr.h"
-#include "xml/repr-private.h"
-#include "xml/sp-repr-iterators.h"
-
-#include "algorithms/longest-common-suffix.h"
+#include "xml/repr-sorting.h"
 
 #include "livarot/Path.h"
 #include "livarot/Shape.h"
 #include "livarot/LivarotDefs.h"
 
 Path   *Path_for_item (SPItem * item,bool doTransformation, bool transformFull = true);
-SPRepr *LCA (SPRepr * a, SPRepr * b);
 bool   Ancetre (SPRepr * a, SPRepr * who);
-SPRepr *AncetreFils (SPRepr * a, SPRepr * d);
 
 void sp_selected_path_boolop (bool_op bop);
 void sp_selected_path_do_offset (bool expand, double prefOffset);
@@ -155,7 +151,7 @@ sp_selected_path_boolop (bool_op bop)
             SPRepr *bs = AncetreFils (b, dad);
 
             // find out which comes first
-            for (SPRepr * child = dad->children; child; child = child->next) {
+            for (SPRepr * child = dad->firstChild(); child; child = child->next()) {
                 if (child == as) {
                     // a en premier->mauvais sens
                     reverseOrderForOp = true;
@@ -204,7 +200,7 @@ sp_selected_path_boolop (bool_op bop)
                 origWind[curOrig]= fill_nonZero;
             }
 
-            originaux[curOrig] = Path_for_item ((SPItem *) l->data, true, false);
+            originaux[curOrig] = Path_for_item ((SPItem *) l->data, true, true);
             if (originaux[curOrig] == NULL || originaux[curOrig]->descr_cmd.size() <= 1)
             {
                 for (int i = curOrig; i >= 0; i--) delete originaux[i];
@@ -422,6 +418,7 @@ sp_selected_path_boolop (bool_op bop)
     } else {
         // find out the bottom object
         GSList *sorted = 	g_slist_copy ((GSList *) selection->reprList());
+
         sorted = g_slist_sort (sorted, (GCompareFunc) sp_repr_compare_position);
         repr_source = ((SPRepr *) sorted->data);
         g_slist_free (sorted);
@@ -446,6 +443,15 @@ sp_selected_path_boolop (bool_op bop)
     }
     g_slist_free (il);
 
+    // premultiply by the inverse of parent's repr
+    SPItem *parent_item = SP_ITEM(SP_DT_DOCUMENT(desktop)->getObjectByRepr(parent));
+    NR::Matrix local = sp_item_i2doc_affine(parent_item);
+    gchar affinestr[80];
+    gchar *transform = NULL;
+    if (!local.test_identity() && sp_svg_transform_write(affinestr, 79, local.inverse())) {
+        transform = affinestr;
+    }
+
     // now that we have the result, add it on the canvas
     if ( bop == bool_op_cut || bop == bool_op_slice ) {
         int    nbRP=0;
@@ -472,7 +478,7 @@ sp_selected_path_boolop (bool_op bop)
         for (int i=0;i<nbRP;i++) {
             gchar *d = resPath[i]->svg_dump_path ();
       
-            SPRepr *repr = sp_repr_new ("path");
+            SPRepr *repr = sp_repr_new ("svg:path");
             sp_repr_set_attr (repr, "style", style);
             sp_repr_set_attr (repr, "d", d);
             g_free (d);
@@ -494,12 +500,14 @@ sp_selected_path_boolop (bool_op bop)
             // a better algorithm might figure out e.g. the biggest piece
             sp_repr_set_attr (repr, "id", id);
 
+            sp_repr_set_attr (repr, "transform", transform);
+
             // add the new repr to the parent
             sp_repr_append_child (parent, repr);
 
             // move to the saved position 
             sp_repr_set_position_absolute (repr, pos > 0 ? pos : 0);
-      
+  
             selection->addRepr(repr);
             sp_repr_unref (repr);
 
@@ -510,12 +518,14 @@ sp_selected_path_boolop (bool_op bop)
     } else {
         gchar *d = res->svg_dump_path ();
 
-        SPRepr *repr = sp_repr_new ("path");
+        SPRepr *repr = sp_repr_new ("svg:path");
         sp_repr_set_attr (repr, "style", style);
 
         sp_repr_set_attr (repr, "d", d);
         g_free (d);
 
+        sp_repr_set_attr (repr, "transform", transform);
+
         sp_repr_set_attr (repr, "id", id);
         sp_repr_append_child (parent, repr);
         sp_repr_set_position_absolute (repr, pos > 0 ? pos : 0);
@@ -693,7 +703,7 @@ sp_selected_path_outline ()
         // remember the position of the item
         gint pos = sp_repr_position (SP_OBJECT_REPR (item));
         // remember parent
-        SPRepr *parent = SP_OBJECT_REPR (item)->parent;
+        SPRepr *parent = SP_OBJECT_REPR (item)->parent();
         // remember id
         const char *id = sp_repr_attr (SP_OBJECT_REPR (item), "id");
 
@@ -702,7 +712,7 @@ sp_selected_path_outline ()
 
         if (res->descr_cmd.size() > 1) { // if there's 0 or 1 node left, drop this path altogether
 
-            SPRepr *repr = sp_repr_new ("path");
+            SPRepr *repr = sp_repr_new ("svg:path");
 
             // restore old style
             sp_repr_set_attr (repr, "style", style);
@@ -853,7 +863,7 @@ sp_selected_path_create_offset_object (int expand, bool updating)
     // remember the position of the item
     gint pos = sp_repr_position (SP_OBJECT_REPR (item));
     // remember parent
-    SPRepr *parent = SP_OBJECT_REPR (item)->parent;
+    SPRepr *parent = SP_OBJECT_REPR (item)->parent();
   
     {
         SPStyle *i_style = SP_OBJECT (item)->style;
@@ -964,7 +974,7 @@ sp_selected_path_create_offset_object (int expand, bool updating)
     
         tstr[79] = '\0';
     
-        repr = sp_repr_new ("path");
+        repr = sp_repr_new ("svg:path");
         sp_repr_set_attr (repr, "sodipodi:type", "inkscape:offset");
         if (expand > 0)
         {
@@ -1224,7 +1234,7 @@ sp_selected_path_do_offset (bool expand, double prefOffset)
         // remember the position of the item
         gint pos = sp_repr_position (SP_OBJECT_REPR (item));
         // remember parent
-        SPRepr *parent = SP_OBJECT_REPR (item)->parent;
+        SPRepr *parent = SP_OBJECT_REPR (item)->parent();
         // remember id
         const char *id = sp_repr_attr (SP_OBJECT_REPR (item), "id");
 
@@ -1237,7 +1247,7 @@ sp_selected_path_do_offset (bool expand, double prefOffset)
 
             tstr[79] = '\0';
 
-            SPRepr *repr = sp_repr_new ("path");
+            SPRepr *repr = sp_repr_new ("svg:path");
 
             sp_repr_set_attr (repr, "style", style);
 
@@ -1274,35 +1284,125 @@ sp_selected_path_do_offset (bool expand, double prefOffset)
 
 
 
-// globals for keeping track of accelerated simplify
-static double prev_time = 0;
-static gdouble simplify_multiply = 1;
-
-void
-sp_selected_path_simplify (void)
+//return true if we changed something, else false
+bool
+sp_selected_path_simplify_item(SPDesktop *desktop, SPSelection *selection, SPItem *item,
+                 float threshold,  bool justCoalesce,
+                 float angleLimit, bool breakableAngles,
+                 gdouble size,     bool modifySelection)
 {
-    gdouble simplify_threshold = prefs_get_double_attribute ("options.simplifythreshold","value", 0.003);
-    bool simplify_justcoalesce = (bool) prefs_get_int_attribute ("options.simplifyjustcoalesce","value", 0);
+    if (!(SP_IS_GROUP(item) || SP_IS_SHAPE (item) || SP_IS_TEXT (item)))
+        return false;
 
-    GTimeVal cu;
-    g_get_current_time (&cu);
-    double current = cu.tv_sec * 1000000 + cu.tv_usec; // current time
+    //If this is a group, do the children instead
+    if (SP_IS_GROUP (item)) {
+    
+        bool didSomething = false;
 
-    if (prev_time != 0 && current - prev_time < 500000) { // last call of the command was within 0.5 sec
-        simplify_multiply += 0.5; // add to the threshold 1/2 of its original value
-        simplify_threshold *= simplify_multiply;
-    } else {
-        simplify_multiply = 1; // reset to the default
+        for ( GSList *children = sp_item_group_item_list (SP_GROUP (item));
+                 children  ; children = children->next) {
+                 
+            SPItem *child = (SPItem *) children->data;
+            didSomething |= sp_selected_path_simplify_item(desktop, selection, child, threshold, justCoalesce,
+                   angleLimit, breakableAngles, size, false);
+        }
+        
+        return didSomething;
     }
-    prev_time = current; // remember time
+        
 
-    //g_print ("%g\n", simplify_threshold);
+    SPCurve *curve = NULL;
+    
+    if (SP_IS_SHAPE (item)) {
+        curve = sp_shape_get_curve (SP_SHAPE (item));
+        if (!curve)
+            return false;
+    }
 
-    sp_selected_path_simplify_withparams (simplify_threshold, simplify_justcoalesce, 0.0, false);
+    if (SP_IS_TEXT (item)) {
+        curve = sp_text_normalized_bpath (SP_TEXT (item));
+        if (!curve)
+            return false;
+    }
+
+    // save the transform, to re-apply it after simplification
+    NR::Matrix const transform(item->transform);
+
+    /*
+       reset the transform, effectively transforming the item by transform.inverse();
+       this is necessary so that the item is transformed twice back and forth,
+       allowing all compensations to cancel out regardless of the preferences
+    */
+    sp_item_write_transform(item, SP_OBJECT_REPR(item), NR::identity());
+
+    gchar *style = g_strdup (sp_repr_attr (SP_OBJECT_REPR (item), "style"));
+
+    Path *orig = Path_for_item (item, false);
+    if (orig == NULL) {
+        g_free (style);
+        sp_curve_unref (curve);
+        return false;
+    }
+
+    sp_curve_unref (curve);
+    // remember the position of the item
+    gint pos = sp_repr_position (SP_OBJECT_REPR (item));
+    // remember parent
+    SPRepr *parent = SP_OBJECT_REPR (item)->parent();
+    // remember id
+    const char *id = sp_repr_attr (SP_OBJECT_REPR (item), "id");
+
+    //If a group was selected, to not change the selection list
+    if (modifySelection)
+        selection->removeItem (item);
+        
+    SP_OBJECT (item)->deleteObject(false);
+
+    if ( justCoalesce ) {
+        orig->Coalesce (threshold * size);
+    } else {
+        orig->ConvertEvenLines (threshold * size);
+        orig->Simplify (threshold * size);
+    }
+
+    SPRepr *repr = sp_repr_new ("svg:path");
+
+    sp_repr_set_attr (repr, "style", style);
+
+    gchar *str = orig->svg_dump_path ();
+    sp_repr_set_attr (repr, "d", str);
+    g_free (str);
+
+    // restore id
+    sp_repr_set_attr (repr, "id", id);
+
+    // add the new repr to the parent
+    sp_repr_append_child (parent, repr);
+
+    // move to the saved position 
+    sp_repr_set_position_absolute (repr, pos > 0 ? pos : 0);
+
+    SPItem *newitem = (SPItem *) SP_DT_DOCUMENT (desktop)->getObjectByRepr(repr);
+
+    // reapply the transform
+    sp_item_write_transform (newitem, repr, transform);
+
+    //If we are not in a selected group
+    if (modifySelection)
+        selection->addRepr (repr);
+
+    sp_repr_unref (repr);
+
+    // clean up
+    if (orig) delete orig;
+
+    return true;
 }
 
+
 void
-sp_selected_path_simplify_withparams (float threshold, bool justCoalesce, float angleLimit, bool breakableAngles)
+sp_selected_path_simplify_selection (float threshold, bool justCoalesce,
+                       float angleLimit, bool breakableAngles)
 {
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
     if (!SP_IS_DESKTOP (desktop))
@@ -1311,124 +1411,82 @@ sp_selected_path_simplify_withparams (float threshold, bool justCoalesce, float
     SPSelection *selection = SP_DT_SELECTION (desktop);
 
     if (selection->isEmpty()) {
-        desktop->messageStack()->flash(Inkscape::WARNING_MESSAGE, _("Select <b>path(s)</b> to simplify."));
+        desktop->messageStack()->flash(Inkscape::WARNING_MESSAGE,
+                         _("Select <b>path(s)</b> to simplify."));
         return;
     }
 
     // remember selection size
     NR::Rect bbox = selection->bounds();
-    gdouble size = L2(bbox.dimensions());
+    gdouble size  = L2(bbox.dimensions());
 
-    bool did = false;
+    bool didSomething = false;
 
+    //Loop through all of the items in the selection
     for (GSList *items = g_slist_copy((GSList *) selection->itemList());
-         items != NULL;
-         items = items->next) {
+                        items != NULL; items = items->next) {
 
         SPItem *item = (SPItem *) items->data;
 
-        if (!SP_IS_SHAPE (item) && !SP_IS_TEXT (item))
+        if (!(SP_IS_GROUP(item) || SP_IS_SHAPE (item) || SP_IS_TEXT (item)))
             continue;
 
-        SPCurve *curve = NULL;
-        if (SP_IS_SHAPE (item)) {
-            curve = sp_shape_get_curve (SP_SHAPE (item));
-            if (curve == NULL)
-                continue;
-        }
-        if (SP_IS_TEXT (item)) {
-            curve = sp_text_normalized_bpath (SP_TEXT (item));
-            if (curve == NULL)
-                continue;
-        }
-
-        // save the transform, to re-apply it after simplification
-        NR::Matrix const transform(item->transform);
-
-        // reset the transform, effectively transforming the item by transform.inverse();
-        // this is necessary so that the item is transformed twice back and forth,
-        // allowing all compensations to cancel out regardless of the preferences
-        sp_item_write_transform(item, SP_OBJECT_REPR(item), NR::identity());
-
-        gchar *style = g_strdup (sp_repr_attr (SP_OBJECT_REPR (item), "style"));
-
-        Path *orig = Path_for_item (item, false);
-        if (orig == NULL) {
-            g_free (style);
-            sp_curve_unref (curve);
-            continue;
-        }
-
-        did = true;
-        sp_curve_unref (curve);
-        // remember the position of the item
-        gint pos = sp_repr_position (SP_OBJECT_REPR (item));
-        // remember parent
-        SPRepr *parent = SP_OBJECT_REPR (item)->parent;
-        // remember id
-        const char *id = sp_repr_attr (SP_OBJECT_REPR (item), "id");
-
-        selection->removeItem (item);
-        SP_OBJECT (item)->deleteObject(false);
-
-        {
-            if ( justCoalesce ) {
-                orig->Coalesce (threshold * size);
-            } else {
-                orig->ConvertEvenLines (threshold * size);
-                orig->Simplify (threshold * size);
-            }
-        }
-
-        {
-            SPRepr *repr = sp_repr_new ("path");
-
-            sp_repr_set_attr (repr, "style", style);
-
-            gchar *str = orig->svg_dump_path ();
-            sp_repr_set_attr (repr, "d", str);
-            g_free (str);
-
-            // restore id
-            sp_repr_set_attr (repr, "id", id);
-
-            // add the new repr to the parent
-            sp_repr_append_child (parent, repr);
-
-            // move to the saved position 
-            sp_repr_set_position_absolute (repr, pos > 0 ? pos : 0);
-
-            SPItem *newitem = (SPItem *) SP_DT_DOCUMENT (desktop)->getObjectByRepr(repr);
-
-            // reapply the transform
-            sp_item_write_transform (newitem, repr, transform);
-
-            selection->addRepr (repr);
-
-            sp_repr_unref (repr);
-        }
+        didSomething |= sp_selected_path_simplify_item(desktop, selection, item,
+                           threshold, justCoalesce, angleLimit, breakableAngles, size, true);
     }
+        
 
-    if (did) {
+    if (didSomething)
         sp_document_done (SP_DT_DOCUMENT (desktop));
-    } else {
+    else
         desktop->messageStack()->flash(Inkscape::ERROR_MESSAGE, _("<b>No paths</b> to simplify in the selection."));
-        return;
+
+}
+
+
+// globals for keeping track of accelerated simplify
+static double previousTime      = 0.0;
+static gdouble simplifyMultiply = 1.0;
+
+void
+sp_selected_path_simplify (void)
+{
+    gdouble simplifyThreshold =
+        prefs_get_double_attribute ("options.simplifythreshold","value", 0.003);
+    bool simplifyJustCoalesce = 
+        (bool) prefs_get_int_attribute ("options.simplifyjustcoalesce","value", 0);
+
+    //Get the current time
+    GTimeVal currentTimeVal;
+    g_get_current_time (&currentTimeVal);
+    double currentTime = currentTimeVal.tv_sec * 1000000 +
+                currentTimeVal.tv_usec;
+
+    //Was the previous call to this function recent? (<0.5 sec)
+    if (previousTime > 0.0 && currentTime - previousTime < 500000.0) { 
+
+        // add to the threshold 1/2 of its original value
+        simplifyMultiply  += 0.5;
+        simplifyThreshold *= simplifyMultiply;
+
+    } else {
+        // reset to the default
+        simplifyMultiply = 1;
     }
+
+    //remember time for next call
+    previousTime = currentTime;
+
+    //g_print ("%g\n", simplify_threshold);
+
+    //Make the actual call
+    sp_selected_path_simplify_selection(simplifyThreshold,
+                      simplifyJustCoalesce, 0.0, false);
 }
 
 
 
 // fonctions utilitaires
-SPRepr *
-AncetreFils (SPRepr * a, SPRepr * d)
-{
-    if (a == NULL || d == NULL)
-        return NULL;
-    if (sp_repr_parent (a) == d)
-        return a;
-    return AncetreFils (sp_repr_parent (a), d);
-}
 
 bool
 Ancetre (SPRepr * a, SPRepr * who)
@@ -1440,28 +1498,6 @@ Ancetre (SPRepr * a, SPRepr * who)
     return Ancetre (sp_repr_parent (a), who);
 }
 
-namespace {
-
-bool same_repr(SPRepr &a, SPRepr &b) {
-    return &a == &b;
-}
-
-}
-
-SPRepr *
-LCA (SPRepr * a, SPRepr * b)
-{
-    using Inkscape::Algorithms::longest_common_suffix;
-    SPRepr *ancestor=longest_common_suffix<SPReprParentIterator>(
-        a, b, NULL, &same_repr
-    );
-    if ( ancestor && SP_REPR_TYPE(ancestor) != SP_XML_DOCUMENT_NODE ) {
-        return ancestor;
-    } else {
-        return NULL;
-    }
-}
-
 Path *
 Path_for_item (SPItem * item, bool doTransformation, bool transformFull)
 {
@@ -1491,7 +1527,7 @@ Path_for_item (SPItem * item, bool doTransformation, bool transformFull)
   
     if ( doTransformation ) {
         if (transformFull)
-            bpath = nr_artpath_affine (curve->bpath, sp_item_i2root_affine (item));
+            bpath = nr_artpath_affine (curve->bpath, sp_item_i2doc_affine (item));
         else 
             bpath = nr_artpath_affine (curve->bpath, item->transform);
         sp_curve_unref (curve);
