@@ -40,7 +40,7 @@
 #include "pixmaps/cursor-star.xpm"
 #include "sp-desktop-widget.h"
 #include "sp-metrics.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "prefs-utils.h"
 #include "knotholder.h"
 #include "xml/repr.h"
@@ -173,15 +173,10 @@ static void shape_event_attr_changed (SPRepr * repr, const gchar * name, const g
 }
 
 static SPReprEventVector shape_repr_events = {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     shape_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
@@ -312,7 +307,7 @@ sp_star_context_root_handler (SPEventContext * event_context, GdkEvent * event)
             /* Snap center to nearest magnetic point */
             namedview_free_snap (event_context->desktop->namedview, Snapper::SNAP_POINT, sc->center);
             sp_canvas_item_grab (SP_CANVAS_ITEM (desktop->acetate),
-                                 GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
+                                 GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
                                  NULL, event->button.time);
             ret = TRUE;
         }
@@ -443,7 +438,7 @@ sp_star_drag(SPStarContext *sc, NR::Point p, guint state)
         }
 
         /* Create object */
-        SPRepr *repr = sp_repr_new ("path");
+        SPRepr *repr = sp_repr_new ("svg:path");
         sp_repr_set_attr (repr, "sodipodi:type", "star");
 
         /* Set style */
@@ -474,7 +469,7 @@ sp_star_drag(SPStarContext *sc, NR::Point p, guint state)
                          arg1, arg1 + M_PI / sides, sc->isflatsided, sc->rounded, sc->randomized);
 
     /* status text */
-    GString *rads = SP_PT_TO_METRIC_STRING (r1, SP_DEFAULT_METRIC);
+    GString *rads = SP_PX_TO_METRIC_STRING(r1, sp_desktop_get_default_metric(desktop));
     sc->_message_context->setF(Inkscape::NORMAL_MESSAGE,
                                       ( sc->isflatsided?
                                       _("<b>Polygon</b>: radius %s, angle %5g; with <b>Ctrl</b> to snap angle")
