@@ -14,8 +14,10 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
+#include <sigc++/sigc++.h>
 #include "event-context.h"
-#include "knotholder.h"
+#include "libnr/nr-point.h"
+struct SPKnotHolder;
 
 #define SP_TYPE_STAR_CONTEXT (sp_star_context_get_type ())
 #define SP_STAR_CONTEXT(obj) (GTK_CHECK_CAST ((obj), SP_TYPE_STAR_CONTEXT, SPStarContext))
@@ -23,11 +25,10 @@
 #define SP_IS_STAR_CONTEXT(obj) (GTK_CHECK_TYPE ((obj), SP_TYPE_STAR_CONTEXT))
 #define SP_IS_STAR_CONTEXT_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), SP_TYPE_STAR_CONTEXT))
 
-typedef struct _SPStarContext SPStarContext;
-typedef struct _SPStarContextClass SPStarContextClass;
+class SPStarContext;
+class SPStarContextClass;
 
-struct _SPStarContext {
-	SPEventContext event_context;
+struct SPStarContext : public SPEventContext {
 	SPItem *item;
 	NR::Point center;
 
@@ -37,20 +38,23 @@ struct _SPStarContext {
 	gdouble proportion;
 	/* flat sides or not? */
 	bool isflatsided;
+	/* rounded corners ratio */
+	gdouble rounded;
+	// randomization
+	gdouble randomized;
 
     SPKnotHolder *knot_holder;
     SPRepr *repr;
 
+    sigc::connection sel_changed_connection;
 
+	Inkscape::MessageContext *_message_context;
 };
 
-struct _SPStarContextClass {
+struct SPStarContextClass {
 	SPEventContextClass parent_class;
 };
 
 GtkType sp_star_context_get_type (void);
 
-
- GtkWidget *sp_star_context_config_widget (SPDesktop *desktop);
-
 #endif
