@@ -28,7 +28,7 @@ namespace Inkscape {
  */
 gchar *parse_css_url(const gchar *string);
 
-};
+}  // namespace Inkscape
 
 class SPIFloat;
 class SPIScale24;
@@ -196,6 +196,9 @@ struct SPStyle {
 	/** display */
 	SPIEnum display;
 
+	/* overflow */
+	SPIEnum overflow;
+
 	/* visibility */
 	SPIEnum visibility;
 
@@ -225,6 +228,7 @@ struct SPStyle {
 	/** stroke-dash* */
 	NRVpathDash stroke_dash;
 	unsigned int stroke_dasharray_set : 1;
+	unsigned int stroke_dasharray_inherit : 1;
 	unsigned int stroke_dashoffset_set : 1;
 	/** stroke-opacity */
 	SPIScale24 stroke_opacity;
@@ -287,12 +291,12 @@ void sp_style_merge_from_parent (SPStyle *style, SPStyle *parent);
 /**
  *
  */
-gchar *sp_style_write_string (SPStyle *style, guint flags = SP_STYLE_FLAG_IFSET);
+gchar *sp_style_write_string(SPStyle const *style, guint flags = SP_STYLE_FLAG_IFSET);
 
 /**
  *
  */
-gchar *sp_style_write_difference (SPStyle *from, SPStyle *to);
+gchar *sp_style_write_difference(SPStyle const *from, SPStyle const *to);
 
 /**
  *
@@ -347,7 +351,7 @@ enum SPCSSFontWeight {
 	SP_CSS_FONT_WEIGHT_NORMAL,
 	SP_CSS_FONT_WEIGHT_BOLD,
 	SP_CSS_FONT_WEIGHT_LIGHTER,
-	SP_CSS_FONT_WEIGHT_DARKER
+	SP_CSS_FONT_WEIGHT_BOLDER
 };
 
 enum SPCSSFontStretch {
@@ -382,10 +386,32 @@ enum SPVisibility {
 	SP_CSS_VISIBILITY_VISIBLE
 };
 
+enum SPOverflow {
+	SP_CSS_OVERFLOW_VISIBLE,
+	SP_CSS_OVERFLOW_HIDDEN,
+	SP_CSS_OVERFLOW_SCROLL,
+	SP_CSS_OVERFLOW_AUTO
+};
+
 // TODO: more display types
 enum SPCSSDisplay {
+	SP_CSS_DISPLAY_NONE,
+	SP_CSS_DISPLAY_INLINE,
 	SP_CSS_DISPLAY_BLOCK,
-	SP_CSS_DISPLAY_NONE
+	SP_CSS_DISPLAY_LIST_ITEM,
+	SP_CSS_DISPLAY_RUN_IN,
+	SP_CSS_DISPLAY_COMPACT,
+	SP_CSS_DISPLAY_MARKER,
+	SP_CSS_DISPLAY_TABLE,
+	SP_CSS_DISPLAY_INLINE_TABLE,
+	SP_CSS_DISPLAY_TABLE_ROW_GROUP,
+	SP_CSS_DISPLAY_TABLE_HEADER_GROUP,
+	SP_CSS_DISPLAY_TABLE_FOOTER_GROUP,
+	SP_CSS_DISPLAY_TABLE_ROW,
+	SP_CSS_DISPLAY_TABLE_COLUMN_GROUP,
+	SP_CSS_DISPLAY_TABLE_COLUMN,
+	SP_CSS_DISPLAY_TABLE_CELL,
+	SP_CSS_DISPLAY_TABLE_CAPTION
 };
 
 struct SPTextStyle {
@@ -411,7 +437,11 @@ struct SPTextStyle {
 	unsigned int text_decoration : 3;
 	unsigned int unicode_bidi : 2;
 
+	unsigned int letterspacing_normal : 1;
 	SPILength letterspacing;
+
+	unsigned int wordspacing_normal : 1;
+	SPILength wordspacing;
 };
 
 SPCSSAttr * sp_css_attr_from_style (SPObject *object, guint flags = SP_STYLE_FLAG_IFSET);
