@@ -157,7 +157,7 @@ sp_svg_view_set_document (SPView *view, SPDocument *doc)
 
 	if (doc) {
 		NRArenaItem *ai = sp_item_invoke_show (SP_ITEM (sp_document_root (doc)), SP_CANVAS_ARENA (svgview->drawing)->arena,
-					  svgview->dkey, SP_ITEM_SHOW_PRINT);
+					  svgview->dkey, SP_ITEM_SHOW_DISPLAY);
 		if (ai) {
 			nr_arena_item_add_child (SP_CANVAS_ARENA (svgview->drawing)->root, ai, NULL);
 			nr_arena_item_unref (ai);
@@ -227,8 +227,8 @@ sp_svg_view_rescale (SPSVGView *svgview, gboolean event)
 
 	if (svgview->rescale) {
 		gdouble hscale, vscale;
-		hscale = svgview->width / (sp_document_width (doc) * 1.25);
-		vscale = svgview->height / (sp_document_height (doc) * 1.25);
+		hscale = svgview->width / sp_document_width (doc);
+		vscale = svgview->height / sp_document_height (doc);
 		if (svgview->keepaspect) {
 			if (hscale > vscale) {
 				hscale = vscale;
@@ -246,8 +246,8 @@ sp_svg_view_rescale (SPSVGView *svgview, gboolean event)
 
 	if (event) {
 		sp_view_emit_resized (SP_VIEW (svgview),
-				      sp_document_width (doc) * 1.25 * svgview->hscale,
-				      sp_document_height (doc) * 1.25 * svgview->vscale);
+				      sp_document_width (doc) * svgview->hscale,
+				      sp_document_height (doc) * svgview->vscale);
 	}
 }
 
@@ -367,8 +367,8 @@ sp_svg_view_widget_size_request (GtkWidget *widget, GtkRequisition *req)
 		gdouble width, height;
 
 		svgv = SP_SVG_VIEW (v);
-		width = sp_document_width (v->doc) * 1.25 * svgv->hscale;
-		height = sp_document_height (v->doc) * 1.25 * svgv->vscale;
+		width = sp_document_width (v->doc) * svgv->hscale;
+		height = sp_document_height (v->doc) * svgv->vscale;
 
 		if (width <= vw->maxwidth) {
 			hpol = GTK_POLICY_NEVER;
