@@ -20,35 +20,16 @@
 
 #include "svg.h"
 #include "stringstream.h"
+#include "../unit-constants.h"
 
 #include <glib.h>
 
+static unsigned sp_svg_length_read_lff(gchar const *str, SPSVGLengthUnit *unit, float *val, float *computed, char **next);
+
 #ifndef MAX
 #define MAX(a,b) ((a < b) ? (b) : (a))
 #endif
 
-unsigned int
-sp_svg_boolean_read (const gchar *str, unsigned int *val)
-{
-	unsigned int v;
-	char *e;
-	if (!val) return 0;
-	if (!g_strcasecmp (str, "true") || !g_strcasecmp (str, "yes")) {
-		*val = 1;
-		return 1;
-	}
-	if (!g_strcasecmp (str, "false") || !g_strcasecmp (str, "no")) {
-		*val = 0;
-		return 1;
-	}
-	v = strtoul (str, &e, 10);
-	if ((const gchar *) e != str) {
-		*val = v;
-		return 1;
-	}
-	return 0;
-}
-
 unsigned int
 sp_svg_number_read_f (const gchar *str, float *val)
 {
@@ -75,7 +56,7 @@ sp_svg_number_read_d (const gchar *str, double *val)
 	return 1;
 }
 
-unsigned int
+static unsigned
 sp_svg_number_write_i (gchar *buf, int val)
 {
 	char c[32];
@@ -96,7 +77,7 @@ sp_svg_number_write_i (gchar *buf, int val)
 	return p;
 }
 
-unsigned int
+static unsigned
 sp_svg_number_write_d (gchar *buf, double val, unsigned int tprec, unsigned int fprec, unsigned int padf)
 {
 	double dival, fval;
@@ -254,7 +235,7 @@ sp_svg_length_list_read (const gchar *str)
 
 #define UVAL(a,b) (((unsigned int) (a) << 8) | (unsigned int) (b))
 
-unsigned int
+static unsigned
 sp_svg_length_read_lff (const gchar *str, SPSVGLengthUnit *unit, float *val, float *computed, char **next)
 {
 	const gchar *e;
@@ -291,33 +272,36 @@ sp_svg_length_read_lff (const gchar *str, SPSVGLengthUnit *unit, float *val, flo
 			return 1;
 		}
 	} else if (e[1] && !g_ascii_isalnum (e[2])) {
+		/* TODO: Allow the number of px per inch to vary (document preferences, X server
+		 * or whatever).  E.g. don't fill in computed here, do it at the same time as
+		 * percentage units are done. */
 		unsigned int uval;
 		/* Units */
 		uval = UVAL (e[0], e[1]);
 		switch (uval) {
 		case UVAL('p','x'):
 			if (unit) *unit = SP_SVG_UNIT_PX;
-			if (computed) *computed = v * 1.0;
+			if (computed) *computed = v;
 			break;
 		case UVAL('p','t'):
 			if (unit) *unit = SP_SVG_UNIT_PT;
-			if (computed) *computed = v * 1.25;
+			if (computed) *computed = v * PX_PER_PT;
 			break;
 		case UVAL('p','c'):
 			if (unit) *unit = SP_SVG_UNIT_PC;
-			if (computed) *computed = v * 15.0;
+			if (computed) *computed = v * 12 * PX_PER_PT;
 			break;
 		case UVAL('m','m'):
 			if (unit) *unit = SP_SVG_UNIT_MM;
-			if (computed) *computed = v * 3.543307;
+			if (computed) *computed = v * PX_PER_MM;
 			break;
 		case UVAL('c','m'):
 			if (unit) *unit = SP_SVG_UNIT_CM;
-			if (computed) *computed = v * 35.43307;
+			if (computed) *computed = v * PX_PER_CM;
 			break;
 		case UVAL('i','n'):
 			if (unit) *unit = SP_SVG_UNIT_IN;
-			if (computed) *computed = v * 90.0;
+			if (computed) *computed = v * PX_PER_IN;
 			break;
 		case UVAL('e','m'):
 			if (unit) *unit = SP_SVG_UNIT_EM;
@@ -342,8 +326,10 @@ sp_svg_length_read_lff (const gchar *str, SPSVGLengthUnit *unit, float *val, flo
 unsigned int sp_svg_length_read_ldd (const gchar *str, SPSVGLengthUnit *unit, double *value, double *computed) {
 	float a, b;
 	unsigned int r = sp_svg_length_read_lff (str, unit, &a, &b, NULL);
-	if(value) *value = a;
-	if(computed) *computed = b;
+	if (r) {
+		if(value) *value = a;
+		if(computed) *computed = b;
+	}
 	return r;
 }
 
@@ -395,11 +381,3 @@ sp_svg_read_percentage (const char * str, double def)
 	return v;
 }
 
-int
-sp_svg_write_percentage (char * buf, int buflen, double val)
-{
-	Inkscape::SVGOStringStream os;
-       os << val * 100.0 << "%";
-	return g_strlcpy (buf, os.str().c_str(), buflen);
-}
-
