@@ -28,7 +28,7 @@
 
 #include <math.h>
 #include <string.h>
-#include <libart_lgpl/art_misc.h>
+#include "libnr/n-art-bpath.h"
 #include "gnome-canvas-bpath-util.h"
 #include "svg.h"
 #include "stringstream.h"
@@ -56,9 +56,7 @@
 #define rsvg_bpath_def_curveto gnome_canvas_bpath_def_curveto
 #define rsvg_bpath_def_closepath gnome_canvas_bpath_def_closepath
 
-typedef struct _RSVGParsePathCtx RSVGParsePathCtx;
-
-struct _RSVGParsePathCtx {
+struct RSVGParsePathCtx {
     GnomeCanvasBpathDef *bpath;
     double cpx, cpy;  /* current point */
     double rpx, rpy;  /* reflection point (for 's' and 't' commands) */
@@ -369,8 +367,8 @@ static void rsvg_parse_path_do_cmd(RSVGParsePathCtx *ctx, gboolean final)
 #endif
             rsvg_bpath_def_curveto(ctx->bpath,
                                    x1, y1, x2, y2, x3, y3);
-            ctx->rpx = x2;
-            ctx->rpy = y2;
+            ctx->rpx = ctx->params[0];
+            ctx->rpy = ctx->params[1];
             ctx->cpx = x3;
             ctx->cpy = y3;
             ctx->param = 0;
@@ -601,10 +599,10 @@ static void rsvg_parse_path_data(RSVGParsePathCtx *ctx, const char *data)
 }
 
 
-ArtBpath *sp_svg_read_path(gchar const *str)
+NArtBpath *sp_svg_read_path(gchar const *str)
 {
     RSVGParsePathCtx ctx;
-    ArtBpath *bpath;
+    NArtBpath *bpath;
 
     ctx.bpath = gnome_canvas_bpath_def_new ();
     ctx.cpx = 0.0;
@@ -620,42 +618,42 @@ ArtBpath *sp_svg_read_path(gchar const *str)
 
     gnome_canvas_bpath_def_art_finish (ctx.bpath);
 
-    bpath = art_new (ArtBpath, ctx.bpath->n_bpath);
-    memcpy (bpath, ctx.bpath->bpath, ctx.bpath->n_bpath * sizeof (ArtBpath));
-    g_assert ((bpath + ctx.bpath->n_bpath - 1)->code == ART_END);
+    bpath = g_new (NArtBpath, ctx.bpath->n_bpath);
+    memcpy (bpath, ctx.bpath->bpath, ctx.bpath->n_bpath * sizeof (NArtBpath));
+    g_assert ((bpath + ctx.bpath->n_bpath - 1)->code == NR_END);
     gnome_canvas_bpath_def_unref (ctx.bpath);
 
     return bpath;
 }
 
-gchar *sp_svg_write_path(ArtBpath const *bpath)
+gchar *sp_svg_write_path(NArtBpath const *bpath)
 {
     Inkscape::SVGOStringStream os;
     bool closed=false;
     
     g_return_val_if_fail (bpath != NULL, NULL);
 
-    for (int i = 0; bpath[i].code != ART_END; i++){
+    for (int i = 0; bpath[i].code != NR_END; i++){
         if (i) {
             os << " ";
         }
         switch (bpath [i].code){
-        case ART_LINETO:
+        case NR_LINETO:
             os << "L " << bpath[i].x3 << "," << bpath[i].y3;
             break;
 
-        case ART_CURVETO:
+        case NR_CURVETO:
             os << "C " << bpath[i].x1 << "," << bpath[i].y1
                << " "  << bpath[i].x2 << "," << bpath[i].y2
                << " "  << bpath[i].x3 << "," << bpath[i].y3;
             break;
 
-        case ART_MOVETO_OPEN:
-        case ART_MOVETO:
+        case NR_MOVETO_OPEN:
+        case NR_MOVETO:
             if (closed) {
                 os << "z ";
             }
-            closed = ( bpath[i].code == ART_MOVETO );
+            closed = ( bpath[i].code == NR_MOVETO );
             os << "M " << bpath[i].x3 << "," << bpath[i].y3;
             break;
         default:
