@@ -57,7 +57,7 @@
 #include "nodepath.h"
 #include "xml/sp-repr-event-vector.h"
 #include "helper/gnome-utils.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/unit-menu.h"
 #include "helper/units.h"
 
@@ -1038,15 +1038,10 @@ static void star_tb_event_attr_changed (SPRepr * repr, const gchar * name, const
 
 static SPReprEventVector star_tb_repr_events =
 {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     star_tb_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
@@ -1268,7 +1263,7 @@ sp_rtb_rxry_value_changed (GtkAdjustment *adj, SPWidget *tbl, const gchar* value
     const SPUnit *unit = sp_unit_selector_get_unit (SP_UNIT_SELECTOR (us));
 
     if (sp_document_get_undo_sensitive (SP_DT_DOCUMENT(desktop))) {
-        prefs_set_double_attribute ("tools.shapes.rect", value_name, sp_units_get_points (adj->value, unit));
+        prefs_set_double_attribute ("tools.shapes.rect", value_name, sp_units_get_pixels (adj->value, *unit));
     }
 
     // quit if run by the attr_changed listener
@@ -1284,7 +1279,7 @@ sp_rtb_rxry_value_changed (GtkAdjustment *adj, SPWidget *tbl, const gchar* value
         for (const GSList *items = selection->itemList(); items != NULL; items = items->next) {
         if (SP_IS_RECT (items->data)) {
             if (adj->value != 0) {
-                setter (SP_RECT (items->data), sp_units_get_points (adj->value, unit));
+                setter (SP_RECT (items->data), sp_units_get_pixels (adj->value, *unit));
             } else {
                 sp_repr_set_attr (SP_OBJECT_REPR (items->data), value_name, NULL);
             }
@@ -1353,13 +1348,13 @@ static void rect_tb_event_attr_changed (SPRepr * repr, const gchar * name, const
         {
             GtkAdjustment *adj = (GtkAdjustment*)gtk_object_get_data (GTK_OBJECT (tbl), "rx");
             gdouble rx = sp_rect_get_visible_rx (SP_RECT (item));
-            gtk_adjustment_set_value(adj, sp_points_get_units(rx, unit));
+            gtk_adjustment_set_value(adj, sp_pixels_get_units (rx, *unit));
         }
 
         {
             GtkAdjustment *adj = (GtkAdjustment*)gtk_object_get_data (GTK_OBJECT (tbl), "ry");
             gdouble ry = sp_rect_get_visible_ry (SP_RECT (item));
-            gtk_adjustment_set_value(adj, sp_points_get_units(ry, unit));
+            gtk_adjustment_set_value(adj, sp_pixels_get_units (ry, *unit));
         }
     }
 
@@ -1368,15 +1363,10 @@ static void rect_tb_event_attr_changed (SPRepr * repr, const gchar * name, const
 
 
 static SPReprEventVector rect_tb_repr_events = {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     rect_tb_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
@@ -1442,9 +1432,10 @@ sp_rect_toolbox_new (SPDesktop *desktop)
     sp_toolbox_add_label(tbl, _("<b>New:</b>"));
 
     // rx/ry units menu: create
-    GtkWidget *us = sp_unit_selector_new (SP_UNIT_ABSOLUTE);
+    GtkWidget *us = sp_unit_selector_new (SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE);
     sp_unit_selector_setsize (us, AUX_OPTION_MENU_WIDTH, AUX_OPTION_MENU_HEIGHT);
-    // fixme: add %
+    sp_unit_selector_set_unit (SP_UNIT_SELECTOR(us), sp_desktop_get_default_unit (desktop));
+    // fixme: add % meaning per cent of the width/height
 
     /* rx */
     {
@@ -1613,15 +1604,10 @@ static void spiral_tb_event_attr_changed (SPRepr * repr, const gchar * name, con
 
 
 static SPReprEventVector spiral_tb_repr_events = {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     spiral_tb_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
@@ -2103,15 +2089,10 @@ static void arc_tb_event_attr_changed (SPRepr * repr, const gchar * name, const
 }
 
 static SPReprEventVector arc_tb_repr_events = {
-    NULL, /* add_child */
     NULL, /* child_added */
-    NULL, /* remove_child */
     NULL, /* child_removed */
-    NULL, /* change_attr */
     arc_tb_event_attr_changed,
-    NULL, /* change_list */
     NULL, /* content_changed */
-    NULL, /* change_order */
     NULL  /* order_changed */
 };
 
