@@ -5,10 +5,10 @@
 
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <file.h>
+#include "io/sys.h"
 
 /*#########################################################################
-### G R A Y M A P
+### G R A Y   M A P
 #########################################################################*/
 
 
@@ -105,7 +105,7 @@ GrayMap *GrayMapCreate(int width, int height)
 
 
 /*#########################################################################
-### I M A G E  M A P
+### R G B      M A P
 #########################################################################*/
 
 
@@ -211,6 +211,122 @@ RgbMap *RgbMapCreate(int width, int height)
 
 
 
+/*#########################################################################
+### I N D E X E D      M A P
+#########################################################################*/
+
+
+
+static void iSetPixel(IndexedMap *me, int x, int y, unsigned int index)
+{
+    unsigned int *pix = me->rows[y] + x;
+    *pix = index;
+}
+
+
+static unsigned int iGetPixel(IndexedMap *me, int x, int y)
+{
+    unsigned int *pix = me->rows[y] + x;
+    return *pix;
+}
+
+static RGB iGetPixelValue(IndexedMap *me, int x, int y)
+{
+    unsigned int *pix = me->rows[y] + x;
+    RGB rgb = me->clut[((*pix)&0xff)];
+    return rgb;
+}
+
+
+
+static int iWritePPM(IndexedMap *me, char *fileName)
+{
+    if (!fileName)
+        return FALSE;
+
+    Inkscape::IO::dump_fopen_call(fileName, "D");
+    FILE *f = Inkscape::IO::fopen_utf8name(fileName, "wb");
+    if (!f)
+        return FALSE;
+
+    fprintf(f, "P6 %d %d 255\n", me->width, me->height);
+
+    for (int y=0 ; y<me->height; y++)
+        {
+        for (int x=0 ; x<me->width ; x++)
+            {
+            RGB rgb = me->getPixelValue(me, x, y);
+            fwrite(&(rgb.r), 1, 1, f);
+            fwrite(&(rgb.g), 1, 1, f);
+            fwrite(&(rgb.b), 1, 1, f);
+            }
+        }
+    fclose(f);
+    return TRUE;
+}
+
+
+static void iDestroy(IndexedMap *me)
+{
+    if (me->pixels)
+        free(me->pixels);
+    if (me->rows)
+        free(me->rows);
+    free(me);
+}
+
+
+
+IndexedMap *IndexedMapCreate(int width, int height)
+{
+
+    IndexedMap *me = (IndexedMap *)malloc(sizeof(IndexedMap));
+    if (!me)
+        return NULL;
+
+    /** methods **/
+    me->setPixel      = iSetPixel;
+    me->getPixel      = iGetPixel;
+    me->getPixelValue = iGetPixelValue;
+    me->writePPM      = iWritePPM;
+    me->destroy       = iDestroy;
+
+
+    /** fields **/
+    me->width  = width;
+    me->height = height;
+    me->pixels = (unsigned int *) 
+              malloc(sizeof(unsigned int) * width * height);
+    me->rows = (unsigned int **) 
+              malloc(sizeof(unsigned int *) * height);
+    if (!me->pixels)
+        {
+        free(me);
+        return NULL;
+        }
+
+    unsigned int *row = me->pixels;
+    for (int i=0 ; i<height ; i++)
+        {
+        me->rows[i] = row;
+        row += width;
+        }
+        
+    me->nrColors = 0;
+    
+    RGB rgb;
+    rgb.r = rgb.g = rgb.b = 0;
+    for (int i=0; i<256 ; i++)
+        {
+        me->clut[i] = rgb;
+        }
+
+    return me;
+}
+
+
+
+
 
 
 /*#########################################################################
