@@ -21,7 +21,7 @@
 #include <desktop.h>
 #include <desktop-handles.h>
 #include <document.h>
-#include <helper/sp-intl.h>
+#include <glibmm/i18n.h>
 #include <selection.h>
 #include <sp-image.h>
 #include <sp-path.h>
@@ -30,13 +30,15 @@
 #include <xml/repr.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-namespace Inkscape
-{
+
+namespace Inkscape {
+
+namespace Trace {
 
 /**
  *
  */
-Trace::Trace()
+Tracer::Tracer()
 {
     engine = NULL;
     selectedItem = NULL;
@@ -47,13 +49,17 @@ Trace::Trace()
 /**
  *
  */
-Trace::~Trace()
+Tracer::~Tracer()
 {
 }
 
 
+
+/**
+ *
+ */
 SPImage *
-Trace::getSelectedSPImage()
+Tracer::getSelectedSPImage()
 {
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
     if (!desktop)
@@ -97,8 +103,12 @@ Trace::getSelectedSPImage()
 }
 
 
+
+/**
+ *
+ */
 GdkPixbuf *
-Trace::getSelectedImage()
+Tracer::getSelectedImage()
 {
 
     SPImage *img = getSelectedSPImage();
@@ -113,10 +123,15 @@ Trace::getSelectedImage()
 
 
 
+//#########################################################################
+//#  T R A C E
+//#########################################################################
+
+
 /**
- *  Threaded method that actually does the conversion
+ *  Threaded method that does single bitmap--->path conversion
  */
-void Trace::convertImageToPathThread()
+void Tracer::traceThread()
 {
     //## Remember. NEVER leave this method without setting
     //## engine back to NULL
@@ -164,20 +179,20 @@ void Trace::convertImageToPathThread()
         return;
         }
 
-    char *d = engine->getPathDataFromPixbuf(pixbuf);
-
-    //## EXAMPLE:  Check if we should stop
-    if (!keepGoing)
+    int nrPaths;
+    TracingEngineResult *results = engine->trace(pixbuf, &nrPaths);
+    //printf("nrPaths:%d\n", nrPaths);
+    
+    //### Check if we should stop
+    if (!keepGoing || !results || nrPaths<1)
         {
         engine = NULL;
         return;
         }
 
-
-    SPRepr *pathRepr    = sp_repr_new("path");
-    SPRepr *imgRepr     = SP_OBJECT(img)->repr;
-    sp_repr_set_attr(pathRepr, "d", d);
-    sp_repr_set_attr(pathRepr, "d", d);
+    //### Get pointers to the <image> and its parent
+    SPRepr *imgRepr   = SP_OBJECT(img)->repr;
+    SPRepr *par       = sp_repr_parent(imgRepr);
 
     //### Get some information for the new transform()
     double x      = 0.0;
@@ -212,26 +227,54 @@ void Trace::convertImageToPathThread()
     tf *= selectedItem->transform;
 
 
-    //#Add to tree
-    SPRepr *par = sp_repr_parent(imgRepr);
-    sp_repr_add_child(par, pathRepr, imgRepr);
+    //#OK.  Now let's start making new nodes
 
-    free(d);
+    SPRepr *groupRepr = NULL;
 
-    //### Apply the transform from the image to the new shape
-    SPObject *reprobj = doc->getObjectByRepr(pathRepr);
-    if (reprobj)
+    //# if more than 1, make a <g>roup of <path>s
+    if (nrPaths > 1)
         {
-        SPItem *newItem = SP_ITEM(reprobj);
-        sp_item_write_transform(newItem, pathRepr, tf, NULL);
+        groupRepr = sp_repr_new("svg:g");
+        sp_repr_add_child(par, groupRepr, imgRepr);
         }
 
-    // Select the new path
-    selection->clear();
-    selection->addRepr(pathRepr);
+    for (TracingEngineResult *result=results ;
+                  result ; result=result->next)
+        {
+        SPRepr *pathRepr = sp_repr_new("svg:path");
+        sp_repr_set_attr(pathRepr, "style", result->getStyle());
+        sp_repr_set_attr(pathRepr, "d",     result->getPathData());
 
-    // Clean up
-    sp_repr_unref (pathRepr);
+        if (nrPaths > 1)
+            sp_repr_add_child(groupRepr, pathRepr, NULL);
+        else
+            sp_repr_add_child(par, pathRepr, imgRepr);
+
+        //### Apply the transform from the image to the new shape
+        SPObject *reprobj = doc->getObjectByRepr(pathRepr);
+        if (reprobj)
+            {
+            SPItem *newItem = SP_ITEM(reprobj);
+            sp_item_write_transform(newItem, pathRepr, tf, NULL);
+            }
+        if (nrPaths == 1)
+            {
+            selection->clear();
+            selection->addRepr(pathRepr);
+            }
+        sp_repr_unref (pathRepr);
+        }
+
+
+    delete results;
+
+    // If we have a group, then focus on, then forget it
+    if (nrPaths > 1)
+        {
+        selection->clear();
+        selection->addRepr(groupRepr);
+        sp_repr_unref (groupRepr);
+        }
 
     //## inform the document, so we can undo
     sp_document_done(doc);
@@ -241,9 +284,9 @@ void Trace::convertImageToPathThread()
 }
 
 /**
- *  Static no-knowledge version
+ *  Main tracing method
  */
-void Trace::convertImageToPath(TracingEngine *theEngine)
+void Tracer::trace(TracingEngine *theEngine)
 {
     //Check if we are already running
     if (engine)
@@ -258,22 +301,22 @@ void Trace::convertImageToPath(TracingEngine *theEngine)
 
     //Create our thread and run it
     Glib::Thread::create(
-        sigc::mem_fun(*this, &Trace::convertImageToPathThread), false);
+        sigc::mem_fun(*this, &Tracer::traceThread), false);
 #else
-    convertImageToPathThread();
+    traceThread();
 #endif
 
 }
 
 
 
-/**
- *  Abort the thread that is executing convertImageToPath()
- */
-void Trace::abort()
-{
 
-    //g_message("Trace::abort() soon to be implemented\n");
+
+/**
+ *  Abort the thread that is executing trace()
+ */
+void Tracer::abort()
+{
 
     //## Inform Trace's working thread
     keepGoing = false;
@@ -287,28 +330,9 @@ void Trace::abort()
 
 
 
+} // namespace Trace
 
-
-
-/**
- *  Static no-knowledge version
- */
-gboolean Trace::staticConvertImageToPath()
-{
-    Trace trace;
-    Inkscape::Potrace::PotraceTracingEngine engine;
-    trace.convertImageToPath(&engine);
-    return true;
-}
-
-
-
-
-
-
-
-
-}//namespace Inkscape
+} // namespace Inkscape
 
 
 //#########################################################################
