@@ -29,7 +29,7 @@
 #include <config.h>
 
 #include "helper/action.h"
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 
 #include "dialogs/text-edit.h"
 #include "dialogs/export.h"
@@ -42,8 +42,12 @@
 #include "dialogs/item-properties.h"
 #include "dialogs/find.h"
 #include "dialogs/debugdialog.h"
+#include "dialogs/scriptdialog.h"
 #include "dialogs/tracedialog.h"
 #include "dialogs/layer-properties.h"
+#include "dialogs/clonetiler.h"
+
+#include "extension/effect.h"
 
 #include "tools-switch.h"
 #include "inkscape-private.h"
@@ -298,13 +302,16 @@ Verb::VerbTable Verb::_verbs;
     each call it is incremented.  The list of allocated verbs is kept
     in the \c _verbs hashtable which is indexed by the \c code.
 */
-Verb::Verb(gchar const * id, gchar const * name, gchar const * tip, gchar const * image)
+Verb::Verb(gchar const * id, gchar const * name, gchar const * tip, gchar const * image) :
+        _actions(NULL), _id(id), _name(name), _tip(tip), _image(image)
 {
     static int count = SP_VERB_LAST;
 
     count++;
-    Verb(count, id, name, tip, image);
+    _code = count;
     _verbs.insert(VerbTable::value_type(count, this));
+
+    return;
 }
 
 /** \brief  Destroy a verb.
@@ -471,7 +478,7 @@ TutorialVerb::make_action (SPView * view)
     the vector that is passed in.
 */
 SPAction *
-Verb::make_action_helper (SPView * view, SPActionEventVector * vector)
+Verb::make_action_helper (SPView * view, SPActionEventVector * vector, void * in_pntr)
 {
     SPAction *action;
     
@@ -480,12 +487,21 @@ Verb::make_action_helper (SPView * view, SPActionEventVector * vector)
                            _(_tip), _image, this);
 
     if (action != NULL) {
-        nr_active_object_add_listener (
-            (NRActiveObject *) action,
-            (NRObjectEventVector *) vector,
-            sizeof (SPActionEventVector),
-            reinterpret_cast<void *>(_code)
-        );
+        if (in_pntr == NULL) {
+            nr_active_object_add_listener (
+                (NRActiveObject *) action,
+                (NRObjectEventVector *) vector,
+                sizeof (SPActionEventVector),
+                reinterpret_cast<void *>(_code)
+            );
+        } else {
+            nr_active_object_add_listener (
+                (NRActiveObject *) action,
+                (NRObjectEventVector *) vector,
+                sizeof (SPActionEventVector),
+                in_pntr
+            );
+        }
     }
 
     return action;
@@ -534,6 +550,7 @@ void
 Verb::delete_view (SPView * view)
 {
     if (_actions == NULL) return;
+    if (_actions->empty()) return;
 
 #if 0
     static int count = 0;
@@ -569,9 +586,9 @@ Verb::delete_all_view (SPView * view)
 
     if (!_verbs.empty()) {
         for (VerbTable::iterator thisverb = _verbs.begin();
-             thisverb != _verbs.end();
-             thisverb = thisverb++) {
+             thisverb != _verbs.end(); thisverb++) {
             Inkscape::Verb * verbpntr = thisverb->second;
+            // std::cout << "Delete In Verb: " << verbpntr->_name << std::endl;
             verbpntr->delete_view(view);
         }
     }
@@ -728,6 +745,19 @@ EditVerb::perform (SPAction *action, void * data, void * pdata)
                 sp_edit_select_all();
             }
             break;
+        case SP_VERB_EDIT_INVERT:
+            if (tools_isactive (dt, TOOLS_NODES)) {
+                //FIXME: implement invert for nodes
+            } else {
+                sp_edit_invert();
+            }
+            break;
+        case SP_VERB_EDIT_SELECT_ALL_IN_ALL_LAYERS:
+            sp_edit_select_all_in_all_layers();
+            break;
+        case SP_VERB_EDIT_INVERT_IN_ALL_LAYERS:
+            sp_edit_invert_in_all_layers();
+            break;
         case SP_VERB_EDIT_DESELECT:
             if (tools_isactive (dt, TOOLS_NODES)) {
                 sp_nodepath_deselect (SP_NODE_CONTEXT(ec)->nodepath);
@@ -1295,9 +1325,15 @@ DialogVerb::perform (SPAction *action, void * data, void * pdata)
         case SP_VERB_DIALOG_DEBUG:
             Inkscape::UI::Dialogs::DebugDialog::showInstance();
             break;
+        case SP_VERB_DIALOG_SCRIPT:
+            Inkscape::UI::Dialogs::ScriptDialog::showInstance();
+            break;
         case SP_VERB_DIALOG_TOGGLE:
             inkscape_dialogs_toggle ();
             break;
+        case SP_VERB_DIALOG_CLONETILER:
+            clonetiler_dialog ();
+            break;
         case SP_VERB_DIALOG_ITEM:
             sp_item_dialog ();
             break;
@@ -1417,6 +1453,8 @@ SPActionEventVector DialogVerb::vector =
 SPActionEventVector HelpVerb::vector =
             {{NULL},HelpVerb::perform, NULL, NULL, NULL};
 
+
+/* *********** Effect Last ********** */
 /**
  * Action vector to define functions called if a staticly defined tutorial verb
  * is called
@@ -1424,6 +1462,70 @@ SPActionEventVector HelpVerb::vector =
 SPActionEventVector TutorialVerb::vector =
             {{NULL},TutorialVerb::perform, NULL, NULL, NULL};
 
+/** \brief A class to represent the last effect issued */
+class EffectLastVerb : public Verb {
+private:
+    static void perform (SPAction * action, void * mydata, void * otherdata);
+    static SPActionEventVector vector;
+protected:
+    virtual SPAction * make_action (SPView * view);
+public:
+    /** \brief Use the Verb initializer with the same parameters. */
+    EffectLastVerb(const unsigned int code,
+                   gchar const * id,
+                   gchar const * name,
+                   gchar const * tip,
+                   gchar const * image) :
+            Verb(code, id, name, tip, image) {
+    }
+}; /* EffectLastVerb class */
+
+/**
+ * The vector to attach in the last effect verb.
+ */
+SPActionEventVector EffectLastVerb::vector =
+            {{NULL},EffectLastVerb::perform, NULL, NULL, NULL};
+
+/** \brief  Create an action for a \c EffectLastVerb
+    \param  view  Which view the action should be created for
+    \return The built action.
+
+    Calls \c make_action_helper with the \c vector.
+*/
+SPAction *
+EffectLastVerb::make_action (SPView * view)
+{
+    return make_action_helper(view, &vector);
+}
+
+/** \brief  Decode the verb code and take appropriate action */
+void
+EffectLastVerb::perform (SPAction *action, void * data, void *pdata)
+{
+    /* These aren't used, but are here to remind people not to use
+       the CURRENT_DOCUMENT macros unless they really have to. */
+    SPView * current_view = sp_action_get_view(action);
+    // SPDocument * current_document = SP_VIEW_DOCUMENT(current_view);
+    Inkscape::Extension::Effect * effect = Inkscape::Extension::Effect::get_last_effect();
+
+    if (effect == NULL) return;
+    if (current_view == NULL) return;
+
+    switch ((long) data) {
+        case SP_VERB_EFFECT_LAST_PREF:
+            if (!effect->prefs(current_view))
+                return;
+        case SP_VERB_EFFECT_LAST:
+            effect->effect(current_view);
+            break;
+        default:
+            return;
+    }
+
+    return;
+}
+/* *********** End Effect Last ********** */
+
 /* these must be in the same order as the SP_VERB_* enum in "verbs.h" */
 Verb * Verb::_base_verbs[] = {
     /* Header */
@@ -1497,6 +1599,12 @@ Verb * Verb::_base_verbs[] = {
         N_("Delete all objects from document"), NULL),
     new EditVerb(SP_VERB_EDIT_SELECT_ALL, "EditSelectAll", N_("Select Al_l"),
         N_("Select all objects or all nodes"), "selection_select_all"),
+    new EditVerb(SP_VERB_EDIT_SELECT_ALL_IN_ALL_LAYERS, "EditSelectAllInAllLayers", N_("Select All in All Layers"),
+        N_("Select all objects in all visible and unlocked layers"), NULL),
+    new EditVerb(SP_VERB_EDIT_INVERT, "EditInvert", N_("Invert Selection"),
+        N_("Invert selection (unselect what is selected and select everything else)"), NULL),
+    new EditVerb(SP_VERB_EDIT_INVERT_IN_ALL_LAYERS, "EditInvertInAllLayers", N_("Invert in All Layers"),
+        N_("Invert selection in all visible and unlocked layers"), NULL),
     new EditVerb(SP_VERB_EDIT_DESELECT, "EditDeselect", N_("D_eselect"),
         N_("Deselect any selected objects or nodes"), NULL),
 
@@ -1588,9 +1696,9 @@ Verb * Verb::_base_verbs[] = {
         N_("Create a new layer"), NULL),
     new LayerVerb(SP_VERB_LAYER_RENAME, "LayerRename", N_("Ren_ame Layer..."),
         N_("Rename the current layer"), NULL),
-    new LayerVerb(SP_VERB_LAYER_NEXT, "LayerNext", N_("Move to Next Layer"),
+    new LayerVerb(SP_VERB_LAYER_NEXT, "LayerNext", N_("Switch to Next Layer"),
         N_("Switch to the next layer in the document"), NULL),
-    new LayerVerb(SP_VERB_LAYER_PREV, "LayerPrev", N_("Move to Previous Layer"),
+    new LayerVerb(SP_VERB_LAYER_PREV, "LayerPrev", N_("Switch to Previous Layer"),
         N_("Switch to the previous layer in the document"), NULL),
     new LayerVerb(SP_VERB_LAYER_TO_TOP, "LayerToTop", N_("Layer to _Top"),
         N_("Raise the current layer to the top"), NULL),
@@ -1613,7 +1721,7 @@ Verb * Verb::_base_verbs[] = {
     new ObjectVerb(SP_VERB_OBJECT_TO_CURVE, "ObjectToCurve", N_("_Object to Path"),
         N_("Convert selected object(s) to path(s)"), "object_tocurve"),
     new ObjectVerb(SP_VERB_OBJECT_FLOWTEXT_TO_TEXT, "ObjectFlowtextToText", N_("_Unflow Text"),
-        N_("Convert selected flowtext to text"), NULL),
+        N_("Convert selected flowed text(s) to regular text objects"), NULL),
     new ObjectVerb(SP_VERB_OBJECT_FLIP_HORIZONTAL, "ObjectFlipHorizontally",
         N_("Flip _Horizontally"), N_("Flip selection horizontally"),
         "object_flip_hor"),
@@ -1639,7 +1747,7 @@ Verb * Verb::_base_verbs[] = {
     new ContextVerb(SP_VERB_CONTEXT_PEN, "DrawPen", N_("Pen"),
         N_("Draw Bezier curves and straight lines"), "draw_pen"),
     new ContextVerb(SP_VERB_CONTEXT_CALLIGRAPHIC, "DrawCalligrphic", N_("Calligraphy"),
-        N_("Draw calligraphic lines"), "draw_dynahand"),
+        N_("Draw calligraphic lines"), "draw_calligraphic"),
     new ContextVerb(SP_VERB_CONTEXT_TEXT, "DrawText", N_("Text"),
         N_("Create and edit text objects"), "draw_text"),
     new ContextVerb(SP_VERB_CONTEXT_ZOOM, "DrawZoom", N_("Zoom"),
@@ -1726,8 +1834,13 @@ Verb * Verb::_base_verbs[] = {
         N_("Find objects in document"), GTK_STOCK_FIND ),
     new DialogVerb(SP_VERB_DIALOG_DEBUG, "DialogDebug", N_("_Messages..."),
         N_("View debug messages"), NULL),
+    new DialogVerb(SP_VERB_DIALOG_SCRIPT, "DialogScript", N_("_Scripts..."),
+        N_("Run scripts"), NULL),
     new DialogVerb(SP_VERB_DIALOG_TOGGLE, "DialogsToggle", N_("Show/_Hide Dialogs"),
         N_("Show or hide all active dialogs"), "dialog_toggle"),
+    // TRANSLATORS: "Tile clones" means: "Create tiled clones"
+    new DialogVerb(SP_VERB_DIALOG_CLONETILER, "DialogsClonetiler", N_("Tile clones..."),
+        N_("Create and arrange multiple clones of selection"), NULL),
     new DialogVerb(SP_VERB_DIALOG_ITEM, "DialogItem", N_("_Object Properties..."),
         N_("Object Properties dialog"), "dialog_item_properties"),
 
@@ -1754,12 +1867,18 @@ Verb * Verb::_base_verbs[] = {
     new TutorialVerb(SP_VERB_TUTORIAL_TIPS, "TutorialsTips", N_("_Tips and Tricks"),
         N_("Miscellaneous tips and tricks"), NULL/*"tutorial_tips"*/),
 
+    /* Effect */
+    new EffectLastVerb(SP_VERB_EFFECT_LAST, "EffectLast", N_("Previous Effect"),
+        N_("Repeat the last effect with the same settings"), NULL/*"tutorial_tips"*/),
+    new EffectLastVerb(SP_VERB_EFFECT_LAST_PREF, "EffectLastPref", N_("Previous Effect..."),
+        N_("Repeat the last effect with new settings"), NULL/*"tutorial_tips"*/),
+
     /* Footer */
     new Verb(SP_VERB_LAST, NULL, NULL, NULL, NULL)
 };
 
 
-}; /* namespace Inkscape */
+}  /* namespace Inkscape */
 
 /*
   Local Variables:
