@@ -56,6 +56,9 @@ enum {
     SP_VERB_EDIT_UNTILE,
     SP_VERB_EDIT_CLEAR_ALL,
     SP_VERB_EDIT_SELECT_ALL,
+    SP_VERB_EDIT_SELECT_ALL_IN_ALL_LAYERS,
+    SP_VERB_EDIT_INVERT,
+    SP_VERB_EDIT_INVERT_IN_ALL_LAYERS,
     SP_VERB_EDIT_DESELECT,
     /* Selection */
     SP_VERB_SELECTION_TO_FRONT,
@@ -164,7 +167,9 @@ enum {
     SP_VERB_DIALOG_XML_EDITOR,
     SP_VERB_DIALOG_FIND,
     SP_VERB_DIALOG_DEBUG,
+    SP_VERB_DIALOG_SCRIPT,
     SP_VERB_DIALOG_TOGGLE,
+    SP_VERB_DIALOG_CLONETILER,
     SP_VERB_DIALOG_ITEM,
     /* Help */
     SP_VERB_HELP_KEYS,
@@ -177,6 +182,9 @@ enum {
     SP_VERB_TUTORIAL_CALLIGRAPHY,
     SP_VERB_TUTORIAL_DESIGN,
     SP_VERB_TUTORIAL_TIPS,
+    /* Effects */
+    SP_VERB_EFFECT_LAST,
+    SP_VERB_EFFECT_LAST_PREF,
     /* Footer */
     SP_VERB_LAST
 };
@@ -206,7 +214,7 @@ public:
 };
 
 #if defined(__GNUG__) && (__GNUG__ >= 3)
-}; /* namespace __gnu_cxx */
+}  /* namespace __gnu_cxx */
 #endif
 
 namespace Inkscape {
@@ -252,7 +260,7 @@ public:
     gchar const * get_id (void) { return _id; }
 
 protected:
-    SPAction * make_action_helper (SPView * view, SPActionEventVector * vector);
+    SPAction * make_action_helper (SPView * view, SPActionEventVector * vector, void * in_pntr = NULL);
     virtual SPAction * make_action (SPView * view);
 
 public:
@@ -265,14 +273,15 @@ public:
 
         This function also sets \c _actions to NULL.
 
-        \warning NO DATA IS COPIED BY CALLING THIS FUNCTION.  In many
-        respects this is very bad object oriented design, but it is done
-        for a reason.  All verbs today are of two types: 1) static or
-        2) created for extension.  In the static case all of the strings
-        are constants in the code, and thus don't really need to be copied.
-        In the extensions case the strings are identical to the ones
-        already created in the extension object, copying them would be
-        a waste of memory.
+        \warning NO DATA IS COPIED BY CALLING THIS FUNCTION.
+        
+        In many respects this is very bad object oriented design, but it
+        is done for a reason.  All verbs today are of two types: 1) static
+        or 2) created for extension.  In the static case all of the
+        strings are constants in the code, and thus don't really need to
+        be copied.  In the extensions case the strings are identical to
+        the ones already created in the extension object, copying them
+        would be a waste of memory.
     */
     Verb(const unsigned int code,
          gchar const * id,
@@ -312,7 +321,7 @@ public:
 }; /* Verb class */
 
 
-}; /* Inkscape namespace */
+}  /* Inkscape namespace */
 
 #endif
 
