@@ -22,8 +22,7 @@
 #include <libnr/nr-macros.h>
 #include <gtk/gtk.h>
 
-#include "helper/sp-intl.h"
-#include "../xml/repr-private.h"
+#include <glibmm/i18n.h>
 #include "../style.h"
 #include "../dialogs/dialog-events.h"
 
@@ -132,7 +131,7 @@ sp_dash_selector_new (SPRepr *drepr)
 	if (!dashes) {
 		int ndashes = 0;
 		if (drepr) {
-			for (SPRepr *dr = drepr->children; dr; dr = dr->next) {
+			for (SPRepr *dr = drepr->firstChild(); dr; dr = dr->next()) {
 				if (!strcmp (sp_repr_name (dr), "dash"))
 					ndashes += 1;
 			}
@@ -142,7 +141,7 @@ sp_dash_selector_new (SPRepr *drepr)
 			int pos = 0;
 			SPStyle *style = sp_style_new ();
 			dashes = g_new (double *, ndashes + 1);
-			for (SPRepr *dr = drepr->children; dr; dr = dr->next) {
+			for (SPRepr *dr = drepr->firstChild(); dr; dr = dr->next()) {
 				if (!strcmp (sp_repr_name (dr), "dash")) {
 					sp_style_read_from_repr (style, dr);
 					if (style->stroke_dash.n_dash > 0) {
