@@ -16,9 +16,6 @@
 
 
 
-typedef struct _SPMenu SPMenu;
-typedef struct _SPMenuClass SPMenuClass;
-
 #define SP_TYPE_MENU (sp_menu_get_type ())
 #define SP_MENU(o) (GTK_CHECK_CAST ((o), SP_TYPE_MENU, SPMenu))
 #define SP_IS_MENU(o) (GTK_CHECK_TYPE ((o), SP_TYPE_MENU))
@@ -26,7 +23,7 @@ typedef struct _SPMenuClass SPMenuClass;
 #include <gtk/gtkmenu.h>
 #include <gtk/gtktooltips.h>
 
-struct _SPMenu {
+struct SPMenu {
 	GtkMenu menu;
 
 	gpointer activedata;
@@ -34,7 +31,7 @@ struct _SPMenu {
 	GtkTooltips *tt;
 };
 
-struct _SPMenuClass {
+struct SPMenuClass {
 	GtkMenuClass parent_class;
 
 	void (* selected) (SPMenu *menu, gpointer itemdata);
