@@ -4,7 +4,7 @@
 #include <stdlib.h>
 #include <gtk/gtk.h>
 #include "../color.h"
-#include "../helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "../dialogs/dialog-events.h"
 #include "sp-color-preview.h"
 #include "sp-color-scales.h"
