@@ -33,7 +33,7 @@
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtkframe.h>
  
-#include "helper/sp-intl.h"
+#include <glibmm/i18n.h>
 #include "helper/window.h"
 #include "widgets/button.h"
 #include "inkscape.h"
@@ -164,7 +164,7 @@ spw_dropdown(GtkWidget * dialog, GtkWidget * table,
 GtkWidget *
 spw_unit_selector(GtkWidget * dialog, GtkWidget * table,
 		  const gchar * label_text, gchar * key, int row,
-		  GtkWidget * us, GCallback cb)
+		GtkWidget * us, GCallback cb, bool can_be_negative)
 {
   GtkWidget * sb;
   GtkObject * a;
@@ -175,13 +175,13 @@ spw_unit_selector(GtkWidget * dialog, GtkWidget * table,
 
   spw_label(table, label_text, 0, row);
 
-  a = gtk_adjustment_new (0.0, -1e6, 1e6, 1.0, 10.0, 10.0);
+  a = gtk_adjustment_new (0.0, can_be_negative?-1e6:0, 1e6, 1.0, 10.0, 10.0);
   g_assert(a != NULL);
   gtk_object_set_data (GTK_OBJECT (a), "key", key);
   gtk_object_set_data (GTK_OBJECT (a), "unit_selector", us);
   gtk_object_set_data (GTK_OBJECT (dialog), key, a);
   sp_unit_selector_add_adjustment (SP_UNIT_SELECTOR (us), GTK_ADJUSTMENT (a));
-  sb = gtk_spin_button_new (GTK_ADJUSTMENT (a), 1.0, 2);
+  sb = gtk_spin_button_new (GTK_ADJUSTMENT (a), 1.0, 4);
   g_assert(sb != NULL);
   gtk_widget_show (sb);
   gtk_table_attach (GTK_TABLE (table), sb, 1, 2, row, row+1, 
