@@ -6,16 +6,19 @@
 
 #include <glib.h>
 
-#include "repr.h"
-#include "repr-private.h"
-#include <xml/sp-repr-attr.h>
+#include "xml/repr.h"
+#include "xml/sp-repr-attr.h"
+#include "xml/sp-css-attr.h"
+#include "xml/simple-node.h"
 
-struct SPCSSAttr : public SPRepr {
+struct SPCSSAttrImpl : public Inkscape::XML::SimpleNode, public SPCSSAttr {
 public:
-	SPCSSAttr() : SPRepr(SP_XML_ELEMENT_NODE, g_quark_from_static_string("css")) {}
+	SPCSSAttrImpl() : SimpleNode(g_quark_from_static_string("css")) {}
+
+	SPReprType type() const { return SP_XML_ELEMENT_NODE; }
 
 protected:
-	SPRepr *_duplicate() const { return new SPCSSAttr(*this); }
+	SimpleNode *_duplicate() const { return new SPCSSAttrImpl(*this); }
 };
 
 static void sp_repr_css_add_components (SPCSSAttr * css, SPRepr * repr, const gchar * attr);
@@ -23,7 +26,7 @@ static void sp_repr_css_add_components (SPCSSAttr * css, SPRepr * repr, const gc
 SPCSSAttr *
 sp_repr_css_attr_new (void)
 {
-	return new SPCSSAttr();
+	return new SPCSSAttrImpl();
 }
 
 void
@@ -118,7 +121,7 @@ sp_repr_css_double_property (SPCSSAttr * css, const gchar * name, double defval)
 void
 sp_repr_css_set (SPRepr * repr, SPCSSAttr * css, const gchar * attr)
 {
-	SPReprAttr * a;
+	SPReprAttr const * a;
 	const char *key;
 	const char *val;
 	char c[4096], *p;
@@ -130,11 +133,18 @@ sp_repr_css_set (SPRepr * repr, SPCSSAttr * css, const gchar * attr)
 	c[0] = '\0';
 	p = c;
 
-	for (a = ((SPRepr *) css)->attributes; a != NULL; a = a->next) {
+	for (a = css->attributeList() ; a != NULL; a = a->next) {
 		key = SP_REPR_ATTRIBUTE_KEY (a);
 		val = SP_REPR_ATTRIBUTE_VALUE (a);
 		p += g_snprintf (p, c + 4096 - p, "%s:%s;", key, val);
 	}
+
+	/* Get rid of trailing `;'. */
+	if (p != c) {
+		--p;
+		*p = '\0';
+	}
+
 	/* g_print ("style: %s\n", c); */
 	sp_repr_set_attr (repr, attr, (c[0]) ? c : NULL);
 }
@@ -142,13 +152,13 @@ sp_repr_css_set (SPRepr * repr, SPCSSAttr * css, const gchar * attr)
 void
 sp_repr_css_merge (SPCSSAttr * dst, SPCSSAttr * src)
 {
-	SPReprAttr * attr;
+	SPReprAttr const * attr;
 	const char * key, * val;
 
 	g_assert (dst != NULL);
 	g_assert (src != NULL);
 
-	for (attr = ((SPRepr *) src)->attributes; attr != NULL; attr = attr->next) {
+	for (attr = src->attributeList() ; attr != NULL; attr = attr->next) {
 		key = SP_REPR_ATTRIBUTE_KEY (attr);
 		val = SP_REPR_ATTRIBUTE_VALUE (attr);
 		sp_repr_set_attr ((SPRepr *) dst, key, val);
@@ -185,7 +195,7 @@ void
 sp_repr_css_print (SPCSSAttr * css)
 {
 	g_print ("== SPCSSAttr:\n");
-	for (SPReprAttr *attr = ((SPRepr *) css)->attributes; attr != NULL; attr = attr->next) {
+	for (SPReprAttr const *attr = css->attributeList(); attr != NULL; attr = attr->next) {
 		g_print("%s: %s\n", SP_REPR_ATTRIBUTE_KEY(attr), SP_REPR_ATTRIBUTE_VALUE(attr).cString());
 	}
 }
@@ -217,7 +227,7 @@ sp_repr_css_change_recursive (SPRepr * repr, SPCSSAttr * css, const gchar * attr
 
 	sp_repr_css_change (repr, css, attr);
 
-	for (child = repr->children; child != NULL; child = child->next) {
+	for (child = repr->firstChild(); child != NULL; child = child->next()) {
 		sp_repr_css_change_recursive (child, css, attr);
 	}
 }
