@@ -25,21 +25,22 @@
 
 #include <glib.h>
 
-#include "repr-private.h"
-#include <xml/sp-repr-attr.h>
+#include "xml/repr.h"
+#include "xml/sp-repr-attr.h"
 
-#include "file.h"
+#include "io/sys.h"
 
-static const gchar *sp_svg_doctype_str =
-"<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 20010904//EN\"\n"
-"\"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd\">\n";
+#include <map>
+#include <glibmm/ustring.h>
+#include <glibmm/quark.h>
+#include "util/shared-c-string-ptr.h"
 
 static SPReprDoc *sp_repr_do_read (xmlDocPtr doc, const gchar *default_ns);
 static SPRepr *sp_repr_svg_read_node (xmlNodePtr node, const gchar *default_ns, GHashTable *prefix_map);
-static void sp_repr_set_xmlns_attr (const gchar *prefix, const gchar *uri, SPRepr *repr);
 static gint sp_repr_qualified_name (gchar *p, gint len, xmlNsPtr ns, const xmlChar *name, const gchar *default_ns, GHashTable *prefix_map);
-static void sp_repr_write_stream (SPRepr *repr, FILE *file, gint indent_level, gboolean add_whitespace);
-static void sp_repr_write_stream_element (SPRepr *repr, FILE *file, gint indent_level, gboolean add_whitespace);
+static void sp_repr_write_stream_root_element (SPRepr *repr, FILE *file, gboolean add_whitespace, gchar const *default_ns);
+static void sp_repr_write_stream (SPRepr *repr, FILE *file, gint indent_level, gboolean add_whitespace, Glib::QueryQuark elide_prefix);
+static void sp_repr_write_stream_element (SPRepr *repr, FILE *file, gint indent_level, gboolean add_whitespace, Glib::QueryQuark elide_prefix, SPReprAttr const *attributes);
 
 #ifdef HAVE_LIBWMF
 static xmlDocPtr sp_wmf_convert (const char * file_name);
@@ -114,6 +115,58 @@ sp_repr_read_mem (const gchar * buffer, gint length, const gchar *default_ns)
     return rdoc;
 }
 
+namespace Inkscape {
+
+struct compare_quark_ids {
+    bool operator()(Glib::QueryQuark const &a, Glib::QueryQuark const &b) {
+        return a.id() < b.id();
+    }
+};
+
+}
+
+namespace {
+
+typedef std::map<Glib::QueryQuark, Glib::QueryQuark, Inkscape::compare_quark_ids> PrefixMap;
+
+Glib::QueryQuark qname_prefix(Glib::QueryQuark qname) {
+    static PrefixMap prefix_map;
+    PrefixMap::iterator iter = prefix_map.find(qname);
+    if ( iter != prefix_map.end() ) {
+        return (*iter).second;
+    } else {
+        gchar const *name_string=g_quark_to_string(qname);
+        gchar const *prefix_end=strchr(name_string, ':');
+        if (prefix_end) {
+            Glib::Quark prefix=Glib::ustring(name_string, prefix_end);
+            prefix_map.insert(PrefixMap::value_type(qname, prefix));
+            return prefix;
+        } else {
+            return GQuark(0);
+        }
+    }
+}
+
+}
+
+namespace {
+
+void promote_to_svg_namespace(SPRepr *repr) {
+    if ( repr->type() == SP_XML_ELEMENT_NODE ) {
+        GQuark code = repr->code();
+        if (!qname_prefix(code).id()) {
+            gchar *svg_name = g_strconcat("svg:", g_quark_to_string(code), NULL);
+            repr->setCodeUnsafe(g_quark_from_string(svg_name));
+            g_free(svg_name);
+        }
+        for ( SPRepr *child = sp_repr_children(repr) ; child ; child = sp_repr_next(child) ) {
+            promote_to_svg_namespace(child);
+        }
+    }
+}
+
+}
+
 /**
  * Reads in a XML file to create a SPReprDoc
  */
@@ -150,21 +203,15 @@ sp_repr_do_read (xmlDocPtr doc, const gchar *default_ns)
     SPReprDoc *rdoc=NULL;
 
     if (root != NULL) {
-        if (default_ns) {
-            sp_repr_set_attr (root, "xmlns", default_ns);
+        /* promote elements of SVG documents that don't use namespaces
+         * into the SVG namespace */
+        if ( default_ns && !strcmp(default_ns, SP_SVG_NS_URI)
+             && !strcmp(sp_repr_name(root), "svg") )
+        {
+            promote_to_svg_namespace(root);
         }
-        g_hash_table_foreach (prefix_map, (GHFunc)sp_repr_set_xmlns_attr, root);
-        /* always include Sodipodi and Inkscape namespaces */
-        sp_repr_set_xmlns_attr (sp_xml_ns_uri_prefix (SP_SODIPODI_NS_URI, "sodipodi"), SP_SODIPODI_NS_URI, root);
-        sp_repr_set_xmlns_attr (sp_xml_ns_uri_prefix (SP_INKSCAPE_NS_URI, "inkscape"), SP_INKSCAPE_NS_URI, root);
 
         rdoc = sp_repr_document_new_list(reprs);
-
-        if (!strcmp (sp_repr_name (root), "svg") && default_ns && !strcmp (default_ns, SP_SVG_NS_URI)) {
-            sp_repr_set_attr ((SPRepr *) rdoc, "doctype", sp_svg_doctype_str);
-            /* always include XLink namespace */
-            sp_repr_set_xmlns_attr (sp_xml_ns_uri_prefix (SP_XLINK_NS_URI, "xlink"), SP_XLINK_NS_URI, root);
-        }
     }
 
     for ( GSList *iter = reprs ; iter ; iter = iter->next ) {
@@ -178,28 +225,13 @@ sp_repr_do_read (xmlDocPtr doc, const gchar *default_ns)
     return rdoc;
 }
 
-void
-sp_repr_set_xmlns_attr (const gchar *prefix, const gchar *uri, SPRepr *repr)
-{
-    gchar *name;
-    name = g_strconcat ("xmlns:", prefix, NULL);
-    sp_repr_set_attr (repr, name, uri);
-    g_free (name);
-}
-
 gint
 sp_repr_qualified_name (gchar *p, gint len, xmlNsPtr ns, const xmlChar *name, const gchar *default_ns, GHashTable *prefix_map)
 {
     const xmlChar *prefix;
-    if (ns) {
-        if (!ns->href) {
-            prefix = ns->prefix;
-        } else if (default_ns && !strcmp ((gchar*)ns->href, default_ns)) {
-            prefix = NULL;
-        } else {
-            prefix = (xmlChar*)sp_xml_ns_uri_prefix ((gchar*)ns->href, (char*)ns->prefix);
-            g_hash_table_insert (prefix_map, (gpointer)prefix, (gpointer)ns->href);
-        }
+    if ( ns && ns->href ) {
+        prefix = (xmlChar*)sp_xml_ns_uri_prefix ((gchar*)ns->href, (char*)ns->prefix);
+        g_hash_table_insert (prefix_map, (gpointer)prefix, (gpointer)ns->href);
     } else {
         prefix = NULL;
     }
@@ -218,10 +250,6 @@ sp_repr_svg_read_node (xmlNodePtr node, const gchar *default_ns, GHashTable *pre
     xmlNodePtr child;
     gchar c[256];
 
-#ifdef SP_REPR_IO_VERBOSE
-    g_print ("Node type %d, name %s, contains |%s|\n", node->type, node->name, node->content);
-#endif
-
     if (node->type == XML_TEXT_NODE || node->type == XML_CDATA_SECTION_NODE) {
 
         if (node->content == NULL || *(node->content) == '\0')
@@ -248,11 +276,13 @@ sp_repr_svg_read_node (xmlNodePtr node, const gchar *default_ns, GHashTable *pre
 
     sp_repr_qualified_name (c, 256, node->ns, node->name, default_ns, prefix_map);
     repr = sp_repr_new (c);
+    /* TODO remember node->ns->prefix if node->ns != NULL */
 
     for (prop = node->properties; prop != NULL; prop = prop->next) {
         if (prop->children) {
             sp_repr_qualified_name (c, 256, prop->ns, prop->name, default_ns, prefix_map);
             sp_repr_set_attr (repr, c, (gchar*)prop->children->content);
+            /* TODO remember prop->ns->prefix if prop->ns != NULL */
         }
     }
 
@@ -272,7 +302,7 @@ sp_repr_svg_read_node (xmlNodePtr node, const gchar *default_ns, GHashTable *pre
 }
 
 void
-sp_repr_save_stream (SPReprDoc *doc, FILE *fp)
+sp_repr_save_stream (SPReprDoc *doc, FILE *fp, gchar const *default_ns)
 {
     SPRepr *repr;
     const gchar *str;
@@ -288,9 +318,13 @@ sp_repr_save_stream (SPReprDoc *doc, FILE *fp)
     for ( repr = sp_repr_document_first_child(doc) ;
           repr ; repr = sp_repr_next(repr) )
     {
-        sp_repr_write_stream(repr, fp, 0, TRUE);
-        if ( repr->type == SP_XML_COMMENT_NODE ) {
+        if ( repr->type() == SP_XML_ELEMENT_NODE ) {
+            sp_repr_write_stream_root_element(repr, fp, TRUE, default_ns);
+        } else if ( repr->type() == SP_XML_COMMENT_NODE ) {
+            sp_repr_write_stream(repr, fp, 0, TRUE, GQuark(0));
             fputc('\n', fp);
+        } else {
+            sp_repr_write_stream(repr, fp, 0, TRUE, GQuark(0));
         }
     }
 }
@@ -298,7 +332,8 @@ sp_repr_save_stream (SPReprDoc *doc, FILE *fp)
 /* Returns TRUE if file successfully saved; FALSE if not
  */
 gboolean
-sp_repr_save_file (SPReprDoc *doc, const gchar *filename)
+sp_repr_save_file (SPReprDoc *doc, const gchar *filename,
+                   gchar const *default_ns)
 {
     if (filename == NULL) {
         return FALSE;
@@ -309,7 +344,7 @@ sp_repr_save_file (SPReprDoc *doc, const gchar *filename)
         return FALSE;
     }
 
-    sp_repr_save_stream (doc, file);
+    sp_repr_save_stream (doc, file, default_ns);
 
     if (fclose (file) != 0) {
         return FALSE;
@@ -321,7 +356,7 @@ sp_repr_save_file (SPReprDoc *doc, const gchar *filename)
 void
 sp_repr_print (SPRepr * repr)
 {
-    sp_repr_write_stream (repr, stdout, 0, TRUE);
+    sp_repr_write_stream (repr, stdout, 0, TRUE, GQuark(0));
 
     return;
 }
@@ -343,16 +378,117 @@ repr_quote_write (FILE * file, const gchar * val)
     }
 }
 
+namespace {
+
+typedef std::map<Glib::QueryQuark, gchar const *, Inkscape::compare_quark_ids> LocalNameMap;
+typedef std::map<Glib::QueryQuark, Inkscape::Util::SharedCStringPtr, Inkscape::compare_quark_ids> NSMap;
+
+gchar const *qname_local_name(Glib::QueryQuark qname) {
+    static LocalNameMap local_name_map;
+    LocalNameMap::iterator iter = local_name_map.find(qname);
+    if ( iter != local_name_map.end() ) {
+        return (*iter).second;
+    } else {
+        gchar const *name_string=g_quark_to_string(qname);
+        gchar const *prefix_end=strchr(name_string, ':');
+        if (prefix_end) {
+            return prefix_end + 1;
+        } else {
+            return name_string;
+        }
+    }
+}
+
+void add_ns_map_entry(NSMap &ns_map, Glib::QueryQuark prefix) {
+    using Inkscape::Util::SharedCStringPtr;
+
+    static const Glib::QueryQuark xml_prefix("xml");
+
+    NSMap::iterator iter=ns_map.find(prefix);
+    if ( iter == ns_map.end() ) {
+        if (prefix.id()) {
+            gchar const *uri=sp_xml_ns_prefix_uri(g_quark_to_string(prefix));
+            if (uri) {
+                ns_map.insert(NSMap::value_type(prefix, SharedCStringPtr::coerce(uri)));
+            } else if ( prefix != xml_prefix ) {
+                g_warning("No namespace known for normalized prefix %s", g_quark_to_string(prefix));
+            }
+        } else {
+            ns_map.insert(NSMap::value_type(prefix, SharedCStringPtr()));
+        }
+    }
+}
+
+void populate_ns_map(NSMap &ns_map, SPRepr &repr) {
+    if ( repr.type() == SP_XML_ELEMENT_NODE ) {
+        add_ns_map_entry(ns_map, qname_prefix(repr.code()));
+        for ( SPReprAttr const *attr=repr.attributeList() ;
+              attr ; attr = attr->next )
+        {
+            Glib::QueryQuark prefix=qname_prefix(attr->key);
+            if (prefix.id()) {
+                add_ns_map_entry(ns_map, prefix);
+            }
+        }
+        for ( SPRepr *child=sp_repr_children(&repr) ;
+              child ; child = sp_repr_next(child) )
+        {
+            populate_ns_map(ns_map, *child);
+        }
+    }
+}
+
+}
+
+void
+sp_repr_write_stream_root_element (SPRepr *repr, FILE *file, gboolean add_whitespace, gchar const *default_ns)
+{
+    using Inkscape::Util::SharedCStringPtr;
+    g_assert(repr != NULL);
+
+    NSMap ns_map;
+    populate_ns_map(ns_map, *repr);
+
+    Glib::QueryQuark elide_prefix=GQuark(0);
+    if ( default_ns && ns_map.find(GQuark(0)) == ns_map.end() ) {
+        elide_prefix = g_quark_from_string(sp_xml_ns_uri_prefix(default_ns, NULL));
+    }
+
+    SPReprAttr const *attributes=repr->attributeList();
+    for ( NSMap::iterator iter=ns_map.begin() ; iter != ns_map.end() ; ++iter ) 
+    {
+        Glib::QueryQuark prefix=(*iter).first;
+        SharedCStringPtr ns_uri=(*iter).second;
+
+        if (prefix.id()) {
+            if ( elide_prefix == prefix ) {
+                attributes = new SPReprAttr(g_quark_from_static_string("xmlns"), ns_uri, const_cast<SPReprAttr *>(attributes));
+            }
+
+            Glib::ustring attr_name="xmlns:";
+            attr_name.append(g_quark_to_string(prefix));
+            GQuark key = g_quark_from_string(attr_name.c_str());
+            attributes = new SPReprAttr(key, ns_uri, const_cast<SPReprAttr *>(attributes)); 
+        } else {
+            // if there are non-namespaced elements, we can't globally
+            // use a default namespace
+            elide_prefix = GQuark(0);
+        }
+    }
+
+    return sp_repr_write_stream_element(repr, file, 0, add_whitespace, elide_prefix, attributes);
+}
+
 void
 sp_repr_write_stream (SPRepr *repr, FILE *file, gint indent_level,
-                      gboolean add_whitespace)
+                      gboolean add_whitespace, Glib::QueryQuark elide_prefix)
 {
-    if (repr->type == SP_XML_TEXT_NODE) {
+    if (repr->type() == SP_XML_TEXT_NODE) {
         repr_quote_write (file, sp_repr_content (repr));
-    } else if (repr->type == SP_XML_COMMENT_NODE) {
+    } else if (repr->type() == SP_XML_COMMENT_NODE) {
         fprintf (file, "<!--%s-->", sp_repr_content (repr));
-    } else if (repr->type == SP_XML_ELEMENT_NODE) {
-        sp_repr_write_stream_element(repr, file, indent_level, add_whitespace);
+    } else if (repr->type() == SP_XML_ELEMENT_NODE) {
+        sp_repr_write_stream_element(repr, file, indent_level, add_whitespace, elide_prefix, repr->attributeList());
     } else {
         g_assert_not_reached();
     }
@@ -360,9 +496,10 @@ sp_repr_write_stream (SPRepr *repr, FILE *file, gint indent_level,
 
 void
 sp_repr_write_stream_element (SPRepr * repr, FILE * file, gint indent_level,
-                              gboolean add_whitespace)
+                              gboolean add_whitespace,
+                              Glib::QueryQuark elide_prefix,
+                              SPReprAttr const *attributes)
 {
-    SPReprAttr *attr;
     SPRepr *child;
     gboolean loose;
     gint i;
@@ -379,16 +516,25 @@ sp_repr_write_stream_element (SPRepr * repr, FILE * file, gint indent_level,
         }
     }
 
-    fprintf (file, "<%s", sp_repr_name (repr));
+    GQuark code = repr->code();
+    gchar const *element_name;
+    if ( elide_prefix == qname_prefix(code) ) {
+        element_name = qname_local_name(code);
+    } else {
+        element_name = g_quark_to_string(code);
+    }
+    fprintf (file, "<%s", element_name);
+
+    // TODO: this should depend on xml:space, not the element name
 
     // if this is a <text> element, suppress formatting whitespace
     // for its content and children:
 
-    if (!strcmp(sp_repr_name(repr), "text")) {
+    if (!strcmp(sp_repr_name(repr), "svg:text")) {
         add_whitespace = FALSE;
     }
 
-    for ( attr = repr->attributes ; attr != NULL ; attr = attr->next ) {
+    for ( SPReprAttr const *attr = attributes ; attr != NULL ; attr = attr->next ) {
         gchar const * const key = SP_REPR_ATTRIBUTE_KEY(attr);
         gchar const * const val = SP_REPR_ATTRIBUTE_VALUE(attr);
         fputs ("\n", file);
@@ -401,19 +547,19 @@ sp_repr_write_stream_element (SPRepr * repr, FILE * file, gint indent_level,
     }
 
     loose = TRUE;
-    for (child = repr->children; child != NULL; child = child->next) {
-        if (child->type == SP_XML_TEXT_NODE) {
+    for (child = repr->firstChild() ; child != NULL; child = child->next()) {
+        if (child->type() == SP_XML_TEXT_NODE) {
             loose = FALSE;
             break;
         }
     }
-    if (repr->children) {
+    if (repr->firstChild()) {
         fputs (">", file);
         if (loose && add_whitespace) {
             fputs ("\n", file);
         }
-        for (child = repr->children; child != NULL; child = child->next) {
-            sp_repr_write_stream (child, file, (loose) ? (indent_level + 1) : 0, add_whitespace);
+        for (child = repr->firstChild(); child != NULL; child = child->next()) {
+            sp_repr_write_stream (child, file, (loose) ? (indent_level + 1) : 0, add_whitespace, elide_prefix);
         }
 
         if (loose && add_whitespace) {
@@ -421,7 +567,7 @@ sp_repr_write_stream_element (SPRepr * repr, FILE * file, gint indent_level,
                 fputs ("  ", file);
             }
         }
-        fprintf (file, "</%s>", sp_repr_name (repr));
+        fprintf (file, "</%s>", element_name);
     } else {
         fputs (" />", file);
     }
@@ -429,7 +575,7 @@ sp_repr_write_stream_element (SPRepr * repr, FILE * file, gint indent_level,
     // text elements cannot nest, so we can output newline
     // after closing text
 
-    if (add_whitespace || !strcmp (sp_repr_name (repr), "text")) {
+    if (add_whitespace || !strcmp (sp_repr_name (repr), "svg:text")) {
         fputs("\n", file);
     }
 }
