@@ -31,9 +31,16 @@
 
 #include <glib.h>
 
-#include <svg/stringstream.h>
-#include <xml/repr-private.h>
-#include <xml/sp-repr-attr.h>
+#include "svg/stringstream.h"
+
+#include "xml/repr.h"
+#include "xml/repr-sorting.h"
+#include "xml/sp-repr-attr.h"
+
+struct SPXMLNs {
+    SPXMLNs *next;
+    unsigned int uri, prefix;
+};
 
 /*#####################
 # DEFINITIONS
@@ -137,7 +144,7 @@ sp_xml_dtoa (gchar *buf, double val, unsigned int tprec, unsigned int fprec, uns
 static SPXMLNs *namespaces=NULL;
 
 /*
- * There are the default XML namespaces to use for the URIs defined
+ * There are the prefixes to use for the XML namespaces defined
  * in repr.h
  */
 static void
@@ -269,91 +276,6 @@ sp_xml_ns_prefix_uri (const gchar *prefix)
     return uri;
 }
 
-/* SPXMLDocument */
-
-SPXMLText *
-sp_xml_document_createTextNode (SPXMLDocument *doc, const gchar *data)
-{
-    SPXMLText *text;
-
-    text = sp_repr_new ("text");
-    text->type = SP_XML_TEXT_NODE;
-    sp_repr_set_content (text, data);
-
-    return text;
-}
-
-SPXMLElement *
-sp_xml_document_createElement (SPXMLDocument *doc, const gchar *name)
-{
-    return sp_repr_new (name);
-}
-
-SPXMLElement *
-sp_xml_document_createElementNS (SPXMLDocument *doc, const gchar *ns, const gchar *qname)
-{
-    if (!strncmp (qname, "svg:", 4)) qname += 4;
-
-    return sp_repr_new (qname);
-}
-
-/* SPXMLNode */
-
-SPXMLDocument *
-sp_xml_node_get_Document (SPXMLNode *node)
-{
-    g_warning ("sp_xml_node_get_Document: unimplemented");
-
-    return NULL;
-}
-
-/* SPXMLElement */
-
-/** Returns the first child of \a repr, or NULL if \a repr has no children (or if repr is itself
- *  NULL).
- *
- * \see sp_repr_next
- */
-SPRepr *
-sp_repr_children (SPRepr *repr)
-{
-    //This is not worth a warning
-    // child of null is null
-    //g_return_val_if_fail (repr != NULL, NULL);
-
-    if (!repr)
-        return NULL;
-    return repr->children;
-}
-
-/** Returns the next sibling of \a repr, or NULL if \a repr is the last sibling (or if repr is
- *  NULL).
- *
- *  \see sp_repr_prev
- *  \see sp_repr_parent
- *  \see sp_repr_children
- */
-SPRepr *
-sp_repr_next (SPRepr *repr)
-{
-    //This is not worth a warning
-    // next of null is null
-    //g_return_val_if_fail (repr != NULL, NULL);
-
-    if (!repr)
-        return NULL;
-    return repr->next;
-}
-
-int sp_repr_attr_is_set (SPRepr * repr, const char * key)
-{
-    char * result;
-
-    result = (char *) sp_repr_attr (repr, key);
-
-    return (result != NULL);
-}
-
 double sp_repr_get_double_attribute (SPRepr * repr, const char * key, double def)
 {
     char * result;
@@ -382,166 +304,61 @@ int sp_repr_get_int_attribute (SPRepr * repr, const char * key, int def)
     return atoi (result);
 }
 
-const char *
-sp_repr_doc_attr (SPRepr * repr, const char * key)
-{
-    SPRepr * p;
-
-    p = sp_repr_parent (repr);
-
-    while (p != NULL) {
-        repr = p;
-        p = sp_repr_parent (p);
-    }
-
-    return sp_repr_attr (repr, key);
-}
-
+/** 
+ *  Works for different-parent objects, so long as they have a common ancestor. Return value:
+ *    0    positions are equivalent
+ *    1    first object's position is greater than the second
+ *   -1    first object's position is less than the second
+ */
 int
 sp_repr_compare_position(SPRepr *first, SPRepr *second)
 {
-    g_assert( sp_repr_parent(first) == sp_repr_parent(second) );
+    int p1, p2;
+    if (sp_repr_parent(first) == sp_repr_parent(second)) {
+        /* Basic case - first and second have same parent */
+        p1 = sp_repr_position(first);
+        p2 = sp_repr_position(second);
+    } else {
+        /* Special case - the two objects have different parents.  They
+           could be in different groups or on different layers for
+           instance. */
 
-    int const p1 = sp_repr_position(first);
-    int const p2 = sp_repr_position(second);
+        // Find the lowest common ancestor (LCA)
+        SPRepr *ancestor = LCA(first, second);
+        g_assert(ancestor != NULL);
+
+        if (ancestor == first) {
+            return 1;
+        } else if (ancestor == second) {
+            return -1;
+        } else {
+            SPRepr const *to_first = AncetreFils(first, ancestor);
+            SPRepr const *to_second = AncetreFils(second, ancestor);
+            g_assert(sp_repr_parent(to_second) == sp_repr_parent(to_first));
+            p1 = sp_repr_position(to_first);
+            p2 = sp_repr_position(to_second);
+        }
+    }
 
     if (p1 > p2) return 1;
     if (p1 < p2) return -1;
     return 0;
 
-    /* effic: Assuming that the parent--child relationship is consistent (i.e. that the parent
-       really does contain first and second among its list of children), it should be equivalent to
-       walk along the children and see which we encounter first (returning 0 iff first == second).
-
-       Given that this function is used solely for sorting, we can use a similar approach to do the
-       sort: gather the things to be sorted, into an STL vector (to allow random access and faster
-       traversals).  Do a single pass of the parent's children; for each child, do a pass on
-       whatever items in the vector we haven't yet encountered.  If the child is found, then swap
-       it to the beginning of the yet-unencountered elements of the vector.  Continue until no more
-       than one remains unencountered.  -- pjrm */
-}
-
-
-/** Returns the position of \a repr among its parent's children (starting with 0 for the first
- *  child).
- *
- *  \pre repr != NULL.
- *  \pre sp_repr_parent(repr) != NULL.
- *  \pre sp_repr_parent(repr)'s list of children includes \a repr.
- */
-int
-sp_repr_position(SPRepr const *repr)
-{
-    g_assert(repr != NULL);
-    SPRepr const *parent = sp_repr_parent(repr);
-    g_assert(parent != NULL);
-
-    if (!parent->_child_counts_complete) {
-        unsigned n_remaining=( parent->children->_n_siblings - 1 );
-        for ( SPRepr *sibling=parent->children->next ;
-              sibling ;
-              sibling = sibling->next )
-        {
-            sibling->_n_siblings = n_remaining;
-            n_remaining--;
-        }
-        g_assert(n_remaining == 0);
-        parent->_child_counts_complete = true;
-    }
-    return (int)parent->children->_n_siblings - (int)repr->_n_siblings;
-}
-
-int
-sp_repr_n_children(SPRepr *repr)
-{
-    return ( repr->children ? repr->children->_n_siblings : 0 );
-}
-
-SPRepr *sp_repr_nth_child(SPRepr *repr, int n) {
-    g_assert(repr != NULL);
-
-    SPRepr *child=repr->children;
-    for ( ; n > 0 && child ; child = child->next ) {
-        n--;
-    }
-
-    return child;
-}
-
-void
-sp_repr_append_child (SPRepr * repr, SPRepr * child)
-{
-    SPRepr * ref;
-
-    g_assert (repr != NULL);
-    g_assert (child != NULL);
-
-    ref = NULL;
-    if (repr->children) {
-        ref = repr->children;
-        while (ref->next) ref = ref->next;
-    }
-
-    sp_repr_add_child (repr, child, ref);
-}
-
-void sp_repr_unparent (SPRepr * repr)
-{
-    SPRepr * parent;
-
-    g_assert (repr != NULL);
-
-    parent = sp_repr_parent (repr);
-    g_assert (parent != NULL);
-
-    sp_repr_remove_child (parent, repr);
-}
-
-SPRepr * sp_repr_duplicate_and_parent (SPRepr * repr)
-{
-    SPRepr * parent, * new_repr;
-
-    g_assert (repr != NULL);
-
-    parent = sp_repr_parent (repr);
-    g_assert (parent != NULL);
-
-    new_repr = sp_repr_duplicate (repr);
-    sp_repr_append_child (parent, new_repr);
-    sp_repr_unref (new_repr);
-
-    return new_repr;
-}
-
-const gchar *
-sp_repr_attr_inherited (SPRepr *repr, const gchar *key)
-{
-    SPRepr *current;
-    const char *val;
-
-    g_assert (repr != NULL);
-    g_assert (key != NULL);
-
-    for (current = repr; current != NULL; current = sp_repr_parent (current)) {
-        val = sp_repr_attr (current, key);
-        if (val != NULL)
-            return val;
-    }
-    return NULL;
-}
-
-unsigned int
-sp_repr_set_attr_recursive (SPRepr *repr, const gchar *key, const gchar *value)
-{
-    SPRepr *child;
-
-    if (!sp_repr_set_attr (repr, key, value)) return FALSE;
-
-    for (child = repr->children; child != NULL; child = child->next) {
-        sp_repr_set_attr (child, key, NULL);
-    }
-
-    return TRUE;
+    /* effic: Assuming that the parent--child relationship is consistent
+       (i.e. that the parent really does contain first and second among
+       its list of children), it should be equivalent to walk along the
+       children and see which we encounter first (returning 0 iff first
+       == second).
+       
+       Given that this function is used solely for sorting, we can use a
+       similar approach to do the sort: gather the things to be sorted,
+       into an STL vector (to allow random access and faster
+       traversals).  Do a single pass of the parent's children; for each
+       child, do a pass on whatever items in the vector we haven't yet
+       encountered.  If the child is found, then swap it to the
+       beginning of the yet-unencountered elements of the vector.
+       Continue until no more than one remains unencountered.  --
+       pjrm */
 }
 
 /**
@@ -553,22 +370,14 @@ sp_repr_lookup_child (SPRepr       *repr,
                       const gchar *value)
 {
     g_return_val_if_fail(repr != NULL, NULL);
-    g_return_val_if_fail(key != NULL, NULL);
-    g_return_val_if_fail(value != NULL, NULL);
-
-    GQuark const quark = g_quark_from_string (key);
-
-    /* Fixme: we should use hash table for faster lookup? */
-    
-    for (SPRepr *child = repr->children; child != NULL; child = child->next) {
-        for (SPReprAttr *attr = child->attributes; attr != NULL; attr = attr->next) {
-            if ( ( attr->key == quark )
-                 && !strcmp(attr->value, value) ) {
-                return child;
-            }
+    for ( SPRepr *child = repr->firstChild() ; child ; child = child->next() ) {
+        gchar const *child_value = child->attribute(key);
+        if ( child_value == value ||
+             value && child_value && !strcmp(child_value, value) )
+        {
+            return child;
         }
     }
-
     return NULL;
 }
 
@@ -587,14 +396,14 @@ sp_repr_lookup_name ( SPRepr *repr, gchar const *name, gint maxdepth )
 
     GQuark const quark = g_quark_from_string (name);
 
-    if ( (unsigned)repr->name == quark ) return repr;
+    if ( (GQuark)repr->code() == quark ) return repr;
     if ( maxdepth == 0 ) return NULL;
 
     // maxdepth == -1 means unlimited
     if ( maxdepth == -1 ) maxdepth = 0;
 
     SPRepr * found = NULL;
-    for (SPRepr *child = repr->children; child && !found; child = child->next) {
+    for (SPRepr *child = repr->firstChild() ; child && !found; child = child->next() ) {
         found = sp_repr_lookup_name ( child, name, maxdepth-1 );
     }
 
@@ -721,13 +530,14 @@ sp_repr_set_double_default (SPRepr *repr, const gchar *key, double val, double d
 }
 
 
+
 /*
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
   c-file-offsets:((innamespace . 0)(inline-open . 0))
   indent-tabs-mode:nil
-  fill-column:99
+  fill-column:72
   End:
 */
 // vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
