@@ -16,26 +16,26 @@
 
 #include <glib/gtypes.h>
 
-struct SPRepr;
+#include "xml/sp-repr.h"
 
 struct SPReprEventVector {
 	/* Immediate signals */
-	unsigned int (* add_child) (SPRepr *repr, SPRepr *child, SPRepr *ref, void * data);
 	void (* child_added) (SPRepr *repr, SPRepr *child, SPRepr *ref, void * data);
-	unsigned int (* remove_child) (SPRepr *repr, SPRepr *child, SPRepr *ref, void * data);
 	void (* child_removed) (SPRepr *repr, SPRepr *child, SPRepr *ref, void * data);
-	unsigned int (* change_attr) (SPRepr *repr, const gchar *key, const gchar *oldval, const gchar *newval, void * data);
 	void (* attr_changed) (SPRepr *repr, const gchar *key, const gchar *oldval, const gchar *newval, bool is_interactive, void * data);
-	unsigned int (* change_content) (SPRepr *repr, const gchar *oldcontent, const gchar *newcontent, void * data);
 	void (* content_changed) (SPRepr *repr, const gchar *oldcontent, const gchar *newcontent, void * data);
-	unsigned int (* change_order) (SPRepr *repr, SPRepr *child, SPRepr *oldref, SPRepr *newref, void * data);
 	void (* order_changed) (SPRepr *repr, SPRepr *child, SPRepr *oldref, SPRepr *newref, void * data);
 };
 
-void sp_repr_synthesize_events (SPRepr *repr, const SPReprEventVector *vector, void * data);
+inline void sp_repr_synthesize_events (SPRepr *repr, const SPReprEventVector *vector, void * data) {
+	repr->synthesizeEvents(vector, data);
+}
                                                                                 
-void sp_repr_add_listener (SPRepr *repr, const SPReprEventVector *vector, void * data);
-void sp_repr_remove_listener_by_data (SPRepr *repr, void * data);
-
+inline void sp_repr_add_listener (SPRepr *repr, const SPReprEventVector *vector, void * data) {
+	repr->addListener(vector, data);
+}
+inline void sp_repr_remove_listener_by_data (SPRepr *repr, void * data) {
+	repr->removeListenerByData(data);
+}
 
 #endif
